""" openconfig_network_instance 

An OpenConfig description of a network\-instance. This may be
a Layer 3 forwarding construct such as a virtual routing and
forwarding (VRF) instance, or a Layer 2 instance such as a
virtual switch instance (VSI). Mixed Layer 2 and Layer 3
instances are also supported.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class NetworkInstances(Entity):
    """
    The L2, L3, or L2+L3 forwarding instances that are
    configured on the local system
    
    .. attribute:: network_instance
    
    	Network instances configured on the local system
    	**type**\: list of  		 :py:class:`NetworkInstance <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance>`
    
    

    """

    _prefix = 'oc-netinst'
    _revision = '2017-01-13'

    def __init__(self):
        super(NetworkInstances, self).__init__()
        self._top_entity = None

        self.yang_name = "network-instances"
        self.yang_parent_name = "openconfig-network-instance"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_container_classes = OrderedDict([])
        self._child_list_classes = OrderedDict([("network-instance", ("network_instance", NetworkInstances.NetworkInstance))])
        self._leafs = OrderedDict()

        self.network_instance = YList(self)
        self._segment_path = lambda: "openconfig-network-instance:network-instances"

    def __setattr__(self, name, value):
        self._perform_setattr(NetworkInstances, [], name, value)


    class NetworkInstance(Entity):
        """
        Network instances configured on the local system
        
        .. attribute:: name  (key)
        
        	A unique name identifying the network instance
        	**type**\: str
        
        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
        
        .. attribute:: fdb
        
        	Operational state and configuration parameters relating to the forwarding database of the network instance
        	**type**\:  :py:class:`Fdb <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb>`
        
        .. attribute:: config
        
        	Configuration parameters relating to a network instance
        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
        
        .. attribute:: state
        
        	Operational state parameters relating to a network instance
        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.State>`
        
        .. attribute:: encapsulation
        
        	Configuration parameters relating to the encapsulation used for the network instance
        	**type**\:  :py:class:`Encapsulation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation>`
        
        .. attribute:: inter_instance_policies
        
        	Policies dictating how RIB or FIB entries are imported to and exported from this instance
        	**type**\:  :py:class:`InterInstancePolicies <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies>`
        
        .. attribute:: table_connections
        
        	Policies dictating how RIB or FIB entries are propagated between tables
        	**type**\:  :py:class:`TableConnections <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections>`
        
        .. attribute:: interfaces
        
        	The interfaces that are associated with this network instance
        	**type**\:  :py:class:`Interfaces <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces>`
        
        .. attribute:: tables
        
        	The routing tables that are managed by this network instance
        	**type**\:  :py:class:`Tables <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables>`
        
        .. attribute:: connection_points
        
        	The set of connection points within a forwarding instance
        	**type**\:  :py:class:`ConnectionPoints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints>`
        
        .. attribute:: mpls
        
        	node added for compilation for forward compatibility
        	**type**\:  :py:class:`Mpls <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls>`
        
        .. attribute:: segment_routing
        
        	Configuration and operational state parameters relating to segment routing
        	**type**\:  :py:class:`SegmentRouting <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting>`
        
        .. attribute:: vlans
        
        	Container for VLAN configuration and state variables
        	**type**\:  :py:class:`Vlans <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans>`
        
        .. attribute:: afts
        
        	The abstract forwarding tables (AFTs) that are associated with the network instance. An AFT is instantiated per\-protocol running within the network\-instance \- such that one exists for IPv4 Unicast, IPv6 Unicast, MPLS, L2 forwarding entries, etc. A forwarding entry within the FIB has a set of next\-hops, which may be a reference to an entry within another table \- e.g., where a Layer 3 next\-hop has an associated Layer 2 forwarding entry
        	**type**\:  :py:class:`Afts <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts>`
        
        .. attribute:: protocols
        
        	The routing protocols that are enabled for this network\-instance
        	**type**\:  :py:class:`Protocols <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols>`
        
        

        """

        _prefix = 'oc-netinst'
        _revision = '2017-01-13'

        def __init__(self):
            super(NetworkInstances.NetworkInstance, self).__init__()

            self.yang_name = "network-instance"
            self.yang_parent_name = "network-instances"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_container_classes = OrderedDict([("fdb", ("fdb", NetworkInstances.NetworkInstance.Fdb)), ("config", ("config", NetworkInstances.NetworkInstance.Config)), ("state", ("state", NetworkInstances.NetworkInstance.State)), ("encapsulation", ("encapsulation", NetworkInstances.NetworkInstance.Encapsulation)), ("inter-instance-policies", ("inter_instance_policies", NetworkInstances.NetworkInstance.InterInstancePolicies)), ("table-connections", ("table_connections", NetworkInstances.NetworkInstance.TableConnections)), ("interfaces", ("interfaces", NetworkInstances.NetworkInstance.Interfaces)), ("tables", ("tables", NetworkInstances.NetworkInstance.Tables)), ("connection-points", ("connection_points", NetworkInstances.NetworkInstance.ConnectionPoints)), ("mpls", ("mpls", NetworkInstances.NetworkInstance.Mpls)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.SegmentRouting)), ("vlans", ("vlans", NetworkInstances.NetworkInstance.Vlans)), ("afts", ("afts", NetworkInstances.NetworkInstance.Afts)), ("protocols", ("protocols", NetworkInstances.NetworkInstance.Protocols))])
            self._child_list_classes = OrderedDict([])
            self._leafs = OrderedDict([
                ('name', YLeaf(YType.str, 'name')),
            ])
            self.name = None

            self.fdb = NetworkInstances.NetworkInstance.Fdb()
            self.fdb.parent = self
            self._children_name_map["fdb"] = "fdb"
            self._children_yang_names.add("fdb")

            self.config = NetworkInstances.NetworkInstance.Config()
            self.config.parent = self
            self._children_name_map["config"] = "config"
            self._children_yang_names.add("config")

            self.state = NetworkInstances.NetworkInstance.State()
            self.state.parent = self
            self._children_name_map["state"] = "state"
            self._children_yang_names.add("state")

            self.encapsulation = NetworkInstances.NetworkInstance.Encapsulation()
            self.encapsulation.parent = self
            self._children_name_map["encapsulation"] = "encapsulation"
            self._children_yang_names.add("encapsulation")

            self.inter_instance_policies = NetworkInstances.NetworkInstance.InterInstancePolicies()
            self.inter_instance_policies.parent = self
            self._children_name_map["inter_instance_policies"] = "inter-instance-policies"
            self._children_yang_names.add("inter-instance-policies")

            self.table_connections = NetworkInstances.NetworkInstance.TableConnections()
            self.table_connections.parent = self
            self._children_name_map["table_connections"] = "table-connections"
            self._children_yang_names.add("table-connections")

            self.interfaces = NetworkInstances.NetworkInstance.Interfaces()
            self.interfaces.parent = self
            self._children_name_map["interfaces"] = "interfaces"
            self._children_yang_names.add("interfaces")

            self.tables = NetworkInstances.NetworkInstance.Tables()
            self.tables.parent = self
            self._children_name_map["tables"] = "tables"
            self._children_yang_names.add("tables")

            self.connection_points = NetworkInstances.NetworkInstance.ConnectionPoints()
            self.connection_points.parent = self
            self._children_name_map["connection_points"] = "connection-points"
            self._children_yang_names.add("connection-points")

            self.mpls = NetworkInstances.NetworkInstance.Mpls()
            self.mpls.parent = self
            self._children_name_map["mpls"] = "mpls"
            self._children_yang_names.add("mpls")

            self.segment_routing = NetworkInstances.NetworkInstance.SegmentRouting()
            self.segment_routing.parent = self
            self._children_name_map["segment_routing"] = "segment-routing"
            self._children_yang_names.add("segment-routing")

            self.vlans = NetworkInstances.NetworkInstance.Vlans()
            self.vlans.parent = self
            self._children_name_map["vlans"] = "vlans"
            self._children_yang_names.add("vlans")

            self.afts = NetworkInstances.NetworkInstance.Afts()
            self.afts.parent = self
            self._children_name_map["afts"] = "afts"
            self._children_yang_names.add("afts")

            self.protocols = NetworkInstances.NetworkInstance.Protocols()
            self.protocols.parent = self
            self._children_name_map["protocols"] = "protocols"
            self._children_yang_names.add("protocols")
            self._segment_path = lambda: "network-instance" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "openconfig-network-instance:network-instances/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(NetworkInstances.NetworkInstance, ['name'], name, value)


        class Fdb(Entity):
            """
            Operational state and configuration parameters relating to
            the forwarding database of the network instance
            
            .. attribute:: config
            
            	Configuration parameters relating to the FDB
            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.Config>`
            
            .. attribute:: state
            
            	Operational state parameters relating to the FDB
            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.State>`
            
            .. attribute:: mac_table
            
            	Table of learned or statically configured MAC addresses and corresponding VLANs in the bridge domain
            	**type**\:  :py:class:`MacTable <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Fdb, self).__init__()

                self.yang_name = "fdb"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.State)), ("mac-table", ("mac_table", NetworkInstances.NetworkInstance.Fdb.MacTable))])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict()

                self.config = NetworkInstances.NetworkInstance.Fdb.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"
                self._children_yang_names.add("config")

                self.state = NetworkInstances.NetworkInstance.Fdb.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._children_yang_names.add("state")

                self.mac_table = NetworkInstances.NetworkInstance.Fdb.MacTable()
                self.mac_table.parent = self
                self._children_name_map["mac_table"] = "mac-table"
                self._children_yang_names.add("mac-table")
                self._segment_path = lambda: "fdb"


            class Config(Entity):
                """
                Configuration parameters relating to the FDB
                
                .. attribute:: mac_learning
                
                	When this leaf is set to true, MAC learning is enabled for the network instance, such that MAC addresses are learned from ingress frames and added to the FDB
                	**type**\: bool
                
                .. attribute:: mac_aging_time
                
                	The number of seconds of inactivity after which the entry in the local FDB is timed out
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: seconds
                
                .. attribute:: maximum_entries
                
                	The maximum number of MAC address entries that should be accepted into the FDB
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Fdb.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                        ('mac_aging_time', YLeaf(YType.uint16, 'mac-aging-time')),
                        ('maximum_entries', YLeaf(YType.uint16, 'maximum-entries')),
                    ])
                    self.mac_learning = None
                    self.mac_aging_time = None
                    self.maximum_entries = None
                    self._segment_path = lambda: "config"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.Config, ['mac_learning', 'mac_aging_time', 'maximum_entries'], name, value)


            class State(Entity):
                """
                Operational state parameters relating to the FDB
                
                .. attribute:: mac_learning
                
                	When this leaf is set to true, MAC learning is enabled for the network instance, such that MAC addresses are learned from ingress frames and added to the FDB
                	**type**\: bool
                
                .. attribute:: mac_aging_time
                
                	The number of seconds of inactivity after which the entry in the local FDB is timed out
                	**type**\: int
                
                	**range:** 0..65535
                
                	**units**\: seconds
                
                .. attribute:: maximum_entries
                
                	The maximum number of MAC address entries that should be accepted into the FDB
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Fdb.State, self).__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                        ('mac_aging_time', YLeaf(YType.uint16, 'mac-aging-time')),
                        ('maximum_entries', YLeaf(YType.uint16, 'maximum-entries')),
                    ])
                    self.mac_learning = None
                    self.mac_aging_time = None
                    self.maximum_entries = None
                    self._segment_path = lambda: "state"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.State, ['mac_learning', 'mac_aging_time', 'maximum_entries'], name, value)


            class MacTable(Entity):
                """
                Table of learned or statically configured MAC addresses and
                corresponding VLANs in the bridge domain
                
                .. attribute:: entries
                
                	Enclosing container for list of MAC table entries
                	**type**\:  :py:class:`Entries <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Fdb.MacTable, self).__init__()

                    self.yang_name = "mac-table"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([("entries", ("entries", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict()

                    self.entries = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries()
                    self.entries.parent = self
                    self._children_name_map["entries"] = "entries"
                    self._children_yang_names.add("entries")
                    self._segment_path = lambda: "mac-table"


                class Entries(Entity):
                    """
                    Enclosing container for list of MAC table entries
                    
                    .. attribute:: entry
                    
                    	List of learned MAC addresses
                    	**type**\: list of  		 :py:class:`Entry <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries, self).__init__()

                        self.yang_name = "entries"
                        self.yang_parent_name = "mac-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("entry", ("entry", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry))])
                        self._leafs = OrderedDict()

                        self.entry = YList(self)
                        self._segment_path = lambda: "entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries, [], name, value)


                    class Entry(Entity):
                        """
                        List of learned MAC addresses
                        
                        .. attribute:: mac_address  (key)
                        
                        	Reference to mac\-address list key
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        	**refers to**\:  :py:class:`mac_address <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config>`
                        
                        .. attribute:: config
                        
                        	Configuration data for MAC table entries
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config>`
                        
                        .. attribute:: state
                        
                        	Operational state data for MAC table entries
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State>`
                        
                        .. attribute:: interface
                        
                        	Reference to the base and/or subinterface for the MAC table entry
                        	**type**\:  :py:class:`Interface <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry, self).__init__()

                            self.yang_name = "entry"
                            self.yang_parent_name = "entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['mac_address']
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State)), ("interface", ("interface", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac_address', YLeaf(YType.str, 'mac-address')),
                            ])
                            self.mac_address = None

                            self.config = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.interface = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._children_yang_names.add("interface")
                            self._segment_path = lambda: "entry" + "[mac-address='" + str(self.mac_address) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry, ['mac_address'], name, value)


                        class Config(Entity):
                            """
                            Configuration data for MAC table entries
                            
                            .. attribute:: mac_address
                            
                            	MAC address for the dynamic or static MAC table entry
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: vlan
                            
                            	VLAN from which this MAC address was received
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            	**refers to**\:  :py:class:`vlan_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mac_address', YLeaf(YType.str, 'mac-address')),
                                    ('vlan', YLeaf(YType.str, 'vlan')),
                                ])
                                self.mac_address = None
                                self.vlan = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config, ['mac_address', 'vlan'], name, value)


                        class State(Entity):
                            """
                            Operational state data for MAC table entries
                            
                            .. attribute:: mac_address
                            
                            	MAC address for the dynamic or static MAC table entry
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: vlan
                            
                            	VLAN from which this MAC address was received
                            	**type**\: int
                            
                            	**range:** 1..4094
                            
                            	**refers to**\:  :py:class:`vlan_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                            
                            .. attribute:: age
                            
                            	The time in seconds since the MAC address has been in the table
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: seconds
                            
                            .. attribute:: entry_type
                            
                            	Indicates whether the entry was statically configured, or dynamically learned
                            	**type**\:  :py:class:`EntryType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State.EntryType>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mac_address', YLeaf(YType.str, 'mac-address')),
                                    ('vlan', YLeaf(YType.str, 'vlan')),
                                    ('age', YLeaf(YType.uint64, 'age')),
                                    ('entry_type', YLeaf(YType.enumeration, 'entry-type')),
                                ])
                                self.mac_address = None
                                self.vlan = None
                                self.age = None
                                self.entry_type = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State, ['mac_address', 'vlan', 'age', 'entry_type'], name, value)

                            class EntryType(Enum):
                                """
                                EntryType (Enum Class)

                                Indicates whether the entry was statically configured, or

                                dynamically learned.

                                .. data:: STATIC = 0

                                	Statically programmed MAC table entry

                                .. data:: DYNAMIC = 1

                                	Dynamically learned MAC table entry

                                """

                                STATIC = Enum.YLeaf(0, "STATIC")

                                DYNAMIC = Enum.YLeaf(1, "DYNAMIC")



                        class Interface(Entity):
                            """
                            Reference to the base and/or subinterface for the
                            MAC table entry
                            
                            .. attribute:: interface_ref
                            
                            	Reference to an interface or subinterface
                            	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.interface_ref = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._children_yang_names.add("interface-ref")
                                self._segment_path = lambda: "interface"


                            class InterfaceRef(Entity):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                	Configured reference to interface / subinterface
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state for interface\-ref
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef, self).__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "interface-ref"


                                class Config(Entity):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', YLeaf(YType.str, 'interface')),
                                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(Entity):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', YLeaf(YType.str, 'interface')),
                                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)


        class Config(Entity):
            """
            Configuration parameters relating to a network
            instance
            
            .. attribute:: name
            
            	An operator\-assigned unique name for the forwarding instance
            	**type**\: str
            
            .. attribute:: type
            
            	The type of network instance. The value of this leaf indicates the type of forwarding entries that should be supported by this network instance
            	**type**\:  :py:class:`NETWORKINSTANCETYPE <ydk.models.openconfig.openconfig_network_instance_types.NETWORKINSTANCETYPE>`
            
            .. attribute:: enabled
            
            	Whether the network instance should be configured to be active on the network element
            	**type**\: bool
            
            .. attribute:: description
            
            	A free\-form string to be used by the network operator to describe the function of this network instance
            	**type**\: str
            
            .. attribute:: router_id
            
            	A identifier for the local network instance \- typically used within associated routing protocols or signalling routing information in another network instance
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
            
            .. attribute:: route_distinguisher
            
            	The route distinguisher that should be used for the local VRF or VSI instance when it is signalled via BGP
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** ^(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])\:(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])$
            
            		**type**\: str
            
            			**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\:(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])$
            
            		**type**\: str
            
            			**pattern:** ^(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])\:(65[0\-5][0\-3][0\-5]\|[1\-5]{2}[0\-9]{3}\|[1\-9]{0,2}[0\-9][0\-9]\|[1\-9])$
            
            .. attribute:: enabled_address_families
            
            	The address families that are to be enabled for this network instance
            	**type**\: list of   :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
            
            .. attribute:: mtu
            
            	The maximum frame size which should be supported for this instance for Layer 2 frames
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Config, self).__init__()

                self.yang_name = "config"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', YLeaf(YType.str, 'name')),
                    ('type', YLeaf(YType.identityref, 'type')),
                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                    ('description', YLeaf(YType.str, 'description')),
                    ('router_id', YLeaf(YType.str, 'router-id')),
                    ('route_distinguisher', YLeaf(YType.str, 'route-distinguisher')),
                    ('enabled_address_families', YLeafList(YType.identityref, 'enabled-address-families')),
                    ('mtu', YLeaf(YType.uint16, 'mtu')),
                ])
                self.name = None
                self.type = None
                self.enabled = None
                self.description = None
                self.router_id = None
                self.route_distinguisher = None
                self.enabled_address_families = []
                self.mtu = None
                self._segment_path = lambda: "config"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Config, ['name', 'type', 'enabled', 'description', 'router_id', 'route_distinguisher', 'enabled_address_families', 'mtu'], name, value)


        class State(Entity):
            """
            Operational state parameters relating to a network
            instance
            
            .. attribute:: name
            
            	An operator\-assigned unique name for the forwarding instance
            	**type**\: str
            
            .. attribute:: type
            
            	The type of network instance. The value of this leaf indicates the type of forwarding entries that should be supported by this network instance
            	**type**\:  :py:class:`NETWORKINSTANCETYPE <ydk.models.openconfig.openconfig_network_instance_types.NETWORKINSTANCETYPE>`
            
            .. attribute:: enabled
            
            	Whether the network instance should be configured to be active on the network element
            	**type**\: bool
            
            .. attribute:: description
            
            	A free\-form string to be used by the network operator to describe the function of this network instance
            	**type**\: str
            
            .. attribute:: router_id
            
            	A identifier for the local network instance \- typically used within associated routing protocols or signalling routing information in another network instance
            	**type**\: str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
            
            .. attribute:: route_distinguisher
            
            	The route distinguisher that should be used for the local VRF or VSI instance when it is signalled via BGP
            	**type**\: union of the below types:
            
            		**type**\: str
            
            			**pattern:** ^(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])\:(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])$
            
            		**type**\: str
            
            			**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\:(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])$
            
            		**type**\: str
            
            			**pattern:** ^(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])\:(65[0\-5][0\-3][0\-5]\|[1\-5]{2}[0\-9]{3}\|[1\-9]{0,2}[0\-9][0\-9]\|[1\-9])$
            
            .. attribute:: enabled_address_families
            
            	The address families that are to be enabled for this network instance
            	**type**\: list of   :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
            
            .. attribute:: mtu
            
            	The maximum frame size which should be supported for this instance for Layer 2 frames
            	**type**\: int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.State, self).__init__()

                self.yang_name = "state"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', YLeaf(YType.str, 'name')),
                    ('type', YLeaf(YType.identityref, 'type')),
                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                    ('description', YLeaf(YType.str, 'description')),
                    ('router_id', YLeaf(YType.str, 'router-id')),
                    ('route_distinguisher', YLeaf(YType.str, 'route-distinguisher')),
                    ('enabled_address_families', YLeafList(YType.identityref, 'enabled-address-families')),
                    ('mtu', YLeaf(YType.uint16, 'mtu')),
                ])
                self.name = None
                self.type = None
                self.enabled = None
                self.description = None
                self.router_id = None
                self.route_distinguisher = None
                self.enabled_address_families = []
                self.mtu = None
                self._segment_path = lambda: "state"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.State, ['name', 'type', 'enabled', 'description', 'router_id', 'route_distinguisher', 'enabled_address_families', 'mtu'], name, value)


        class Encapsulation(Entity):
            """
            Configuration parameters relating to the encapsulation
            used for the network instance
            
            .. attribute:: config
            
            	Configuration parameters relating to the encapsulation of the network instance
            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation.Config>`
            
            .. attribute:: state
            
            	State parameters relating to the encapsulation of the network instance
            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation.State>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Encapsulation, self).__init__()

                self.yang_name = "encapsulation"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Encapsulation.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Encapsulation.State))])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict()

                self.config = NetworkInstances.NetworkInstance.Encapsulation.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"
                self._children_yang_names.add("config")

                self.state = NetworkInstances.NetworkInstance.Encapsulation.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._children_yang_names.add("state")
                self._segment_path = lambda: "encapsulation"


            class Config(Entity):
                """
                Configuration parameters relating to the encapsulation
                of the network instance
                
                .. attribute:: encapsulation_type
                
                	The on\-the\-wire encapsulation that should be used when sending traffic from this network instance
                	**type**\:  :py:class:`ENCAPSULATION <ydk.models.openconfig.openconfig_network_instance_types.ENCAPSULATION>`
                
                .. attribute:: label_allocation_mode
                
                	The label allocation mode to be used for L3 entries in the network instance
                	**type**\:  :py:class:`LABELALLOCATIONMODE <ydk.models.openconfig.openconfig_network_instance_types.LABELALLOCATIONMODE>`
                
                .. attribute:: control_word
                
                	Whether the control\-word should be used for the network instance
                	**type**\: bool
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Encapsulation.Config, self).__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "encapsulation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encapsulation_type', YLeaf(YType.identityref, 'encapsulation-type')),
                        ('label_allocation_mode', YLeaf(YType.identityref, 'label-allocation-mode')),
                        ('control_word', YLeaf(YType.boolean, 'control-word')),
                    ])
                    self.encapsulation_type = None
                    self.label_allocation_mode = None
                    self.control_word = None
                    self._segment_path = lambda: "config"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Encapsulation.Config, ['encapsulation_type', 'label_allocation_mode', 'control_word'], name, value)


            class State(Entity):
                """
                State parameters relating to the encapsulation of
                the network instance
                
                .. attribute:: encapsulation_type
                
                	The on\-the\-wire encapsulation that should be used when sending traffic from this network instance
                	**type**\:  :py:class:`ENCAPSULATION <ydk.models.openconfig.openconfig_network_instance_types.ENCAPSULATION>`
                
                .. attribute:: label_allocation_mode
                
                	The label allocation mode to be used for L3 entries in the network instance
                	**type**\:  :py:class:`LABELALLOCATIONMODE <ydk.models.openconfig.openconfig_network_instance_types.LABELALLOCATIONMODE>`
                
                .. attribute:: control_word
                
                	Whether the control\-word should be used for the network instance
                	**type**\: bool
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Encapsulation.State, self).__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "encapsulation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encapsulation_type', YLeaf(YType.identityref, 'encapsulation-type')),
                        ('label_allocation_mode', YLeaf(YType.identityref, 'label-allocation-mode')),
                        ('control_word', YLeaf(YType.boolean, 'control-word')),
                    ])
                    self.encapsulation_type = None
                    self.label_allocation_mode = None
                    self.control_word = None
                    self._segment_path = lambda: "state"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Encapsulation.State, ['encapsulation_type', 'label_allocation_mode', 'control_word'], name, value)


        class InterInstancePolicies(Entity):
            """
            Policies dictating how RIB or FIB entries are imported
            to and exported from this instance
            
            .. attribute:: apply_policy
            
            	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
            	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.InterInstancePolicies, self).__init__()

                self.yang_name = "inter-instance-policies"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy))])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict()

                self.apply_policy = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy()
                self.apply_policy.parent = self
                self._children_name_map["apply_policy"] = "apply-policy"
                self._children_yang_names.add("apply-policy")
                self._segment_path = lambda: "inter-instance-policies"


            class ApplyPolicy(Entity):
                """
                Anchor point for routing policies in the model.
                Import and export policies are with respect to the local
                routing table, i.e., export (send) and import (receive),
                depending on the context.
                
                .. attribute:: config
                
                	Policy configuration data
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config>`
                
                .. attribute:: state
                
                	Operational state for routing policy
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy, self).__init__()

                    self.yang_name = "apply-policy"
                    self.yang_parent_name = "inter-instance-policies"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict()

                    self.config = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")
                    self._segment_path = lambda: "apply-policy"


                class Config(Entity):
                    """
                    Policy configuration data.
                    
                    .. attribute:: import_policy
                    
                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    .. attribute:: export_policy
                    
                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_export_policy
                    
                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "apply-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                        ])
                        self.import_policy = []
                        self.default_import_policy = None
                        self.export_policy = []
                        self.default_export_policy = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                class State(Entity):
                    """
                    Operational state for routing policy
                    
                    .. attribute:: import_policy
                    
                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    .. attribute:: export_policy
                    
                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_export_policy
                    
                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "apply-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                        ])
                        self.import_policy = []
                        self.default_import_policy = None
                        self.export_policy = []
                        self.default_export_policy = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


        class TableConnections(Entity):
            """
            Policies dictating how RIB or FIB entries are propagated
            between tables
            
            .. attribute:: table_connection
            
            	A list of connections between pairs of routing or forwarding tables, the leaking of entries between which is specified by the import policy.  A connection connecting a source table to a destination table implies that routes that match the policy specified for the connection are available for the destination protocol to advertise, or match within its policies
            	**type**\: list of  		 :py:class:`TableConnection <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.TableConnections, self).__init__()

                self.yang_name = "table-connections"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("table-connection", ("table_connection", NetworkInstances.NetworkInstance.TableConnections.TableConnection))])
                self._leafs = OrderedDict()

                self.table_connection = YList(self)
                self._segment_path = lambda: "table-connections"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections, [], name, value)


            class TableConnection(Entity):
                """
                A list of connections between pairs of routing or
                forwarding tables, the leaking of entries between
                which is specified by the import policy.
                
                A connection connecting a source table to a destination
                table implies that routes that match the policy specified
                for the connection are available for the destination
                protocol to advertise, or match within its policies.
                
                .. attribute:: src_protocol  (key)
                
                	The name of the protocol associated with the table which should be utilised as the source of forwarding or routing information
                	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: dst_protocol  (key)
                
                	The table to which routing entries should be exported
                	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: address_family  (key)
                
                	The address family associated with the connection
                	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                
                .. attribute:: config
                
                	Configuration parameters relating to the connection between tables
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config>`
                
                .. attribute:: state
                
                	State parameters relating to the connection between tables
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection.State>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.TableConnections.TableConnection, self).__init__()

                    self.yang_name = "table-connection"
                    self.yang_parent_name = "table-connections"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['src_protocol','dst_protocol','address_family']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config)), ("state", ("state", NetworkInstances.NetworkInstance.TableConnections.TableConnection.State))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('src_protocol', YLeaf(YType.identityref, 'src-protocol')),
                        ('dst_protocol', YLeaf(YType.identityref, 'dst-protocol')),
                        ('address_family', YLeaf(YType.identityref, 'address-family')),
                    ])
                    self.src_protocol = None
                    self.dst_protocol = None
                    self.address_family = None

                    self.config = NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.TableConnections.TableConnection.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")
                    self._segment_path = lambda: "table-connection" + "[src-protocol='" + str(self.src_protocol) + "']" + "[dst-protocol='" + str(self.dst_protocol) + "']" + "[address-family='" + str(self.address_family) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection, ['src_protocol', 'dst_protocol', 'address_family'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to the connection
                    between tables
                    
                    .. attribute:: src_protocol
                    
                    	The source protocol for the table connection
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                    	The address family associated with the connection. This must be defined for the source protocol. The target address family is implicitly defined by the address family specified for the source protocol
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    .. attribute:: dst_protocol
                    
                    	The destination protocol for the table connection
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: import_policy
                    
                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "table-connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('src_protocol', YLeaf(YType.identityref, 'src-protocol')),
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                            ('dst_protocol', YLeaf(YType.identityref, 'dst-protocol')),
                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                        ])
                        self.src_protocol = None
                        self.address_family = None
                        self.dst_protocol = None
                        self.import_policy = []
                        self.default_import_policy = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config, ['src_protocol', 'address_family', 'dst_protocol', 'import_policy', 'default_import_policy'], name, value)


                class State(Entity):
                    """
                    State parameters relating to the connection between
                    tables
                    
                    .. attribute:: src_protocol
                    
                    	The source protocol for the table connection
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                    	The address family associated with the connection. This must be defined for the source protocol. The target address family is implicitly defined by the address family specified for the source protocol
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    .. attribute:: dst_protocol
                    
                    	The destination protocol for the table connection
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: import_policy
                    
                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    	**type**\: list of str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                    	**default value**\: REJECT_ROUTE
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.TableConnections.TableConnection.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "table-connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('src_protocol', YLeaf(YType.identityref, 'src-protocol')),
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                            ('dst_protocol', YLeaf(YType.identityref, 'dst-protocol')),
                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                        ])
                        self.src_protocol = None
                        self.address_family = None
                        self.dst_protocol = None
                        self.import_policy = []
                        self.default_import_policy = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection.State, ['src_protocol', 'address_family', 'dst_protocol', 'import_policy', 'default_import_policy'], name, value)


        class Interfaces(Entity):
            """
            The interfaces that are associated with this network
            instance
            
            .. attribute:: interface
            
            	An interface associated with the network instance
            	**type**\: list of  		 :py:class:`Interface <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Interfaces, self).__init__()

                self.yang_name = "interfaces"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Interfaces.Interface))])
                self._leafs = OrderedDict()

                self.interface = YList(self)
                self._segment_path = lambda: "interfaces"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces, [], name, value)


            class Interface(Entity):
                """
                An interface associated with the network instance
                
                .. attribute:: id  (key)
                
                	A reference to an identifier for this interface which acts as a key for this list
                	**type**\: str
                
                	**refers to**\:  :py:class:`id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.Config>`
                
                .. attribute:: config
                
                	Configuration parameters relating to the associated interface
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.Config>`
                
                .. attribute:: state
                
                	Operational state parameters relating to the associated interface
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.State>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Interfaces.Interface, self).__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "interfaces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Interfaces.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Interfaces.Interface.State))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('id', YLeaf(YType.str, 'id')),
                    ])
                    self.id = None

                    self.config = NetworkInstances.NetworkInstance.Interfaces.Interface.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.Interfaces.Interface.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")
                    self._segment_path = lambda: "interface" + "[id='" + str(self.id) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface, ['id'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to the associated
                    interface
                    
                    .. attribute:: id
                    
                    	A unique identifier for this interface \- this is expressed as a free\-text string
                    	**type**\: str
                    
                    .. attribute:: interface
                    
                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                    	**type**\: str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                    
                    .. attribute:: subinterface
                    
                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                    
                    .. attribute:: associated_address_families
                    
                    	The address families on the subinterface which are to be associated with this network instance. When this leaf\-list is empty and the network instance requires Layer 3 information the address families for which the network instance is enabled should be imported. If the value of this leaf\-list is specified then the association MUST only be made for those address families that are included in the list
                    	**type**\: list of   :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Interfaces.Interface.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', YLeaf(YType.str, 'id')),
                            ('interface', YLeaf(YType.str, 'interface')),
                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                            ('associated_address_families', YLeafList(YType.identityref, 'associated-address-families')),
                        ])
                        self.id = None
                        self.interface = None
                        self.subinterface = None
                        self.associated_address_families = []
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface.Config, ['id', 'interface', 'subinterface', 'associated_address_families'], name, value)


                class State(Entity):
                    """
                    Operational state parameters relating to the
                    associated interface
                    
                    .. attribute:: id
                    
                    	A unique identifier for this interface \- this is expressed as a free\-text string
                    	**type**\: str
                    
                    .. attribute:: interface
                    
                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                    	**type**\: str
                    
                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                    
                    .. attribute:: subinterface
                    
                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                    
                    .. attribute:: associated_address_families
                    
                    	The address families on the subinterface which are to be associated with this network instance. When this leaf\-list is empty and the network instance requires Layer 3 information the address families for which the network instance is enabled should be imported. If the value of this leaf\-list is specified then the association MUST only be made for those address families that are included in the list
                    	**type**\: list of   :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Interfaces.Interface.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', YLeaf(YType.str, 'id')),
                            ('interface', YLeaf(YType.str, 'interface')),
                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                            ('associated_address_families', YLeafList(YType.identityref, 'associated-address-families')),
                        ])
                        self.id = None
                        self.interface = None
                        self.subinterface = None
                        self.associated_address_families = []
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface.State, ['id', 'interface', 'subinterface', 'associated_address_families'], name, value)


        class Tables(Entity):
            """
            The routing tables that are managed by this network
            instance
            
            .. attribute:: table
            
            	A network instance manages one or more forwarding or routing tables. These may reflect a Layer 2 forwarding information base, a Layer 3 routing table, or an MPLS LFIB.  The table populated by a protocol within an instance is identified by the protocol identifier (e.g., BGP, IS\-IS) and the address family (e.g., IPv4, IPv6) supported by that protocol. Multiple instances of the same protocol populate a single table \-\- such that a single IS\-IS or OSPF IPv4 table exists per network instance.  An implementation is expected to create entries within this list when the relevant protocol context is enabled. i.e., when a BGP instance is created with IPv4 and IPv6 address families enabled, the protocol=BGP, address\-family=IPv4 table is created by the system
            	**type**\: list of  		 :py:class:`Table <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Tables, self).__init__()

                self.yang_name = "tables"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("table", ("table", NetworkInstances.NetworkInstance.Tables.Table))])
                self._leafs = OrderedDict()

                self.table = YList(self)
                self._segment_path = lambda: "tables"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Tables, [], name, value)


            class Table(Entity):
                """
                A network instance manages one or more forwarding or
                routing tables. These may reflect a Layer 2 forwarding
                information base, a Layer 3 routing table, or an MPLS
                LFIB.
                
                The table populated by a protocol within an instance is
                identified by the protocol identifier (e.g., BGP, IS\-IS)
                and the address family (e.g., IPv4, IPv6) supported by
                that protocol. Multiple instances of the same protocol
                populate a single table \-\- such that
                a single IS\-IS or OSPF IPv4 table exists per network
                instance.
                
                An implementation is expected to create entries within
                this list when the relevant protocol context is enabled.
                i.e., when a BGP instance is created with IPv4 and IPv6
                address families enabled, the protocol=BGP,
                address\-family=IPv4 table is created by the system.
                
                .. attribute:: protocol  (key)
                
                	A reference to the protocol that populates the table
                	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: address_family  (key)
                
                	A reference to the address\-family that the table represents
                	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                
                .. attribute:: config
                
                	Configuration parameters relating to the table
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table.Config>`
                
                .. attribute:: state
                
                	State parameters related to the table
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table.State>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Tables.Table, self).__init__()

                    self.yang_name = "table"
                    self.yang_parent_name = "tables"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['protocol','address_family']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Tables.Table.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Tables.Table.State))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('protocol', YLeaf(YType.identityref, 'protocol')),
                        ('address_family', YLeaf(YType.identityref, 'address-family')),
                    ])
                    self.protocol = None
                    self.address_family = None

                    self.config = NetworkInstances.NetworkInstance.Tables.Table.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.Tables.Table.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")
                    self._segment_path = lambda: "table" + "[protocol='" + str(self.protocol) + "']" + "[address-family='" + str(self.address_family) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table, ['protocol', 'address_family'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to the
                    table
                    
                    .. attribute:: protocol
                    
                    	Reference to the protocol that the table is associated with
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                    	The address family (IPv4, IPv6) of the table's entries
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Tables.Table.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', YLeaf(YType.identityref, 'protocol')),
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                        ])
                        self.protocol = None
                        self.address_family = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table.Config, ['protocol', 'address_family'], name, value)


                class State(Entity):
                    """
                    State parameters related to the table
                    
                    .. attribute:: protocol
                    
                    	Reference to the protocol that the table is associated with
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                    	The address family (IPv4, IPv6) of the table's entries
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Tables.Table.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', YLeaf(YType.identityref, 'protocol')),
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                        ])
                        self.protocol = None
                        self.address_family = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table.State, ['protocol', 'address_family'], name, value)


        class ConnectionPoints(Entity):
            """
            The set of connection points within a forwarding
            instance
            
            .. attribute:: connection_point
            
            	A connection point within a Layer 2 network instance. Each connection\-point consists of a set of interfaces only one of which is active at any one time. Other than the specification of whether an interface is local (i.e., exists within this network\-instance), or remote, all configuration and state parameters are common
            	**type**\: list of  		 :py:class:`ConnectionPoint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.ConnectionPoints, self).__init__()

                self.yang_name = "connection-points"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("connection-point", ("connection_point", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint))])
                self._leafs = OrderedDict()

                self.connection_point = YList(self)
                self._segment_path = lambda: "connection-points"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints, [], name, value)


            class ConnectionPoint(Entity):
                """
                A connection point within a Layer 2 network instance.
                Each connection\-point consists of a set of interfaces
                only one of which is active at any one time. Other than
                the specification of whether an interface is local
                (i.e., exists within this network\-instance), or remote,
                all configuration and state parameters are common
                
                .. attribute:: connection_point_id  (key)
                
                	A locally significant reference for the connection\-point
                	**type**\: str
                
                	**refers to**\:  :py:class:`connection_point_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config>`
                
                .. attribute:: config
                
                	Configuration parameters relating to a Layer 2 network instance connection point
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config>`
                
                .. attribute:: state
                
                	Operational state parameters relating to a Layer 2 network instance connection point
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State>`
                
                .. attribute:: endpoints
                
                	The set of endpoints which are grouped within the connection point
                	**type**\:  :py:class:`Endpoints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint, self).__init__()

                    self.yang_name = "connection-point"
                    self.yang_parent_name = "connection-points"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['connection_point_id']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State)), ("endpoints", ("endpoints", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('connection_point_id', YLeaf(YType.str, 'connection-point-id')),
                    ])
                    self.connection_point_id = None

                    self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")

                    self.endpoints = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints()
                    self.endpoints.parent = self
                    self._children_name_map["endpoints"] = "endpoints"
                    self._children_yang_names.add("endpoints")
                    self._segment_path = lambda: "connection-point" + "[connection-point-id='" + str(self.connection_point_id) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint, ['connection_point_id'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to a Layer 2
                    network instance connection point
                    
                    .. attribute:: connection_point_id
                    
                    	An identifier for a connection point
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('connection_point_id', YLeaf(YType.str, 'connection-point-id')),
                        ])
                        self.connection_point_id = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config, ['connection_point_id'], name, value)


                class State(Entity):
                    """
                    Operational state parameters relating to a Layer 2
                    network instance connection point
                    
                    .. attribute:: connection_point_id
                    
                    	An identifier for a connection point
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('connection_point_id', YLeaf(YType.str, 'connection-point-id')),
                        ])
                        self.connection_point_id = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State, ['connection_point_id'], name, value)


                class Endpoints(Entity):
                    """
                    The set of endpoints which are grouped within the
                    connection point
                    
                    .. attribute:: endpoint
                    
                    	A list of the endpoints (interfaces or remote connection points that can be used for this connection point). The active endpoint is selected based on the precedence that it is configured with
                    	**type**\: list of  		 :py:class:`Endpoint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints, self).__init__()

                        self.yang_name = "endpoints"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("endpoint", ("endpoint", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint))])
                        self._leafs = OrderedDict()

                        self.endpoint = YList(self)
                        self._segment_path = lambda: "endpoints"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints, [], name, value)


                    class Endpoint(Entity):
                        """
                        A list of the endpoints (interfaces or remote
                        connection points that can be used for this
                        connection point). The active endpoint is selected
                        based on the precedence that it is configured
                        with
                        
                        .. attribute:: endpoint_id  (key)
                        
                        	A pointer to the configured identifier for the endpoint
                        	**type**\: str
                        
                        	**refers to**\:  :py:class:`endpoint_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config>`
                        
                        .. attribute:: config
                        
                        	Configuration parameters relating to the endpoint
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config>`
                        
                        .. attribute:: state
                        
                        	Operational state parameters relating to the endpoint
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State>`
                        
                        .. attribute:: local
                        
                        	Configuration and operational state parameters relating to a local interface
                        	**type**\:  :py:class:`Local <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local>`
                        
                        .. attribute:: remote
                        
                        	Configuration and operational state parameters relating to a remote interface
                        	**type**\:  :py:class:`Remote <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint, self).__init__()

                            self.yang_name = "endpoint"
                            self.yang_parent_name = "endpoints"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['endpoint_id']
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State)), ("local", ("local", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local)), ("remote", ("remote", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('endpoint_id', YLeaf(YType.str, 'endpoint-id')),
                            ])
                            self.endpoint_id = None

                            self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.local = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"
                            self._children_yang_names.add("local")

                            self.remote = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote()
                            self.remote.parent = self
                            self._children_name_map["remote"] = "remote"
                            self._children_yang_names.add("remote")
                            self._segment_path = lambda: "endpoint" + "[endpoint-id='" + str(self.endpoint_id) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint, ['endpoint_id'], name, value)


                        class Config(Entity):
                            """
                            Configuration parameters relating to the
                            endpoint
                            
                            .. attribute:: endpoint_id
                            
                            	An identifier for the endpoint
                            	**type**\: str
                            
                            .. attribute:: precedence
                            
                            	The precedence of the endpoint \- the lowest precendence viable endpoint will be utilised as the active endpoint within a connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: type
                            
                            	The type of endpoint that is referred to by the current endpoint
                            	**type**\:  :py:class:`ENDPOINTTYPE <ydk.models.openconfig.openconfig_network_instance_types.ENDPOINTTYPE>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('endpoint_id', YLeaf(YType.str, 'endpoint-id')),
                                    ('precedence', YLeaf(YType.uint16, 'precedence')),
                                    ('type', YLeaf(YType.identityref, 'type')),
                                ])
                                self.endpoint_id = None
                                self.precedence = None
                                self.type = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config, ['endpoint_id', 'precedence', 'type'], name, value)


                        class State(Entity):
                            """
                            Operational state parameters relating to the
                            endpoint
                            
                            .. attribute:: endpoint_id
                            
                            	An identifier for the endpoint
                            	**type**\: str
                            
                            .. attribute:: precedence
                            
                            	The precedence of the endpoint \- the lowest precendence viable endpoint will be utilised as the active endpoint within a connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: type
                            
                            	The type of endpoint that is referred to by the current endpoint
                            	**type**\:  :py:class:`ENDPOINTTYPE <ydk.models.openconfig.openconfig_network_instance_types.ENDPOINTTYPE>`
                            
                            .. attribute:: active
                            
                            	When the backup endpoint is active, the value of this parameter is set to true
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('endpoint_id', YLeaf(YType.str, 'endpoint-id')),
                                    ('precedence', YLeaf(YType.uint16, 'precedence')),
                                    ('type', YLeaf(YType.identityref, 'type')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.endpoint_id = None
                                self.precedence = None
                                self.type = None
                                self.active = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State, ['endpoint_id', 'precedence', 'type', 'active'], name, value)


                        class Local(Entity):
                            """
                            Configuration and operational state parameters
                            relating to a local interface
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to a local endpoint
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config>`
                            
                            .. attribute:: state
                            
                            	Operational state parameters relating to a local endpoint
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local, self).__init__()

                                self.yang_name = "local"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "local"


                            class Config(Entity):
                                """
                                Configuration parameters relating to a local
                                endpoint
                                
                                .. attribute:: interface
                                
                                	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                .. attribute:: subinterface
                                
                                	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "local"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', YLeaf(YType.str, 'interface')),
                                        ('subinterface', YLeaf(YType.str, 'subinterface')),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config, ['interface', 'subinterface'], name, value)


                            class State(Entity):
                                """
                                Operational state parameters relating to a
                                local endpoint
                                
                                .. attribute:: interface
                                
                                	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                .. attribute:: subinterface
                                
                                	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "local"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', YLeaf(YType.str, 'interface')),
                                        ('subinterface', YLeaf(YType.str, 'subinterface')),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State, ['interface', 'subinterface'], name, value)


                        class Remote(Entity):
                            """
                            Configuration and operational state parameters
                            relating to a remote interface
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to a remote endpoint
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config>`
                            
                            .. attribute:: state
                            
                            	Operational state parameters relating to a remote endpoint
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote, self).__init__()

                                self.yang_name = "remote"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "remote"


                            class Config(Entity):
                                """
                                Configuration parameters relating to a remote
                                endpoint
                                
                                .. attribute:: remote_system
                                
                                	The IP address of the device which hosts the remote end\-point
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_circuit_identifier
                                
                                	The virtual\-circuit identifier that identifies the connection at the remote end\-point
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('remote_system', YLeaf(YType.str, 'remote-system')),
                                        ('virtual_circuit_identifier', YLeaf(YType.uint32, 'virtual-circuit-identifier')),
                                    ])
                                    self.remote_system = None
                                    self.virtual_circuit_identifier = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config, ['remote_system', 'virtual_circuit_identifier'], name, value)


                            class State(Entity):
                                """
                                Operational state parameters relating to
                                a remote endpoint
                                
                                .. attribute:: remote_system
                                
                                	The IP address of the device which hosts the remote end\-point
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_circuit_identifier
                                
                                	The virtual\-circuit identifier that identifies the connection at the remote end\-point
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('remote_system', YLeaf(YType.str, 'remote-system')),
                                        ('virtual_circuit_identifier', YLeaf(YType.uint32, 'virtual-circuit-identifier')),
                                    ])
                                    self.remote_system = None
                                    self.virtual_circuit_identifier = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State, ['remote_system', 'virtual_circuit_identifier'], name, value)


        class Mpls(Entity):
            """
            node added for compilation for forward compatibility
            
            .. attribute:: global_
            
            	node added for compilation for forward compatibility
            	**type**\:  :py:class:`Global <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Mpls, self).__init__()

                self.yang_name = "mpls"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Mpls.Global))])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict()

                self.global_ = NetworkInstances.NetworkInstance.Mpls.Global()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"
                self._children_yang_names.add("global")
                self._segment_path = lambda: "mpls"


            class Global(Entity):
                """
                node added for compilation for forward compatibility
                
                .. attribute:: reserved_label_blocks
                
                	node added for compilation for forward compatibility
                	**type**\:  :py:class:`ReservedLabelBlocks <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Mpls.Global, self).__init__()

                    self.yang_name = "global"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([("reserved-label-blocks", ("reserved_label_blocks", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict()

                    self.reserved_label_blocks = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks()
                    self.reserved_label_blocks.parent = self
                    self._children_name_map["reserved_label_blocks"] = "reserved-label-blocks"
                    self._children_yang_names.add("reserved-label-blocks")
                    self._segment_path = lambda: "global"


                class ReservedLabelBlocks(Entity):
                    """
                    node added for compilation for forward compatibility
                    
                    .. attribute:: reserved_label_block
                    
                    	node added for compilation for forward compatibility
                    	**type**\:  :py:class:`ReservedLabelBlock <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks, self).__init__()

                        self.yang_name = "reserved-label-blocks"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([("reserved-label-block", ("reserved_label_block", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock))])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict()

                        self.reserved_label_block = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock()
                        self.reserved_label_block.parent = self
                        self._children_name_map["reserved_label_block"] = "reserved-label-block"
                        self._children_yang_names.add("reserved-label-block")
                        self._segment_path = lambda: "reserved-label-blocks"


                    class ReservedLabelBlock(Entity):
                        """
                        node added for compilation for forward compatibility
                        
                        .. attribute:: config
                        
                        	node added for compilation for forward compatibility
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock, self).__init__()

                            self.yang_name = "reserved-label-block"
                            self.yang_parent_name = "reserved-label-blocks"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")
                            self._segment_path = lambda: "reserved-label-block"


                        class Config(Entity):
                            """
                            node added for compilation for forward compatibility
                            
                            .. attribute:: local_id
                            
                            	node added for compilation for forward compatibility
                            	**type**\: list of str
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "reserved-label-block"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_id', YLeafList(YType.str, 'local-id')),
                                ])
                                self.local_id = []
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config, ['local_id'], name, value)


        class SegmentRouting(Entity):
            """
            Configuration and operational state parameters relating to
            segment routing.
            
            .. attribute:: srgbs
            
            	Configuration and operational state parameters relating to the SRGBs defined for the system
            	**type**\:  :py:class:`Srgbs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs>`
            
            .. attribute:: srlbs
            
            	Configuration and operational state parameters relating to the Segment Routing Local Blocks (SRLBs) defined for the system
            	**type**\:  :py:class:`Srlbs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.SegmentRouting, self).__init__()

                self.yang_name = "segment-routing"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([("srgbs", ("srgbs", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs)), ("srlbs", ("srlbs", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs))])
                self._child_list_classes = OrderedDict([])
                self._leafs = OrderedDict()

                self.srgbs = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs()
                self.srgbs.parent = self
                self._children_name_map["srgbs"] = "srgbs"
                self._children_yang_names.add("srgbs")

                self.srlbs = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs()
                self.srlbs.parent = self
                self._children_name_map["srlbs"] = "srlbs"
                self._children_yang_names.add("srlbs")
                self._segment_path = lambda: "segment-routing"


            class Srgbs(Entity):
                """
                Configuration and operational state parameters relating to the
                SRGBs defined for the system.
                
                .. attribute:: srgb
                
                	A single definition of an SRGB which may comprise of multiple sets of dataplane addresses (IPv6 addresses, or MPLS labels)
                	**type**\: list of  		 :py:class:`Srgb <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs, self).__init__()

                    self.yang_name = "srgbs"
                    self.yang_parent_name = "segment-routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([("srgb", ("srgb", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb))])
                    self._leafs = OrderedDict()

                    self.srgb = YList(self)
                    self._segment_path = lambda: "srgbs"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs, [], name, value)


                class Srgb(Entity):
                    """
                    A single definition of an SRGB which may comprise of multiple
                    sets of dataplane addresses (IPv6 addresses, or MPLS labels).
                    
                    .. attribute:: local_id  (key)
                    
                    	A reference to the identifier for the SRGB
                    	**type**\: str
                    
                    	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                    
                    .. attribute:: config
                    
                    	Configuration parameters relating to the SRGB
                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                    
                    .. attribute:: state
                    
                    	State parameters relating to the SRGB
                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb, self).__init__()

                        self.yang_name = "srgb"
                        self.yang_parent_name = "srgbs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_id']
                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State))])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local_id', YLeaf(YType.str, 'local-id')),
                        ])
                        self.local_id = None

                        self.config = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "srgb" + "[local-id='" + str(self.local_id) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb, ['local_id'], name, value)


                    class Config(Entity):
                        """
                        Configuration parameters relating to the SRGB.
                        
                        .. attribute:: local_id
                        
                        	Unique identifier for the segment routing global block on the local system
                        	**type**\: str
                        
                        .. attribute:: dataplane_type
                        
                        	The dataplane being used to instantiate the SRGB. When MPLS is specified the set of MPLS label blocks that are defined in the mpls\-label\-blocks list are used to make up the SRGB. When IPv6 is specified, the set of IPv6 prefixes specified in the ipv6\-prefixes list are used
                        	**type**\:  :py:class:`SrDataplaneType <ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_blocks
                        
                        	A list of refences to the label blocks that are used to make up the SRGB
                        	**type**\: list of str
                        
                        	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefixes
                        
                        	A list of IPv6 prefixes which are to be used for segment routing using the IPv6 dataplane
                        	**type**\: list of str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "srgb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', YLeaf(YType.str, 'local-id')),
                                ('dataplane_type', YLeaf(YType.enumeration, 'dataplane-type')),
                                ('mpls_label_blocks', YLeafList(YType.str, 'mpls-label-blocks')),
                                ('ipv6_prefixes', YLeafList(YType.str, 'ipv6-prefixes')),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_blocks = []
                            self.ipv6_prefixes = []
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config, ['local_id', 'dataplane_type', 'mpls_label_blocks', 'ipv6_prefixes'], name, value)


                    class State(Entity):
                        """
                        State parameters relating to the SRGB.
                        
                        .. attribute:: local_id
                        
                        	Unique identifier for the segment routing global block on the local system
                        	**type**\: str
                        
                        .. attribute:: dataplane_type
                        
                        	The dataplane being used to instantiate the SRGB. When MPLS is specified the set of MPLS label blocks that are defined in the mpls\-label\-blocks list are used to make up the SRGB. When IPv6 is specified, the set of IPv6 prefixes specified in the ipv6\-prefixes list are used
                        	**type**\:  :py:class:`SrDataplaneType <ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_blocks
                        
                        	A list of refences to the label blocks that are used to make up the SRGB
                        	**type**\: list of str
                        
                        	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefixes
                        
                        	A list of IPv6 prefixes which are to be used for segment routing using the IPv6 dataplane
                        	**type**\: list of str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        .. attribute:: size
                        
                        	The total number of SRGB entries that are available within the SRGB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: used
                        
                        	The total number of SRGB entries that have already been alocated by protocols referencing the SRGB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "srgb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', YLeaf(YType.str, 'local-id')),
                                ('dataplane_type', YLeaf(YType.enumeration, 'dataplane-type')),
                                ('mpls_label_blocks', YLeafList(YType.str, 'mpls-label-blocks')),
                                ('ipv6_prefixes', YLeafList(YType.str, 'ipv6-prefixes')),
                                ('size', YLeaf(YType.uint32, 'size')),
                                ('used', YLeaf(YType.uint32, 'used')),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_blocks = []
                            self.ipv6_prefixes = []
                            self.size = None
                            self.used = None
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State, ['local_id', 'dataplane_type', 'mpls_label_blocks', 'ipv6_prefixes', 'size', 'used'], name, value)


            class Srlbs(Entity):
                """
                Configuration and operational state parameters relating to the
                Segment Routing Local Blocks (SRLBs) defined for the system.
                
                .. attribute:: srlb
                
                	A definition of a Segment Routing Local Block, defined to be a set of Segment Identifiers (specified as MPLS labels or IPv6 addreses) that are defined for local allocation by the system. A block may optionally be advertised into an IGP
                	**type**\: list of  		 :py:class:`Srlb <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs, self).__init__()

                    self.yang_name = "srlbs"
                    self.yang_parent_name = "segment-routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_container_classes = OrderedDict([])
                    self._child_list_classes = OrderedDict([("srlb", ("srlb", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb))])
                    self._leafs = OrderedDict()

                    self.srlb = YList(self)
                    self._segment_path = lambda: "srlbs"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs, [], name, value)


                class Srlb(Entity):
                    """
                    A definition of a Segment Routing Local Block, defined to be
                    a set of Segment Identifiers (specified as MPLS labels or
                    IPv6 addreses) that are defined for local allocation by the
                    system. A block may optionally be advertised into an IGP.
                    
                    .. attribute:: local_id  (key)
                    
                    	Reference to the local identifier used for the SRLB
                    	**type**\: str
                    
                    	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                    
                    .. attribute:: config
                    
                    	Configuration parameters relating to the SRLB
                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                    
                    .. attribute:: state
                    
                    	Operational state parmeters relating to the SRLB
                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb, self).__init__()

                        self.yang_name = "srlb"
                        self.yang_parent_name = "srlbs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_id']
                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State))])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local_id', YLeaf(YType.str, 'local-id')),
                        ])
                        self.local_id = None

                        self.config = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"
                        self._children_yang_names.add("config")

                        self.state = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._children_yang_names.add("state")
                        self._segment_path = lambda: "srlb" + "[local-id='" + str(self.local_id) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb, ['local_id'], name, value)


                    class Config(Entity):
                        """
                        Configuration parameters relating to the SRLB.
                        
                        .. attribute:: local_id
                        
                        	A unique local identifier used for the Segment Routing Local Block. The identifier is used when referencing the SRLB within other contexts
                        	**type**\: str
                        
                        .. attribute:: dataplane_type
                        
                        	The dataplane that is to be used for the Segment Routing Local Block. When MPLS is specified, the local block corresponds to a block of MPLS labels; when IPv6 is specified it corresponds to an IPv6 prefix
                        	**type**\:  :py:class:`SrDataplaneType <ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_block
                        
                        	A reference to the MPLS label block that is used to contain the SIDs of the SRLB
                        	**type**\: str
                        
                        	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefix
                        
                        	The IPv6 prefix that is used for the SRLB
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config, self).__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "srlb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', YLeaf(YType.str, 'local-id')),
                                ('dataplane_type', YLeaf(YType.enumeration, 'dataplane-type')),
                                ('mpls_label_block', YLeaf(YType.str, 'mpls-label-block')),
                                ('ipv6_prefix', YLeaf(YType.str, 'ipv6-prefix')),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_block = None
                            self.ipv6_prefix = None
                            self._segment_path = lambda: "config"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config, ['local_id', 'dataplane_type', 'mpls_label_block', 'ipv6_prefix'], name, value)


                    class State(Entity):
                        """
                        Operational state parmeters relating to the SRLB.
                        
                        .. attribute:: local_id
                        
                        	A unique local identifier used for the Segment Routing Local Block. The identifier is used when referencing the SRLB within other contexts
                        	**type**\: str
                        
                        .. attribute:: dataplane_type
                        
                        	The dataplane that is to be used for the Segment Routing Local Block. When MPLS is specified, the local block corresponds to a block of MPLS labels; when IPv6 is specified it corresponds to an IPv6 prefix
                        	**type**\:  :py:class:`SrDataplaneType <ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_block
                        
                        	A reference to the MPLS label block that is used to contain the SIDs of the SRLB
                        	**type**\: str
                        
                        	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefix
                        
                        	The IPv6 prefix that is used for the SRLB
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "srlb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', YLeaf(YType.str, 'local-id')),
                                ('dataplane_type', YLeaf(YType.enumeration, 'dataplane-type')),
                                ('mpls_label_block', YLeaf(YType.str, 'mpls-label-block')),
                                ('ipv6_prefix', YLeaf(YType.str, 'ipv6-prefix')),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_block = None
                            self.ipv6_prefix = None
                            self._segment_path = lambda: "state"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State, ['local_id', 'dataplane_type', 'mpls_label_block', 'ipv6_prefix'], name, value)


        class Vlans(Entity):
            """
            Container for VLAN configuration and state
            variables
            
            .. attribute:: vlan
            
            	Configured VLANs keyed by id
            	**type**\: list of  		 :py:class:`Vlan <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Vlans, self).__init__()

                self.yang_name = "vlans"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("vlan", ("vlan", NetworkInstances.NetworkInstance.Vlans.Vlan))])
                self._leafs = OrderedDict()

                self.vlan = YList(self)
                self._segment_path = lambda: "vlans"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Vlans, [], name, value)


            class Vlan(Entity):
                """
                Configured VLANs keyed by id
                
                .. attribute:: vlan_id  (key)
                
                	references the configured vlan\-id
                	**type**\: int
                
                	**range:** 1..4094
                
                	**refers to**\:  :py:class:`vlan_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                
                .. attribute:: config
                
                	Configuration parameters for VLANs
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                
                .. attribute:: state
                
                	State variables for VLANs
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.State>`
                
                .. attribute:: members
                
                	Enclosing container for list of member interfaces
                	**type**\:  :py:class:`Members <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Vlans.Vlan, self).__init__()

                    self.yang_name = "vlan"
                    self.yang_parent_name = "vlans"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['vlan_id']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Vlans.Vlan.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Vlans.Vlan.State)), ("members", ("members", NetworkInstances.NetworkInstance.Vlans.Vlan.Members))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('vlan_id', YLeaf(YType.str, 'vlan-id')),
                    ])
                    self.vlan_id = None

                    self.config = NetworkInstances.NetworkInstance.Vlans.Vlan.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.Vlans.Vlan.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")

                    self.members = NetworkInstances.NetworkInstance.Vlans.Vlan.Members()
                    self.members.parent = self
                    self._children_name_map["members"] = "members"
                    self._children_yang_names.add("members")
                    self._segment_path = lambda: "vlan" + "[vlan-id='" + str(self.vlan_id) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan, ['vlan_id'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters for VLANs
                    
                    .. attribute:: vlan_id
                    
                    	Interface VLAN id
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: name
                    
                    	Interface VLAN name
                    	**type**\: str
                    
                    .. attribute:: status
                    
                    	Admin state of the VLAN
                    	**type**\:  :py:class:`Status <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config.Status>`
                    
                    	**default value**\: ACTIVE
                    
                    .. attribute:: tpid
                    
                    	Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
                    	**type**\:  :py:class:`TPIDTYPES <ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
                    
                    	**default value**\: oc-vlan-types:TPID_0x8100
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Vlans.Vlan.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', YLeaf(YType.uint16, 'vlan-id')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('status', YLeaf(YType.enumeration, 'status')),
                            ('tpid', YLeaf(YType.identityref, 'tpid')),
                        ])
                        self.vlan_id = None
                        self.name = None
                        self.status = None
                        self.tpid = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Config, ['vlan_id', 'name', 'status', 'tpid'], name, value)

                    class Status(Enum):
                        """
                        Status (Enum Class)

                        Admin state of the VLAN

                        .. data:: ACTIVE = 0

                        	VLAN is active

                        .. data:: SUSPENDED = 1

                        	VLAN is inactive / suspended

                        """

                        ACTIVE = Enum.YLeaf(0, "ACTIVE")

                        SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



                class State(Entity):
                    """
                    State variables for VLANs
                    
                    .. attribute:: vlan_id
                    
                    	Interface VLAN id
                    	**type**\: int
                    
                    	**range:** 1..4094
                    
                    .. attribute:: name
                    
                    	Interface VLAN name
                    	**type**\: str
                    
                    .. attribute:: status
                    
                    	Admin state of the VLAN
                    	**type**\:  :py:class:`Status <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.State.Status>`
                    
                    	**default value**\: ACTIVE
                    
                    .. attribute:: tpid
                    
                    	Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
                    	**type**\:  :py:class:`TPIDTYPES <ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
                    
                    	**default value**\: oc-vlan-types:TPID_0x8100
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Vlans.Vlan.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', YLeaf(YType.uint16, 'vlan-id')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('status', YLeaf(YType.enumeration, 'status')),
                            ('tpid', YLeaf(YType.identityref, 'tpid')),
                        ])
                        self.vlan_id = None
                        self.name = None
                        self.status = None
                        self.tpid = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.State, ['vlan_id', 'name', 'status', 'tpid'], name, value)

                    class Status(Enum):
                        """
                        Status (Enum Class)

                        Admin state of the VLAN

                        .. data:: ACTIVE = 0

                        	VLAN is active

                        .. data:: SUSPENDED = 1

                        	VLAN is inactive / suspended

                        """

                        ACTIVE = Enum.YLeaf(0, "ACTIVE")

                        SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



                class Members(Entity):
                    """
                    Enclosing container for list of member interfaces
                    
                    .. attribute:: member
                    
                    	List of references to interfaces / subinterfaces associated with the VLAN
                    	**type**\: list of  		 :py:class:`Member <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Vlans.Vlan.Members, self).__init__()

                        self.yang_name = "members"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("member", ("member", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member))])
                        self._leafs = OrderedDict()

                        self.member = YList(self)
                        self._segment_path = lambda: "members"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members, [], name, value)


                    class Member(Entity):
                        """
                        List of references to interfaces / subinterfaces
                        associated with the VLAN.
                        
                        .. attribute:: interface_ref
                        
                        	Reference to an interface or subinterface
                        	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member, self).__init__()

                            self.yang_name = "member"
                            self.yang_parent_name = "members"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict()

                            self.interface_ref = NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef()
                            self.interface_ref.parent = self
                            self._children_name_map["interface_ref"] = "interface-ref"
                            self._children_yang_names.add("interface-ref")
                            self._segment_path = lambda: "member"


                        class InterfaceRef(Entity):
                            """
                            Reference to an interface or subinterface
                            
                            .. attribute:: state
                            
                            	Operational state for interface\-ref
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef, self).__init__()

                                self.yang_name = "interface-ref"
                                self.yang_parent_name = "member"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.state = NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "interface-ref"


                            class State(Entity):
                                """
                                Operational state for interface\-ref
                                
                                .. attribute:: interface
                                
                                	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                .. attribute:: subinterface
                                
                                	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface-ref"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', YLeaf(YType.str, 'interface')),
                                        ('subinterface', YLeaf(YType.str, 'subinterface')),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State, ['interface', 'subinterface'], name, value)


        class Afts(Entity):
            """
            The abstract forwarding tables (AFTs) that are associated
            with the network instance. An AFT is instantiated per\-protocol
            running within the network\-instance \- such that one exists for
            IPv4 Unicast, IPv6 Unicast, MPLS, L2 forwarding entries, etc.
            A forwarding entry within the FIB has a set of next\-hops,
            which may be a reference to an entry within another table \-
            e.g., where a Layer 3 next\-hop has an associated Layer 2
            forwarding entry.
            
            .. attribute:: aft
            
            	An individual abstract forwarding table associated with a an address family wtihin the network instance
            	**type**\: list of  		 :py:class:`Aft <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Afts, self).__init__()

                self.yang_name = "afts"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("aft", ("aft", NetworkInstances.NetworkInstance.Afts.Aft))])
                self._leafs = OrderedDict()

                self.aft = YList(self)
                self._segment_path = lambda: "afts"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Afts, [], name, value)


            class Aft(Entity):
                """
                An individual abstract forwarding table associated with a
                an address family wtihin the network instance.
                
                .. attribute:: address_family  (key)
                
                	Reference to the address family with which the AFT is associated
                	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                
                .. attribute:: config
                
                	Configuration parameters relating to the AFT
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Config>`
                
                .. attribute:: state
                
                	Operational state parameters relating to the AFT
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.State>`
                
                .. attribute:: entries
                
                	Enclosing container for a list of abstract forwarding table entries within the network instance for a particular protocol (e.g., IPv4, IPv6, MPLS)
                	**type**\:  :py:class:`Entries <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Afts.Aft, self).__init__()

                    self.yang_name = "aft"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['address_family']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Aft.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.State)), ("entries", ("entries", NetworkInstances.NetworkInstance.Afts.Aft.Entries))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('address_family', YLeaf(YType.identityref, 'address-family')),
                    ])
                    self.address_family = None

                    self.config = NetworkInstances.NetworkInstance.Afts.Aft.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.Afts.Aft.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")

                    self.entries = NetworkInstances.NetworkInstance.Afts.Aft.Entries()
                    self.entries.parent = self
                    self._children_name_map["entries"] = "entries"
                    self._children_yang_names.add("entries")
                    self._segment_path = lambda: "aft" + "[address-family='" + str(self.address_family) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft, ['address_family'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to the AFT.
                    
                    .. attribute:: address_family
                    
                    	The address family of entries that are described by the AFT
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Afts.Aft.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "aft"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                        ])
                        self.address_family = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Config, ['address_family'], name, value)


                class State(Entity):
                    """
                    Operational state parameters relating to the AFT.
                    
                    .. attribute:: address_family
                    
                    	The address family of entries that are described by the AFT
                    	**type**\:  :py:class:`ADDRESSFAMILY <ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Afts.Aft.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "aft"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('address_family', YLeaf(YType.identityref, 'address-family')),
                        ])
                        self.address_family = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.State, ['address_family'], name, value)


                class Entries(Entity):
                    """
                    Enclosing container for a list of abstract forwarding table
                    entries within the network instance for a particular protocol
                    (e.g., IPv4, IPv6, MPLS).
                    
                    .. attribute:: entry
                    
                    	A forwarding database entry within the network instance
                    	**type**\: list of  		 :py:class:`Entry <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Afts.Aft.Entries, self).__init__()

                        self.yang_name = "entries"
                        self.yang_parent_name = "aft"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("entry", ("entry", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry))])
                        self._leafs = OrderedDict()

                        self.entry = YList(self)
                        self._segment_path = lambda: "entries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries, [], name, value)


                    class Entry(Entity):
                        """
                        A forwarding database entry within the network instance
                        
                        .. attribute:: index  (key)
                        
                        	A pointer to the index of the AFT entry within the network instance
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config>`
                        
                        .. attribute:: config
                        
                        	Configuration parameters relating to the forwarding entry
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config>`
                        
                        .. attribute:: state
                        
                        	Operational state parameters relating to the forwarding entry
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.State>`
                        
                        .. attribute:: match
                        
                        	Match criteria for the AFT entry
                        	**type**\:  :py:class:`Match <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match>`
                        
                        .. attribute:: next_hops
                        
                        	Enclosing container for the list of next\-hops associated with the forwarding entry
                        	**type**\:  :py:class:`NextHops <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry, self).__init__()

                            self.yang_name = "entry"
                            self.yang_parent_name = "entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['index']
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.State)), ("match", ("match", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('index', YLeaf(YType.str, 'index')),
                            ])
                            self.index = None

                            self.config = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.match = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match()
                            self.match.parent = self
                            self._children_name_map["match"] = "match"
                            self._children_yang_names.add("match")

                            self.next_hops = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops()
                            self.next_hops.parent = self
                            self._children_name_map["next_hops"] = "next-hops"
                            self._children_yang_names.add("next-hops")
                            self._segment_path = lambda: "entry" + "[index='" + str(self.index) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry, ['index'], name, value)


                        class Config(Entity):
                            """
                            Configuration parameters relating to the forwarding
                            entry
                            
                            .. attribute:: index
                            
                            	A unique index referring to the AFT entry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('index', YLeaf(YType.uint64, 'index')),
                                ])
                                self.index = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Config, ['index'], name, value)


                        class State(Entity):
                            """
                            Operational state parameters relating to the forwarding
                            entry
                            
                            .. attribute:: index
                            
                            	A unique index referring to the AFT entry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: packets_forwarded
                            
                            	The number of packets which have matched, and been forwarded, based on the AFT entry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: octets_forwarded
                            
                            	The number of octets which have matched, and been forwarded, based on the AFT entry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('index', YLeaf(YType.uint64, 'index')),
                                    ('packets_forwarded', YLeaf(YType.uint64, 'packets-forwarded')),
                                    ('octets_forwarded', YLeaf(YType.uint64, 'octets-forwarded')),
                                ])
                                self.index = None
                                self.packets_forwarded = None
                                self.octets_forwarded = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.State, ['index', 'packets_forwarded', 'octets_forwarded'], name, value)


                        class Match(Entity):
                            """
                            Match criteria for the AFT entry
                            
                            .. attribute:: config
                            
                            	Configuration of match criteria for the AFT entry
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.Config>`
                            
                            .. attribute:: state
                            
                            	Operational state parameters for match criteria of the AFT entry
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.State>`
                            
                            .. attribute:: interface_ref
                            
                            	Reference to an interface or subinterface
                            	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match, self).__init__()

                                self.yang_name = "match"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._children_yang_names.add("interface-ref")
                                self._segment_path = lambda: "match"


                            class Config(Entity):
                                """
                                Configuration of match criteria for the AFT entry
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "config"


                            class State(Entity):
                                """
                                Operational state parameters for match criteria of the
                                AFT entry
                                
                                .. attribute:: ip_prefix
                                
                                	The IP prefix that the forwarding entry matches. Used for Layer 3 forwarding entries
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: mac_address
                                
                                	The MAC address that the forwarding entry matches. Used for Layer 2 forwarding entries, e.g., within a VSI instance
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: mpls_label
                                
                                	The MPLS label that the forwarding entry matches. Used for MPLS forwarding entries, whereby the local device acts as an LSR
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 16..1048575
                                
                                		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                .. attribute:: mpls_tc
                                
                                	The value of the MPLS Traffic Class bits (formerly known as the MPLS experimental bits) that are to be matched by the AFT entry
                                	**type**\: int
                                
                                	**range:** 0..7
                                
                                .. attribute:: ip_dscp
                                
                                	The value of the differentiated services code point (DSCP) to be matched for the forwarding entry. The value is specified in cases where specific class\-based forwarding based on IP is implemented by the device
                                	**type**\: int
                                
                                	**range:** 0..63
                                
                                .. attribute:: ip_protocol
                                
                                	The value of the IP protocol field of an IPv4 packet, or the next\-header field of an IPv6 packet which is to be matched by the AFT entry. This field is utilised where forwarding is performed based on L4 information
                                	**type**\: union of the below types:
                                
                                		**type**\: int
                                
                                			**range:** 0..254
                                
                                		**type**\:  :py:class:`IPPROTOCOL <ydk.models.openconfig.openconfig_packet_match_types.IPPROTOCOL>`
                                
                                .. attribute:: l4_src_port
                                
                                	The value of the source port field of the transport header that is to be matched by the AFT entry
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: l4_dst_port
                                
                                	The value of the destination port field of the transport header that is to be matched by the AFT entry
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: origin_network_instance
                                
                                	If the AFT entry was imported from another network instance (e.g., it corresponds to a L3 forwarding entry which was learned within another network\-instance), the value of this leaf reflects the network\-instance from which it was learned.  For example, if the local network\-instance corresponds to a L3VRF, and routes are imported from the VPNv4 address\-family of the BGP instance in the DEFAULT\_INSTANCE, then this value would reflect the DEFAULT\_INSTANCE as the origin\-network\-instance
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip_prefix', YLeaf(YType.str, 'ip-prefix')),
                                        ('mac_address', YLeaf(YType.str, 'mac-address')),
                                        ('mpls_label', YLeaf(YType.str, 'mpls-label')),
                                        ('mpls_tc', YLeaf(YType.uint8, 'mpls-tc')),
                                        ('ip_dscp', YLeaf(YType.uint8, 'ip-dscp')),
                                        ('ip_protocol', YLeaf(YType.str, 'ip-protocol')),
                                        ('l4_src_port', YLeaf(YType.uint16, 'l4-src-port')),
                                        ('l4_dst_port', YLeaf(YType.uint16, 'l4-dst-port')),
                                        ('origin_network_instance', YLeaf(YType.str, 'openconfig-aft-network-instance:origin-network-instance')),
                                    ])
                                    self.ip_prefix = None
                                    self.mac_address = None
                                    self.mpls_label = None
                                    self.mpls_tc = None
                                    self.ip_dscp = None
                                    self.ip_protocol = None
                                    self.l4_src_port = None
                                    self.l4_dst_port = None
                                    self.origin_network_instance = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.State, ['ip_prefix', 'mac_address', 'mpls_label', 'mpls_tc', 'ip_dscp', 'ip_protocol', 'l4_src_port', 'l4_dst_port', 'origin_network_instance'], name, value)


                            class InterfaceRef(Entity):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: state
                                
                                	Operational state for interface\-ref
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef, self).__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "match"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.state = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "interface-ref"


                                class State(Entity):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', YLeaf(YType.str, 'interface')),
                                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.Match.InterfaceRef.State, ['interface', 'subinterface'], name, value)


                        class NextHops(Entity):
                            """
                            Enclosing container for the list of next\-hops associated
                            with the forwarding entry
                            
                            .. attribute:: next_hop
                            
                            	A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                            	**type**\: list of  		 :py:class:`NextHop <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops, self).__init__()

                                self.yang_name = "next-hops"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop))])
                                self._leafs = OrderedDict()

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "next-hops"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops, [], name, value)


                            class NextHop(Entity):
                                """
                                A next\-hop associated with the forwarding instance. The
                                entries within the next\-hop list should only reflect
                                next\-hops that are actively used by the local system.
                                That is to say inactive, backup or FRR next\-hops should
                                not be included within this list.
                                
                                .. attribute:: index  (key)
                                
                                	A unique index identifying the next\-hop entry for the AFT entry
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config>`
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the AFT next\-hop entry
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state parameters relating to the AFT next\-hop entry
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.State>`
                                
                                .. attribute:: interface_ref
                                
                                	Reference to an interface or subinterface
                                	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "next-hops"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['index']
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', YLeaf(YType.str, 'index')),
                                    ])
                                    self.index = None

                                    self.config = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.interface_ref = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"
                                    self._children_yang_names.add("interface-ref")
                                    self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop, ['index'], name, value)


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the AFT next\-hop
                                    entry
                                    
                                    .. attribute:: index
                                    
                                    	A unique entry for the next\-hop
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', YLeaf(YType.uint64, 'index')),
                                        ])
                                        self.index = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.Config, ['index'], name, value)


                                class State(Entity):
                                    """
                                    Operational state parameters relating to the AFT
                                    next\-hop entry
                                    
                                    .. attribute:: index
                                    
                                    	A unique entry for the next\-hop
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: weight
                                    
                                    	The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_address
                                    
                                    	The IP address of the next\-hop system
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mac_address
                                    
                                    	The MAC address of the next\-hop if resolved by the local network instance
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: popped_mpls_label_stack
                                    
                                    	The MPLS label stack to be popped from the packet when switched by the system. The stack is encoding as a leaf\-list whereby the other of the entries is such that the first entry is the label lowest down the label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 500, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: list of int
                                    
                                    			**range:** 16..1048575
                                    
                                    		**type**\: list of   :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                    
                                    .. attribute:: pushed_mpls_label_stack
                                    
                                    	The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: list of int
                                    
                                    			**range:** 16..1048575
                                    
                                    		**type**\: list of   :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                    
                                    .. attribute:: decapsulate_header
                                    
                                    	When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                    	**type**\:  :py:class:`EncapsulationHeaderType <ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                    
                                    .. attribute:: encapsulate_header
                                    
                                    	When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                    	**type**\:  :py:class:`EncapsulationHeaderType <ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                    
                                    .. attribute:: origin_protocol
                                    
                                    	The protocol from which the AFT entry was learned
                                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                    
                                    .. attribute:: network_instance
                                    
                                    	The network\-instance within which the next\-hop should be resolved. When this leaf is unspecified, the next\-hop is resolved within  the local instance
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', YLeaf(YType.uint64, 'index')),
                                            ('weight', YLeaf(YType.uint32, 'weight')),
                                            ('ip_address', YLeaf(YType.str, 'ip-address')),
                                            ('mac_address', YLeaf(YType.str, 'mac-address')),
                                            ('popped_mpls_label_stack', YLeafList(YType.str, 'popped-mpls-label-stack')),
                                            ('pushed_mpls_label_stack', YLeafList(YType.str, 'pushed-mpls-label-stack')),
                                            ('decapsulate_header', YLeaf(YType.enumeration, 'decapsulate-header')),
                                            ('encapsulate_header', YLeaf(YType.enumeration, 'encapsulate-header')),
                                            ('origin_protocol', YLeaf(YType.identityref, 'origin-protocol')),
                                            ('network_instance', YLeaf(YType.str, 'openconfig-aft-network-instance:network-instance')),
                                        ])
                                        self.index = None
                                        self.weight = None
                                        self.ip_address = None
                                        self.mac_address = None
                                        self.popped_mpls_label_stack = []
                                        self.pushed_mpls_label_stack = []
                                        self.decapsulate_header = None
                                        self.encapsulate_header = None
                                        self.origin_protocol = None
                                        self.network_instance = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol', 'network_instance'], name, value)


                                class InterfaceRef(Entity):
                                    """
                                    Reference to an interface or subinterface
                                    
                                    .. attribute:: config
                                    
                                    	Configured reference to interface / subinterface
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	Operational state for interface\-ref
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef, self).__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "interface-ref"


                                    class Config(Entity):
                                        """
                                        Configured reference to interface / subinterface
                                        
                                        .. attribute:: interface
                                        
                                        	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                        .. attribute:: subinterface
                                        
                                        	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', YLeaf(YType.str, 'interface')),
                                                ('subinterface', YLeaf(YType.str, 'subinterface')),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                    class State(Entity):
                                        """
                                        Operational state for interface\-ref
                                        
                                        .. attribute:: interface
                                        
                                        	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                        .. attribute:: subinterface
                                        
                                        	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', YLeaf(YType.str, 'interface')),
                                                ('subinterface', YLeaf(YType.str, 'subinterface')),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Aft.Entries.Entry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)


        class Protocols(Entity):
            """
            The routing protocols that are enabled for this
            network\-instance.
            
            .. attribute:: protocol
            
            	A process (instance) of a routing protocol. Some systems may not support more than one instance of a particular routing protocol
            	**type**\: list of  		 :py:class:`Protocol <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol>`
            
            

            """

            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super(NetworkInstances.NetworkInstance.Protocols, self).__init__()

                self.yang_name = "protocols"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_container_classes = OrderedDict([])
                self._child_list_classes = OrderedDict([("protocol", ("protocol", NetworkInstances.NetworkInstance.Protocols.Protocol))])
                self._leafs = OrderedDict()

                self.protocol = YList(self)
                self._segment_path = lambda: "protocols"

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols, [], name, value)


            class Protocol(Entity):
                """
                A process (instance) of a routing protocol. Some
                systems may not support more than one instance of
                a particular routing protocol
                
                .. attribute:: identifier  (key)
                
                	The protocol name for the routing or forwarding protocol to be instantiated
                	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: name  (key)
                
                	An operator\-assigned identifier for the routing or forwarding protocol. For some processes this leaf may be system defined
                	**type**\: str
                
                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Config>`
                
                .. attribute:: config
                
                	Configuration parameters relating to the routing protocol instance
                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Config>`
                
                .. attribute:: state
                
                	State parameters relating to the routing protocol instance
                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.State>`
                
                .. attribute:: static_routes
                
                	Enclosing container for the list of static routes
                	**type**\:  :py:class:`StaticRoutes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes>`
                
                .. attribute:: local_aggregates
                
                	Enclosing container for locally\-defined aggregate routes
                	**type**\:  :py:class:`LocalAggregates <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates>`
                
                .. attribute:: bgp
                
                	Top\-level configuration and state for the BGP router
                	**type**\:  :py:class:`Bgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp>`
                
                .. attribute:: isis
                
                	This container defines top\-level ISIS configuration and state information
                	**type**\:  :py:class:`Isis <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis>`
                
                

                """

                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super(NetworkInstances.NetworkInstance.Protocols.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "protocols"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['identifier','name']
                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.State)), ("static-routes", ("static_routes", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes)), ("local-aggregates", ("local_aggregates", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates)), ("bgp", ("bgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp)), ("isis", ("isis", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis))])
                    self._child_list_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('identifier', YLeaf(YType.identityref, 'identifier')),
                        ('name', YLeaf(YType.str, 'name')),
                    ])
                    self.identifier = None
                    self.name = None

                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"
                    self._children_yang_names.add("config")

                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._children_yang_names.add("state")

                    self.static_routes = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes()
                    self.static_routes.parent = self
                    self._children_name_map["static_routes"] = "static-routes"
                    self._children_yang_names.add("static-routes")

                    self.local_aggregates = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates()
                    self.local_aggregates.parent = self
                    self._children_name_map["local_aggregates"] = "local-aggregates"
                    self._children_yang_names.add("local-aggregates")

                    self.bgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "bgp"
                    self._children_yang_names.add("bgp")

                    self.isis = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"
                    self._children_yang_names.add("isis")
                    self._segment_path = lambda: "protocol" + "[identifier='" + str(self.identifier) + "']" + "[name='" + str(self.name) + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol, ['identifier', 'name'], name, value)


                class Config(Entity):
                    """
                    Configuration parameters relating to the routing
                    protocol instance
                    
                    .. attribute:: identifier
                    
                    	The protocol identifier for the instance
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: name
                    
                    	A unique name for the protocol instance
                    	**type**\: str
                    
                    .. attribute:: enabled
                    
                    	A boolean value indicating whether the local protocol instance is enabled
                    	**type**\: bool
                    
                    .. attribute:: default_metric
                    
                    	The default metric within the RIB for entries that are installed by this protocol instance. This value may be overridden by protocol specific configuration options. The lower the metric specified the more preferable the RIB entry is to be selected for use within the network instance. Where multiple entries have the same metric value then these equal cost paths should be treated according to the specified ECMP path selection behaviour for the instance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Config, self).__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('identifier', YLeaf(YType.identityref, 'identifier')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                            ('default_metric', YLeaf(YType.uint32, 'default-metric')),
                        ])
                        self.identifier = None
                        self.name = None
                        self.enabled = None
                        self.default_metric = None
                        self._segment_path = lambda: "config"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Config, ['identifier', 'name', 'enabled', 'default_metric'], name, value)


                class State(Entity):
                    """
                    State parameters relating to the routing protocol
                    instance
                    
                    .. attribute:: identifier
                    
                    	The protocol identifier for the instance
                    	**type**\:  :py:class:`INSTALLPROTOCOLTYPE <ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: name
                    
                    	A unique name for the protocol instance
                    	**type**\: str
                    
                    .. attribute:: enabled
                    
                    	A boolean value indicating whether the local protocol instance is enabled
                    	**type**\: bool
                    
                    .. attribute:: default_metric
                    
                    	The default metric within the RIB for entries that are installed by this protocol instance. This value may be overridden by protocol specific configuration options. The lower the metric specified the more preferable the RIB entry is to be selected for use within the network instance. Where multiple entries have the same metric value then these equal cost paths should be treated according to the specified ECMP path selection behaviour for the instance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.State, self).__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('identifier', YLeaf(YType.identityref, 'identifier')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                            ('default_metric', YLeaf(YType.uint32, 'default-metric')),
                        ])
                        self.identifier = None
                        self.name = None
                        self.enabled = None
                        self.default_metric = None
                        self._segment_path = lambda: "state"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.State, ['identifier', 'name', 'enabled', 'default_metric'], name, value)


                class StaticRoutes(Entity):
                    """
                    Enclosing container for the list of static routes
                    
                    .. attribute:: static
                    
                    	List of locally configured static routes
                    	**type**\: list of  		 :py:class:`Static <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes, self).__init__()

                        self.yang_name = "static-routes"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("static", ("static", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static))])
                        self._leafs = OrderedDict()

                        self.static = YList(self)
                        self._segment_path = lambda: "static-routes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes, [], name, value)


                    class Static(Entity):
                        """
                        List of locally configured static routes
                        
                        .. attribute:: prefix  (key)
                        
                        	Reference to the destination prefix list key
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config>`
                        
                        .. attribute:: config
                        
                        	Configuration data for static routes
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config>`
                        
                        .. attribute:: state
                        
                        	Operational state data for static routes
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State>`
                        
                        .. attribute:: next_hops
                        
                        	Configuration and state parameters relating to the next\-hops that are to be utilised for the static route being specified
                        	**type**\:  :py:class:`NextHops <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static, self).__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.prefix = None

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.next_hops = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops()
                            self.next_hops.parent = self
                            self._children_name_map["next_hops"] = "next-hops"
                            self._children_yang_names.add("next-hops")
                            self._segment_path = lambda: "static" + "[prefix='" + str(self.prefix) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static, ['prefix'], name, value)


                        class Config(Entity):
                            """
                            Configuration data for static routes
                            
                            .. attribute:: prefix
                            
                            	Destination prefix for the static route, either IPv4 or IPv6
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: set_tag
                            
                            	Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                    ('set_tag', YLeaf(YType.str, 'set-tag')),
                                ])
                                self.prefix = None
                                self.set_tag = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config, ['prefix', 'set_tag'], name, value)


                        class State(Entity):
                            """
                            Operational state data for static routes
                            
                            .. attribute:: prefix
                            
                            	Destination prefix for the static route, either IPv4 or IPv6
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: set_tag
                            
                            	Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                    ('set_tag', YLeaf(YType.str, 'set-tag')),
                                ])
                                self.prefix = None
                                self.set_tag = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State, ['prefix', 'set_tag'], name, value)


                        class NextHops(Entity):
                            """
                            Configuration and state parameters relating to the
                            next\-hops that are to be utilised for the static
                            route being specified
                            
                            .. attribute:: next_hop
                            
                            	A list of next\-hops to be utilised for the static route being specified
                            	**type**\: list of  		 :py:class:`NextHop <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops, self).__init__()

                                self.yang_name = "next-hops"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop))])
                                self._leafs = OrderedDict()

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "next-hops"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops, [], name, value)


                            class NextHop(Entity):
                                """
                                A list of next\-hops to be utilised for the static
                                route being specified.
                                
                                .. attribute:: index  (key)
                                
                                	A reference to the index of the current next\-hop. The index is intended to be a user\-specified value which can be used to reference the next\-hop in question, without any other semantics being assigned to it
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config>`
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the next\-hop entry
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state parameters relating to the next\-hop entry
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State>`
                                
                                .. attribute:: interface_ref
                                
                                	Reference to an interface or subinterface
                                	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "next-hops"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['index']
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', YLeaf(YType.str, 'index')),
                                    ])
                                    self.index = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.interface_ref = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"
                                    self._children_yang_names.add("interface-ref")
                                    self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop, ['index'], name, value)


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the next\-hop
                                    entry
                                    
                                    .. attribute:: index
                                    
                                    	An user\-specified identifier utilised to uniquely reference the next\-hop entry in the next\-hop list. The value of this index has no semantic meaning other than for referencing the entry
                                    	**type**\: str
                                    
                                    .. attribute:: next_hop
                                    
                                    	The next\-hop that is to be used for the static route \- this may be specified as an IP address, an interface or a pre\-defined next\-hop type \- for instance, DROP or LOCAL\_LINK. When this leaf is not set, and the interface\-ref value is specified for the next\-hop, then the system should treat the prefix as though it is directly connected to the interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\:  :py:class:`LOCALDEFINEDNEXTHOP <ydk.models.openconfig.openconfig_local_routing.LOCALDEFINEDNEXTHOP>`
                                    
                                    .. attribute:: metric
                                    
                                    	A metric which is utilised to specify the preference of the next\-hop entry when it is injected into the RIB. The lower the metric, the more preferable the prefix is. When this value is not specified the metric is inherited from the default metric utilised for static routes within the network instance that the static routes are being instantiated. When multiple next\-hops are specified for a static route, the metric is utilised to determine which of the next\-hops is to be installed in the RIB. When multiple next\-hops have the same metric (be it specified, or simply the default) then these next\-hops should all be installed in the RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recurse
                                    
                                    	Determines whether the next\-hop should be allowed to be looked up recursively \- i.e., via a RIB entry which has been installed by a routing protocol, or another static route \- rather than needing to be connected directly to an interface of the local system within the current network instance. When the interface reference specified within the next\-hop entry is set (i.e., is not null) then forwarding is restricted to being via the interface specified \- and recursion is hence disabled
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', YLeaf(YType.str, 'index')),
                                            ('next_hop', YLeaf(YType.str, 'next-hop')),
                                            ('metric', YLeaf(YType.uint32, 'metric')),
                                            ('recurse', YLeaf(YType.boolean, 'recurse')),
                                        ])
                                        self.index = None
                                        self.next_hop = None
                                        self.metric = None
                                        self.recurse = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config, ['index', 'next_hop', 'metric', 'recurse'], name, value)


                                class State(Entity):
                                    """
                                    Operational state parameters relating to the
                                    next\-hop entry
                                    
                                    .. attribute:: index
                                    
                                    	An user\-specified identifier utilised to uniquely reference the next\-hop entry in the next\-hop list. The value of this index has no semantic meaning other than for referencing the entry
                                    	**type**\: str
                                    
                                    .. attribute:: next_hop
                                    
                                    	The next\-hop that is to be used for the static route \- this may be specified as an IP address, an interface or a pre\-defined next\-hop type \- for instance, DROP or LOCAL\_LINK. When this leaf is not set, and the interface\-ref value is specified for the next\-hop, then the system should treat the prefix as though it is directly connected to the interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\:  :py:class:`LOCALDEFINEDNEXTHOP <ydk.models.openconfig.openconfig_local_routing.LOCALDEFINEDNEXTHOP>`
                                    
                                    .. attribute:: metric
                                    
                                    	A metric which is utilised to specify the preference of the next\-hop entry when it is injected into the RIB. The lower the metric, the more preferable the prefix is. When this value is not specified the metric is inherited from the default metric utilised for static routes within the network instance that the static routes are being instantiated. When multiple next\-hops are specified for a static route, the metric is utilised to determine which of the next\-hops is to be installed in the RIB. When multiple next\-hops have the same metric (be it specified, or simply the default) then these next\-hops should all be installed in the RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recurse
                                    
                                    	Determines whether the next\-hop should be allowed to be looked up recursively \- i.e., via a RIB entry which has been installed by a routing protocol, or another static route \- rather than needing to be connected directly to an interface of the local system within the current network instance. When the interface reference specified within the next\-hop entry is set (i.e., is not null) then forwarding is restricted to being via the interface specified \- and recursion is hence disabled
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', YLeaf(YType.str, 'index')),
                                            ('next_hop', YLeaf(YType.str, 'next-hop')),
                                            ('metric', YLeaf(YType.uint32, 'metric')),
                                            ('recurse', YLeaf(YType.boolean, 'recurse')),
                                        ])
                                        self.index = None
                                        self.next_hop = None
                                        self.metric = None
                                        self.recurse = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State, ['index', 'next_hop', 'metric', 'recurse'], name, value)


                                class InterfaceRef(Entity):
                                    """
                                    Reference to an interface or subinterface
                                    
                                    .. attribute:: config
                                    
                                    	Configured reference to interface / subinterface
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	Operational state for interface\-ref
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef, self).__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "interface-ref"


                                    class Config(Entity):
                                        """
                                        Configured reference to interface / subinterface
                                        
                                        .. attribute:: interface
                                        
                                        	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                        .. attribute:: subinterface
                                        
                                        	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', YLeaf(YType.str, 'interface')),
                                                ('subinterface', YLeaf(YType.str, 'subinterface')),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                    class State(Entity):
                                        """
                                        Operational state for interface\-ref
                                        
                                        .. attribute:: interface
                                        
                                        	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        	**type**\: str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                        .. attribute:: subinterface
                                        
                                        	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', YLeaf(YType.str, 'interface')),
                                                ('subinterface', YLeaf(YType.str, 'subinterface')),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)


                class LocalAggregates(Entity):
                    """
                    Enclosing container for locally\-defined aggregate
                    routes
                    
                    .. attribute:: aggregate
                    
                    	List of aggregates
                    	**type**\: list of  		 :py:class:`Aggregate <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates, self).__init__()

                        self.yang_name = "local-aggregates"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([])
                        self._child_list_classes = OrderedDict([("aggregate", ("aggregate", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate))])
                        self._leafs = OrderedDict()

                        self.aggregate = YList(self)
                        self._segment_path = lambda: "local-aggregates"

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates, [], name, value)


                    class Aggregate(Entity):
                        """
                        List of aggregates
                        
                        .. attribute:: prefix  (key)
                        
                        	Reference to the configured prefix for this aggregate
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config>`
                        
                        .. attribute:: config
                        
                        	Configuration data for aggregate advertisements
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config>`
                        
                        .. attribute:: state
                        
                        	Operational state data for aggregate advertisements
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate, self).__init__()

                            self.yang_name = "aggregate"
                            self.yang_parent_name = "local-aggregates"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.prefix = None

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")
                            self._segment_path = lambda: "aggregate" + "[prefix='" + str(self.prefix) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate, ['prefix'], name, value)


                        class Config(Entity):
                            """
                            Configuration data for aggregate advertisements
                            
                            .. attribute:: prefix
                            
                            	Aggregate prefix to be advertised
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: discard
                            
                            	When true, install the aggregate route with a discard next\-hop \-\- traffic destined to the aggregate will be discarded with no ICMP message generated.  When false, traffic destined to an aggregate address when no constituent routes are present will generate an ICMP unreachable message
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: set_tag
                            
                            	Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "aggregate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                    ('discard', YLeaf(YType.boolean, 'discard')),
                                    ('set_tag', YLeaf(YType.str, 'set-tag')),
                                ])
                                self.prefix = None
                                self.discard = None
                                self.set_tag = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config, ['prefix', 'discard', 'set_tag'], name, value)


                        class State(Entity):
                            """
                            Operational state data for aggregate
                            advertisements
                            
                            .. attribute:: prefix
                            
                            	Aggregate prefix to be advertised
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: discard
                            
                            	When true, install the aggregate route with a discard next\-hop \-\- traffic destined to the aggregate will be discarded with no ICMP message generated.  When false, traffic destined to an aggregate address when no constituent routes are present will generate an ICMP unreachable message
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: set_tag
                            
                            	Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            	**type**\: union of the below types:
                            
                            		**type**\: int
                            
                            			**range:** 0..4294967295
                            
                            		**type**\: str
                            
                            			**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "aggregate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                    ('discard', YLeaf(YType.boolean, 'discard')),
                                    ('set_tag', YLeaf(YType.str, 'set-tag')),
                                ])
                                self.prefix = None
                                self.discard = None
                                self.set_tag = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State, ['prefix', 'discard', 'set_tag'], name, value)


                class Bgp(Entity):
                    """
                    Top\-level configuration and state for the BGP router
                    
                    .. attribute:: global_
                    
                    	Global configuration for the BGP router
                    	**type**\:  :py:class:`Global <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global>`
                    
                    .. attribute:: neighbors
                    
                    	Configuration for BGP neighbors
                    	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors>`
                    
                    .. attribute:: peer_groups
                    
                    	Configuration for BGP peer\-groups
                    	**type**\:  :py:class:`PeerGroups <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp, self).__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global)), ("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors)), ("peer-groups", ("peer_groups", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups))])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict()

                        self.global_ = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"
                        self._children_yang_names.add("global")

                        self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.peer_groups = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups()
                        self.peer_groups.parent = self
                        self._children_name_map["peer_groups"] = "peer-groups"
                        self._children_yang_names.add("peer-groups")
                        self._segment_path = lambda: "bgp"


                    class Global(Entity):
                        """
                        Global configuration for the BGP router
                        
                        .. attribute:: config
                        
                        	Configuration parameters relating to the global BGP router
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config>`
                        
                        .. attribute:: state
                        
                        	State information relating to the global BGP router
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State>`
                        
                        .. attribute:: default_route_distance
                        
                        	Administrative distance (or preference) assigned to routes received from different sources (external, internal, and local)
                        	**type**\:  :py:class:`DefaultRouteDistance <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance>`
                        
                        .. attribute:: confederation
                        
                        	Parameters indicating whether the local system acts as part of a BGP confederation
                        	**type**\:  :py:class:`Confederation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation>`
                        
                        .. attribute:: graceful_restart
                        
                        	Parameters relating the graceful restart mechanism for BGP
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart>`
                        
                        .. attribute:: use_multiple_paths
                        
                        	Parameters related to the use of multiple paths for the same NLRI
                        	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths>`
                        
                        .. attribute:: route_selection_options
                        
                        	Parameters relating to options for route selection
                        	**type**\:  :py:class:`RouteSelectionOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions>`
                        
                        .. attribute:: afi_safis
                        
                        	Address family specific configuration
                        	**type**\:  :py:class:`AfiSafis <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis>`
                        
                        .. attribute:: apply_policy
                        
                        	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                        	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State)), ("default-route-distance", ("default_route_distance", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance)), ("confederation", ("confederation", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.default_route_distance = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance()
                            self.default_route_distance.parent = self
                            self._children_name_map["default_route_distance"] = "default-route-distance"
                            self._children_yang_names.add("default-route-distance")

                            self.confederation = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation()
                            self.confederation.parent = self
                            self._children_name_map["confederation"] = "confederation"
                            self._children_yang_names.add("confederation")

                            self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"
                            self._children_yang_names.add("graceful-restart")

                            self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths()
                            self.use_multiple_paths.parent = self
                            self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                            self._children_yang_names.add("use-multiple-paths")

                            self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions()
                            self.route_selection_options.parent = self
                            self._children_name_map["route_selection_options"] = "route-selection-options"
                            self._children_yang_names.add("route-selection-options")

                            self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis()
                            self.afi_safis.parent = self
                            self._children_name_map["afi_safis"] = "afi-safis"
                            self._children_yang_names.add("afi-safis")

                            self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy()
                            self.apply_policy.parent = self
                            self._children_name_map["apply_policy"] = "apply-policy"
                            self._children_yang_names.add("apply-policy")
                            self._segment_path = lambda: "global"


                        class Config(Entity):
                            """
                            Configuration parameters relating to the global BGP router
                            
                            .. attribute:: as_
                            
                            	Local autonomous system number of the router.  Uses the 32\-bit as\-number type from the model in RFC 6991
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**mandatory**\: True
                            
                            .. attribute:: router_id
                            
                            	Router id of the router \- an unsigned 32\-bit integer expressed in dotted quad notation
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_', YLeaf(YType.uint32, 'as')),
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                ])
                                self.as_ = None
                                self.router_id = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config, ['as_', 'router_id'], name, value)


                        class State(Entity):
                            """
                            State information relating to the global BGP router
                            
                            .. attribute:: as_
                            
                            	Local autonomous system number of the router.  Uses the 32\-bit as\-number type from the model in RFC 6991
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**mandatory**\: True
                            
                            .. attribute:: router_id
                            
                            	Router id of the router \- an unsigned 32\-bit integer expressed in dotted quad notation
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
                            
                            .. attribute:: total_paths
                            
                            	Total number of BGP paths within the context
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_prefixes
                            
                            	Total number of BGP prefixes received within the context
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_', YLeaf(YType.uint32, 'as')),
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('total_paths', YLeaf(YType.uint32, 'total-paths')),
                                    ('total_prefixes', YLeaf(YType.uint32, 'total-prefixes')),
                                ])
                                self.as_ = None
                                self.router_id = None
                                self.total_paths = None
                                self.total_prefixes = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State, ['as_', 'router_id', 'total_paths', 'total_prefixes'], name, value)


                        class DefaultRouteDistance(Entity):
                            """
                            Administrative distance (or preference) assigned to
                            routes received from different sources
                            (external, internal, and local).
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to the default route distance
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config>`
                            
                            .. attribute:: state
                            
                            	State information relating to the default route distance
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance, self).__init__()

                                self.yang_name = "default-route-distance"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "default-route-distance"


                            class Config(Entity):
                                """
                                Configuration parameters relating to the default route
                                distance
                                
                                .. attribute:: external_route_distance
                                
                                	Administrative distance for routes learned from external BGP (eBGP)
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: internal_route_distance
                                
                                	Administrative distance for routes learned from internal BGP (iBGP)
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "default-route-distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external_route_distance', YLeaf(YType.uint8, 'external-route-distance')),
                                        ('internal_route_distance', YLeaf(YType.uint8, 'internal-route-distance')),
                                    ])
                                    self.external_route_distance = None
                                    self.internal_route_distance = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config, ['external_route_distance', 'internal_route_distance'], name, value)


                            class State(Entity):
                                """
                                State information relating to the default route distance
                                
                                .. attribute:: external_route_distance
                                
                                	Administrative distance for routes learned from external BGP (eBGP)
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                .. attribute:: internal_route_distance
                                
                                	Administrative distance for routes learned from internal BGP (iBGP)
                                	**type**\: int
                                
                                	**range:** 1..255
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "default-route-distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external_route_distance', YLeaf(YType.uint8, 'external-route-distance')),
                                        ('internal_route_distance', YLeaf(YType.uint8, 'internal-route-distance')),
                                    ])
                                    self.external_route_distance = None
                                    self.internal_route_distance = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State, ['external_route_distance', 'internal_route_distance'], name, value)


                        class Confederation(Entity):
                            """
                            Parameters indicating whether the local system acts as part
                            of a BGP confederation
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to BGP confederations
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config>`
                            
                            .. attribute:: state
                            
                            	State information relating to the BGP confederations
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation, self).__init__()

                                self.yang_name = "confederation"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "confederation"


                            class Config(Entity):
                                """
                                Configuration parameters relating to BGP confederations
                                
                                .. attribute:: enabled
                                
                                	When this leaf is set to true it indicates that the local\-AS is part of a BGP confederation
                                	**type**\: bool
                                
                                .. attribute:: identifier
                                
                                	Confederation identifier for the autonomous system
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: member_as
                                
                                	Remote autonomous systems that are to be treated as part of the local confederation
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "confederation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('identifier', YLeaf(YType.uint32, 'identifier')),
                                        ('member_as', YLeafList(YType.uint32, 'member-as')),
                                    ])
                                    self.enabled = None
                                    self.identifier = None
                                    self.member_as = []
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config, ['enabled', 'identifier', 'member_as'], name, value)


                            class State(Entity):
                                """
                                State information relating to the BGP confederations
                                
                                .. attribute:: enabled
                                
                                	When this leaf is set to true it indicates that the local\-AS is part of a BGP confederation
                                	**type**\: bool
                                
                                .. attribute:: identifier
                                
                                	Confederation identifier for the autonomous system
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: member_as
                                
                                	Remote autonomous systems that are to be treated as part of the local confederation
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "confederation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('identifier', YLeaf(YType.uint32, 'identifier')),
                                        ('member_as', YLeafList(YType.uint32, 'member-as')),
                                    ])
                                    self.enabled = None
                                    self.identifier = None
                                    self.member_as = []
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State, ['enabled', 'identifier', 'member_as'], name, value)


                        class GracefulRestart(Entity):
                            """
                            Parameters relating the graceful restart mechanism for BGP
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to graceful\-restart
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config>`
                            
                            .. attribute:: state
                            
                            	State information associated with graceful\-restart
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "graceful-restart"


                            class Config(Entity):
                                """
                                Configuration parameters relating to graceful\-restart
                                
                                .. attribute:: enabled
                                
                                	Enable or disable the graceful\-restart capability
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                	**type**\: int
                                
                                	**range:** 0..4096
                                
                                .. attribute:: stale_routes_time
                                
                                	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                
                                	**range:** \-92233720368547758.08..92233720368547758.07
                                
                                .. attribute:: helper_only
                                
                                	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                        ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                        ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                    ])
                                    self.enabled = None
                                    self.restart_time = None
                                    self.stale_routes_time = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                            class State(Entity):
                                """
                                State information associated with graceful\-restart
                                
                                .. attribute:: enabled
                                
                                	Enable or disable the graceful\-restart capability
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                	**type**\: int
                                
                                	**range:** 0..4096
                                
                                .. attribute:: stale_routes_time
                                
                                	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                
                                	**range:** \-92233720368547758.08..92233720368547758.07
                                
                                .. attribute:: helper_only
                                
                                	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                        ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                        ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                    ])
                                    self.enabled = None
                                    self.restart_time = None
                                    self.stale_routes_time = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                        class UseMultiplePaths(Entity):
                            """
                            Parameters related to the use of multiple paths for the
                            same NLRI
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to multipath
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config>`
                            
                            .. attribute:: state
                            
                            	State parameters relating to multipath
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State>`
                            
                            .. attribute:: ebgp
                            
                            	Multipath parameters for eBGP
                            	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp>`
                            
                            .. attribute:: ibgp
                            
                            	Multipath parameters for iBGP
                            	**type**\:  :py:class:`Ibgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths, self).__init__()

                                self.yang_name = "use-multiple-paths"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp()
                                self.ebgp.parent = self
                                self._children_name_map["ebgp"] = "ebgp"
                                self._children_yang_names.add("ebgp")

                                self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp()
                                self.ibgp.parent = self
                                self._children_name_map["ibgp"] = "ibgp"
                                self._children_yang_names.add("ibgp")
                                self._segment_path = lambda: "use-multiple-paths"


                            class Config(Entity):
                                """
                                Configuration parameters relating to multipath
                                
                                .. attribute:: enabled
                                
                                	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config, ['enabled'], name, value)


                            class State(Entity):
                                """
                                State parameters relating to multipath
                                
                                .. attribute:: enabled
                                
                                	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State, ['enabled'], name, value)


                            class Ebgp(Entity):
                                """
                                Multipath parameters for eBGP
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to eBGP multipath
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to eBGP multipath
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp, self).__init__()

                                    self.yang_name = "ebgp"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "ebgp"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to eBGP multipath
                                    
                                    .. attribute:: allow_multiple_as
                                    
                                    	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                            ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                        ])
                                        self.allow_multiple_as = None
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to eBGP multipath
                                    
                                    .. attribute:: allow_multiple_as
                                    
                                    	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                            ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                        ])
                                        self.allow_multiple_as = None
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)


                            class Ibgp(Entity):
                                """
                                Multipath parameters for iBGP
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to iBGP multipath
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to iBGP multipath
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp, self).__init__()

                                    self.yang_name = "ibgp"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "ibgp"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to iBGP multipath
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ibgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                        ])
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to iBGP multipath
                                    
                                    .. attribute:: maximum_paths
                                    
                                    	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ibgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                        ])
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)


                        class RouteSelectionOptions(Entity):
                            """
                            Parameters relating to options for route selection
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to route selection options
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config>`
                            
                            .. attribute:: state
                            
                            	State information for the route selection options
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions, self).__init__()

                                self.yang_name = "route-selection-options"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "route-selection-options"


                            class Config(Entity):
                                """
                                Configuration parameters relating to route selection
                                options
                                
                                .. attribute:: always_compare_med
                                
                                	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: ignore_as_path_length
                                
                                	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: external_compare_router_id
                                
                                	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                .. attribute:: advertise_inactive_routes
                                
                                	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable_aigp
                                
                                	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: ignore_next_hop_igp_metric
                                
                                	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "route-selection-options"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                        ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                        ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                        ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                        ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                        ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                    ])
                                    self.always_compare_med = None
                                    self.ignore_as_path_length = None
                                    self.external_compare_router_id = None
                                    self.advertise_inactive_routes = None
                                    self.enable_aigp = None
                                    self.ignore_next_hop_igp_metric = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                            class State(Entity):
                                """
                                State information for the route selection options
                                
                                .. attribute:: always_compare_med
                                
                                	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: ignore_as_path_length
                                
                                	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: external_compare_router_id
                                
                                	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                .. attribute:: advertise_inactive_routes
                                
                                	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable_aigp
                                
                                	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: ignore_next_hop_igp_metric
                                
                                	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "route-selection-options"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                        ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                        ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                        ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                        ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                        ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                    ])
                                    self.always_compare_med = None
                                    self.ignore_as_path_length = None
                                    self.external_compare_router_id = None
                                    self.advertise_inactive_routes = None
                                    self.enable_aigp = None
                                    self.ignore_next_hop_igp_metric = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                        class AfiSafis(Entity):
                            """
                            Address family specific configuration
                            
                            .. attribute:: afi_safi
                            
                            	AFI,SAFI configuration available for the neighbour or group
                            	**type**\: list of  		 :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis, self).__init__()

                                self.yang_name = "afi-safis"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi))])
                                self._leafs = OrderedDict()

                                self.afi_safi = YList(self)
                                self._segment_path = lambda: "afi-safis"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis, [], name, value)


                            class AfiSafi(Entity):
                                """
                                AFI,SAFI configuration available for the
                                neighbour or group
                                
                                .. attribute:: afi_safi_name  (key)
                                
                                	Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                
                                .. attribute:: config
                                
                                	Configuration parameters for the AFI\-SAFI
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the AFI\-SAFI
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State>`
                                
                                .. attribute:: graceful_restart
                                
                                	Parameters relating to BGP graceful\-restart
                                	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart>`
                                
                                .. attribute:: route_selection_options
                                
                                	Parameters relating to options for route selection
                                	**type**\:  :py:class:`RouteSelectionOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions>`
                                
                                .. attribute:: use_multiple_paths
                                
                                	Parameters related to the use of multiple paths for the same NLRI
                                	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths>`
                                
                                .. attribute:: apply_policy
                                
                                	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                                	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy>`
                                
                                .. attribute:: ipv4_unicast
                                
                                	IPv4 unicast configuration options
                                	**type**\:  :py:class:`Ipv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast>`
                                
                                .. attribute:: ipv6_unicast
                                
                                	IPv6 unicast configuration options
                                	**type**\:  :py:class:`Ipv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast>`
                                
                                .. attribute:: ipv4_labeled_unicast
                                
                                	IPv4 Labeled Unicast configuration options
                                	**type**\:  :py:class:`Ipv4LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                
                                .. attribute:: ipv6_labeled_unicast
                                
                                	IPv6 Labeled Unicast configuration options
                                	**type**\:  :py:class:`Ipv6LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                
                                .. attribute:: l3vpn_ipv4_unicast
                                
                                	Unicast IPv4 L3VPN configuration options
                                	**type**\:  :py:class:`L3VpnIpv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast>`
                                
                                .. attribute:: l3vpn_ipv6_unicast
                                
                                	Unicast IPv6 L3VPN configuration options
                                	**type**\:  :py:class:`L3VpnIpv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast>`
                                
                                .. attribute:: l3vpn_ipv4_multicast
                                
                                	Multicast IPv4 L3VPN configuration options
                                	**type**\:  :py:class:`L3VpnIpv4Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast>`
                                
                                .. attribute:: l3vpn_ipv6_multicast
                                
                                	Multicast IPv6 L3VPN configuration options
                                	**type**\:  :py:class:`L3VpnIpv6Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast>`
                                
                                .. attribute:: l2vpn_vpls
                                
                                	BGP\-signalled VPLS configuration options
                                	**type**\:  :py:class:`L2VpnVpls <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls>`
                                
                                .. attribute:: l2vpn_evpn
                                
                                	BGP EVPN configuration options
                                	**type**\:  :py:class:`L2VpnEvpn <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi, self).__init__()

                                    self.yang_name = "afi-safi"
                                    self.yang_parent_name = "afi-safis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_safi_name']
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                    ])
                                    self.afi_safi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart()
                                    self.graceful_restart.parent = self
                                    self._children_name_map["graceful_restart"] = "graceful-restart"
                                    self._children_yang_names.add("graceful-restart")

                                    self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions()
                                    self.route_selection_options.parent = self
                                    self._children_name_map["route_selection_options"] = "route-selection-options"
                                    self._children_yang_names.add("route-selection-options")

                                    self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths()
                                    self.use_multiple_paths.parent = self
                                    self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                    self._children_yang_names.add("use-multiple-paths")

                                    self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy()
                                    self.apply_policy.parent = self
                                    self._children_name_map["apply_policy"] = "apply-policy"
                                    self._children_yang_names.add("apply-policy")

                                    self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast()
                                    self.ipv4_unicast.parent = self
                                    self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                                    self._children_yang_names.add("ipv4-unicast")

                                    self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast()
                                    self.ipv6_unicast.parent = self
                                    self._children_name_map["ipv6_unicast"] = "ipv6-unicast"
                                    self._children_yang_names.add("ipv6-unicast")

                                    self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                    self.ipv4_labeled_unicast.parent = self
                                    self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"
                                    self._children_yang_names.add("ipv4-labeled-unicast")

                                    self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                    self.ipv6_labeled_unicast.parent = self
                                    self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"
                                    self._children_yang_names.add("ipv6-labeled-unicast")

                                    self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast()
                                    self.l3vpn_ipv4_unicast.parent = self
                                    self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"
                                    self._children_yang_names.add("l3vpn-ipv4-unicast")

                                    self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast()
                                    self.l3vpn_ipv6_unicast.parent = self
                                    self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"
                                    self._children_yang_names.add("l3vpn-ipv6-unicast")

                                    self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast()
                                    self.l3vpn_ipv4_multicast.parent = self
                                    self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"
                                    self._children_yang_names.add("l3vpn-ipv4-multicast")

                                    self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast()
                                    self.l3vpn_ipv6_multicast.parent = self
                                    self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"
                                    self._children_yang_names.add("l3vpn-ipv6-multicast")

                                    self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls()
                                    self.l2vpn_vpls.parent = self
                                    self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                                    self._children_yang_names.add("l2vpn-vpls")

                                    self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn()
                                    self.l2vpn_evpn.parent = self
                                    self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"
                                    self._children_yang_names.add("l2vpn-evpn")
                                    self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)


                                class Config(Entity):
                                    """
                                    Configuration parameters for the AFI\-SAFI
                                    
                                    .. attribute:: afi_safi_name
                                    
                                    	AFI,SAFI
                                    	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: enabled
                                    
                                    	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.afi_safi_name = None
                                        self.enabled = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the AFI\-SAFI
                                    
                                    .. attribute:: afi_safi_name
                                    
                                    	AFI,SAFI
                                    	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: enabled
                                    
                                    	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: total_paths
                                    
                                    	Total number of BGP paths within the context
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_prefixes
                                    
                                    	Total number of BGP prefixes received within the context
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('total_paths', YLeaf(YType.uint32, 'total-paths')),
                                            ('total_prefixes', YLeaf(YType.uint32, 'total-prefixes')),
                                        ])
                                        self.afi_safi_name = None
                                        self.enabled = None
                                        self.total_paths = None
                                        self.total_prefixes = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled', 'total_paths', 'total_prefixes'], name, value)


                                class GracefulRestart(Entity):
                                    """
                                    Parameters relating to BGP graceful\-restart
                                    
                                    .. attribute:: config
                                    
                                    	Configuration options for BGP graceful\-restart
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information for BGP graceful\-restart
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart, self).__init__()

                                        self.yang_name = "graceful-restart"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "graceful-restart"


                                    class Config(Entity):
                                        """
                                        Configuration options for BGP graceful\-restart
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "graceful-restart"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                    class State(Entity):
                                        """
                                        State information for BGP graceful\-restart
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "graceful-restart"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled'], name, value)


                                class RouteSelectionOptions(Entity):
                                    """
                                    Parameters relating to options for route selection
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters relating to route selection options
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information for the route selection options
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions, self).__init__()

                                        self.yang_name = "route-selection-options"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "route-selection-options"


                                    class Config(Entity):
                                        """
                                        Configuration parameters relating to route selection
                                        options
                                        
                                        .. attribute:: always_compare_med
                                        
                                        	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: ignore_as_path_length
                                        
                                        	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: external_compare_router_id
                                        
                                        	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                        	**type**\: bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: advertise_inactive_routes
                                        
                                        	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: enable_aigp
                                        
                                        	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: ignore_next_hop_igp_metric
                                        
                                        	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "route-selection-options"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                                ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                                ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                                ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                                ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                                ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                            ])
                                            self.always_compare_med = None
                                            self.ignore_as_path_length = None
                                            self.external_compare_router_id = None
                                            self.advertise_inactive_routes = None
                                            self.enable_aigp = None
                                            self.ignore_next_hop_igp_metric = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                    class State(Entity):
                                        """
                                        State information for the route selection options
                                        
                                        .. attribute:: always_compare_med
                                        
                                        	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: ignore_as_path_length
                                        
                                        	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: external_compare_router_id
                                        
                                        	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                        	**type**\: bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: advertise_inactive_routes
                                        
                                        	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: enable_aigp
                                        
                                        	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: ignore_next_hop_igp_metric
                                        
                                        	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "route-selection-options"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                                ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                                ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                                ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                                ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                                ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                            ])
                                            self.always_compare_med = None
                                            self.ignore_as_path_length = None
                                            self.external_compare_router_id = None
                                            self.advertise_inactive_routes = None
                                            self.enable_aigp = None
                                            self.ignore_next_hop_igp_metric = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                class UseMultiplePaths(Entity):
                                    """
                                    Parameters related to the use of multiple paths for the
                                    same NLRI
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters relating to multipath
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State parameters relating to multipath
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                    
                                    .. attribute:: ebgp
                                    
                                    	Multipath parameters for eBGP
                                    	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                    
                                    .. attribute:: ibgp
                                    
                                    	Multipath parameters for iBGP
                                    	**type**\:  :py:class:`Ibgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths, self).__init__()

                                        self.yang_name = "use-multiple-paths"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")

                                        self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                        self.ebgp.parent = self
                                        self._children_name_map["ebgp"] = "ebgp"
                                        self._children_yang_names.add("ebgp")

                                        self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"
                                        self._children_yang_names.add("ibgp")
                                        self._segment_path = lambda: "use-multiple-paths"


                                    class Config(Entity):
                                        """
                                        Configuration parameters relating to multipath
                                        
                                        .. attribute:: enabled
                                        
                                        	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                    class State(Entity):
                                        """
                                        State parameters relating to multipath
                                        
                                        .. attribute:: enabled
                                        
                                        	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                    class Ebgp(Entity):
                                        """
                                        Multipath parameters for eBGP
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to eBGP multipath
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to eBGP multipath
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, self).__init__()

                                            self.yang_name = "ebgp"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ebgp"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to eBGP multipath
                                            
                                            .. attribute:: allow_multiple_as
                                            
                                            	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: maximum_paths
                                            
                                            	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 1
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ebgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                    ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                ])
                                                self.allow_multiple_as = None
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to eBGP multipath
                                            
                                            .. attribute:: allow_multiple_as
                                            
                                            	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: maximum_paths
                                            
                                            	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 1
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ebgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                    ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                ])
                                                self.allow_multiple_as = None
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        Multipath parameters for iBGP
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to iBGP multipath
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to iBGP multipath
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ibgp"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to iBGP multipath
                                            
                                            .. attribute:: maximum_paths
                                            
                                            	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 1
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ibgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                ])
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to iBGP multipath
                                            
                                            .. attribute:: maximum_paths
                                            
                                            	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 1
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ibgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                ])
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)


                                class ApplyPolicy(Entity):
                                    """
                                    Anchor point for routing policies in the model.
                                    Import and export policies are with respect to the local
                                    routing table, i.e., export (send) and import (receive),
                                    depending on the context.
                                    
                                    .. attribute:: config
                                    
                                    	Policy configuration data
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	Operational state for routing policy
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy, self).__init__()

                                        self.yang_name = "apply-policy"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "apply-policy"


                                    class Config(Entity):
                                        """
                                        Policy configuration data.
                                        
                                        .. attribute:: import_policy
                                        
                                        	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                        	**type**\: list of str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                        
                                        .. attribute:: default_import_policy
                                        
                                        	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                        	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                        
                                        	**default value**\: REJECT_ROUTE
                                        
                                        .. attribute:: export_policy
                                        
                                        	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                        	**type**\: list of str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                        
                                        .. attribute:: default_export_policy
                                        
                                        	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                        	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                        
                                        	**default value**\: REJECT_ROUTE
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "apply-policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                            ])
                                            self.import_policy = []
                                            self.default_import_policy = None
                                            self.export_policy = []
                                            self.default_export_policy = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                    class State(Entity):
                                        """
                                        Operational state for routing policy
                                        
                                        .. attribute:: import_policy
                                        
                                        	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                        	**type**\: list of str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                        
                                        .. attribute:: default_import_policy
                                        
                                        	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                        	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                        
                                        	**default value**\: REJECT_ROUTE
                                        
                                        .. attribute:: export_policy
                                        
                                        	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                        	**type**\: list of str
                                        
                                        	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                        
                                        .. attribute:: default_export_policy
                                        
                                        	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                        	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                        
                                        	**default value**\: REJECT_ROUTE
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "apply-policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                            ])
                                            self.import_policy = []
                                            self.default_import_policy = None
                                            self.export_policy = []
                                            self.default_export_policy = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                class Ipv4Unicast(Entity):
                                    """
                                    IPv4 unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information for common IPv4 and IPv6 unicast parameters
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast, self).__init__()

                                        self.yang_name = "ipv4-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "ipv4-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class Config(Entity):
                                        """
                                        Configuration parameters for common IPv4 and IPv6 unicast
                                        AFI\-SAFI options
                                        
                                        .. attribute:: send_default_route
                                        
                                        	If set to true, send the default\-route to the neighbour(s)
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                    class State(Entity):
                                        """
                                        State information for common IPv4 and IPv6 unicast
                                        parameters
                                        
                                        .. attribute:: send_default_route
                                        
                                        	If set to true, send the default\-route to the neighbour(s)
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)


                                class Ipv6Unicast(Entity):
                                    """
                                    IPv6 unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information for common IPv4 and IPv6 unicast parameters
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast, self).__init__()

                                        self.yang_name = "ipv6-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "ipv6-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class Config(Entity):
                                        """
                                        Configuration parameters for common IPv4 and IPv6 unicast
                                        AFI\-SAFI options
                                        
                                        .. attribute:: send_default_route
                                        
                                        	If set to true, send the default\-route to the neighbour(s)
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                    class State(Entity):
                                        """
                                        State information for common IPv4 and IPv6 unicast
                                        parameters
                                        
                                        .. attribute:: send_default_route
                                        
                                        	If set to true, send the default\-route to the neighbour(s)
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)


                                class Ipv4LabeledUnicast(Entity):
                                    """
                                    IPv4 Labeled Unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast, self).__init__()

                                        self.yang_name = "ipv4-labeled-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "ipv4-labeled-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv4-labeled-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class Ipv6LabeledUnicast(Entity):
                                    """
                                    IPv6 Labeled Unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast, self).__init__()

                                        self.yang_name = "ipv6-labeled-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "ipv6-labeled-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv6-labeled-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L3VpnIpv4Unicast(Entity):
                                    """
                                    Unicast IPv4 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast, self).__init__()

                                        self.yang_name = "l3vpn-ipv4-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l3vpn-ipv4-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L3VpnIpv6Unicast(Entity):
                                    """
                                    Unicast IPv6 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast, self).__init__()

                                        self.yang_name = "l3vpn-ipv6-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l3vpn-ipv6-unicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L3VpnIpv4Multicast(Entity):
                                    """
                                    Multicast IPv4 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast, self).__init__()

                                        self.yang_name = "l3vpn-ipv4-multicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l3vpn-ipv4-multicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv4-multicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L3VpnIpv6Multicast(Entity):
                                    """
                                    Multicast IPv6 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast, self).__init__()

                                        self.yang_name = "l3vpn-ipv6-multicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l3vpn-ipv6-multicast"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv6-multicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L2VpnVpls(Entity):
                                    """
                                    BGP\-signalled VPLS configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls, self).__init__()

                                        self.yang_name = "l2vpn-vpls"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l2vpn-vpls"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                class L2VpnEvpn(Entity):
                                    """
                                    BGP EVPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                    	Configure the maximum number of prefixes that will be accepted from a peer
                                    	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn, self).__init__()

                                        self.yang_name = "l2vpn-evpn"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._children_yang_names.add("prefix-limit")
                                        self._segment_path = lambda: "l2vpn-evpn"


                                    class PrefixLimit(Entity):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information relating to the prefix\-limit for the AFI\-SAFI
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit, self).__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "prefix-limit"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(Entity):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                            	Maximum number of prefixes that will be accepted from the neighbour
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                            	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                            	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                            	**range:** \-92233720368547758.08..92233720368547758.07
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                    ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                    ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                ])
                                                self.max_prefixes = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                        class ApplyPolicy(Entity):
                            """
                            Anchor point for routing policies in the model.
                            Import and export policies are with respect to the local
                            routing table, i.e., export (send) and import (receive),
                            depending on the context.
                            
                            .. attribute:: config
                            
                            	Policy configuration data
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.Config>`
                            
                            .. attribute:: state
                            
                            	Operational state for routing policy
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy, self).__init__()

                                self.yang_name = "apply-policy"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "apply-policy"


                            class Config(Entity):
                                """
                                Policy configuration data.
                                
                                .. attribute:: import_policy
                                
                                	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                	**type**\: list of str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                
                                .. attribute:: default_import_policy
                                
                                	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                
                                	**default value**\: REJECT_ROUTE
                                
                                .. attribute:: export_policy
                                
                                	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                	**type**\: list of str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                
                                .. attribute:: default_export_policy
                                
                                	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                
                                	**default value**\: REJECT_ROUTE
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "apply-policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('import_policy', YLeafList(YType.str, 'import-policy')),
                                        ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ('export_policy', YLeafList(YType.str, 'export-policy')),
                                        ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                    ])
                                    self.import_policy = []
                                    self.default_import_policy = None
                                    self.export_policy = []
                                    self.default_export_policy = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                            class State(Entity):
                                """
                                Operational state for routing policy
                                
                                .. attribute:: import_policy
                                
                                	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                	**type**\: list of str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                
                                .. attribute:: default_import_policy
                                
                                	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                
                                	**default value**\: REJECT_ROUTE
                                
                                .. attribute:: export_policy
                                
                                	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                	**type**\: list of str
                                
                                	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                
                                .. attribute:: default_export_policy
                                
                                	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                
                                	**default value**\: REJECT_ROUTE
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "apply-policy"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('import_policy', YLeafList(YType.str, 'import-policy')),
                                        ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ('export_policy', YLeafList(YType.str, 'export-policy')),
                                        ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                    ])
                                    self.import_policy = []
                                    self.default_import_policy = None
                                    self.export_policy = []
                                    self.default_export_policy = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                    class Neighbors(Entity):
                        """
                        Configuration for BGP neighbors
                        
                        .. attribute:: neighbor
                        
                        	List of BGP neighbors configured on the local system, uniquely identified by peer IPv[46] address
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            List of BGP neighbors configured on the local system,
                            uniquely identified by peer IPv[46] address
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Reference to the address of the BGP neighbor used as a key in the neighbor list
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            	**refers to**\:  :py:class:`neighbor_address <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config>`
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to the BGP neighbor or group
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config>`
                            
                            .. attribute:: state
                            
                            	State information relating to the BGP neighbor
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State>`
                            
                            .. attribute:: timers
                            
                            	Timers related to a BGP neighbor
                            	**type**\:  :py:class:`Timers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers>`
                            
                            .. attribute:: transport
                            
                            	Transport session parameters for the BGP neighbor
                            	**type**\:  :py:class:`Transport <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport>`
                            
                            .. attribute:: error_handling
                            
                            	Error handling parameters used for the BGP neighbor or group
                            	**type**\:  :py:class:`ErrorHandling <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling>`
                            
                            .. attribute:: graceful_restart
                            
                            	Parameters relating the graceful restart mechanism for BGP
                            	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart>`
                            
                            .. attribute:: logging_options
                            
                            	Logging options for events related to the BGP neighbor or group
                            	**type**\:  :py:class:`LoggingOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions>`
                            
                            .. attribute:: ebgp_multihop
                            
                            	eBGP multi\-hop parameters for the BGPgroup
                            	**type**\:  :py:class:`EbgpMultihop <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop>`
                            
                            .. attribute:: route_reflector
                            
                            	Route reflector parameters for the BGPgroup
                            	**type**\:  :py:class:`RouteReflector <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector>`
                            
                            .. attribute:: as_path_options
                            
                            	AS\_PATH manipulation parameters for the BGP neighbor or group
                            	**type**\:  :py:class:`AsPathOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions>`
                            
                            .. attribute:: add_paths
                            
                            	Parameters relating to the advertisement and receipt of multiple paths for a single NLRI (add\-paths)
                            	**type**\:  :py:class:`AddPaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths>`
                            
                            .. attribute:: use_multiple_paths
                            
                            	Parameters related to the use of multiple\-paths for the same NLRI when they are received only from this neighbor
                            	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths>`
                            
                            .. attribute:: apply_policy
                            
                            	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                            	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy>`
                            
                            .. attribute:: afi_safis
                            
                            	Per\-address\-family configuration parameters associated with the neighbor
                            	**type**\:  :py:class:`AfiSafis <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport)), ("error-handling", ("error_handling", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart)), ("logging-options", ("logging_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions)), ("ebgp-multihop", ("ebgp_multihop", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop)), ("route-reflector", ("route_reflector", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector)), ("as-path-options", ("as_path_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions)), ("add-paths", ("add_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', YLeaf(YType.str, 'neighbor-address')),
                                ])
                                self.neighbor_address = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._children_yang_names.add("timers")

                                self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._children_yang_names.add("transport")

                                self.error_handling = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling()
                                self.error_handling.parent = self
                                self._children_name_map["error_handling"] = "error-handling"
                                self._children_yang_names.add("error-handling")

                                self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart()
                                self.graceful_restart.parent = self
                                self._children_name_map["graceful_restart"] = "graceful-restart"
                                self._children_yang_names.add("graceful-restart")

                                self.logging_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions()
                                self.logging_options.parent = self
                                self._children_name_map["logging_options"] = "logging-options"
                                self._children_yang_names.add("logging-options")

                                self.ebgp_multihop = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop()
                                self.ebgp_multihop.parent = self
                                self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                self._children_yang_names.add("ebgp-multihop")

                                self.route_reflector = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector()
                                self.route_reflector.parent = self
                                self._children_name_map["route_reflector"] = "route-reflector"
                                self._children_yang_names.add("route-reflector")

                                self.as_path_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions()
                                self.as_path_options.parent = self
                                self._children_name_map["as_path_options"] = "as-path-options"
                                self._children_yang_names.add("as-path-options")

                                self.add_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths()
                                self.add_paths.parent = self
                                self._children_name_map["add_paths"] = "add-paths"
                                self._children_yang_names.add("add-paths")

                                self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths()
                                self.use_multiple_paths.parent = self
                                self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                self._children_yang_names.add("use-multiple-paths")

                                self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy()
                                self.apply_policy.parent = self
                                self._children_name_map["apply_policy"] = "apply-policy"
                                self._children_yang_names.add("apply-policy")

                                self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis()
                                self.afi_safis.parent = self
                                self._children_name_map["afi_safis"] = "afi-safis"
                                self._children_yang_names.add("afi-safis")
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor, ['neighbor_address'], name, value)


                            class Config(Entity):
                                """
                                Configuration parameters relating to the BGP neighbor or
                                group
                                
                                .. attribute:: peer_group
                                
                                	The peer\-group with which this neighbor is associated
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`peer_group_name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                                
                                .. attribute:: neighbor_address
                                
                                	Address of the BGP peer, either in IPv4 or IPv6
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: enabled
                                
                                	Whether the BGP peer is enabled. In cases where the enabled leaf is set to false, the local system should not initiate connections to the neighbor, and should not respond to TCP connections attempts from the neighbor. If the state of the BGP session is ESTABLISHED at the time that this leaf is set to false, the BGP session should be ceased
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                .. attribute:: peer_as
                                
                                	AS number of the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                	The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                	Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                	**type**\:  :py:class:`PeerType <ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                	Configures an MD5 authentication password for use with neighboring devices
                                	**type**\: str
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                	**type**\:  :py:class:`REMOVEPRIVATEASOPTION <ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                	Enable route flap damping
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: send_community
                                
                                	Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                	**type**\:  :py:class:`CommunityType <ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                	**default value**\: NONE
                                
                                .. attribute:: description
                                
                                	An optional textual description (intended primarily for use with a peer or group
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group', YLeaf(YType.str, 'peer-group')),
                                        ('neighbor_address', YLeaf(YType.str, 'neighbor-address')),
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('peer_as', YLeaf(YType.uint32, 'peer-as')),
                                        ('local_as', YLeaf(YType.uint32, 'local-as')),
                                        ('peer_type', YLeaf(YType.enumeration, 'peer-type')),
                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                        ('remove_private_as', YLeaf(YType.identityref, 'remove-private-as')),
                                        ('route_flap_damping', YLeaf(YType.boolean, 'route-flap-damping')),
                                        ('send_community', YLeaf(YType.enumeration, 'send-community')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.peer_group = None
                                    self.neighbor_address = None
                                    self.enabled = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config, ['peer_group', 'neighbor_address', 'enabled', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description'], name, value)


                            class State(Entity):
                                """
                                State information relating to the BGP neighbor
                                
                                .. attribute:: peer_group
                                
                                	The peer\-group with which this neighbor is associated
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`peer_group_name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                                
                                .. attribute:: neighbor_address
                                
                                	Address of the BGP peer, either in IPv4 or IPv6
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: enabled
                                
                                	Whether the BGP peer is enabled. In cases where the enabled leaf is set to false, the local system should not initiate connections to the neighbor, and should not respond to TCP connections attempts from the neighbor. If the state of the BGP session is ESTABLISHED at the time that this leaf is set to false, the BGP session should be ceased
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                .. attribute:: peer_as
                                
                                	AS number of the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                	The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                	Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                	**type**\:  :py:class:`PeerType <ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                	Configures an MD5 authentication password for use with neighboring devices
                                	**type**\: str
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                	**type**\:  :py:class:`REMOVEPRIVATEASOPTION <ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                	Enable route flap damping
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: send_community
                                
                                	Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                	**type**\:  :py:class:`CommunityType <ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                	**default value**\: NONE
                                
                                .. attribute:: description
                                
                                	An optional textual description (intended primarily for use with a peer or group
                                	**type**\: str
                                
                                .. attribute:: session_state
                                
                                	Operational state of the BGP peer
                                	**type**\:  :py:class:`SessionState <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.SessionState>`
                                
                                .. attribute:: last_established
                                
                                	This timestamp indicates the time that the BGP session last transitioned in or out of the Established state.  The value is the timestamp in seconds relative to the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC). The BGP session uptime can be computed by clients as the difference between this value and the current time in UTC (assuming the session is in the ESTABLISHED state, per the session\-state leaf)
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: established_transitions
                                
                                	Number of transitions to the Established state for the neighbor session.  This value is analogous to the bgpPeerFsmEstablishedTransitions object from the standard BGP\-4 MIB
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: supported_capabilities
                                
                                	BGP capabilities negotiated as supported with the peer
                                	**type**\: list of   :py:class:`BGPCAPABILITY <ydk.models.openconfig.openconfig_bgp_types.BGPCAPABILITY>`
                                
                                .. attribute:: messages
                                
                                	Counters for BGP messages sent and received from the neighbor
                                	**type**\:  :py:class:`Messages <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages>`
                                
                                .. attribute:: queues
                                
                                	Counters related to queued messages associated with the BGP neighbor
                                	**type**\:  :py:class:`Queues <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("messages", ("messages", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages)), ("queues", ("queues", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group', YLeaf(YType.str, 'peer-group')),
                                        ('neighbor_address', YLeaf(YType.str, 'neighbor-address')),
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('peer_as', YLeaf(YType.uint32, 'peer-as')),
                                        ('local_as', YLeaf(YType.uint32, 'local-as')),
                                        ('peer_type', YLeaf(YType.enumeration, 'peer-type')),
                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                        ('remove_private_as', YLeaf(YType.identityref, 'remove-private-as')),
                                        ('route_flap_damping', YLeaf(YType.boolean, 'route-flap-damping')),
                                        ('send_community', YLeaf(YType.enumeration, 'send-community')),
                                        ('description', YLeaf(YType.str, 'description')),
                                        ('session_state', YLeaf(YType.enumeration, 'session-state')),
                                        ('last_established', YLeaf(YType.uint64, 'last-established')),
                                        ('established_transitions', YLeaf(YType.uint64, 'established-transitions')),
                                        ('supported_capabilities', YLeafList(YType.identityref, 'supported-capabilities')),
                                    ])
                                    self.peer_group = None
                                    self.neighbor_address = None
                                    self.enabled = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self.session_state = None
                                    self.last_established = None
                                    self.established_transitions = None
                                    self.supported_capabilities = []

                                    self.messages = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages()
                                    self.messages.parent = self
                                    self._children_name_map["messages"] = "messages"
                                    self._children_yang_names.add("messages")

                                    self.queues = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues()
                                    self.queues.parent = self
                                    self._children_name_map["queues"] = "queues"
                                    self._children_yang_names.add("queues")
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State, ['peer_group', 'neighbor_address', 'enabled', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description', 'session_state', 'last_established', 'established_transitions', 'supported_capabilities'], name, value)

                                class SessionState(Enum):
                                    """
                                    SessionState (Enum Class)

                                    Operational state of the BGP peer

                                    .. data:: IDLE = 0

                                    	neighbor is down, and in the Idle state of the

                                    	FSM

                                    .. data:: CONNECT = 1

                                    	neighbor is down, and the session is waiting for

                                    	the underlying transport session to be established

                                    .. data:: ACTIVE = 2

                                    	neighbor is down, and the local system is awaiting

                                    	a conncetion from the remote peer

                                    .. data:: OPENSENT = 3

                                    	neighbor is in the process of being established.

                                    	The local system has sent an OPEN message

                                    .. data:: OPENCONFIRM = 4

                                    	neighbor is in the process of being established.

                                    	The local system is awaiting a NOTIFICATION or

                                    	KEEPALIVE message

                                    .. data:: ESTABLISHED = 5

                                    	neighbor is up - the BGP session with the peer is

                                    	established

                                    """

                                    IDLE = Enum.YLeaf(0, "IDLE")

                                    CONNECT = Enum.YLeaf(1, "CONNECT")

                                    ACTIVE = Enum.YLeaf(2, "ACTIVE")

                                    OPENSENT = Enum.YLeaf(3, "OPENSENT")

                                    OPENCONFIRM = Enum.YLeaf(4, "OPENCONFIRM")

                                    ESTABLISHED = Enum.YLeaf(5, "ESTABLISHED")



                                class Messages(Entity):
                                    """
                                    Counters for BGP messages sent and received from the
                                    neighbor
                                    
                                    .. attribute:: sent
                                    
                                    	Counters relating to BGP messages sent to the neighbor
                                    	**type**\:  :py:class:`Sent <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent>`
                                    
                                    .. attribute:: received
                                    
                                    	Counters for BGP messages received from the neighbor
                                    	**type**\:  :py:class:`Received <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages, self).__init__()

                                        self.yang_name = "messages"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("sent", ("sent", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent)), ("received", ("received", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.sent = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent()
                                        self.sent.parent = self
                                        self._children_name_map["sent"] = "sent"
                                        self._children_yang_names.add("sent")

                                        self.received = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received()
                                        self.received.parent = self
                                        self._children_name_map["received"] = "received"
                                        self._children_yang_names.add("received")
                                        self._segment_path = lambda: "messages"


                                    class Sent(Entity):
                                        """
                                        Counters relating to BGP messages sent to the neighbor
                                        
                                        .. attribute:: update
                                        
                                        	Number of BGP UPDATE messages announcing, withdrawing or modifying paths exchanged
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: notification
                                        
                                        	Number of BGP NOTIFICATION messages indicating an error condition has occurred exchanged
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent, self).__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "messages"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update', YLeaf(YType.uint64, 'UPDATE')),
                                                ('notification', YLeaf(YType.uint64, 'NOTIFICATION')),
                                            ])
                                            self.update = None
                                            self.notification = None
                                            self._segment_path = lambda: "sent"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent, ['update', 'notification'], name, value)


                                    class Received(Entity):
                                        """
                                        Counters for BGP messages received from the neighbor
                                        
                                        .. attribute:: update
                                        
                                        	Number of BGP UPDATE messages announcing, withdrawing or modifying paths exchanged
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: notification
                                        
                                        	Number of BGP NOTIFICATION messages indicating an error condition has occurred exchanged
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received, self).__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "messages"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update', YLeaf(YType.uint64, 'UPDATE')),
                                                ('notification', YLeaf(YType.uint64, 'NOTIFICATION')),
                                            ])
                                            self.update = None
                                            self.notification = None
                                            self._segment_path = lambda: "received"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received, ['update', 'notification'], name, value)


                                class Queues(Entity):
                                    """
                                    Counters related to queued messages associated with the
                                    BGP neighbor
                                    
                                    .. attribute:: input
                                    
                                    	The number of messages received from the peer currently queued
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: output
                                    
                                    	The number of messages queued to be sent to the peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues, self).__init__()

                                        self.yang_name = "queues"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', YLeaf(YType.uint32, 'input')),
                                            ('output', YLeaf(YType.uint32, 'output')),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "queues"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues, ['input', 'output'], name, value)


                            class Timers(Entity):
                                """
                                Timers related to a BGP neighbor
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to timers used for the BGP neighbor
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the timers used for the BGP neighbor
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "timers"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to timers used for the
                                    BGP neighbor
                                    
                                    .. attribute:: connect_retry
                                    
                                    	Time interval in seconds between attempts to establish a session with the peer
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: hold_time
                                    
                                    	Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', YLeaf(YType.str, 'connect-retry')),
                                            ('hold_time', YLeaf(YType.str, 'hold-time')),
                                            ('keepalive_interval', YLeaf(YType.str, 'keepalive-interval')),
                                            ('minimum_advertisement_interval', YLeaf(YType.str, 'minimum-advertisement-interval')),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the timers used for the BGP
                                    neighbor
                                    
                                    .. attribute:: connect_retry
                                    
                                    	Time interval in seconds between attempts to establish a session with the peer
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: hold_time
                                    
                                    	Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: negotiated_hold_time
                                    
                                    	The negotiated hold\-time for the BGP session
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', YLeaf(YType.str, 'connect-retry')),
                                            ('hold_time', YLeaf(YType.str, 'hold-time')),
                                            ('keepalive_interval', YLeaf(YType.str, 'keepalive-interval')),
                                            ('minimum_advertisement_interval', YLeaf(YType.str, 'minimum-advertisement-interval')),
                                            ('negotiated_hold_time', YLeaf(YType.str, 'negotiated-hold-time')),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self.negotiated_hold_time = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval', 'negotiated_hold_time'], name, value)


                            class Transport(Entity):
                                """
                                Transport session parameters for the BGP neighbor
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the transport session(s) used for the BGP neighbor
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the transport session(s) used for the BGP neighbor
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "transport"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the transport
                                    session(s) used for the BGP neighbor
                                    
                                    .. attribute:: tcp_mss
                                    
                                    	Sets the max segment size for BGP TCP sessions
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                    	Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: passive_mode
                                    
                                    	Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: local_address
                                    
                                    	Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', YLeaf(YType.uint16, 'tcp-mss')),
                                            ('mtu_discovery', YLeaf(YType.boolean, 'mtu-discovery')),
                                            ('passive_mode', YLeaf(YType.boolean, 'passive-mode')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the transport session(s)
                                    used for the BGP neighbor
                                    
                                    .. attribute:: tcp_mss
                                    
                                    	Sets the max segment size for BGP TCP sessions
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                    	Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: passive_mode
                                    
                                    	Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: local_address
                                    
                                    	Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    .. attribute:: local_port
                                    
                                    	Local TCP port being used for the TCP session supporting the BGP session
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address to which the BGP session has been established
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_port
                                    
                                    	Remote port being used by the peer for the TCP session supporting the BGP session
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', YLeaf(YType.uint16, 'tcp-mss')),
                                            ('mtu_discovery', YLeaf(YType.boolean, 'mtu-discovery')),
                                            ('passive_mode', YLeaf(YType.boolean, 'passive-mode')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('local_port', YLeaf(YType.uint16, 'local-port')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('remote_port', YLeaf(YType.uint16, 'remote-port')),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self.local_port = None
                                        self.remote_address = None
                                        self.remote_port = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address', 'local_port', 'remote_address', 'remote_port'], name, value)


                            class ErrorHandling(Entity):
                                """
                                Error handling parameters used for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                	Configuration parameters enabling or modifying the behavior or enhanced error handling mechanisms for the BGP neighbor
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to enhanced error handling mechanisms for the BGP neighbor
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling, self).__init__()

                                    self.yang_name = "error-handling"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "error-handling"


                                class Config(Entity):
                                    """
                                    Configuration parameters enabling or modifying the
                                    behavior or enhanced error handling mechanisms for the BGP
                                    neighbor
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                    	Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', YLeaf(YType.boolean, 'treat-as-withdraw')),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config, ['treat_as_withdraw'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to enhanced error handling
                                    mechanisms for the BGP neighbor
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                    	Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: erroneous_update_messages
                                    
                                    	The number of BGP UPDATE messages for which the treat\-as\-withdraw mechanism has been applied based on erroneous message contents
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', YLeaf(YType.boolean, 'treat-as-withdraw')),
                                            ('erroneous_update_messages', YLeaf(YType.uint32, 'erroneous-update-messages')),
                                        ])
                                        self.treat_as_withdraw = None
                                        self.erroneous_update_messages = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State, ['treat_as_withdraw', 'erroneous_update_messages'], name, value)


                            class GracefulRestart(Entity):
                                """
                                Parameters relating the graceful restart mechanism for BGP
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to graceful\-restart
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config>`
                                
                                .. attribute:: state
                                
                                	State information associated with graceful\-restart
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart, self).__init__()

                                    self.yang_name = "graceful-restart"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "graceful-restart"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                    	Enable or disable the graceful\-restart capability
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                    	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                    	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                            ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                            ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                                class State(Entity):
                                    """
                                    State information associated with graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                    	Enable or disable the graceful\-restart capability
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                    	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                    	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    	**type**\: bool
                                    
                                    .. attribute:: peer_restart_time
                                    
                                    	The period of time (advertised by the peer) that the peer expects a restart of a BGP session to take
                                    	**type**\: int
                                    
                                    	**range:** 0..4096
                                    
                                    .. attribute:: peer_restarting
                                    
                                    	This flag indicates whether the remote neighbor is currently in the process of restarting, and hence received routes are currently stale
                                    	**type**\: bool
                                    
                                    .. attribute:: local_restarting
                                    
                                    	This flag indicates whether the local neighbor is currently restarting. The flag is unset after all NLRI have been advertised to the peer, and the End\-of\-RIB (EOR) marker has been unset
                                    	**type**\: bool
                                    
                                    .. attribute:: mode
                                    
                                    	Ths leaf indicates the mode of operation of BGP graceful restart with the peer
                                    	**type**\:  :py:class:`Mode <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State.Mode>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                            ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                            ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                            ('peer_restart_time', YLeaf(YType.uint16, 'peer-restart-time')),
                                            ('peer_restarting', YLeaf(YType.boolean, 'peer-restarting')),
                                            ('local_restarting', YLeaf(YType.boolean, 'local-restarting')),
                                            ('mode', YLeaf(YType.enumeration, 'mode')),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self.peer_restart_time = None
                                        self.peer_restarting = None
                                        self.local_restarting = None
                                        self.mode = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only', 'peer_restart_time', 'peer_restarting', 'local_restarting', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        Ths leaf indicates the mode of operation of BGP graceful

                                        restart with the peer

                                        .. data:: HELPER_ONLY = 0

                                        	The local router is operating in helper-only mode, and

                                        	hence will not retain forwarding state during a local

                                        	session restart, but will do so during a restart of the

                                        	remote peer

                                        .. data:: BILATERAL = 1

                                        	The local router is operating in both helper mode, and

                                        	hence retains forwarding state during a remote restart,

                                        	and also maintains forwarding state during local session

                                        	restart

                                        .. data:: REMOTE_HELPER = 2

                                        	The local system is able to retain routes during restart

                                        	but the remote system is only able to act as a helper

                                        """

                                        HELPER_ONLY = Enum.YLeaf(0, "HELPER_ONLY")

                                        BILATERAL = Enum.YLeaf(1, "BILATERAL")

                                        REMOTE_HELPER = Enum.YLeaf(2, "REMOTE_HELPER")



                            class LoggingOptions(Entity):
                                """
                                Logging options for events related to the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                	Configuration parameters enabling or modifying logging for events relating to the BGPgroup
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to logging for the BGP neighbor or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions, self).__init__()

                                    self.yang_name = "logging-options"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "logging-options"


                                class Config(Entity):
                                    """
                                    Configuration parameters enabling or modifying logging
                                    for events relating to the BGPgroup
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                    	Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', YLeaf(YType.boolean, 'log-neighbor-state-changes')),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config, ['log_neighbor_state_changes'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to logging for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                    	Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', YLeaf(YType.boolean, 'log-neighbor-state-changes')),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State, ['log_neighbor_state_changes'], name, value)


                            class EbgpMultihop(Entity):
                                """
                                eBGP multi\-hop parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to eBGP multihop for the BGP group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config>`
                                
                                .. attribute:: state
                                
                                	State information for eBGP multihop, for the BGP neighbor or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop, self).__init__()

                                    self.yang_name = "ebgp-multihop"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "ebgp-multihop"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to eBGP multihop for the
                                    BGP group
                                    
                                    .. attribute:: enabled
                                    
                                    	When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                    	Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('multihop_ttl', YLeaf(YType.uint8, 'multihop-ttl')),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config, ['enabled', 'multihop_ttl'], name, value)


                                class State(Entity):
                                    """
                                    State information for eBGP multihop, for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: enabled
                                    
                                    	When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                    	Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('multihop_ttl', YLeaf(YType.uint8, 'multihop-ttl')),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State, ['enabled', 'multihop_ttl'], name, value)


                            class RouteReflector(Entity):
                                """
                                Route reflector parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                	Configuraton parameters relating to route reflection for the BGPgroup
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to route reflection for the BGPgroup
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector, self).__init__()

                                    self.yang_name = "route-reflector"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "route-reflector"


                                class Config(Entity):
                                    """
                                    Configuraton parameters relating to route reflection
                                    for the BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                    	route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure the neighbor as a route reflector client
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', YLeaf(YType.str, 'route-reflector-cluster-id')),
                                            ('route_reflector_client', YLeaf(YType.boolean, 'route-reflector-client')),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to route reflection for the
                                    BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                    	route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure the neighbor as a route reflector client
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', YLeaf(YType.str, 'route-reflector-cluster-id')),
                                            ('route_reflector_client', YLeaf(YType.boolean, 'route-reflector-client')),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                            class AsPathOptions(Entity):
                                """
                                AS\_PATH manipulation parameters for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to AS\_PATH manipulation for the BGP peer or group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the AS\_PATH manipulation mechanisms for the BGP peer or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions, self).__init__()

                                    self.yang_name = "as-path-options"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "as-path-options"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to AS\_PATH manipulation
                                    for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                    	Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                    	Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', YLeaf(YType.uint8, 'allow-own-as')),
                                            ('replace_peer_as', YLeaf(YType.boolean, 'replace-peer-as')),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config, ['allow_own_as', 'replace_peer_as'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the AS\_PATH manipulation
                                    mechanisms for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                    	Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                    	Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', YLeaf(YType.uint8, 'allow-own-as')),
                                            ('replace_peer_as', YLeaf(YType.boolean, 'replace-peer-as')),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State, ['allow_own_as', 'replace_peer_as'], name, value)


                            class AddPaths(Entity):
                                """
                                Parameters relating to the advertisement and receipt of
                                multiple paths for a single NLRI (add\-paths)
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to ADD\_PATHS
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config>`
                                
                                .. attribute:: state
                                
                                	State information associated with ADD\_PATHS
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths, self).__init__()

                                    self.yang_name = "add-paths"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "add-paths"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                    	Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: send_max
                                    
                                    	The maximum number of paths to advertise to neighbors for a single NLRI
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                    	A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', YLeaf(YType.boolean, 'receive')),
                                            ('send_max', YLeaf(YType.uint8, 'send-max')),
                                            ('eligible_prefix_policy', YLeaf(YType.str, 'eligible-prefix-policy')),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                                class State(Entity):
                                    """
                                    State information associated with ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                    	Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: send_max
                                    
                                    	The maximum number of paths to advertise to neighbors for a single NLRI
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                    	A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', YLeaf(YType.boolean, 'receive')),
                                            ('send_max', YLeaf(YType.uint8, 'send-max')),
                                            ('eligible_prefix_policy', YLeaf(YType.str, 'eligible-prefix-policy')),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                            class UseMultiplePaths(Entity):
                                """
                                Parameters related to the use of multiple\-paths for the same
                                NLRI when they are received only from this neighbor
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to multipath
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config>`
                                
                                .. attribute:: state
                                
                                	State parameters relating to multipath
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State>`
                                
                                .. attribute:: ebgp
                                
                                	Multipath configuration for eBGP
                                	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths, self).__init__()

                                    self.yang_name = "use-multiple-paths"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp()
                                    self.ebgp.parent = self
                                    self._children_name_map["ebgp"] = "ebgp"
                                    self._children_yang_names.add("ebgp")
                                    self._segment_path = lambda: "use-multiple-paths"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                    	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config, ['enabled'], name, value)


                                class State(Entity):
                                    """
                                    State parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                    	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State, ['enabled'], name, value)


                                class Ebgp(Entity):
                                    """
                                    Multipath configuration for eBGP
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters relating to eBGP multipath
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information relating to eBGP multipath
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp, self).__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "ebgp"


                                    class Config(Entity):
                                        """
                                        Configuration parameters relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                        	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                            ])
                                            self.allow_multiple_as = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as'], name, value)


                                    class State(Entity):
                                        """
                                        State information relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                        	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                            ])
                                            self.allow_multiple_as = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State, ['allow_multiple_as'], name, value)


                            class ApplyPolicy(Entity):
                                """
                                Anchor point for routing policies in the model.
                                Import and export policies are with respect to the local
                                routing table, i.e., export (send) and import (receive),
                                depending on the context.
                                
                                .. attribute:: config
                                
                                	Policy configuration data
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state for routing policy
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy, self).__init__()

                                    self.yang_name = "apply-policy"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "apply-policy"


                                class Config(Entity):
                                    """
                                    Policy configuration data.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                class State(Entity):
                                    """
                                    Operational state for routing policy
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                            class AfiSafis(Entity):
                                """
                                Per\-address\-family configuration parameters associated with
                                the neighbor
                                
                                .. attribute:: afi_safi
                                
                                	AFI,SAFI configuration available for the neighbour or group
                                	**type**\: list of  		 :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis, self).__init__()

                                    self.yang_name = "afi-safis"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi))])
                                    self._leafs = OrderedDict()

                                    self.afi_safi = YList(self)
                                    self._segment_path = lambda: "afi-safis"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis, [], name, value)


                                class AfiSafi(Entity):
                                    """
                                    AFI,SAFI configuration available for the
                                    neighbour or group
                                    
                                    .. attribute:: afi_safi_name  (key)
                                    
                                    	Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                    	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters for the AFI\-SAFI
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information relating to the AFI\-SAFI
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State>`
                                    
                                    .. attribute:: graceful_restart
                                    
                                    	Parameters relating to BGP graceful\-restart
                                    	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart>`
                                    
                                    .. attribute:: apply_policy
                                    
                                    	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                                    	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy>`
                                    
                                    .. attribute:: ipv4_unicast
                                    
                                    	IPv4 unicast configuration options
                                    	**type**\:  :py:class:`Ipv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast>`
                                    
                                    .. attribute:: ipv6_unicast
                                    
                                    	IPv6 unicast configuration options
                                    	**type**\:  :py:class:`Ipv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast>`
                                    
                                    .. attribute:: ipv4_labeled_unicast
                                    
                                    	IPv4 Labeled Unicast configuration options
                                    	**type**\:  :py:class:`Ipv4LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                    
                                    .. attribute:: ipv6_labeled_unicast
                                    
                                    	IPv6 Labeled Unicast configuration options
                                    	**type**\:  :py:class:`Ipv6LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_unicast
                                    
                                    	Unicast IPv4 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_unicast
                                    
                                    	Unicast IPv6 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_multicast
                                    
                                    	Multicast IPv4 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv4Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_multicast
                                    
                                    	Multicast IPv6 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv6Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast>`
                                    
                                    .. attribute:: l2vpn_vpls
                                    
                                    	BGP\-signalled VPLS configuration options
                                    	**type**\:  :py:class:`L2VpnVpls <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls>`
                                    
                                    .. attribute:: l2vpn_evpn
                                    
                                    	BGP EVPN configuration options
                                    	**type**\:  :py:class:`L2VpnEvpn <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn>`
                                    
                                    .. attribute:: use_multiple_paths
                                    
                                    	Parameters related to the use of multiple\-paths for the same NLRI when they are received only from this neighbor
                                    	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi, self).__init__()

                                        self.yang_name = "afi-safi"
                                        self.yang_parent_name = "afi-safis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_safi_name']
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                        ])
                                        self.afi_safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")

                                        self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart()
                                        self.graceful_restart.parent = self
                                        self._children_name_map["graceful_restart"] = "graceful-restart"
                                        self._children_yang_names.add("graceful-restart")

                                        self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy()
                                        self.apply_policy.parent = self
                                        self._children_name_map["apply_policy"] = "apply-policy"
                                        self._children_yang_names.add("apply-policy")

                                        self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast()
                                        self.ipv4_unicast.parent = self
                                        self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                                        self._children_yang_names.add("ipv4-unicast")

                                        self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast()
                                        self.ipv6_unicast.parent = self
                                        self._children_name_map["ipv6_unicast"] = "ipv6-unicast"
                                        self._children_yang_names.add("ipv6-unicast")

                                        self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                        self.ipv4_labeled_unicast.parent = self
                                        self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"
                                        self._children_yang_names.add("ipv4-labeled-unicast")

                                        self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                        self.ipv6_labeled_unicast.parent = self
                                        self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"
                                        self._children_yang_names.add("ipv6-labeled-unicast")

                                        self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast()
                                        self.l3vpn_ipv4_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"
                                        self._children_yang_names.add("l3vpn-ipv4-unicast")

                                        self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast()
                                        self.l3vpn_ipv6_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"
                                        self._children_yang_names.add("l3vpn-ipv6-unicast")

                                        self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast()
                                        self.l3vpn_ipv4_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"
                                        self._children_yang_names.add("l3vpn-ipv4-multicast")

                                        self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast()
                                        self.l3vpn_ipv6_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"
                                        self._children_yang_names.add("l3vpn-ipv6-multicast")

                                        self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls()
                                        self.l2vpn_vpls.parent = self
                                        self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                                        self._children_yang_names.add("l2vpn-vpls")

                                        self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn()
                                        self.l2vpn_evpn.parent = self
                                        self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"
                                        self._children_yang_names.add("l2vpn-evpn")

                                        self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths()
                                        self.use_multiple_paths.parent = self
                                        self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                        self._children_yang_names.add("use-multiple-paths")
                                        self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)


                                    class Config(Entity):
                                        """
                                        Configuration parameters for the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                        	AFI,SAFI
                                        	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                    class State(Entity):
                                        """
                                        State information relating to the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                        	AFI,SAFI
                                        	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: active
                                        
                                        	This value indicates whether a particular AFI\-SAFI has been succesfully negotiated with the peer. An AFI\-SAFI may be enabled in the current running configuration, but a session restart may be required in order to negotiate the new capability
                                        	**type**\: bool
                                        
                                        .. attribute:: prefixes
                                        
                                        	Prefix counters for the BGP session
                                        	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ('active', YLeaf(YType.boolean, 'active')),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self.active = None

                                            self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes()
                                            self.prefixes.parent = self
                                            self._children_name_map["prefixes"] = "prefixes"
                                            self._children_yang_names.add("prefixes")
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled', 'active'], name, value)


                                        class Prefixes(Entity):
                                            """
                                            Prefix counters for the BGP session
                                            
                                            .. attribute:: received
                                            
                                            	The number of prefixes received from the neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent
                                            
                                            	The number of prefixes advertised to the neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: installed
                                            
                                            	The number of advertised prefixes installed in the Loc\-RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes, self).__init__()

                                                self.yang_name = "prefixes"
                                                self.yang_parent_name = "state"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received', YLeaf(YType.uint32, 'received')),
                                                    ('sent', YLeaf(YType.uint32, 'sent')),
                                                    ('installed', YLeaf(YType.uint32, 'installed')),
                                                ])
                                                self.received = None
                                                self.sent = None
                                                self.installed = None
                                                self._segment_path = lambda: "prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes, ['received', 'sent', 'installed'], name, value)


                                    class GracefulRestart(Entity):
                                        """
                                        Parameters relating to BGP graceful\-restart
                                        
                                        .. attribute:: config
                                        
                                        	Configuration options for BGP graceful\-restart
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for BGP graceful\-restart
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart, self).__init__()

                                            self.yang_name = "graceful-restart"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "graceful-restart"


                                        class Config(Entity):
                                            """
                                            Configuration options for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                            	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                        class State(Entity):
                                            """
                                            State information for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                            	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: received
                                            
                                            	This leaf indicates whether the neighbor advertised the ability to support graceful\-restart for this AFI\-SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: advertised
                                            
                                            	This leaf indicates whether the ability to support graceful\-restart has been advertised to the peer
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                    ('received', YLeaf(YType.boolean, 'received')),
                                                    ('advertised', YLeaf(YType.boolean, 'advertised')),
                                                ])
                                                self.enabled = None
                                                self.received = None
                                                self.advertised = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled', 'received', 'advertised'], name, value)


                                    class ApplyPolicy(Entity):
                                        """
                                        Anchor point for routing policies in the model.
                                        Import and export policies are with respect to the local
                                        routing table, i.e., export (send) and import (receive),
                                        depending on the context.
                                        
                                        .. attribute:: config
                                        
                                        	Policy configuration data
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	Operational state for routing policy
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy, self).__init__()

                                            self.yang_name = "apply-policy"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "apply-policy"


                                        class Config(Entity):
                                            """
                                            Policy configuration data.
                                            
                                            .. attribute:: import_policy
                                            
                                            	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                            	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                            	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                            	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                    ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                    ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                    ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                        class State(Entity):
                                            """
                                            Operational state for routing policy
                                            
                                            .. attribute:: import_policy
                                            
                                            	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                            	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                            	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                            	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                    ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                    ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                    ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                    class Ipv4Unicast(Entity):
                                        """
                                        IPv4 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for common IPv4 and IPv6 unicast parameters
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast, self).__init__()

                                            self.yang_name = "ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ipv4-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class Config(Entity):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                        class State(Entity):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)


                                    class Ipv6Unicast(Entity):
                                        """
                                        IPv6 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for common IPv4 and IPv6 unicast parameters
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast, self).__init__()

                                            self.yang_name = "ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ipv6-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class Config(Entity):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                        class State(Entity):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)


                                    class Ipv4LabeledUnicast(Entity):
                                        """
                                        IPv4 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast, self).__init__()

                                            self.yang_name = "ipv4-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "ipv4-labeled-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class Ipv6LabeledUnicast(Entity):
                                        """
                                        IPv6 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast, self).__init__()

                                            self.yang_name = "ipv6-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "ipv6-labeled-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv4Unicast(Entity):
                                        """
                                        Unicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv4-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv6Unicast(Entity):
                                        """
                                        Unicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv6-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv4Multicast(Entity):
                                        """
                                        Multicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv4-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv4-multicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv6Multicast(Entity):
                                        """
                                        Multicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv6-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv6-multicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L2VpnVpls(Entity):
                                        """
                                        BGP\-signalled VPLS configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls, self).__init__()

                                            self.yang_name = "l2vpn-vpls"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l2vpn-vpls"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-vpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L2VpnEvpn(Entity):
                                        """
                                        BGP EVPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn, self).__init__()

                                            self.yang_name = "l2vpn-evpn"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l2vpn-evpn"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-evpn"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class UseMultiplePaths(Entity):
                                        """
                                        Parameters related to the use of multiple\-paths for the same
                                        NLRI when they are received only from this neighbor
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to multipath
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State parameters relating to multipath
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                        
                                        .. attribute:: ebgp
                                        
                                        	Multipath configuration for eBGP
                                        	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths, self).__init__()

                                            self.yang_name = "use-multiple-paths"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")

                                            self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                            self.ebgp.parent = self
                                            self._children_name_map["ebgp"] = "ebgp"
                                            self._children_yang_names.add("ebgp")
                                            self._segment_path = lambda: "use-multiple-paths"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                            	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                        class State(Entity):
                                            """
                                            State parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                            	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                        class Ebgp(Entity):
                                            """
                                            Multipath configuration for eBGP
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to eBGP multipath
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to eBGP multipath
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, self).__init__()

                                                self.yang_name = "ebgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "ebgp"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as'], name, value)


                    class PeerGroups(Entity):
                        """
                        Configuration for BGP peer\-groups
                        
                        .. attribute:: peer_group
                        
                        	List of BGP peer\-groups configured on the local system \- uniquely identified by peer\-group name
                        	**type**\: list of  		 :py:class:`PeerGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups, self).__init__()

                            self.yang_name = "peer-groups"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([("peer-group", ("peer_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup))])
                            self._leafs = OrderedDict()

                            self.peer_group = YList(self)
                            self._segment_path = lambda: "peer-groups"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups, [], name, value)


                        class PeerGroup(Entity):
                            """
                            List of BGP peer\-groups configured on the local system \-
                            uniquely identified by peer\-group name
                            
                            .. attribute:: peer_group_name  (key)
                            
                            	Reference to the name of the BGP peer\-group used as a key in the peer\-group list
                            	**type**\: str
                            
                            	**refers to**\:  :py:class:`peer_group_name <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to the BGP neighbor or group
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                            
                            .. attribute:: state
                            
                            	State information relating to the BGP peer\-group
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State>`
                            
                            .. attribute:: timers
                            
                            	Timers related to a BGP peer\-group
                            	**type**\:  :py:class:`Timers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers>`
                            
                            .. attribute:: transport
                            
                            	Transport session parameters for the BGP peer\-group
                            	**type**\:  :py:class:`Transport <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport>`
                            
                            .. attribute:: error_handling
                            
                            	Error handling parameters used for the BGP peer\-group
                            	**type**\:  :py:class:`ErrorHandling <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling>`
                            
                            .. attribute:: graceful_restart
                            
                            	Parameters relating the graceful restart mechanism for BGP
                            	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart>`
                            
                            .. attribute:: logging_options
                            
                            	Logging options for events related to the BGP neighbor or group
                            	**type**\:  :py:class:`LoggingOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions>`
                            
                            .. attribute:: ebgp_multihop
                            
                            	eBGP multi\-hop parameters for the BGPgroup
                            	**type**\:  :py:class:`EbgpMultihop <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop>`
                            
                            .. attribute:: route_reflector
                            
                            	Route reflector parameters for the BGPgroup
                            	**type**\:  :py:class:`RouteReflector <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector>`
                            
                            .. attribute:: as_path_options
                            
                            	AS\_PATH manipulation parameters for the BGP neighbor or group
                            	**type**\:  :py:class:`AsPathOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions>`
                            
                            .. attribute:: add_paths
                            
                            	Parameters relating to the advertisement and receipt of multiple paths for a single NLRI (add\-paths)
                            	**type**\:  :py:class:`AddPaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths>`
                            
                            .. attribute:: use_multiple_paths
                            
                            	Parameters related to the use of multiple paths for the same NLRI
                            	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths>`
                            
                            .. attribute:: apply_policy
                            
                            	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                            	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy>`
                            
                            .. attribute:: afi_safis
                            
                            	Per\-address\-family configuration parameters associated with thegroup
                            	**type**\:  :py:class:`AfiSafis <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup, self).__init__()

                                self.yang_name = "peer-group"
                                self.yang_parent_name = "peer-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['peer_group_name']
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport)), ("error-handling", ("error_handling", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart)), ("logging-options", ("logging_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions)), ("ebgp-multihop", ("ebgp_multihop", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop)), ("route-reflector", ("route_reflector", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector)), ("as-path-options", ("as_path_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions)), ("add-paths", ("add_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('peer_group_name', YLeaf(YType.str, 'peer-group-name')),
                                ])
                                self.peer_group_name = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._children_yang_names.add("timers")

                                self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._children_yang_names.add("transport")

                                self.error_handling = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling()
                                self.error_handling.parent = self
                                self._children_name_map["error_handling"] = "error-handling"
                                self._children_yang_names.add("error-handling")

                                self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart()
                                self.graceful_restart.parent = self
                                self._children_name_map["graceful_restart"] = "graceful-restart"
                                self._children_yang_names.add("graceful-restart")

                                self.logging_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions()
                                self.logging_options.parent = self
                                self._children_name_map["logging_options"] = "logging-options"
                                self._children_yang_names.add("logging-options")

                                self.ebgp_multihop = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop()
                                self.ebgp_multihop.parent = self
                                self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                self._children_yang_names.add("ebgp-multihop")

                                self.route_reflector = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector()
                                self.route_reflector.parent = self
                                self._children_name_map["route_reflector"] = "route-reflector"
                                self._children_yang_names.add("route-reflector")

                                self.as_path_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions()
                                self.as_path_options.parent = self
                                self._children_name_map["as_path_options"] = "as-path-options"
                                self._children_yang_names.add("as-path-options")

                                self.add_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths()
                                self.add_paths.parent = self
                                self._children_name_map["add_paths"] = "add-paths"
                                self._children_yang_names.add("add-paths")

                                self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths()
                                self.use_multiple_paths.parent = self
                                self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                self._children_yang_names.add("use-multiple-paths")

                                self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy()
                                self.apply_policy.parent = self
                                self._children_name_map["apply_policy"] = "apply-policy"
                                self._children_yang_names.add("apply-policy")

                                self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis()
                                self.afi_safis.parent = self
                                self._children_name_map["afi_safis"] = "afi-safis"
                                self._children_yang_names.add("afi-safis")
                                self._segment_path = lambda: "peer-group" + "[peer-group-name='" + str(self.peer_group_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup, ['peer_group_name'], name, value)


                            class Config(Entity):
                                """
                                Configuration parameters relating to the BGP neighbor or
                                group
                                
                                .. attribute:: peer_group_name
                                
                                	Name of the BGP peer\-group
                                	**type**\: str
                                
                                .. attribute:: peer_as
                                
                                	AS number of the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                	The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                	Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                	**type**\:  :py:class:`PeerType <ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                	Configures an MD5 authentication password for use with neighboring devices
                                	**type**\: str
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                	**type**\:  :py:class:`REMOVEPRIVATEASOPTION <ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                	Enable route flap damping
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: send_community
                                
                                	Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                	**type**\:  :py:class:`CommunityType <ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                	**default value**\: NONE
                                
                                .. attribute:: description
                                
                                	An optional textual description (intended primarily for use with a peer or group
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', YLeaf(YType.str, 'peer-group-name')),
                                        ('peer_as', YLeaf(YType.uint32, 'peer-as')),
                                        ('local_as', YLeaf(YType.uint32, 'local-as')),
                                        ('peer_type', YLeaf(YType.enumeration, 'peer-type')),
                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                        ('remove_private_as', YLeaf(YType.identityref, 'remove-private-as')),
                                        ('route_flap_damping', YLeaf(YType.boolean, 'route-flap-damping')),
                                        ('send_community', YLeaf(YType.enumeration, 'send-community')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.peer_group_name = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config, ['peer_group_name', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description'], name, value)


                            class State(Entity):
                                """
                                State information relating to the BGP peer\-group
                                
                                .. attribute:: peer_group_name
                                
                                	Name of the BGP peer\-group
                                	**type**\: str
                                
                                .. attribute:: peer_as
                                
                                	AS number of the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                	The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                	Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                	**type**\:  :py:class:`PeerType <ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                	Configures an MD5 authentication password for use with neighboring devices
                                	**type**\: str
                                
                                .. attribute:: remove_private_as
                                
                                	Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                	**type**\:  :py:class:`REMOVEPRIVATEASOPTION <ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                	Enable route flap damping
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: send_community
                                
                                	Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                	**type**\:  :py:class:`CommunityType <ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                	**default value**\: NONE
                                
                                .. attribute:: description
                                
                                	An optional textual description (intended primarily for use with a peer or group
                                	**type**\: str
                                
                                .. attribute:: total_paths
                                
                                	Total number of BGP paths within the context
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_prefixes
                                
                                	Total number of BGP prefixes received within the context
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', YLeaf(YType.str, 'peer-group-name')),
                                        ('peer_as', YLeaf(YType.uint32, 'peer-as')),
                                        ('local_as', YLeaf(YType.uint32, 'local-as')),
                                        ('peer_type', YLeaf(YType.enumeration, 'peer-type')),
                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                        ('remove_private_as', YLeaf(YType.identityref, 'remove-private-as')),
                                        ('route_flap_damping', YLeaf(YType.boolean, 'route-flap-damping')),
                                        ('send_community', YLeaf(YType.enumeration, 'send-community')),
                                        ('description', YLeaf(YType.str, 'description')),
                                        ('total_paths', YLeaf(YType.uint32, 'total-paths')),
                                        ('total_prefixes', YLeaf(YType.uint32, 'total-prefixes')),
                                    ])
                                    self.peer_group_name = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self.total_paths = None
                                    self.total_prefixes = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State, ['peer_group_name', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description', 'total_paths', 'total_prefixes'], name, value)


                            class Timers(Entity):
                                """
                                Timers related to a BGP peer\-group
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to timers used for the BGP neighbor or peer group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the timers used for the BGP group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "timers"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to timers used for the
                                    BGP neighbor or peer group
                                    
                                    .. attribute:: connect_retry
                                    
                                    	Time interval in seconds between attempts to establish a session with the peer
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: hold_time
                                    
                                    	Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', YLeaf(YType.str, 'connect-retry')),
                                            ('hold_time', YLeaf(YType.str, 'hold-time')),
                                            ('keepalive_interval', YLeaf(YType.str, 'keepalive-interval')),
                                            ('minimum_advertisement_interval', YLeaf(YType.str, 'minimum-advertisement-interval')),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the timers used for the BGP
                                    group
                                    
                                    .. attribute:: connect_retry
                                    
                                    	Time interval in seconds between attempts to establish a session with the peer
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: hold_time
                                    
                                    	Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    	**default value**\: 30
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', YLeaf(YType.str, 'connect-retry')),
                                            ('hold_time', YLeaf(YType.str, 'hold-time')),
                                            ('keepalive_interval', YLeaf(YType.str, 'keepalive-interval')),
                                            ('minimum_advertisement_interval', YLeaf(YType.str, 'minimum-advertisement-interval')),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)


                            class Transport(Entity):
                                """
                                Transport session parameters for the BGP peer\-group
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the transport session(s) used for the BGP neighbor or group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the transport session(s) used for the BGP neighbor or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "transport"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the transport
                                    session(s) used for the BGP neighbor or group
                                    
                                    .. attribute:: tcp_mss
                                    
                                    	Sets the max segment size for BGP TCP sessions
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                    	Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: passive_mode
                                    
                                    	Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: local_address
                                    
                                    	Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', YLeaf(YType.uint16, 'tcp-mss')),
                                            ('mtu_discovery', YLeaf(YType.boolean, 'mtu-discovery')),
                                            ('passive_mode', YLeaf(YType.boolean, 'passive-mode')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the transport session(s)
                                    used for the BGP neighbor or group
                                    
                                    .. attribute:: tcp_mss
                                    
                                    	Sets the max segment size for BGP TCP sessions
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                    	Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: passive_mode
                                    
                                    	Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: local_address
                                    
                                    	Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', YLeaf(YType.uint16, 'tcp-mss')),
                                            ('mtu_discovery', YLeaf(YType.boolean, 'mtu-discovery')),
                                            ('passive_mode', YLeaf(YType.boolean, 'passive-mode')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)


                            class ErrorHandling(Entity):
                                """
                                Error handling parameters used for the BGP peer\-group
                                
                                .. attribute:: config
                                
                                	Configuration parameters enabling or modifying the behavior or enhanced error handling mechanisms for the BGP group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to enhanced error handling mechanisms for the BGP group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling, self).__init__()

                                    self.yang_name = "error-handling"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "error-handling"


                                class Config(Entity):
                                    """
                                    Configuration parameters enabling or modifying the
                                    behavior or enhanced error handling mechanisms for the BGP
                                    group
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                    	Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', YLeaf(YType.boolean, 'treat-as-withdraw')),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config, ['treat_as_withdraw'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to enhanced error handling
                                    mechanisms for the BGP group
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                    	Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', YLeaf(YType.boolean, 'treat-as-withdraw')),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State, ['treat_as_withdraw'], name, value)


                            class GracefulRestart(Entity):
                                """
                                Parameters relating the graceful restart mechanism for BGP
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to graceful\-restart
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config>`
                                
                                .. attribute:: state
                                
                                	State information associated with graceful\-restart
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart, self).__init__()

                                    self.yang_name = "graceful-restart"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "graceful-restart"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                    	Enable or disable the graceful\-restart capability
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                    	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                    	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                            ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                            ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                                class State(Entity):
                                    """
                                    State information associated with graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                    	Enable or disable the graceful\-restart capability
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                    	An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                    	**range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                    	Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('restart_time', YLeaf(YType.uint16, 'restart-time')),
                                            ('stale_routes_time', YLeaf(YType.str, 'stale-routes-time')),
                                            ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                            class LoggingOptions(Entity):
                                """
                                Logging options for events related to the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                	Configuration parameters enabling or modifying logging for events relating to the BGPgroup
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to logging for the BGP neighbor or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions, self).__init__()

                                    self.yang_name = "logging-options"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "logging-options"


                                class Config(Entity):
                                    """
                                    Configuration parameters enabling or modifying logging
                                    for events relating to the BGPgroup
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                    	Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', YLeaf(YType.boolean, 'log-neighbor-state-changes')),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config, ['log_neighbor_state_changes'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to logging for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                    	Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', YLeaf(YType.boolean, 'log-neighbor-state-changes')),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State, ['log_neighbor_state_changes'], name, value)


                            class EbgpMultihop(Entity):
                                """
                                eBGP multi\-hop parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to eBGP multihop for the BGP group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config>`
                                
                                .. attribute:: state
                                
                                	State information for eBGP multihop, for the BGP neighbor or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop, self).__init__()

                                    self.yang_name = "ebgp-multihop"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "ebgp-multihop"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to eBGP multihop for the
                                    BGP group
                                    
                                    .. attribute:: enabled
                                    
                                    	When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                    	Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('multihop_ttl', YLeaf(YType.uint8, 'multihop-ttl')),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config, ['enabled', 'multihop_ttl'], name, value)


                                class State(Entity):
                                    """
                                    State information for eBGP multihop, for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: enabled
                                    
                                    	When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                    	Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('multihop_ttl', YLeaf(YType.uint8, 'multihop-ttl')),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State, ['enabled', 'multihop_ttl'], name, value)


                            class RouteReflector(Entity):
                                """
                                Route reflector parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                	Configuraton parameters relating to route reflection for the BGPgroup
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to route reflection for the BGPgroup
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector, self).__init__()

                                    self.yang_name = "route-reflector"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "route-reflector"


                                class Config(Entity):
                                    """
                                    Configuraton parameters relating to route reflection
                                    for the BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                    	route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure the neighbor as a route reflector client
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', YLeaf(YType.str, 'route-reflector-cluster-id')),
                                            ('route_reflector_client', YLeaf(YType.boolean, 'route-reflector-client')),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to route reflection for the
                                    BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                    	route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: int
                                    
                                    			**range:** 0..4294967295
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_reflector_client
                                    
                                    	Configure the neighbor as a route reflector client
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', YLeaf(YType.str, 'route-reflector-cluster-id')),
                                            ('route_reflector_client', YLeaf(YType.boolean, 'route-reflector-client')),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                            class AsPathOptions(Entity):
                                """
                                AS\_PATH manipulation parameters for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to AS\_PATH manipulation for the BGP peer or group
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config>`
                                
                                .. attribute:: state
                                
                                	State information relating to the AS\_PATH manipulation mechanisms for the BGP peer or group
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions, self).__init__()

                                    self.yang_name = "as-path-options"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "as-path-options"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to AS\_PATH manipulation
                                    for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                    	Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                    	Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', YLeaf(YType.uint8, 'allow-own-as')),
                                            ('replace_peer_as', YLeaf(YType.boolean, 'replace-peer-as')),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config, ['allow_own_as', 'replace_peer_as'], name, value)


                                class State(Entity):
                                    """
                                    State information relating to the AS\_PATH manipulation
                                    mechanisms for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                    	Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                    	Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', YLeaf(YType.uint8, 'allow-own-as')),
                                            ('replace_peer_as', YLeaf(YType.boolean, 'replace-peer-as')),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State, ['allow_own_as', 'replace_peer_as'], name, value)


                            class AddPaths(Entity):
                                """
                                Parameters relating to the advertisement and receipt of
                                multiple paths for a single NLRI (add\-paths)
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to ADD\_PATHS
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config>`
                                
                                .. attribute:: state
                                
                                	State information associated with ADD\_PATHS
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths, self).__init__()

                                    self.yang_name = "add-paths"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "add-paths"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                    	Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: send_max
                                    
                                    	The maximum number of paths to advertise to neighbors for a single NLRI
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                    	A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', YLeaf(YType.boolean, 'receive')),
                                            ('send_max', YLeaf(YType.uint8, 'send-max')),
                                            ('eligible_prefix_policy', YLeaf(YType.str, 'eligible-prefix-policy')),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                                class State(Entity):
                                    """
                                    State information associated with ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                    	Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: send_max
                                    
                                    	The maximum number of paths to advertise to neighbors for a single NLRI
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                    	A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', YLeaf(YType.boolean, 'receive')),
                                            ('send_max', YLeaf(YType.uint8, 'send-max')),
                                            ('eligible_prefix_policy', YLeaf(YType.str, 'eligible-prefix-policy')),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                            class UseMultiplePaths(Entity):
                                """
                                Parameters related to the use of multiple paths for the
                                same NLRI
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to multipath
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config>`
                                
                                .. attribute:: state
                                
                                	State parameters relating to multipath
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State>`
                                
                                .. attribute:: ebgp
                                
                                	Multipath parameters for eBGP
                                	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp>`
                                
                                .. attribute:: ibgp
                                
                                	Multipath parameters for iBGP
                                	**type**\:  :py:class:`Ibgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths, self).__init__()

                                    self.yang_name = "use-multiple-paths"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp()
                                    self.ebgp.parent = self
                                    self._children_name_map["ebgp"] = "ebgp"
                                    self._children_yang_names.add("ebgp")

                                    self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"
                                    self._children_yang_names.add("ibgp")
                                    self._segment_path = lambda: "use-multiple-paths"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                    	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config, ['enabled'], name, value)


                                class State(Entity):
                                    """
                                    State parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                    	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State, ['enabled'], name, value)


                                class Ebgp(Entity):
                                    """
                                    Multipath parameters for eBGP
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters relating to eBGP multipath
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information relating to eBGP multipath
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp, self).__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "ebgp"


                                    class Config(Entity):
                                        """
                                        Configuration parameters relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                        	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: maximum_paths
                                        
                                        	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 1
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                            ])
                                            self.allow_multiple_as = None
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                    class State(Entity):
                                        """
                                        State information relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                        	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: maximum_paths
                                        
                                        	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 1
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                            ])
                                            self.allow_multiple_as = None
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)


                                class Ibgp(Entity):
                                    """
                                    Multipath parameters for iBGP
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters relating to iBGP multipath
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information relating to iBGP multipath
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "ibgp"


                                    class Config(Entity):
                                        """
                                        Configuration parameters relating to iBGP multipath
                                        
                                        .. attribute:: maximum_paths
                                        
                                        	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 1
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ibgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                            ])
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                    class State(Entity):
                                        """
                                        State information relating to iBGP multipath
                                        
                                        .. attribute:: maximum_paths
                                        
                                        	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 1
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ibgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                            ])
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)


                            class ApplyPolicy(Entity):
                                """
                                Anchor point for routing policies in the model.
                                Import and export policies are with respect to the local
                                routing table, i.e., export (send) and import (receive),
                                depending on the context.
                                
                                .. attribute:: config
                                
                                	Policy configuration data
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state for routing policy
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy, self).__init__()

                                    self.yang_name = "apply-policy"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "apply-policy"


                                class Config(Entity):
                                    """
                                    Policy configuration data.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                class State(Entity):
                                    """
                                    Operational state for routing policy
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                    	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                    	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                            ('export_policy', YLeafList(YType.str, 'export-policy')),
                                            ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                            class AfiSafis(Entity):
                                """
                                Per\-address\-family configuration parameters associated with
                                thegroup
                                
                                .. attribute:: afi_safi
                                
                                	AFI,SAFI configuration available for the neighbour or group
                                	**type**\: list of  		 :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis, self).__init__()

                                    self.yang_name = "afi-safis"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi))])
                                    self._leafs = OrderedDict()

                                    self.afi_safi = YList(self)
                                    self._segment_path = lambda: "afi-safis"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis, [], name, value)


                                class AfiSafi(Entity):
                                    """
                                    AFI,SAFI configuration available for the
                                    neighbour or group
                                    
                                    .. attribute:: afi_safi_name  (key)
                                    
                                    	Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                    	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                    	Configuration parameters for the AFI\-SAFI
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	State information relating to the AFI\-SAFI
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State>`
                                    
                                    .. attribute:: graceful_restart
                                    
                                    	Parameters relating to BGP graceful\-restart
                                    	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart>`
                                    
                                    .. attribute:: route_selection_options
                                    
                                    	Parameters relating to options for route selection
                                    	**type**\:  :py:class:`RouteSelectionOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions>`
                                    
                                    .. attribute:: use_multiple_paths
                                    
                                    	Parameters related to the use of multiple paths for the same NLRI
                                    	**type**\:  :py:class:`UseMultiplePaths <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths>`
                                    
                                    .. attribute:: apply_policy
                                    
                                    	Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                                    	**type**\:  :py:class:`ApplyPolicy <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy>`
                                    
                                    .. attribute:: ipv4_unicast
                                    
                                    	IPv4 unicast configuration options
                                    	**type**\:  :py:class:`Ipv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast>`
                                    
                                    .. attribute:: ipv6_unicast
                                    
                                    	IPv6 unicast configuration options
                                    	**type**\:  :py:class:`Ipv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast>`
                                    
                                    .. attribute:: ipv4_labeled_unicast
                                    
                                    	IPv4 Labeled Unicast configuration options
                                    	**type**\:  :py:class:`Ipv4LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                    
                                    .. attribute:: ipv6_labeled_unicast
                                    
                                    	IPv6 Labeled Unicast configuration options
                                    	**type**\:  :py:class:`Ipv6LabeledUnicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_unicast
                                    
                                    	Unicast IPv4 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv4Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_unicast
                                    
                                    	Unicast IPv6 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv6Unicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_multicast
                                    
                                    	Multicast IPv4 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv4Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_multicast
                                    
                                    	Multicast IPv6 L3VPN configuration options
                                    	**type**\:  :py:class:`L3VpnIpv6Multicast <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast>`
                                    
                                    .. attribute:: l2vpn_vpls
                                    
                                    	BGP\-signalled VPLS configuration options
                                    	**type**\:  :py:class:`L2VpnVpls <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls>`
                                    
                                    .. attribute:: l2vpn_evpn
                                    
                                    	BGP EVPN configuration options
                                    	**type**\:  :py:class:`L2VpnEvpn <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi, self).__init__()

                                        self.yang_name = "afi-safi"
                                        self.yang_parent_name = "afi-safis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_safi_name']
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                        ])
                                        self.afi_safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")

                                        self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart()
                                        self.graceful_restart.parent = self
                                        self._children_name_map["graceful_restart"] = "graceful-restart"
                                        self._children_yang_names.add("graceful-restart")

                                        self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions()
                                        self.route_selection_options.parent = self
                                        self._children_name_map["route_selection_options"] = "route-selection-options"
                                        self._children_yang_names.add("route-selection-options")

                                        self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths()
                                        self.use_multiple_paths.parent = self
                                        self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                        self._children_yang_names.add("use-multiple-paths")

                                        self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy()
                                        self.apply_policy.parent = self
                                        self._children_name_map["apply_policy"] = "apply-policy"
                                        self._children_yang_names.add("apply-policy")

                                        self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast()
                                        self.ipv4_unicast.parent = self
                                        self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                                        self._children_yang_names.add("ipv4-unicast")

                                        self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast()
                                        self.ipv6_unicast.parent = self
                                        self._children_name_map["ipv6_unicast"] = "ipv6-unicast"
                                        self._children_yang_names.add("ipv6-unicast")

                                        self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                        self.ipv4_labeled_unicast.parent = self
                                        self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"
                                        self._children_yang_names.add("ipv4-labeled-unicast")

                                        self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                        self.ipv6_labeled_unicast.parent = self
                                        self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"
                                        self._children_yang_names.add("ipv6-labeled-unicast")

                                        self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast()
                                        self.l3vpn_ipv4_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"
                                        self._children_yang_names.add("l3vpn-ipv4-unicast")

                                        self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast()
                                        self.l3vpn_ipv6_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"
                                        self._children_yang_names.add("l3vpn-ipv6-unicast")

                                        self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast()
                                        self.l3vpn_ipv4_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"
                                        self._children_yang_names.add("l3vpn-ipv4-multicast")

                                        self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast()
                                        self.l3vpn_ipv6_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"
                                        self._children_yang_names.add("l3vpn-ipv6-multicast")

                                        self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls()
                                        self.l2vpn_vpls.parent = self
                                        self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"
                                        self._children_yang_names.add("l2vpn-vpls")

                                        self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn()
                                        self.l2vpn_evpn.parent = self
                                        self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"
                                        self._children_yang_names.add("l2vpn-evpn")
                                        self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)


                                    class Config(Entity):
                                        """
                                        Configuration parameters for the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                        	AFI,SAFI
                                        	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                    class State(Entity):
                                        """
                                        State information relating to the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                        	AFI,SAFI
                                        	**type**\:  :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', YLeaf(YType.identityref, 'afi-safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled'], name, value)


                                    class GracefulRestart(Entity):
                                        """
                                        Parameters relating to BGP graceful\-restart
                                        
                                        .. attribute:: config
                                        
                                        	Configuration options for BGP graceful\-restart
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for BGP graceful\-restart
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart, self).__init__()

                                            self.yang_name = "graceful-restart"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "graceful-restart"


                                        class Config(Entity):
                                            """
                                            Configuration options for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                            	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                        class State(Entity):
                                            """
                                            State information for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                            	This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled'], name, value)


                                    class RouteSelectionOptions(Entity):
                                        """
                                        Parameters relating to options for route selection
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to route selection options
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for the route selection options
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions, self).__init__()

                                            self.yang_name = "route-selection-options"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "route-selection-options"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to route selection
                                            options
                                            
                                            .. attribute:: always_compare_med
                                            
                                            	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: ignore_as_path_length
                                            
                                            	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: external_compare_router_id
                                            
                                            	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                            	**type**\: bool
                                            
                                            	**default value**\: true
                                            
                                            .. attribute:: advertise_inactive_routes
                                            
                                            	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: enable_aigp
                                            
                                            	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: ignore_next_hop_igp_metric
                                            
                                            	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "route-selection-options"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                                    ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                                    ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                                    ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                                    ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                                    ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                                ])
                                                self.always_compare_med = None
                                                self.ignore_as_path_length = None
                                                self.external_compare_router_id = None
                                                self.advertise_inactive_routes = None
                                                self.enable_aigp = None
                                                self.ignore_next_hop_igp_metric = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                        class State(Entity):
                                            """
                                            State information for the route selection options
                                            
                                            .. attribute:: always_compare_med
                                            
                                            	Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: ignore_as_path_length
                                            
                                            	Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: external_compare_router_id
                                            
                                            	When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                            	**type**\: bool
                                            
                                            	**default value**\: true
                                            
                                            .. attribute:: advertise_inactive_routes
                                            
                                            	Advertise inactive routes to external peers.  The default is to only advertise active routes
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: enable_aigp
                                            
                                            	Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: ignore_next_hop_igp_metric
                                            
                                            	Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "route-selection-options"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always_compare_med', YLeaf(YType.boolean, 'always-compare-med')),
                                                    ('ignore_as_path_length', YLeaf(YType.boolean, 'ignore-as-path-length')),
                                                    ('external_compare_router_id', YLeaf(YType.boolean, 'external-compare-router-id')),
                                                    ('advertise_inactive_routes', YLeaf(YType.boolean, 'advertise-inactive-routes')),
                                                    ('enable_aigp', YLeaf(YType.boolean, 'enable-aigp')),
                                                    ('ignore_next_hop_igp_metric', YLeaf(YType.boolean, 'ignore-next-hop-igp-metric')),
                                                ])
                                                self.always_compare_med = None
                                                self.ignore_as_path_length = None
                                                self.external_compare_router_id = None
                                                self.advertise_inactive_routes = None
                                                self.enable_aigp = None
                                                self.ignore_next_hop_igp_metric = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                    class UseMultiplePaths(Entity):
                                        """
                                        Parameters related to the use of multiple paths for the
                                        same NLRI
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters relating to multipath
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State parameters relating to multipath
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                        
                                        .. attribute:: ebgp
                                        
                                        	Multipath parameters for eBGP
                                        	**type**\:  :py:class:`Ebgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                        
                                        .. attribute:: ibgp
                                        
                                        	Multipath parameters for iBGP
                                        	**type**\:  :py:class:`Ibgp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths, self).__init__()

                                            self.yang_name = "use-multiple-paths"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")

                                            self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                            self.ebgp.parent = self
                                            self._children_name_map["ebgp"] = "ebgp"
                                            self._children_yang_names.add("ebgp")

                                            self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"
                                            self._children_yang_names.add("ibgp")
                                            self._segment_path = lambda: "use-multiple-paths"


                                        class Config(Entity):
                                            """
                                            Configuration parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                            	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                        class State(Entity):
                                            """
                                            State parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                            	Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                        class Ebgp(Entity):
                                            """
                                            Multipath parameters for eBGP
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to eBGP multipath
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to eBGP multipath
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, self).__init__()

                                                self.yang_name = "ebgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "ebgp"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: maximum_paths
                                                
                                                	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 1
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                        ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                	Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                	**type**\: bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: maximum_paths
                                                
                                                	Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 1
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', YLeaf(YType.boolean, 'allow-multiple-as')),
                                                        ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)


                                        class Ibgp(Entity):
                                            """
                                            Multipath parameters for iBGP
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to iBGP multipath
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to iBGP multipath
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp, self).__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "ibgp"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to iBGP multipath
                                                
                                                .. attribute:: maximum_paths
                                                
                                                	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 1
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ibgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                    ])
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to iBGP multipath
                                                
                                                .. attribute:: maximum_paths
                                                
                                                	Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 1
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ibgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_paths', YLeaf(YType.uint32, 'maximum-paths')),
                                                    ])
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)


                                    class ApplyPolicy(Entity):
                                        """
                                        Anchor point for routing policies in the model.
                                        Import and export policies are with respect to the local
                                        routing table, i.e., export (send) and import (receive),
                                        depending on the context.
                                        
                                        .. attribute:: config
                                        
                                        	Policy configuration data
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	Operational state for routing policy
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy, self).__init__()

                                            self.yang_name = "apply-policy"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "apply-policy"


                                        class Config(Entity):
                                            """
                                            Policy configuration data.
                                            
                                            .. attribute:: import_policy
                                            
                                            	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                            	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                            	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                            	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                    ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                    ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                    ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                        class State(Entity):
                                            """
                                            Operational state for routing policy
                                            
                                            .. attribute:: import_policy
                                            
                                            	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                            	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                            	list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            	**type**\: list of str
                                            
                                            	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                            	explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                            	**default value**\: REJECT_ROUTE
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', YLeafList(YType.str, 'import-policy')),
                                                    ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                                    ('export_policy', YLeafList(YType.str, 'export-policy')),
                                                    ('default_export_policy', YLeaf(YType.enumeration, 'default-export-policy')),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                    class Ipv4Unicast(Entity):
                                        """
                                        IPv4 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for common IPv4 and IPv6 unicast parameters
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast, self).__init__()

                                            self.yang_name = "ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ipv4-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class Config(Entity):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                        class State(Entity):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)


                                    class Ipv6Unicast(Entity):
                                        """
                                        IPv6 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                        	Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	State information for common IPv4 and IPv6 unicast parameters
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast, self).__init__()

                                            self.yang_name = "ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "ipv6-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class Config(Entity):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                        class State(Entity):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                            	If set to true, send the default\-route to the neighbour(s)
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', YLeaf(YType.boolean, 'send-default-route')),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)


                                    class Ipv4LabeledUnicast(Entity):
                                        """
                                        IPv4 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast, self).__init__()

                                            self.yang_name = "ipv4-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "ipv4-labeled-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class Ipv6LabeledUnicast(Entity):
                                        """
                                        IPv6 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast, self).__init__()

                                            self.yang_name = "ipv6-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "ipv6-labeled-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv4Unicast(Entity):
                                        """
                                        Unicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv4-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv6Unicast(Entity):
                                        """
                                        Unicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv6-unicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv4Multicast(Entity):
                                        """
                                        Multicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv4-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv4-multicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L3VpnIpv6Multicast(Entity):
                                        """
                                        Multicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast, self).__init__()

                                            self.yang_name = "l3vpn-ipv6-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l3vpn-ipv6-multicast"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3VpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L2VpnVpls(Entity):
                                        """
                                        BGP\-signalled VPLS configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls, self).__init__()

                                            self.yang_name = "l2vpn-vpls"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l2vpn-vpls"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-vpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnVpls.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                    class L2VpnEvpn(Entity):
                                        """
                                        BGP EVPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                        	Configure the maximum number of prefixes that will be accepted from a peer
                                        	**type**\:  :py:class:`PrefixLimit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn, self).__init__()

                                            self.yang_name = "l2vpn-evpn"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._children_yang_names.add("prefix-limit")
                                            self._segment_path = lambda: "l2vpn-evpn"


                                        class PrefixLimit(Entity):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                            	Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	State information relating to the prefix\-limit for the AFI\-SAFI
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit, self).__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-evpn"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "prefix-limit"


                                            class Config(Entity):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.Config, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(Entity):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                	Maximum number of prefixes that will be accepted from the neighbour
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                	Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                	**type**\: int
                                                
                                                	**range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                	Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                	**type**\: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                	**range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                	**units**\: seconds
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', YLeaf(YType.uint32, 'max-prefixes')),
                                                        ('shutdown_threshold_pct', YLeaf(YType.uint8, 'shutdown-threshold-pct')),
                                                        ('restart_timer', YLeaf(YType.str, 'restart-timer')),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2VpnEvpn.PrefixLimit.State, ['max_prefixes', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                class Isis(Entity):
                    """
                    This container defines top\-level ISIS configuration and state
                    information.
                    
                    .. attribute:: global_
                    
                    	This container defines global ISIS configuration and state information
                    	**type**\:  :py:class:`Global <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global>`
                    
                    .. attribute:: levels
                    
                    	This container defines ISIS level configuration and state information
                    	**type**\:  :py:class:`Levels <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels>`
                    
                    .. attribute:: interfaces
                    
                    	This container defines global ISIS interface configuration and state information
                    	**type**\:  :py:class:`Interfaces <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces>`
                    
                    

                    """

                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis, self).__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_container_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global)), ("levels", ("levels", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels)), ("interfaces", ("interfaces", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces))])
                        self._child_list_classes = OrderedDict([])
                        self._leafs = OrderedDict()

                        self.global_ = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"
                        self._children_yang_names.add("global")

                        self.levels = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels()
                        self.levels.parent = self
                        self._children_name_map["levels"] = "levels"
                        self._children_yang_names.add("levels")

                        self.interfaces = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                        self._children_yang_names.add("interfaces")
                        self._segment_path = lambda: "isis"


                    class Global(Entity):
                        """
                        This container defines global ISIS configuration and state
                        information.
                        
                        .. attribute:: config
                        
                        	This container defines ISIS global configuration router
                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config>`
                        
                        .. attribute:: state
                        
                        	This container defines state for ISIS global router
                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State>`
                        
                        .. attribute:: lsp_bit
                        
                        	This container defines ISIS LSP Operational Bits
                        	**type**\:  :py:class:`LspBit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit>`
                        
                        .. attribute:: reference_bandwidth
                        
                        	This container defines ISIS Reference Bandwidth
                        	**type**\:  :py:class:`ReferenceBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth>`
                        
                        .. attribute:: nsr
                        
                        	This container defines ISIS Non\-Stop Routing
                        	**type**\:  :py:class:`Nsr <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr>`
                        
                        .. attribute:: graceful_restart
                        
                        	This container defines ISIS Graceful Restart
                        	**type**\:  :py:class:`GracefulRestart <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart>`
                        
                        .. attribute:: timers
                        
                        	This container defines ISIS timers
                        	**type**\:  :py:class:`Timers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers>`
                        
                        .. attribute:: transport
                        
                        	This container defines ISIS transport
                        	**type**\:  :py:class:`Transport <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport>`
                        
                        .. attribute:: mpls
                        
                        	Configuration and operational state relating to MPLS\-related features in IS\-IS
                        	**type**\:  :py:class:`Mpls <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls>`
                        
                        .. attribute:: igp_shortcuts
                        
                        	This container defines IGP shortcuts configuration and state information
                        	**type**\:  :py:class:`IgpShortcuts <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts>`
                        
                        .. attribute:: afi_safi
                        
                        	This container defines address\-family specific configuration and state information
                        	**type**\:  :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi>`
                        
                        .. attribute:: segment_routing
                        
                        	Configuration and operational state relating to segment routing
                        	**type**\:  :py:class:`SegmentRouting <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting>`
                        
                        .. attribute:: inter_level_propagation_policies
                        
                        	Policies to propagate prefixes between IS\-IS levels
                        	**type**\:  :py:class:`InterLevelPropagationPolicies <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State)), ("lsp-bit", ("lsp_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit)), ("reference-bandwidth", ("reference_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth)), ("nsr", ("nsr", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport)), ("mpls", ("mpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls)), ("igp-shortcuts", ("igp_shortcuts", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting)), ("inter-level-propagation-policies", ("inter_level_propagation_policies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies))])
                            self._child_list_classes = OrderedDict([])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"
                            self._children_yang_names.add("config")

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._children_yang_names.add("state")

                            self.lsp_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit()
                            self.lsp_bit.parent = self
                            self._children_name_map["lsp_bit"] = "lsp-bit"
                            self._children_yang_names.add("lsp-bit")

                            self.reference_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth()
                            self.reference_bandwidth.parent = self
                            self._children_name_map["reference_bandwidth"] = "reference-bandwidth"
                            self._children_yang_names.add("reference-bandwidth")

                            self.nsr = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr()
                            self.nsr.parent = self
                            self._children_name_map["nsr"] = "nsr"
                            self._children_yang_names.add("nsr")

                            self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"
                            self._children_yang_names.add("graceful-restart")

                            self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"
                            self._children_yang_names.add("timers")

                            self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"
                            self._children_yang_names.add("transport")

                            self.mpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"
                            self._children_yang_names.add("mpls")

                            self.igp_shortcuts = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts()
                            self.igp_shortcuts.parent = self
                            self._children_name_map["igp_shortcuts"] = "igp-shortcuts"
                            self._children_yang_names.add("igp-shortcuts")

                            self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi()
                            self.afi_safi.parent = self
                            self._children_name_map["afi_safi"] = "afi-safi"
                            self._children_yang_names.add("afi-safi")

                            self.segment_routing = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting()
                            self.segment_routing.parent = self
                            self._children_name_map["segment_routing"] = "segment-routing"
                            self._children_yang_names.add("segment-routing")

                            self.inter_level_propagation_policies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies()
                            self.inter_level_propagation_policies.parent = self
                            self._children_name_map["inter_level_propagation_policies"] = "inter-level-propagation-policies"
                            self._children_yang_names.add("inter-level-propagation-policies")
                            self._segment_path = lambda: "global"


                        class Config(Entity):
                            """
                            This container defines ISIS global configuration router.
                            
                            .. attribute:: authentication_check
                            
                            	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                            	**type**\: bool
                            
                            	**default value**\: true
                            
                            .. attribute:: instance
                            
                            	ISIS Instance
                            	**type**\: str
                            
                            	**default value**\: 0
                            
                            .. attribute:: net
                            
                            	ISIS network entity title (NET). The first 8 bits are usually 49 (private AFI), next 16 bits represent area, next 48 bits represent system id and final 8 bits are set to 0
                            	**type**\: list of str
                            
                            	**pattern:** ^[a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){3,9}\\.[a\-fA\-F0\-9]{2}$
                            
                            .. attribute:: maximum_area_addresses
                            
                            	Maximum areas supported
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 3
                            
                            .. attribute:: level_capability
                            
                            	ISIS level capability(level\-1, level\-2,vlevel\-1\-2)
                            	**type**\:  :py:class:`LevelType <ydk.models.openconfig.openconfig_isis_types.LevelType>`
                            
                            	**default value**\: LEVEL_1_2
                            
                            .. attribute:: max_ecmp_paths
                            
                            	ISIS max\-paths count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: poi_tlv
                            
                            	ISIS purge TLV. When set to true, a TLV is added to purges to record the system ID  of the IS generating the purge
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: iid_tlv
                            
                            	ISIS Instance Identifier TLV. When set to trues, the IID\-TLV identifies the unique instance as well as the topology/topologies to which the PDU applies
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: fast_flooding
                            
                            	When set to true, IS will always flood the LSP that triggered an SPF before the router actually runs the SPF computation
                            	**type**\: bool
                            
                            	**default value**\: true
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config, self).__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('authentication_check', YLeaf(YType.boolean, 'authentication-check')),
                                    ('instance', YLeaf(YType.str, 'instance')),
                                    ('net', YLeafList(YType.str, 'net')),
                                    ('maximum_area_addresses', YLeaf(YType.uint8, 'maximum-area-addresses')),
                                    ('level_capability', YLeaf(YType.enumeration, 'level-capability')),
                                    ('max_ecmp_paths', YLeaf(YType.uint8, 'max-ecmp-paths')),
                                    ('poi_tlv', YLeaf(YType.boolean, 'poi-tlv')),
                                    ('iid_tlv', YLeaf(YType.boolean, 'iid-tlv')),
                                    ('fast_flooding', YLeaf(YType.boolean, 'fast-flooding')),
                                ])
                                self.authentication_check = None
                                self.instance = None
                                self.net = []
                                self.maximum_area_addresses = None
                                self.level_capability = None
                                self.max_ecmp_paths = None
                                self.poi_tlv = None
                                self.iid_tlv = None
                                self.fast_flooding = None
                                self._segment_path = lambda: "config"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config, ['authentication_check', 'instance', 'net', 'maximum_area_addresses', 'level_capability', 'max_ecmp_paths', 'poi_tlv', 'iid_tlv', 'fast_flooding'], name, value)


                        class State(Entity):
                            """
                            This container defines state for ISIS global router.
                            
                            .. attribute:: authentication_check
                            
                            	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                            	**type**\: bool
                            
                            	**default value**\: true
                            
                            .. attribute:: instance
                            
                            	ISIS Instance
                            	**type**\: str
                            
                            	**default value**\: 0
                            
                            .. attribute:: net
                            
                            	ISIS network entity title (NET). The first 8 bits are usually 49 (private AFI), next 16 bits represent area, next 48 bits represent system id and final 8 bits are set to 0
                            	**type**\: list of str
                            
                            	**pattern:** ^[a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){3,9}\\.[a\-fA\-F0\-9]{2}$
                            
                            .. attribute:: maximum_area_addresses
                            
                            	Maximum areas supported
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 3
                            
                            .. attribute:: level_capability
                            
                            	ISIS level capability(level\-1, level\-2,vlevel\-1\-2)
                            	**type**\:  :py:class:`LevelType <ydk.models.openconfig.openconfig_isis_types.LevelType>`
                            
                            	**default value**\: LEVEL_1_2
                            
                            .. attribute:: max_ecmp_paths
                            
                            	ISIS max\-paths count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: poi_tlv
                            
                            	ISIS purge TLV. When set to true, a TLV is added to purges to record the system ID  of the IS generating the purge
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: iid_tlv
                            
                            	ISIS Instance Identifier TLV. When set to trues, the IID\-TLV identifies the unique instance as well as the topology/topologies to which the PDU applies
                            	**type**\: bool
                            
                            	**default value**\: false
                            
                            .. attribute:: fast_flooding
                            
                            	When set to true, IS will always flood the LSP that triggered an SPF before the router actually runs the SPF computation
                            	**type**\: bool
                            
                            	**default value**\: true
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State, self).__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('authentication_check', YLeaf(YType.boolean, 'authentication-check')),
                                    ('instance', YLeaf(YType.str, 'instance')),
                                    ('net', YLeafList(YType.str, 'net')),
                                    ('maximum_area_addresses', YLeaf(YType.uint8, 'maximum-area-addresses')),
                                    ('level_capability', YLeaf(YType.enumeration, 'level-capability')),
                                    ('max_ecmp_paths', YLeaf(YType.uint8, 'max-ecmp-paths')),
                                    ('poi_tlv', YLeaf(YType.boolean, 'poi-tlv')),
                                    ('iid_tlv', YLeaf(YType.boolean, 'iid-tlv')),
                                    ('fast_flooding', YLeaf(YType.boolean, 'fast-flooding')),
                                ])
                                self.authentication_check = None
                                self.instance = None
                                self.net = []
                                self.maximum_area_addresses = None
                                self.level_capability = None
                                self.max_ecmp_paths = None
                                self.poi_tlv = None
                                self.iid_tlv = None
                                self.fast_flooding = None
                                self._segment_path = lambda: "state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State, ['authentication_check', 'instance', 'net', 'maximum_area_addresses', 'level_capability', 'max_ecmp_paths', 'poi_tlv', 'iid_tlv', 'fast_flooding'], name, value)


                        class LspBit(Entity):
                            """
                            This container defines ISIS LSP Operational Bits.
                            
                            .. attribute:: overload_bit
                            
                            	This container defines Overload Bit configuration
                            	**type**\:  :py:class:`OverloadBit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit>`
                            
                            .. attribute:: attached_bit
                            
                            	This container defines Attached Bit
                            	**type**\:  :py:class:`AttachedBit <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit, self).__init__()

                                self.yang_name = "lsp-bit"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("overload-bit", ("overload_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit)), ("attached-bit", ("attached_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.overload_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit()
                                self.overload_bit.parent = self
                                self._children_name_map["overload_bit"] = "overload-bit"
                                self._children_yang_names.add("overload-bit")

                                self.attached_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit()
                                self.attached_bit.parent = self
                                self._children_name_map["attached_bit"] = "attached-bit"
                                self._children_yang_names.add("attached-bit")
                                self._segment_path = lambda: "lsp-bit"


                            class OverloadBit(Entity):
                                """
                                This container defines Overload Bit configuration.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS Overload Bit configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state for ISIS Overload Bit
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State>`
                                
                                .. attribute:: reset_triggers
                                
                                	This container defines state for ISIS Overload Bit reset triggers
                                	**type**\:  :py:class:`ResetTriggers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit, self).__init__()

                                    self.yang_name = "overload-bit"
                                    self.yang_parent_name = "lsp-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State)), ("reset-triggers", ("reset_triggers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.reset_triggers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers()
                                    self.reset_triggers.parent = self
                                    self._children_name_map["reset_triggers"] = "reset-triggers"
                                    self._children_yang_names.add("reset-triggers")
                                    self._segment_path = lambda: "overload-bit"


                                class Config(Entity):
                                    """
                                    This container defines ISIS Overload Bit configuration.
                                    
                                    .. attribute:: set_bit
                                    
                                    	When set to true, IS\-IS overload bit is set
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: set_bit_on_boot
                                    
                                    	When set to true, the IS\-IS overload bit is set on system boot
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: advertise_high_metric
                                    
                                    	When set to true, the local IS advertises links with the highest available metric regardless of their configured metric. The metric value is based on the metric style \- if wide metrics are utilised the metric is advertised as 16777214, otherwise they are advertised with a value of 63
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('set_bit', YLeaf(YType.boolean, 'set-bit')),
                                            ('set_bit_on_boot', YLeaf(YType.boolean, 'set-bit-on-boot')),
                                            ('advertise_high_metric', YLeaf(YType.boolean, 'advertise-high-metric')),
                                        ])
                                        self.set_bit = None
                                        self.set_bit_on_boot = None
                                        self.advertise_high_metric = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config, ['set_bit', 'set_bit_on_boot', 'advertise_high_metric'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state for ISIS Overload Bit.
                                    
                                    .. attribute:: set_bit
                                    
                                    	When set to true, IS\-IS overload bit is set
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: set_bit_on_boot
                                    
                                    	When set to true, the IS\-IS overload bit is set on system boot
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: advertise_high_metric
                                    
                                    	When set to true, the local IS advertises links with the highest available metric regardless of their configured metric. The metric value is based on the metric style \- if wide metrics are utilised the metric is advertised as 16777214, otherwise they are advertised with a value of 63
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('set_bit', YLeaf(YType.boolean, 'set-bit')),
                                            ('set_bit_on_boot', YLeaf(YType.boolean, 'set-bit-on-boot')),
                                            ('advertise_high_metric', YLeaf(YType.boolean, 'advertise-high-metric')),
                                        ])
                                        self.set_bit = None
                                        self.set_bit_on_boot = None
                                        self.advertise_high_metric = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State, ['set_bit', 'set_bit_on_boot', 'advertise_high_metric'], name, value)


                                class ResetTriggers(Entity):
                                    """
                                    This container defines state for ISIS Overload Bit reset triggers
                                    
                                    .. attribute:: reset_trigger
                                    
                                    	This list describes ISIS Overload reset trigger reasons
                                    	**type**\: list of  		 :py:class:`ResetTrigger <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers, self).__init__()

                                        self.yang_name = "reset-triggers"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([("reset-trigger", ("reset_trigger", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger))])
                                        self._leafs = OrderedDict()

                                        self.reset_trigger = YList(self)
                                        self._segment_path = lambda: "reset-triggers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers, [], name, value)


                                    class ResetTrigger(Entity):
                                        """
                                        This list describes ISIS Overload reset trigger reasons.
                                        
                                        .. attribute:: reset_trigger  (key)
                                        
                                        	Reference to the reset trigger reason
                                        	**type**\:  :py:class:`OVERLOADRESETTRIGGERTYPE <ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                        
                                        .. attribute:: config
                                        
                                        	This container defines ISIS Overload Bit reset trigger configuration
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	This container defines state for ISIS Overload Bit reset triggers
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger, self).__init__()

                                            self.yang_name = "reset-trigger"
                                            self.yang_parent_name = "reset-triggers"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['reset_trigger']
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reset_trigger', YLeaf(YType.identityref, 'reset-trigger')),
                                            ])
                                            self.reset_trigger = None

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "reset-trigger" + "[reset-trigger='" + str(self.reset_trigger) + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger, ['reset_trigger'], name, value)


                                        class Config(Entity):
                                            """
                                            This container defines ISIS Overload Bit reset trigger
                                            configuration.
                                            
                                            .. attribute:: reset_trigger
                                            
                                            	In the case that the system sets the overload bit on start, the system should reset the bit (i.e., clear the overload bit) upon the specified trigger
                                            	**type**\:  :py:class:`OVERLOADRESETTRIGGERTYPE <ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                            
                                            .. attribute:: delay
                                            
                                            	If a reset trigger is specified, the system should delay resetting the overload bit for the specified number of seconds after the trigger occurs
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "reset-trigger"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('reset_trigger', YLeaf(YType.identityref, 'reset-trigger')),
                                                    ('delay', YLeaf(YType.uint16, 'delay')),
                                                ])
                                                self.reset_trigger = None
                                                self.delay = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config, ['reset_trigger', 'delay'], name, value)


                                        class State(Entity):
                                            """
                                            This container defines state for ISIS Overload Bit reset
                                            triggers.
                                            
                                            .. attribute:: reset_trigger
                                            
                                            	In the case that the system sets the overload bit on start, the system should reset the bit (i.e., clear the overload bit) upon the specified trigger
                                            	**type**\:  :py:class:`OVERLOADRESETTRIGGERTYPE <ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                            
                                            .. attribute:: delay
                                            
                                            	If a reset trigger is specified, the system should delay resetting the overload bit for the specified number of seconds after the trigger occurs
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: seconds
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "reset-trigger"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('reset_trigger', YLeaf(YType.identityref, 'reset-trigger')),
                                                    ('delay', YLeaf(YType.uint16, 'delay')),
                                                ])
                                                self.reset_trigger = None
                                                self.delay = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State, ['reset_trigger', 'delay'], name, value)


                            class AttachedBit(Entity):
                                """
                                This container defines Attached Bit.
                                
                                .. attribute:: config
                                
                                	This container defines Attached Bit configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state for Link State PDU Bit
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit, self).__init__()

                                    self.yang_name = "attached-bit"
                                    self.yang_parent_name = "lsp-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "attached-bit"


                                class Config(Entity):
                                    """
                                    This container defines Attached Bit configuration.
                                    
                                    .. attribute:: ignore_bit
                                    
                                    	When set to true, if the attached bit is set on an incoming Level 1 IS\-IS, the local system ignores it. In this case the local system does not set a default route to the L1L2 router advertising the PDU with the attached bit set
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: suppress_bit
                                    
                                    	When set to true, if the local IS acts as a L1L2 router, then the attached bit is not advertised in locally generated PDUs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "attached-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore_bit', YLeaf(YType.boolean, 'ignore-bit')),
                                            ('suppress_bit', YLeaf(YType.boolean, 'suppress-bit')),
                                        ])
                                        self.ignore_bit = None
                                        self.suppress_bit = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config, ['ignore_bit', 'suppress_bit'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state for Link State PDU Bit.
                                    
                                    .. attribute:: ignore_bit
                                    
                                    	When set to true, if the attached bit is set on an incoming Level 1 IS\-IS, the local system ignores it. In this case the local system does not set a default route to the L1L2 router advertising the PDU with the attached bit set
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: suppress_bit
                                    
                                    	When set to true, if the local IS acts as a L1L2 router, then the attached bit is not advertised in locally generated PDUs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "attached-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore_bit', YLeaf(YType.boolean, 'ignore-bit')),
                                            ('suppress_bit', YLeaf(YType.boolean, 'suppress-bit')),
                                        ])
                                        self.ignore_bit = None
                                        self.suppress_bit = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State, ['ignore_bit', 'suppress_bit'], name, value)


                        class ReferenceBandwidth(Entity):
                            """
                            This container defines ISIS Reference Bandwidth.
                            
                            .. attribute:: config
                            
                            	This container defines Reference Bandwidth configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state for Reference Bandwidth
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth, self).__init__()

                                self.yang_name = "reference-bandwidth"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "reference-bandwidth"


                            class Config(Entity):
                                """
                                This container defines Reference Bandwidth configuration
                                
                                .. attribute:: reference_bandwidth
                                
                                	ISIS Reference Bandwidth value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "reference-bandwidth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reference_bandwidth', YLeaf(YType.uint32, 'reference-bandwidth')),
                                    ])
                                    self.reference_bandwidth = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config, ['reference_bandwidth'], name, value)


                            class State(Entity):
                                """
                                This container defines state for Reference Bandwidth.
                                
                                .. attribute:: reference_bandwidth
                                
                                	ISIS Reference Bandwidth value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "reference-bandwidth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reference_bandwidth', YLeaf(YType.uint32, 'reference-bandwidth')),
                                    ])
                                    self.reference_bandwidth = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State, ['reference_bandwidth'], name, value)


                        class Nsr(Entity):
                            """
                            This container defines ISIS Non\-Stop Routing.
                            
                            .. attribute:: config
                            
                            	This container defines Non\-Stop\-Routing configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state for Non\-Stop\-Routing
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr, self).__init__()

                                self.yang_name = "nsr"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "nsr"


                            class Config(Entity):
                                """
                                This container defines Non\-Stop\-Routing configuration.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "nsr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config, ['enabled'], name, value)


                            class State(Entity):
                                """
                                This container defines state for Non\-Stop\-Routing
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "nsr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State, ['enabled'], name, value)


                        class GracefulRestart(Entity):
                            """
                            This container defines ISIS Graceful Restart.
                            
                            .. attribute:: config
                            
                            	This container defines ISIS graceful\-restart configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state information for ISIS graceful\-restart
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart, self).__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "graceful-restart"


                            class Config(Entity):
                                """
                                This container defines ISIS graceful\-restart configuration.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: helper_only
                                
                                	Enable or disable the IS\-IS graceful restart helper function. When this leaf is set, the local system does not utilise the IS\-IS graceful restart procedures during its own restart, but supports retaining forwarding information during a remote speaker's restart
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                    ])
                                    self.enabled = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config, ['enabled', 'helper_only'], name, value)


                            class State(Entity):
                                """
                                This container defines state information for ISIS graceful\-restart.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: helper_only
                                
                                	Enable or disable the IS\-IS graceful restart helper function. When this leaf is set, the local system does not utilise the IS\-IS graceful restart procedures during its own restart, but supports retaining forwarding information during a remote speaker's restart
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('helper_only', YLeaf(YType.boolean, 'helper-only')),
                                    ])
                                    self.enabled = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State, ['enabled', 'helper_only'], name, value)


                        class Timers(Entity):
                            """
                            This container defines ISIS timers.
                            
                            .. attribute:: config
                            
                            	This container defines ISIS global timers configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state information for ISIS global timers
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State>`
                            
                            .. attribute:: spf
                            
                            	This container defines ISIS SPF timer settings
                            	**type**\:  :py:class:`Spf <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf>`
                            
                            .. attribute:: lsp_generation
                            
                            	This container defines ISIS LSP Generation
                            	**type**\:  :py:class:`LspGeneration <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers, self).__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State)), ("spf", ("spf", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf)), ("lsp-generation", ("lsp_generation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.spf = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf()
                                self.spf.parent = self
                                self._children_name_map["spf"] = "spf"
                                self._children_yang_names.add("spf")

                                self.lsp_generation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration()
                                self.lsp_generation.parent = self
                                self._children_name_map["lsp_generation"] = "lsp-generation"
                                self._children_yang_names.add("lsp-generation")
                                self._segment_path = lambda: "timers"


                            class Config(Entity):
                                """
                                This container defines ISIS global timers configuration.
                                
                                .. attribute:: lsp_lifetime_interval
                                
                                	Time interval in seconds that specifies how long an LSP remains in LSDB without being refreshed
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: seconds
                                
                                	**default value**\: 1200
                                
                                .. attribute:: lsp_refresh_interval
                                
                                	Time interval in seconds that specifies how often route topology that a device originates is transmitted in LSPs
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: seconds
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_lifetime_interval', YLeaf(YType.uint16, 'lsp-lifetime-interval')),
                                        ('lsp_refresh_interval', YLeaf(YType.uint16, 'lsp-refresh-interval')),
                                    ])
                                    self.lsp_lifetime_interval = None
                                    self.lsp_refresh_interval = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config, ['lsp_lifetime_interval', 'lsp_refresh_interval'], name, value)


                            class State(Entity):
                                """
                                This container defines state information for ISIS global timers.
                                
                                .. attribute:: lsp_lifetime_interval
                                
                                	Time interval in seconds that specifies how long an LSP remains in LSDB without being refreshed
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: seconds
                                
                                	**default value**\: 1200
                                
                                .. attribute:: lsp_refresh_interval
                                
                                	Time interval in seconds that specifies how often route topology that a device originates is transmitted in LSPs
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: seconds
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_lifetime_interval', YLeaf(YType.uint16, 'lsp-lifetime-interval')),
                                        ('lsp_refresh_interval', YLeaf(YType.uint16, 'lsp-refresh-interval')),
                                    ])
                                    self.lsp_lifetime_interval = None
                                    self.lsp_refresh_interval = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State, ['lsp_lifetime_interval', 'lsp_refresh_interval'], name, value)


                            class Spf(Entity):
                                """
                                This container defines ISIS SPF timer settings.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS SPF timers configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS SPF timers
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf, self).__init__()

                                    self.yang_name = "spf"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "spf"


                                class Config(Entity):
                                    """
                                    This container defines ISIS SPF timers configuration.
                                    
                                    .. attribute:: spf_hold_interval
                                    
                                    	SPF Hold Down time interval in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    	**default value**\: 5000
                                    
                                    .. attribute:: spf_first_interval
                                    
                                    	Time interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: spf_second_interval
                                    
                                    	Time interval in milliseconds between the first and second SPF calculation
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "spf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('spf_hold_interval', YLeaf(YType.uint64, 'spf-hold-interval')),
                                            ('spf_first_interval', YLeaf(YType.uint64, 'spf-first-interval')),
                                            ('spf_second_interval', YLeaf(YType.uint64, 'spf-second-interval')),
                                        ])
                                        self.spf_hold_interval = None
                                        self.spf_first_interval = None
                                        self.spf_second_interval = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config, ['spf_hold_interval', 'spf_first_interval', 'spf_second_interval'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for ISIS SPF timers.
                                    
                                    .. attribute:: spf_hold_interval
                                    
                                    	SPF Hold Down time interval in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    	**default value**\: 5000
                                    
                                    .. attribute:: spf_first_interval
                                    
                                    	Time interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: spf_second_interval
                                    
                                    	Time interval in milliseconds between the first and second SPF calculation
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: adaptive_timer
                                    
                                    	ISIS adaptive timer types (linear, exponential)
                                    	**type**\:  :py:class:`AdaptiveTimerType <ydk.models.openconfig.openconfig_isis_types.AdaptiveTimerType>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "spf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('spf_hold_interval', YLeaf(YType.uint64, 'spf-hold-interval')),
                                            ('spf_first_interval', YLeaf(YType.uint64, 'spf-first-interval')),
                                            ('spf_second_interval', YLeaf(YType.uint64, 'spf-second-interval')),
                                            ('adaptive_timer', YLeaf(YType.enumeration, 'adaptive-timer')),
                                        ])
                                        self.spf_hold_interval = None
                                        self.spf_first_interval = None
                                        self.spf_second_interval = None
                                        self.adaptive_timer = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State, ['spf_hold_interval', 'spf_first_interval', 'spf_second_interval', 'adaptive_timer'], name, value)


                            class LspGeneration(Entity):
                                """
                                This container defines ISIS LSP Generation.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS LSP Generation timers configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS LSP Generation timers
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration, self).__init__()

                                    self.yang_name = "lsp-generation"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "lsp-generation"


                                class Config(Entity):
                                    """
                                    This container defines ISIS LSP Generation timers
                                    configuration.
                                    
                                    .. attribute:: lsp_max_wait_interval
                                    
                                    	Time interval in milliseconds that specifies max interval between two consecutive occurrences of an LSP being generated
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: lsp_first_wait_interval
                                    
                                    	Time interval in milliseconds that specifies the first LSP generation delay
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: lsp_second_wait_interval
                                    
                                    	Time interval in milliseconds that specifies the millisecond LSP generation delay
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "lsp-generation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_max_wait_interval', YLeaf(YType.uint64, 'lsp-max-wait-interval')),
                                            ('lsp_first_wait_interval', YLeaf(YType.uint64, 'lsp-first-wait-interval')),
                                            ('lsp_second_wait_interval', YLeaf(YType.uint64, 'lsp-second-wait-interval')),
                                        ])
                                        self.lsp_max_wait_interval = None
                                        self.lsp_first_wait_interval = None
                                        self.lsp_second_wait_interval = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config, ['lsp_max_wait_interval', 'lsp_first_wait_interval', 'lsp_second_wait_interval'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for ISIS LSP Generation
                                    timers.
                                    
                                    .. attribute:: lsp_max_wait_interval
                                    
                                    	Time interval in milliseconds that specifies max interval between two consecutive occurrences of an LSP being generated
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: lsp_first_wait_interval
                                    
                                    	Time interval in milliseconds that specifies the first LSP generation delay
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: lsp_second_wait_interval
                                    
                                    	Time interval in milliseconds that specifies the millisecond LSP generation delay
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    .. attribute:: adaptive_timer
                                    
                                    	ISIS adaptive timer types (linear, exponential)
                                    	**type**\:  :py:class:`AdaptiveTimerType <ydk.models.openconfig.openconfig_isis_types.AdaptiveTimerType>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "lsp-generation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_max_wait_interval', YLeaf(YType.uint64, 'lsp-max-wait-interval')),
                                            ('lsp_first_wait_interval', YLeaf(YType.uint64, 'lsp-first-wait-interval')),
                                            ('lsp_second_wait_interval', YLeaf(YType.uint64, 'lsp-second-wait-interval')),
                                            ('adaptive_timer', YLeaf(YType.enumeration, 'adaptive-timer')),
                                        ])
                                        self.lsp_max_wait_interval = None
                                        self.lsp_first_wait_interval = None
                                        self.lsp_second_wait_interval = None
                                        self.adaptive_timer = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State, ['lsp_max_wait_interval', 'lsp_first_wait_interval', 'lsp_second_wait_interval', 'adaptive_timer'], name, value)


                        class Transport(Entity):
                            """
                            This container defines ISIS transport.
                            
                            .. attribute:: config
                            
                            	This container defines ISIS transport related configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state information for ISIS transport parameters
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport, self).__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "transport"


                            class Config(Entity):
                                """
                                This container defines ISIS transport related configuration.
                                
                                .. attribute:: lsp_mtu_size
                                
                                	The maximum size in bytes of an IS\-IS Link state PDU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "transport"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_mtu_size', YLeaf(YType.uint16, 'lsp-mtu-size')),
                                    ])
                                    self.lsp_mtu_size = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config, ['lsp_mtu_size'], name, value)


                            class State(Entity):
                                """
                                This container defines state information for ISIS transport
                                parameters.
                                
                                .. attribute:: lsp_mtu_size
                                
                                	The maximum size in bytes of an IS\-IS Link state PDU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "transport"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_mtu_size', YLeaf(YType.uint16, 'lsp-mtu-size')),
                                    ])
                                    self.lsp_mtu_size = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State, ['lsp_mtu_size'], name, value)


                        class Mpls(Entity):
                            """
                            Configuration and operational state relating to MPLS\-related
                            features in IS\-IS
                            
                            .. attribute:: igp_ldp_sync
                            
                            	Configuration and operational state relating to synchronisation between the LDP and IS\-IS
                            	**type**\:  :py:class:`IgpLdpSync <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls, self).__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("igp-ldp-sync", ("igp_ldp_sync", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.igp_ldp_sync = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync()
                                self.igp_ldp_sync.parent = self
                                self._children_name_map["igp_ldp_sync"] = "igp-ldp-sync"
                                self._children_yang_names.add("igp-ldp-sync")
                                self._segment_path = lambda: "mpls"


                            class IgpLdpSync(Entity):
                                """
                                Configuration and operational state relating to synchronisation
                                between the LDP and IS\-IS
                                
                                .. attribute:: config
                                
                                	This container defines ISIS/IGP configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS/LDP Sync
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync, self).__init__()

                                    self.yang_name = "igp-ldp-sync"
                                    self.yang_parent_name = "mpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "igp-ldp-sync"


                                class Config(Entity):
                                    """
                                    This container defines ISIS/IGP configuration.
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, rely on IGP/LDP synchronization. IGP cost for link is maintained at max until LDP adjacencies are established 
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    .. attribute:: post_session_up_delay
                                    
                                    	Specifies a delay, expressed in units of seconds, between the LDP session to the IGP neighbor being established, and it being considered synchronized by the IGP
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "igp-ldp-sync"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('post_session_up_delay', YLeaf(YType.uint16, 'post-session-up-delay')),
                                        ])
                                        self.enabled = None
                                        self.post_session_up_delay = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config, ['enabled', 'post_session_up_delay'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for ISIS/LDP Sync.
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, rely on IGP/LDP synchronization. IGP cost for link is maintained at max until LDP adjacencies are established 
                                    	**type**\: bool
                                    
                                    	**default value**\: true
                                    
                                    .. attribute:: post_session_up_delay
                                    
                                    	Specifies a delay, expressed in units of seconds, between the LDP session to the IGP neighbor being established, and it being considered synchronized by the IGP
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: seconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "igp-ldp-sync"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('post_session_up_delay', YLeaf(YType.uint16, 'post-session-up-delay')),
                                        ])
                                        self.enabled = None
                                        self.post_session_up_delay = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State, ['enabled', 'post_session_up_delay'], name, value)


                        class IgpShortcuts(Entity):
                            """
                            This container defines IGP shortcuts configuration and state
                            information.
                            
                            .. attribute:: afi
                            
                            	Address\-family list
                            	**type**\: list of  		 :py:class:`Afi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts, self).__init__()

                                self.yang_name = "igp-shortcuts"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([("afi", ("afi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi))])
                                self._leafs = OrderedDict()

                                self.afi = YList(self)
                                self._segment_path = lambda: "igp-shortcuts"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts, [], name, value)


                            class Afi(Entity):
                                """
                                Address\-family list.
                                
                                .. attribute:: afi_name  (key)
                                
                                	Reference to address\-family type
                                	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                
                                .. attribute:: config
                                
                                	This container defines ISIS Shortcuts configuration parameters
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines ISIS Shortcuts state information
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi, self).__init__()

                                    self.yang_name = "afi"
                                    self.yang_parent_name = "igp-shortcuts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_name']
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                    ])
                                    self.afi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "afi" + "[afi-name='" + str(self.afi_name) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi, ['afi_name'], name, value)


                                class Config(Entity):
                                    """
                                    This container defines ISIS Shortcuts configuration parameters
                                    
                                    .. attribute:: afi_name
                                    
                                    	Address\-family type
                                    	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: nh_type
                                    
                                    	Tunnel NH Type(RSVP,SR). When present it implies that nh\-type shortcut is enabled for a specified AFI
                                    	**type**\: list of   :py:class:`PATHSETUPPROTOCOL <ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "afi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                            ('nh_type', YLeafList(YType.identityref, 'nh-type')),
                                        ])
                                        self.afi_name = None
                                        self.nh_type = []
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config, ['afi_name', 'nh_type'], name, value)


                                class State(Entity):
                                    """
                                    This container defines ISIS Shortcuts state information
                                    
                                    .. attribute:: afi_name
                                    
                                    	Address\-family type
                                    	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: nh_type
                                    
                                    	Tunnel NH Type(RSVP,SR). When present it implies that nh\-type shortcut is enabled for a specified AFI
                                    	**type**\: list of   :py:class:`PATHSETUPPROTOCOL <ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "afi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                            ('nh_type', YLeafList(YType.identityref, 'nh-type')),
                                        ])
                                        self.afi_name = None
                                        self.nh_type = []
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State, ['afi_name', 'nh_type'], name, value)


                        class AfiSafi(Entity):
                            """
                            This container defines address\-family specific configuration
                            and state information.
                            
                            .. attribute:: af
                            
                            	Address\-family/Subsequent Address\-family list
                            	**type**\: list of  		 :py:class:`Af <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi, self).__init__()

                                self.yang_name = "afi-safi"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([])
                                self._child_list_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af))])
                                self._leafs = OrderedDict()

                                self.af = YList(self)
                                self._segment_path = lambda: "afi-safi"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi, [], name, value)


                            class Af(Entity):
                                """
                                Address\-family/Subsequent Address\-family list.
                                
                                .. attribute:: afi_name  (key)
                                
                                	Reference to address\-family type
                                	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                
                                .. attribute:: safi_name  (key)
                                
                                	Reference to subsequent address\-family type
                                	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                
                                .. attribute:: config
                                
                                	This container defines AFI\-SAFI configuration parameters
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines AFI\-SAFI State information
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State>`
                                
                                .. attribute:: multi_topology
                                
                                	This container defines multi\-topology address\-family configuration and state information. ISIS TLV 235, 237
                                	**type**\:  :py:class:`MultiTopology <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af, self).__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afi-safi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_name','safi_name']
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State)), ("multi-topology", ("multi_topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                        ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                    ])
                                    self.afi_name = None
                                    self.safi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.multi_topology = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology()
                                    self.multi_topology.parent = self
                                    self._children_name_map["multi_topology"] = "multi-topology"
                                    self._children_yang_names.add("multi-topology")
                                    self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)


                                class Config(Entity):
                                    """
                                    This container defines AFI\-SAFI configuration parameters
                                    
                                    .. attribute:: afi_name
                                    
                                    	Address\-family type
                                    	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: safi_name
                                    
                                    	Subsequent address\-family type
                                    	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS metric value(default=10)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 10
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                            ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                            ('metric', YLeaf(YType.uint32, 'metric')),
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None
                                        self.metric = None
                                        self.enabled = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                class State(Entity):
                                    """
                                    This container defines AFI\-SAFI State information
                                    
                                    .. attribute:: afi_name
                                    
                                    	Address\-family type
                                    	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: safi_name
                                    
                                    	Subsequent address\-family type
                                    	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                    .. attribute:: metric
                                    
                                    	ISIS metric value(default=10)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**default value**\: 10
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                            ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                            ('metric', YLeaf(YType.uint32, 'metric')),
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None
                                        self.metric = None
                                        self.enabled = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                class MultiTopology(Entity):
                                    """
                                    This container defines multi\-topology address\-family configuration
                                    and state information. ISIS TLV 235, 237.
                                    
                                    .. attribute:: config
                                    
                                    	This container defines AFI\-SAFI multi\-topology configuration parameters
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	This container defines AFI\-SAFI multi\-topology state information
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology, self).__init__()

                                        self.yang_name = "multi-topology"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "multi-topology"


                                    class Config(Entity):
                                        """
                                        This container defines AFI\-SAFI multi\-topology configuration
                                        parameters
                                        
                                        .. attribute:: afi_name
                                        
                                        	Address\-family type
                                        	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                        	Subsequent address\-family type
                                        	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "multi-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config, ['afi_name', 'safi_name'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines AFI\-SAFI multi\-topology state information
                                        
                                        .. attribute:: afi_name
                                        
                                        	Address\-family type
                                        	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                        	Subsequent address\-family type
                                        	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "multi-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State, ['afi_name', 'safi_name', 'enabled'], name, value)


                        class SegmentRouting(Entity):
                            """
                            Configuration and operational state relating to segment routing.
                            
                            .. attribute:: config
                            
                            	Configuration parameters relating to the configuration of segment routing for the IGP instance
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config>`
                            
                            .. attribute:: state
                            
                            	Operational state parameters relating to segment routing for the IGP instance
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting, self).__init__()

                                self.yang_name = "segment-routing"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")
                                self._segment_path = lambda: "segment-routing"


                            class Config(Entity):
                                """
                                Configuration parameters relating to the configuration of segment
                                routing for the IGP instance.
                                
                                .. attribute:: enabled
                                
                                	When this leaf is set to true, the segment routing extensions are utilised within the IGP
                                	**type**\: bool
                                
                                .. attribute:: srgb
                                
                                	A reference to the Segment Routing Global Block (SRGB) that is to be used by this IGP instance
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                                
                                .. attribute:: srlb
                                
                                	A reference to the Segment Routing Local Block (SRLB) that is to be advertised by the IGP instance
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "segment-routing"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('srgb', YLeaf(YType.str, 'srgb')),
                                        ('srlb', YLeaf(YType.str, 'srlb')),
                                    ])
                                    self.enabled = None
                                    self.srgb = None
                                    self.srlb = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config, ['enabled', 'srgb', 'srlb'], name, value)


                            class State(Entity):
                                """
                                Operational state parameters relating to segment routing for the
                                IGP instance.
                                
                                .. attribute:: enabled
                                
                                	When this leaf is set to true, the segment routing extensions are utilised within the IGP
                                	**type**\: bool
                                
                                .. attribute:: srgb
                                
                                	A reference to the Segment Routing Global Block (SRGB) that is to be used by this IGP instance
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                                
                                .. attribute:: srlb
                                
                                	A reference to the Segment Routing Local Block (SRLB) that is to be advertised by the IGP instance
                                	**type**\: str
                                
                                	**refers to**\:  :py:class:`local_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "segment-routing"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('srgb', YLeaf(YType.str, 'srgb')),
                                        ('srlb', YLeaf(YType.str, 'srlb')),
                                    ])
                                    self.enabled = None
                                    self.srgb = None
                                    self.srlb = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State, ['enabled', 'srgb', 'srlb'], name, value)


                        class InterLevelPropagationPolicies(Entity):
                            """
                            Policies to propagate prefixes between IS\-IS levels.
                            
                            .. attribute:: level1_to_level2
                            
                            	Policies relating to prefixes to be propagated from Level 1 to Level 2
                            	**type**\:  :py:class:`Level1ToLevel2 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2>`
                            
                            .. attribute:: level2_to_level1
                            
                            	Policies relating to prefixes to be propagated from Level2 to Level 1
                            	**type**\:  :py:class:`Level2ToLevel1 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies, self).__init__()

                                self.yang_name = "inter-level-propagation-policies"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_container_classes = OrderedDict([("level1-to-level2", ("level1_to_level2", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2)), ("level2-to-level1", ("level2_to_level1", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict()

                                self.level1_to_level2 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2()
                                self.level1_to_level2.parent = self
                                self._children_name_map["level1_to_level2"] = "level1-to-level2"
                                self._children_yang_names.add("level1-to-level2")

                                self.level2_to_level1 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1()
                                self.level2_to_level1.parent = self
                                self._children_name_map["level2_to_level1"] = "level2-to-level1"
                                self._children_yang_names.add("level2-to-level1")
                                self._segment_path = lambda: "inter-level-propagation-policies"


                            class Level1ToLevel2(Entity):
                                """
                                Policies relating to prefixes to be propagated from
                                Level 1 to Level 2.
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the propagation of prefixes from IS\-IS Level 1 to Level 2
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state parameters relating to the propagation of prefixes from IS\-IS Level 1 to Level 2
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2, self).__init__()

                                    self.yang_name = "level1-to-level2"
                                    self.yang_parent_name = "inter-level-propagation-policies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "level1-to-level2"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the propagation
                                    of prefixes from IS\-IS Level 1 to Level 2.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "level1-to-level2"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config, ['import_policy', 'default_import_policy'], name, value)


                                class State(Entity):
                                    """
                                    Operational state parameters relating to the
                                    propagation of prefixes from IS\-IS Level 1 to Level 2.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "level1-to-level2"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State, ['import_policy', 'default_import_policy'], name, value)


                            class Level2ToLevel1(Entity):
                                """
                                Policies relating to prefixes to be propagated from
                                Level2 to Level 1.
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to the propagation of prefixes from IS\-IS Level 2 to Level 1
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state parameters relating to the propagation of prefixes from IS\-IS Level 2 to Level 1
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1, self).__init__()

                                    self.yang_name = "level2-to-level1"
                                    self.yang_parent_name = "inter-level-propagation-policies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "level2-to-level1"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to the propagation
                                    of prefixes from IS\-IS Level 2 to Level 1.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "level2-to-level1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config, ['import_policy', 'default_import_policy'], name, value)


                                class State(Entity):
                                    """
                                    Operational state parameters relating to the propagation
                                    of prefixes from IS\-IS Level 2 to Level 1.
                                    
                                    .. attribute:: import_policy
                                    
                                    	list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    	**type**\: list of str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                    	explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    	**type**\:  :py:class:`DefaultPolicyType <ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                    	**default value**\: REJECT_ROUTE
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "level2-to-level1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', YLeafList(YType.str, 'import-policy')),
                                            ('default_import_policy', YLeaf(YType.enumeration, 'default-import-policy')),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State, ['import_policy', 'default_import_policy'], name, value)


                    class Levels(Entity):
                        """
                        This container defines ISIS level configuration and state
                        information.
                        
                        .. attribute:: level
                        
                        	Configuration and operational state parameters related to a particular level within the IS\-IS protocol instance
                        	**type**\: list of  		 :py:class:`Level <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels, self).__init__()

                            self.yang_name = "levels"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([("level", ("level", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level))])
                            self._leafs = OrderedDict()

                            self.level = YList(self)
                            self._segment_path = lambda: "levels"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels, [], name, value)


                        class Level(Entity):
                            """
                            Configuration and operational state parameters related to a
                            particular level within the IS\-IS protocol instance
                            
                            .. attribute:: level_number  (key)
                            
                            	Reference to ISIS level\-number
                            	**type**\: int
                            
                            	**range:** 1..2
                            
                            	**refers to**\:  :py:class:`level_number <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config>`
                            
                            .. attribute:: config
                            
                            	This container defines ISIS level based configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines ISIS level state information
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State>`
                            
                            .. attribute:: system_level_counters
                            
                            	This container defines ISIS system level counters
                            	**type**\:  :py:class:`SystemLevelCounters <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters>`
                            
                            .. attribute:: link_state_database
                            
                            	This container defines ISIS LSDB
                            	**type**\:  :py:class:`LinkStateDatabase <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase>`
                            
                            .. attribute:: traffic_engineering
                            
                            	This container defines ISIS TE
                            	**type**\:  :py:class:`TrafficEngineering <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering>`
                            
                            .. attribute:: route_preference
                            
                            	This container defines Administrative Distance (or preference) assigned to ISIS routes (level1 internal, level2 internal, level1 external, level2 external)
                            	**type**\:  :py:class:`RoutePreference <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference>`
                            
                            .. attribute:: authentication
                            
                            	This container defines ISIS authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level, self).__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "levels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['level_number']
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State)), ("system-level-counters", ("system_level_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters)), ("link-state-database", ("link_state_database", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase)), ("traffic-engineering", ("traffic_engineering", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering)), ("route-preference", ("route_preference", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('level_number', YLeaf(YType.str, 'level-number')),
                                ])
                                self.level_number = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.system_level_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters()
                                self.system_level_counters.parent = self
                                self._children_name_map["system_level_counters"] = "system-level-counters"
                                self._children_yang_names.add("system-level-counters")

                                self.link_state_database = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase()
                                self.link_state_database.parent = self
                                self._children_name_map["link_state_database"] = "link-state-database"
                                self._children_yang_names.add("link-state-database")

                                self.traffic_engineering = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering()
                                self.traffic_engineering.parent = self
                                self._children_name_map["traffic_engineering"] = "traffic-engineering"
                                self._children_yang_names.add("traffic-engineering")

                                self.route_preference = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference()
                                self.route_preference.parent = self
                                self._children_name_map["route_preference"] = "route-preference"
                                self._children_yang_names.add("route-preference")

                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")
                                self._segment_path = lambda: "level" + "[level-number='" + str(self.level_number) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level, ['level_number'], name, value)


                            class Config(Entity):
                                """
                                This container defines ISIS level based configuration.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: level_number
                                
                                	ISIS level number (level\-1, level\-2)
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: metric_style
                                
                                	ISIS metric style types(narrow, wide)
                                	**type**\:  :py:class:`MetricStyle <ydk.models.openconfig.openconfig_isis_types.MetricStyle>`
                                
                                .. attribute:: authentication_check
                                
                                	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('level_number', YLeaf(YType.uint8, 'level-number')),
                                        ('metric_style', YLeaf(YType.enumeration, 'metric-style')),
                                        ('authentication_check', YLeaf(YType.boolean, 'authentication-check')),
                                    ])
                                    self.enabled = None
                                    self.level_number = None
                                    self.metric_style = None
                                    self.authentication_check = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config, ['enabled', 'level_number', 'metric_style', 'authentication_check'], name, value)


                            class State(Entity):
                                """
                                This container defines ISIS level state information.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: level_number
                                
                                	ISIS level number (level\-1, level\-2)
                                	**type**\: int
                                
                                	**range:** 1..2
                                
                                .. attribute:: metric_style
                                
                                	ISIS metric style types(narrow, wide)
                                	**type**\:  :py:class:`MetricStyle <ydk.models.openconfig.openconfig_isis_types.MetricStyle>`
                                
                                .. attribute:: authentication_check
                                
                                	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                	**type**\: bool
                                
                                	**default value**\: true
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('level_number', YLeaf(YType.uint8, 'level-number')),
                                        ('metric_style', YLeaf(YType.enumeration, 'metric-style')),
                                        ('authentication_check', YLeaf(YType.boolean, 'authentication-check')),
                                    ])
                                    self.enabled = None
                                    self.level_number = None
                                    self.metric_style = None
                                    self.authentication_check = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State, ['enabled', 'level_number', 'metric_style', 'authentication_check'], name, value)


                            class SystemLevelCounters(Entity):
                                """
                                This container defines ISIS system level counters.
                                
                                .. attribute:: state
                                
                                	The container defines a list of system counters for the IS
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters, self).__init__()

                                    self.yang_name = "system-level-counters"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "system-level-counters"


                                class State(Entity):
                                    """
                                    The container defines a list of system counters for the IS.
                                    
                                    .. attribute:: corrupted_lsps
                                    
                                    	Number of corrupted in\-memory LSPs detected. LSPs received from the wire with a bad checksum are silently dropped and not counted. LSPs received from the wire with parse errors are counted by lsp\-errors. MIB Entry\: SysCorrLSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: database_overloads
                                    
                                    	Number of times the database has become overloaded. MIB entry\: SysLSPL(Level)DbaseOloads
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: manual_address_drop_from_areas
                                    
                                    	Number of times a manual address has been dropped from area. MIB Entry\: SysManAddrDropFromAreas
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exceed_max_seq_nums
                                    
                                    	The number of times the system has attempted to exceed the maximum sequence number. MIB Entry\: SysAttmptToExMaxSeqNums
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: seq_num_skips
                                    
                                    	Number of times a sequence number skip has occurred. MIB Entry\: SysSeqNumSkips
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: own_lsp_purges
                                    
                                    	Number of times a zero\-aged copy of the system's own LSP is received from some other node. MIB Entry\: isisSysOwnLSPPurges
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: id_len_mismatch
                                    
                                    	Number of times a PDU is received with a different value for ID field length from that of the receiving system. MIB Entry\: isisSysIDFieldLenMismatches
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: part_changes
                                    
                                    	The number of partition changes detected. MIB Entry\: SysPartChanges
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_area_address_mismatches
                                    
                                    	Number of times a PDU is received with a different value for MaximumAreaAddresses from that of the receiving system. MIB Entry\: SysMaxAreaAddrMismatches
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auth_fails
                                    
                                    	The number of authentication key failures. MIB Entry\: SysAuthFails
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_runs
                                    
                                    	The number of times SPF was ran at this level
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auth_type_fails
                                    
                                    	The number of authentication type mismatches
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsp_errors
                                    
                                    	The number of received LSPs with errors
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "system-level-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('corrupted_lsps', YLeaf(YType.uint32, 'corrupted-lsps')),
                                            ('database_overloads', YLeaf(YType.uint32, 'database-overloads')),
                                            ('manual_address_drop_from_areas', YLeaf(YType.uint32, 'manual-address-drop-from-areas')),
                                            ('exceed_max_seq_nums', YLeaf(YType.uint32, 'exceed-max-seq-nums')),
                                            ('seq_num_skips', YLeaf(YType.uint32, 'seq-num-skips')),
                                            ('own_lsp_purges', YLeaf(YType.uint32, 'own-lsp-purges')),
                                            ('id_len_mismatch', YLeaf(YType.uint32, 'id-len-mismatch')),
                                            ('part_changes', YLeaf(YType.uint32, 'part-changes')),
                                            ('max_area_address_mismatches', YLeaf(YType.uint32, 'max-area-address-mismatches')),
                                            ('auth_fails', YLeaf(YType.uint32, 'auth-fails')),
                                            ('spf_runs', YLeaf(YType.uint32, 'spf-runs')),
                                            ('auth_type_fails', YLeaf(YType.uint32, 'auth-type-fails')),
                                            ('lsp_errors', YLeaf(YType.uint32, 'lsp-errors')),
                                        ])
                                        self.corrupted_lsps = None
                                        self.database_overloads = None
                                        self.manual_address_drop_from_areas = None
                                        self.exceed_max_seq_nums = None
                                        self.seq_num_skips = None
                                        self.own_lsp_purges = None
                                        self.id_len_mismatch = None
                                        self.part_changes = None
                                        self.max_area_address_mismatches = None
                                        self.auth_fails = None
                                        self.spf_runs = None
                                        self.auth_type_fails = None
                                        self.lsp_errors = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State, ['corrupted_lsps', 'database_overloads', 'manual_address_drop_from_areas', 'exceed_max_seq_nums', 'seq_num_skips', 'own_lsp_purges', 'id_len_mismatch', 'part_changes', 'max_area_address_mismatches', 'auth_fails', 'spf_runs', 'auth_type_fails', 'lsp_errors'], name, value)


                            class LinkStateDatabase(Entity):
                                """
                                This container defines ISIS LSDB.
                                
                                .. attribute:: lsp
                                
                                	This list describes LSPs in the LSDB
                                	**type**\: list of  		 :py:class:`Lsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase, self).__init__()

                                    self.yang_name = "link-state-database"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([("lsp", ("lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp))])
                                    self._leafs = OrderedDict()

                                    self.lsp = YList(self)
                                    self._segment_path = lambda: "link-state-database"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase, [], name, value)


                                class Lsp(Entity):
                                    """
                                    This list describes LSPs in the LSDB.
                                    
                                    .. attribute:: lsp_id  (key)
                                    
                                    	A reference to the Link State PDU ID
                                    	**type**\: str
                                    
                                    	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9][0\-9]\-[0\-9][0\-9]$
                                    
                                    	**refers to**\:  :py:class:`lsp_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State>`
                                    
                                    .. attribute:: state
                                    
                                    	State parameters of Link State PDU
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State>`
                                    
                                    .. attribute:: tlvs
                                    
                                    	This container defines Link State PDU State TLVs
                                    	**type**\:  :py:class:`Tlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs>`
                                    
                                    .. attribute:: undefined_tlvs
                                    
                                    	Surrounding container for a list of unknown TLVs
                                    	**type**\:  :py:class:`UndefinedTlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp, self).__init__()

                                        self.yang_name = "lsp"
                                        self.yang_parent_name = "link-state-database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['lsp_id']
                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State)), ("tlvs", ("tlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs)), ("undefined-tlvs", ("undefined_tlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_id', YLeaf(YType.str, 'lsp-id')),
                                        ])
                                        self.lsp_id = None

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")

                                        self.tlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs()
                                        self.tlvs.parent = self
                                        self._children_name_map["tlvs"] = "tlvs"
                                        self._children_yang_names.add("tlvs")

                                        self.undefined_tlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs()
                                        self.undefined_tlvs.parent = self
                                        self._children_name_map["undefined_tlvs"] = "undefined-tlvs"
                                        self._children_yang_names.add("undefined-tlvs")
                                        self._segment_path = lambda: "lsp" + "[lsp-id='" + str(self.lsp_id) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp, ['lsp_id'], name, value)


                                    class State(Entity):
                                        """
                                        State parameters of Link State PDU.
                                        
                                        .. attribute:: lsp_id
                                        
                                        	LSP ID of the LSP
                                        	**type**\: str
                                        
                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9][0\-9]\-[0\-9][0\-9]$
                                        
                                        .. attribute:: maximum_area_addresses
                                        
                                        	Number of area addresses permitted for this ISs area. 0 indicates the IS only supports three area addresses (by default). Any number inclusive of 1 and 254 indicates the number of areas allowed
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: version
                                        
                                        	PDU version. This is set to 1
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: version2
                                        
                                        	PDU version2. This is set to 1
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: id_length
                                        
                                        	Length of the ID field of NSAP addresses and NETs used in this routing domain
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: pdu_type
                                        
                                        	Link State PDU type
                                        	**type**\:  :py:class:`PduType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.PduType>`
                                        
                                        .. attribute:: remaining_lifetime
                                        
                                        	Remaining lifetime in seconds before the LSP expiration
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: seconds
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Sequence number of the LSP
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum of the LSP
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: pdu_length
                                        
                                        	Total length of the LSP
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	LSP Type\-Block flags
                                        	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.Flags>`
                                        
                                        .. attribute:: is_type
                                        
                                        	Type of neighboring system
                                        	**type**\: int
                                        
                                        	**range:** 1..2
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsp_id', YLeaf(YType.str, 'lsp-id')),
                                                ('maximum_area_addresses', YLeaf(YType.uint8, 'maximum-area-addresses')),
                                                ('version', YLeaf(YType.uint8, 'version')),
                                                ('version2', YLeaf(YType.uint8, 'version2')),
                                                ('id_length', YLeaf(YType.uint8, 'id-length')),
                                                ('pdu_type', YLeaf(YType.enumeration, 'pdu-type')),
                                                ('remaining_lifetime', YLeaf(YType.uint16, 'remaining-lifetime')),
                                                ('sequence_number', YLeaf(YType.uint32, 'sequence-number')),
                                                ('checksum', YLeaf(YType.uint16, 'checksum')),
                                                ('pdu_length', YLeaf(YType.uint16, 'pdu-length')),
                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                ('is_type', YLeaf(YType.uint8, 'is-type')),
                                            ])
                                            self.lsp_id = None
                                            self.maximum_area_addresses = None
                                            self.version = None
                                            self.version2 = None
                                            self.id_length = None
                                            self.pdu_type = None
                                            self.remaining_lifetime = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.pdu_length = None
                                            self.flags = []
                                            self.is_type = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State, ['lsp_id', 'maximum_area_addresses', 'version', 'version2', 'id_length', 'pdu_type', 'remaining_lifetime', 'sequence_number', 'checksum', 'pdu_length', 'flags', 'is_type'], name, value)

                                        class Flags(Enum):
                                            """
                                            Flags (Enum Class)

                                            LSP Type\-Block flags.

                                            .. data:: PARTITION_REPAIR = 0

                                            	When set, the originator supports partition

                                            	repair.

                                            .. data:: ATTACHED_ERROR = 1

                                            	When set, the originator is attached to another

                                            	area using the referred metric.

                                            .. data:: ATTACHED_EXPENSE = 2

                                            	When set, the originator is attached to another

                                            	area using the referred metric.

                                            .. data:: ATTACHED_DELAY = 3

                                            	When set, the originator is attached to another

                                            	area using the referred metric.

                                            .. data:: ATTACHED_DEFAULT = 4

                                            	When set, the originator is attached to another

                                            	area using the referred metric.

                                            .. data:: OVERLOAD = 5

                                            	When set, the originator is overloaded, and must

                                            	be avoided in path calculation.

                                            """

                                            PARTITION_REPAIR = Enum.YLeaf(0, "PARTITION_REPAIR")

                                            ATTACHED_ERROR = Enum.YLeaf(1, "ATTACHED_ERROR")

                                            ATTACHED_EXPENSE = Enum.YLeaf(2, "ATTACHED_EXPENSE")

                                            ATTACHED_DELAY = Enum.YLeaf(3, "ATTACHED_DELAY")

                                            ATTACHED_DEFAULT = Enum.YLeaf(4, "ATTACHED_DEFAULT")

                                            OVERLOAD = Enum.YLeaf(5, "OVERLOAD")


                                        class PduType(Enum):
                                            """
                                            PduType (Enum Class)

                                            Link State PDU type.

                                            .. data:: LEVEL_1 = 0

                                            	This enum describes ISIS level 1 PDU.

                                            .. data:: LEVEL_2 = 1

                                            	This enum describes ISIS level 2 PDU.

                                            """

                                            LEVEL_1 = Enum.YLeaf(0, "LEVEL_1")

                                            LEVEL_2 = Enum.YLeaf(1, "LEVEL_2")



                                    class Tlvs(Entity):
                                        """
                                        This container defines Link State PDU State TLVs.
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLV types in the LSDB for the specified LSP
                                        	**type**\: list of  		 :py:class:`Tlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs, self).__init__()

                                            self.yang_name = "tlvs"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([("tlv", ("tlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv))])
                                            self._leafs = OrderedDict()

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "tlvs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs, [], name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLV types in the LSDB for the specified LSP.
                                            
                                            .. attribute:: type  (key)
                                            
                                            	Reference to the TLV's type
                                            	**type**\:  :py:class:`ISISTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISTLVTYPE>`
                                            
                                            .. attribute:: state
                                            
                                            	Operational state parameters relating to the specified LSP
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State>`
                                            
                                            .. attribute:: area_address
                                            
                                            	This container defines TLV 1
                                            	**type**\:  :py:class:`AreaAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress>`
                                            
                                            .. attribute:: lsp_buffer_size
                                            
                                            	This container defines TLV 14 \- the LSP Buffer Size TLV
                                            	**type**\:  :py:class:`LspBufferSize <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize>`
                                            
                                            .. attribute:: nlpid
                                            
                                            	This container defines TLV 129
                                            	**type**\:  :py:class:`Nlpid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid>`
                                            
                                            .. attribute:: hostname
                                            
                                            	This container defines TLV 137
                                            	**type**\:  :py:class:`Hostname <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname>`
                                            
                                            .. attribute:: ipv4_interface_addresses
                                            
                                            	This container defines TLV 132
                                            	**type**\:  :py:class:`Ipv4InterfaceAddresses <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses>`
                                            
                                            .. attribute:: ipv6_interface_addresses
                                            
                                            	This container defines TLV 232
                                            	**type**\:  :py:class:`Ipv6InterfaceAddresses <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses>`
                                            
                                            .. attribute:: ipv4_te_router_id
                                            
                                            	This container defines TLV 134
                                            	**type**\:  :py:class:`Ipv4TeRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId>`
                                            
                                            .. attribute:: ipv6_te_router_id
                                            
                                            	This container defines TLV 140
                                            	**type**\:  :py:class:`Ipv6TeRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId>`
                                            
                                            .. attribute:: instance_ids
                                            
                                            	This container defines ISIS Instance Identifier TLV
                                            	**type**\:  :py:class:`InstanceIds <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds>`
                                            
                                            .. attribute:: ipv4_srlgs
                                            
                                            	This container defines ISIS SRLG TLV 138
                                            	**type**\:  :py:class:`Ipv4Srlgs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs>`
                                            
                                            .. attribute:: ipv6_srlgs
                                            
                                            	This container defines ISIS SRLG TLV
                                            	**type**\:  :py:class:`Ipv6Srlgs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs>`
                                            
                                            .. attribute:: purge_oi
                                            
                                            	This container defines ISIS purge TLV
                                            	**type**\:  :py:class:`PurgeOi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi>`
                                            
                                            .. attribute:: router_capabilities
                                            
                                            	This container defines router capabilities
                                            	**type**\:  :py:class:`RouterCapabilities <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities>`
                                            
                                            .. attribute:: is_reachability
                                            
                                            	This container describes list of ISIS neighbors and attributes
                                            	**type**\:  :py:class:`IsReachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability>`
                                            
                                            .. attribute:: ipv4_internal_reachability
                                            
                                            	This container defines list of IPv4 internal reachability information
                                            	**type**\:  :py:class:`Ipv4InternalReachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability>`
                                            
                                            .. attribute:: ipv4_external_reachability
                                            
                                            	This container defines list of IPv4 external reachability information
                                            	**type**\:  :py:class:`Ipv4ExternalReachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability>`
                                            
                                            .. attribute:: authentication
                                            
                                            	This container defines authentication information of the node
                                            	**type**\:  :py:class:`Authentication <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication>`
                                            
                                            .. attribute:: extended_is_reachability
                                            
                                            	This container defines list of ISIS extended reachability neighbors
                                            	**type**\:  :py:class:`ExtendedIsReachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability>`
                                            
                                            .. attribute:: extended_ipv4_reachability
                                            
                                            	This container defines list of IPv4 extended reachability information
                                            	**type**\:  :py:class:`ExtendedIpv4Reachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability>`
                                            
                                            .. attribute:: ipv6_reachability
                                            
                                            	This container defines list of IPv6 reachability information
                                            	**type**\:  :py:class:`Ipv6Reachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability>`
                                            
                                            .. attribute:: multi_topology
                                            
                                            	This container defines the topology supported
                                            	**type**\:  :py:class:`MultiTopology <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology>`
                                            
                                            .. attribute:: isis_neighbor_attribute
                                            
                                            	This container defines list of ISIS topology neighbors for extended ISIS LSP (multiple system IDs). 
                                            	**type**\:  :py:class:`IsisNeighborAttribute <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute>`
                                            
                                            .. attribute:: is_alias_id
                                            
                                            	This container defines the IS\-Alias TLV which allows extension\-capable ISs to recognize the Originating System of an Extended LSP set. It identifies the Normal system\- id of the Originating System
                                            	**type**\:  :py:class:`IsAliasId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId>`
                                            
                                            .. attribute:: mt_isn
                                            
                                            	This container defines list of ISIS multi\-topology neighbors
                                            	**type**\:  :py:class:`MtIsn <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn>`
                                            
                                            .. attribute:: mt_isis_neighbor_attribute
                                            
                                            	This container defines list of ISIS multi\-topology neighbors
                                            	**type**\:  :py:class:`MtIsisNeighborAttribute <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute>`
                                            
                                            .. attribute:: mt_ipv4_reachability
                                            
                                            	This container defines list of IPv4 reachability Information in multi\-topology environment
                                            	**type**\:  :py:class:`MtIpv4Reachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability>`
                                            
                                            .. attribute:: mt_ipv6_reachability
                                            
                                            	This container defines list of IPv6 reachability information in multi \- topology environment
                                            	**type**\:  :py:class:`MtIpv6Reachability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "tlvs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['type']
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State)), ("area-address", ("area_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress)), ("lsp-buffer-size", ("lsp_buffer_size", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize)), ("nlpid", ("nlpid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid)), ("hostname", ("hostname", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname)), ("ipv4-interface-addresses", ("ipv4_interface_addresses", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses)), ("ipv6-interface-addresses", ("ipv6_interface_addresses", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses)), ("ipv4-te-router-id", ("ipv4_te_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId)), ("ipv6-te-router-id", ("ipv6_te_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId)), ("instance-ids", ("instance_ids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds)), ("ipv4-srlgs", ("ipv4_srlgs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs)), ("ipv6-srlgs", ("ipv6_srlgs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs)), ("purge-oi", ("purge_oi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi)), ("router-capabilities", ("router_capabilities", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities)), ("is-reachability", ("is_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability)), ("ipv4-internal-reachability", ("ipv4_internal_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability)), ("ipv4-external-reachability", ("ipv4_external_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication)), ("extended-is-reachability", ("extended_is_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability)), ("extended-ipv4-reachability", ("extended_ipv4_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability)), ("ipv6-reachability", ("ipv6_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability)), ("multi-topology", ("multi_topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology)), ("isis-neighbor-attribute", ("isis_neighbor_attribute", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute)), ("is-alias-id", ("is_alias_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId)), ("mt-isn", ("mt_isn", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn)), ("mt-isis-neighbor-attribute", ("mt_isis_neighbor_attribute", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute)), ("mt-ipv4-reachability", ("mt_ipv4_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability)), ("mt-ipv6-reachability", ("mt_ipv6_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.identityref, 'type')),
                                                ])
                                                self.type = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")

                                                self.area_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress()
                                                self.area_address.parent = self
                                                self._children_name_map["area_address"] = "area-address"
                                                self._children_yang_names.add("area-address")

                                                self.lsp_buffer_size = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize()
                                                self.lsp_buffer_size.parent = self
                                                self._children_name_map["lsp_buffer_size"] = "lsp-buffer-size"
                                                self._children_yang_names.add("lsp-buffer-size")

                                                self.nlpid = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid()
                                                self.nlpid.parent = self
                                                self._children_name_map["nlpid"] = "nlpid"
                                                self._children_yang_names.add("nlpid")

                                                self.hostname = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname()
                                                self.hostname.parent = self
                                                self._children_name_map["hostname"] = "hostname"
                                                self._children_yang_names.add("hostname")

                                                self.ipv4_interface_addresses = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses()
                                                self.ipv4_interface_addresses.parent = self
                                                self._children_name_map["ipv4_interface_addresses"] = "ipv4-interface-addresses"
                                                self._children_yang_names.add("ipv4-interface-addresses")

                                                self.ipv6_interface_addresses = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses()
                                                self.ipv6_interface_addresses.parent = self
                                                self._children_name_map["ipv6_interface_addresses"] = "ipv6-interface-addresses"
                                                self._children_yang_names.add("ipv6-interface-addresses")

                                                self.ipv4_te_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId()
                                                self.ipv4_te_router_id.parent = self
                                                self._children_name_map["ipv4_te_router_id"] = "ipv4-te-router-id"
                                                self._children_yang_names.add("ipv4-te-router-id")

                                                self.ipv6_te_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId()
                                                self.ipv6_te_router_id.parent = self
                                                self._children_name_map["ipv6_te_router_id"] = "ipv6-te-router-id"
                                                self._children_yang_names.add("ipv6-te-router-id")

                                                self.instance_ids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds()
                                                self.instance_ids.parent = self
                                                self._children_name_map["instance_ids"] = "instance-ids"
                                                self._children_yang_names.add("instance-ids")

                                                self.ipv4_srlgs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs()
                                                self.ipv4_srlgs.parent = self
                                                self._children_name_map["ipv4_srlgs"] = "ipv4-srlgs"
                                                self._children_yang_names.add("ipv4-srlgs")

                                                self.ipv6_srlgs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs()
                                                self.ipv6_srlgs.parent = self
                                                self._children_name_map["ipv6_srlgs"] = "ipv6-srlgs"
                                                self._children_yang_names.add("ipv6-srlgs")

                                                self.purge_oi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi()
                                                self.purge_oi.parent = self
                                                self._children_name_map["purge_oi"] = "purge-oi"
                                                self._children_yang_names.add("purge-oi")

                                                self.router_capabilities = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities()
                                                self.router_capabilities.parent = self
                                                self._children_name_map["router_capabilities"] = "router-capabilities"
                                                self._children_yang_names.add("router-capabilities")

                                                self.is_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability()
                                                self.is_reachability.parent = self
                                                self._children_name_map["is_reachability"] = "is-reachability"
                                                self._children_yang_names.add("is-reachability")

                                                self.ipv4_internal_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability()
                                                self.ipv4_internal_reachability.parent = self
                                                self._children_name_map["ipv4_internal_reachability"] = "ipv4-internal-reachability"
                                                self._children_yang_names.add("ipv4-internal-reachability")

                                                self.ipv4_external_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability()
                                                self.ipv4_external_reachability.parent = self
                                                self._children_name_map["ipv4_external_reachability"] = "ipv4-external-reachability"
                                                self._children_yang_names.add("ipv4-external-reachability")

                                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"
                                                self._children_yang_names.add("authentication")

                                                self.extended_is_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability()
                                                self.extended_is_reachability.parent = self
                                                self._children_name_map["extended_is_reachability"] = "extended-is-reachability"
                                                self._children_yang_names.add("extended-is-reachability")

                                                self.extended_ipv4_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability()
                                                self.extended_ipv4_reachability.parent = self
                                                self._children_name_map["extended_ipv4_reachability"] = "extended-ipv4-reachability"
                                                self._children_yang_names.add("extended-ipv4-reachability")

                                                self.ipv6_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability()
                                                self.ipv6_reachability.parent = self
                                                self._children_name_map["ipv6_reachability"] = "ipv6-reachability"
                                                self._children_yang_names.add("ipv6-reachability")

                                                self.multi_topology = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology()
                                                self.multi_topology.parent = self
                                                self._children_name_map["multi_topology"] = "multi-topology"
                                                self._children_yang_names.add("multi-topology")

                                                self.isis_neighbor_attribute = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute()
                                                self.isis_neighbor_attribute.parent = self
                                                self._children_name_map["isis_neighbor_attribute"] = "isis-neighbor-attribute"
                                                self._children_yang_names.add("isis-neighbor-attribute")

                                                self.is_alias_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId()
                                                self.is_alias_id.parent = self
                                                self._children_name_map["is_alias_id"] = "is-alias-id"
                                                self._children_yang_names.add("is-alias-id")

                                                self.mt_isn = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn()
                                                self.mt_isn.parent = self
                                                self._children_name_map["mt_isn"] = "mt-isn"
                                                self._children_yang_names.add("mt-isn")

                                                self.mt_isis_neighbor_attribute = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute()
                                                self.mt_isis_neighbor_attribute.parent = self
                                                self._children_name_map["mt_isis_neighbor_attribute"] = "mt-isis-neighbor-attribute"
                                                self._children_yang_names.add("mt-isis-neighbor-attribute")

                                                self.mt_ipv4_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability()
                                                self.mt_ipv4_reachability.parent = self
                                                self._children_name_map["mt_ipv4_reachability"] = "mt-ipv4-reachability"
                                                self._children_yang_names.add("mt-ipv4-reachability")

                                                self.mt_ipv6_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability()
                                                self.mt_ipv6_reachability.parent = self
                                                self._children_name_map["mt_ipv6_reachability"] = "mt-ipv6-reachability"
                                                self._children_yang_names.add("mt-ipv6-reachability")
                                                self._segment_path = lambda: "tlv" + "[type='" + str(self.type) + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv, ['type'], name, value)


                                            class State(Entity):
                                                """
                                                Operational state parameters relating to the specified
                                                LSP
                                                
                                                .. attribute:: type
                                                
                                                	The type of TLV being described. The type of TLV is expressed as a canonical name
                                                	**type**\:  :py:class:`ISISTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISTLVTYPE>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                    ])
                                                    self.type = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State, ['type'], name, value)


                                            class AreaAddress(Entity):
                                                """
                                                This container defines TLV 1.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 1
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress, self).__init__()

                                                    self.yang_name = "area-address"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "area-address"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 1.
                                                    
                                                    .. attribute:: area_address
                                                    
                                                    	Area adress(es) of the IS. Set of manual area addresses of this IS
                                                    	**type**\: list of str
                                                    
                                                    	**pattern:** ^[0\-9A\-Fa\-f]{2}\\.([0\-9A\-Fa\-f]{4}\\.){0,3}$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "area-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('area_address', YLeafList(YType.str, 'area-address')),
                                                        ])
                                                        self.area_address = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State, ['area_address'], name, value)


                                            class LspBufferSize(Entity):
                                                """
                                                This container defines TLV 14 \- the LSP Buffer Size TLV
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of TLV 14
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize, self).__init__()

                                                    self.yang_name = "lsp-buffer-size"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "lsp-buffer-size"


                                                class State(Entity):
                                                    """
                                                    State parameters of TLV 14.
                                                    
                                                    .. attribute:: buffer_size
                                                    
                                                    	The maximum MTU that the advertising system can receive, expressed in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: bytes
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "lsp-buffer-size"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('buffer_size', YLeaf(YType.uint16, 'buffer-size')),
                                                        ])
                                                        self.buffer_size = None
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State, ['buffer_size'], name, value)


                                            class Nlpid(Entity):
                                                """
                                                This container defines TLV 129.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 129
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid, self).__init__()

                                                    self.yang_name = "nlpid"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "nlpid"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 129.
                                                    
                                                    .. attribute:: nlpid
                                                    
                                                    	Protocol supported. IPv4 is defined as (0xcc) and IPv6 \- (0x8e)
                                                    	**type**\: list of   :py:class:`Nlpid_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State.Nlpid_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "nlpid"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('nlpid', YLeafList(YType.enumeration, 'nlpid')),
                                                        ])
                                                        self.nlpid = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State, ['nlpid'], name, value)

                                                    class Nlpid_(Enum):
                                                        """
                                                        Nlpid\_ (Enum Class)

                                                        Protocol supported. IPv4 is defined as (0xcc) and IPv6 \-

                                                        (0x8e)

                                                        .. data:: IPV4 = 0

                                                        	IPv4 Address family.

                                                        .. data:: IPV6 = 1

                                                        	IPv6 Address family.

                                                        """

                                                        IPV4 = Enum.YLeaf(0, "IPV4")

                                                        IPV6 = Enum.YLeaf(1, "IPV6")



                                            class Hostname(Entity):
                                                """
                                                This container defines TLV 137.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 137
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname, self).__init__()

                                                    self.yang_name = "hostname"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "hostname"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 137.
                                                    
                                                    .. attribute:: hostname
                                                    
                                                    	Name of the node
                                                    	**type**\: list of str
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "hostname"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('hostname', YLeafList(YType.str, 'hostname')),
                                                        ])
                                                        self.hostname = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State, ['hostname'], name, value)


                                            class Ipv4InterfaceAddresses(Entity):
                                                """
                                                This container defines TLV 132.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 132
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses, self).__init__()

                                                    self.yang_name = "ipv4-interface-addresses"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "ipv4-interface-addresses"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 132.
                                                    
                                                    .. attribute:: ipv4_interface_addresses
                                                    
                                                    	IPv4 address(es) of the interface corresponding to the SNPA over which this PDU is to be transmitted
                                                    	**type**\: list of str
                                                    
                                                    	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv4-interface-addresses"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_interface_addresses', YLeafList(YType.str, 'ipv4-interface-addresses')),
                                                        ])
                                                        self.ipv4_interface_addresses = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State, ['ipv4_interface_addresses'], name, value)


                                            class Ipv6InterfaceAddresses(Entity):
                                                """
                                                This container defines TLV 232.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 232
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses, self).__init__()

                                                    self.yang_name = "ipv6-interface-addresses"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "ipv6-interface-addresses"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 232.
                                                    
                                                    .. attribute:: ipv6_interface_addresses
                                                    
                                                    	IPv6 interface addresses of the node.  MUST contain only the non\-link\-local IPv6 addresses assigned to the IS
                                                    	**type**\: list of str
                                                    
                                                    	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv6-interface-addresses"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_interface_addresses', YLeafList(YType.str, 'ipv6-interface-addresses')),
                                                        ])
                                                        self.ipv6_interface_addresses = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State, ['ipv6_interface_addresses'], name, value)


                                            class Ipv4TeRouterId(Entity):
                                                """
                                                This container defines TLV 134.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 134
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId, self).__init__()

                                                    self.yang_name = "ipv4-te-router-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "ipv4-te-router-id"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 134.
                                                    
                                                    .. attribute:: router_id
                                                    
                                                    	IPv4 Traffic Engineering router ID of the node. For traffic engineering, it guarantees that we have a single stable address that can always be referenced in a path that will be reachable from multiple hops away, regardless of the state of the node's interfaces
                                                    	**type**\: list of str
                                                    
                                                    	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv4-te-router-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('router_id', YLeafList(YType.str, 'router-id')),
                                                        ])
                                                        self.router_id = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State, ['router_id'], name, value)


                                            class Ipv6TeRouterId(Entity):
                                                """
                                                This container defines TLV 140.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of ISIS TLV 140
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId, self).__init__()

                                                    self.yang_name = "ipv6-te-router-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "ipv6-te-router-id"


                                                class State(Entity):
                                                    """
                                                    State parameters of ISIS TLV 140.
                                                    
                                                    .. attribute:: router_id
                                                    
                                                    	IPv6 Traffic Engineering router ID of the node. For traffic engineering, it guarantees that we have a single stable address that can always be referenced in a path that will be reachable from multiple hops away, regardless of the state of the node's interfaces
                                                    	**type**\: list of str
                                                    
                                                    	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv6-te-router-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('router_id', YLeafList(YType.str, 'router-id')),
                                                        ])
                                                        self.router_id = []
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State, ['router_id'], name, value)


                                            class InstanceIds(Entity):
                                                """
                                                This container defines ISIS Instance Identifier TLV.
                                                
                                                .. attribute:: instance_id
                                                
                                                	A list of instance IDs received within TLV 7 within an IS\-IS LSP. In the case that more than one instance of TLV 7 is included in the LSP, the instance IDs specified within the instances are concatenated within this list
                                                	**type**\: list of  		 :py:class:`InstanceId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds, self).__init__()

                                                    self.yang_name = "instance-ids"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([("instance-id", ("instance_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId))])
                                                    self._leafs = OrderedDict()

                                                    self.instance_id = YList(self)
                                                    self._segment_path = lambda: "instance-ids"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds, [], name, value)


                                                class InstanceId(Entity):
                                                    """
                                                    A list of instance IDs received within TLV 7 within an
                                                    IS\-IS LSP. In the case that more than one instance of TLV 7
                                                    is included in the LSP, the instance IDs specified within
                                                    the instances are concatenated within this list.
                                                    
                                                    .. attribute:: instance_id  (key)
                                                    
                                                    	Reference to the unique instance ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**refers to**\:  :py:class:`instance_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 7
                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId, self).__init__()

                                                        self.yang_name = "instance-id"
                                                        self.yang_parent_name = "instance-ids"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_id']
                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State))])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('instance_id', YLeaf(YType.str, 'instance-id')),
                                                        ])
                                                        self.instance_id = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._children_yang_names.add("state")
                                                        self._segment_path = lambda: "instance-id" + "[instance-id='" + str(self.instance_id) + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId, ['instance_id'], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 7.
                                                        
                                                        .. attribute:: instance_id
                                                        
                                                        	An Instance Identifier (IID) to uniquely identify an IS\-IS instance. When the IID = 0, the list of supported ITIDs MUST NOT be present. An IID\-TLV with IID = 0 MUST NOT appear in an SNP or LSP. When the TLV appears (with a non\-zero IID) in an SNP or LSP, exactly one ITID. MUST be present indicating the topology with which the PDU is associated. If no ITIDs or multiple ITIDs are present or the IID is zero, then the PDU MUST be ignored
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: topology_id
                                                        
                                                        	Instance\-Specific Topology Identifiers (ITIDs)
                                                        	**type**\: list of int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "instance-id"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_id', YLeaf(YType.uint16, 'instance-id')),
                                                                ('topology_id', YLeafList(YType.uint16, 'topology-id')),
                                                            ])
                                                            self.instance_id = None
                                                            self.topology_id = []
                                                            self._segment_path = lambda: "state"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State, ['instance_id', 'topology_id'], name, value)


                                            class Ipv4Srlgs(Entity):
                                                """
                                                This container defines ISIS SRLG TLV 138.
                                                
                                                .. attribute:: ipv4_srlg
                                                
                                                	Instance of the IPv4 SRLG TLV
                                                	**type**\: list of  		 :py:class:`Ipv4Srlg <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs, self).__init__()

                                                    self.yang_name = "ipv4-srlgs"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([("ipv4-srlg", ("ipv4_srlg", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4_srlg = YList(self)
                                                    self._segment_path = lambda: "ipv4-srlgs"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs, [], name, value)


                                                class Ipv4Srlg(Entity):
                                                    """
                                                    Instance of the IPv4 SRLG TLV
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                    	Reference to the instance number of TLV 138
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**refers to**\:  :py:class:`instance_number <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of TLV 138
                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg, self).__init__()

                                                        self.yang_name = "ipv4-srlg"
                                                        self.yang_parent_name = "ipv4-srlgs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State))])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', YLeaf(YType.str, 'instance-number')),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._children_yang_names.add("state")
                                                        self._segment_path = lambda: "ipv4-srlg" + "[instance-number='" + str(self.instance_number) + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg, ['instance_number'], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of TLV 138.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                        	An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138. The instance identifier is synthesised by the system and may be renumbered for the same SRLG definition in subsequent advertised LSPs if (and only if) the entire list of SRLGs is replaced
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: system_id
                                                        
                                                        	Neighbor system ID
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        .. attribute:: psn_number
                                                        
                                                        	Pseudonode number if the neighbor is on a LAN interface
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	SRLG flags
                                                        	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State.Flags>`
                                                        
                                                        .. attribute:: ipv4_interface_address
                                                        
                                                        	IPv4 interface address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                        .. attribute:: ipv4_neighbor_address
                                                        
                                                        	IPv4 neighbor address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                        .. attribute:: srlg_value
                                                        
                                                        	List of SRLG values
                                                        	**type**\: list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv4-srlg"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', YLeaf(YType.uint32, 'instance-number')),
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                                ('psn_number', YLeaf(YType.uint8, 'psn-number')),
                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                ('ipv4_interface_address', YLeaf(YType.str, 'ipv4-interface-address')),
                                                                ('ipv4_neighbor_address', YLeaf(YType.str, 'ipv4-neighbor-address')),
                                                                ('srlg_value', YLeafList(YType.uint32, 'srlg-value')),
                                                            ])
                                                            self.instance_number = None
                                                            self.system_id = None
                                                            self.psn_number = None
                                                            self.flags = []
                                                            self.ipv4_interface_address = None
                                                            self.ipv4_neighbor_address = None
                                                            self.srlg_value = []
                                                            self._segment_path = lambda: "state"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State, ['instance_number', 'system_id', 'psn_number', 'flags', 'ipv4_interface_address', 'ipv4_neighbor_address', 'srlg_value'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            SRLG flags.

                                                            .. data:: NUMBERED = 0

                                                            	When set, the interface is numbered, whereas if

                                                            	unset indicates that the interface is

                                                            	unnumbered.

                                                            """

                                                            NUMBERED = Enum.YLeaf(0, "NUMBERED")



                                            class Ipv6Srlgs(Entity):
                                                """
                                                This container defines ISIS SRLG TLV.
                                                
                                                .. attribute:: ipv6_srlg
                                                
                                                	Instance of the IPv6 SRLG TLV
                                                	**type**\: list of  		 :py:class:`Ipv6Srlg <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs, self).__init__()

                                                    self.yang_name = "ipv6-srlgs"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([("ipv6-srlg", ("ipv6_srlg", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_srlg = YList(self)
                                                    self._segment_path = lambda: "ipv6-srlgs"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs, [], name, value)


                                                class Ipv6Srlg(Entity):
                                                    """
                                                    Instance of the IPv6 SRLG TLV.
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                    	Reference to the instance number of the IPv6 Shared Risk Link Group (SRLG) TLV
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**refers to**\:  :py:class:`instance_number <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of TLV 139
                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg, self).__init__()

                                                        self.yang_name = "ipv6-srlg"
                                                        self.yang_parent_name = "ipv6-srlgs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State))])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', YLeaf(YType.str, 'instance-number')),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._children_yang_names.add("state")
                                                        self._segment_path = lambda: "ipv6-srlg" + "[instance-number='" + str(self.instance_number) + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg, ['instance_number'], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of TLV 139.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                        	An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138. The instance identifier is synthesised by the system and may be renumbered for the same SRLG definition in subsequent advertised LSPs if (and only if) the entire list of SRLGs is replaced
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: system_id
                                                        
                                                        	Neighbor system ID
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        .. attribute:: psn_number
                                                        
                                                        	Pseudonode number if the neighbor is on a LAN interface
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	IPv6 SRLG flags
                                                        	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State.Flags>`
                                                        
                                                        .. attribute:: ipv6_interface_address
                                                        
                                                        	IPv6 interface address or Link Local Identifier
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                        
                                                        .. attribute:: ipv6_neighbor_address
                                                        
                                                        	IPv6 neighbor address or Link Remote Identifier
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                        
                                                        .. attribute:: srlg_value
                                                        
                                                        	SRLG values
                                                        	**type**\: list of int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv6-srlg"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', YLeaf(YType.uint32, 'instance-number')),
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                                ('psn_number', YLeaf(YType.uint8, 'psn-number')),
                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                ('ipv6_interface_address', YLeaf(YType.str, 'ipv6-interface-address')),
                                                                ('ipv6_neighbor_address', YLeaf(YType.str, 'ipv6-neighbor-address')),
                                                                ('srlg_value', YLeafList(YType.uint32, 'srlg-value')),
                                                            ])
                                                            self.instance_number = None
                                                            self.system_id = None
                                                            self.psn_number = None
                                                            self.flags = []
                                                            self.ipv6_interface_address = None
                                                            self.ipv6_neighbor_address = None
                                                            self.srlg_value = []
                                                            self._segment_path = lambda: "state"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State, ['instance_number', 'system_id', 'psn_number', 'flags', 'ipv6_interface_address', 'ipv6_neighbor_address', 'srlg_value'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            IPv6 SRLG flags.

                                                            .. data:: NA = 0

                                                            	When set, the IPv6 neighbour address is included,

                                                            	whereas if unset, it is omitted

                                                            """

                                                            NA = Enum.YLeaf(0, "NA")



                                            class PurgeOi(Entity):
                                                """
                                                This container defines ISIS purge TLV.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of TLV 13
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi, self).__init__()

                                                    self.yang_name = "purge-oi"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "purge-oi"


                                                class State(Entity):
                                                    """
                                                    State parameters of TLV 13.
                                                    
                                                    .. attribute:: system_id_count
                                                    
                                                    	Number of system IDs carried in this TLV
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: source_system_id
                                                    
                                                    	System ID of the Intermediate System that inserted this TLV
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                    .. attribute:: received_system_id
                                                    
                                                    	System ID of the Intermediate System from which the purge was received
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "purge-oi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('system_id_count', YLeaf(YType.uint8, 'system-id-count')),
                                                            ('source_system_id', YLeaf(YType.str, 'source-system-id')),
                                                            ('received_system_id', YLeaf(YType.str, 'received-system-id')),
                                                        ])
                                                        self.system_id_count = None
                                                        self.source_system_id = None
                                                        self.received_system_id = None
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State, ['system_id_count', 'source_system_id', 'received_system_id'], name, value)


                                            class RouterCapabilities(Entity):
                                                """
                                                This container defines router capabilities.
                                                
                                                .. attribute:: router_capability
                                                
                                                	This list describes IS Router capabilities
                                                	**type**\: list of  		 :py:class:`RouterCapability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities, self).__init__()

                                                    self.yang_name = "router-capabilities"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([("router-capability", ("router_capability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability))])
                                                    self._leafs = OrderedDict()

                                                    self.router_capability = YList(self)
                                                    self._segment_path = lambda: "router-capabilities"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities, [], name, value)


                                                class RouterCapability(Entity):
                                                    """
                                                    This list describes IS Router capabilities.
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                    	Reference to the instance number of the router capability TLV
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**refers to**\:  :py:class:`instance_number <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State>`
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of TLV 242
                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State>`
                                                    
                                                    .. attribute:: subtlvs
                                                    
                                                    	This container describes router capability TLV sub\-TLVs
                                                    	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs>`
                                                    
                                                    .. attribute:: undefined_subtlvs
                                                    
                                                    	This container describes undefined ISIS TLVs
                                                    	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability, self).__init__()

                                                        self.yang_name = "router-capability"
                                                        self.yang_parent_name = "router-capabilities"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs))])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', YLeaf(YType.str, 'instance-number')),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._children_yang_names.add("state")

                                                        self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs()
                                                        self.subtlvs.parent = self
                                                        self._children_name_map["subtlvs"] = "subtlvs"
                                                        self._children_yang_names.add("subtlvs")

                                                        self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs()
                                                        self.undefined_subtlvs.parent = self
                                                        self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                        self._children_yang_names.add("undefined-subtlvs")
                                                        self._segment_path = lambda: "router-capability" + "[instance-number='" + str(self.instance_number) + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability, ['instance_number'], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of TLV 242.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                        	A unique instance number for the instance of the router capabilities TLV. The instance number should be autogenerated by the producer of the data and may be renumbered if the entire LSP contents are replaced in subsequent advertisements
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: router_id
                                                        
                                                        	IPv4 router\-id
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Router capability flags
                                                        	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State.Flags>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "router-capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', YLeaf(YType.uint32, 'instance-number')),
                                                                ('router_id', YLeaf(YType.str, 'router-id')),
                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                            ])
                                                            self.instance_number = None
                                                            self.router_id = None
                                                            self.flags = []
                                                            self._segment_path = lambda: "state"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.State, ['instance_number', 'router_id', 'flags'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            Router capability flags.

                                                            .. data:: FLOOD = 0

                                                            	When the S bit is set(1), the IS - IS Router

                                                            	CAPABILITY TLV MUST be flooded across the entire

                                                            	routing domain. When the S bit is not set(0),

                                                            	the TLV MUST NOT be leaked between levels . This

                                                            	bit MUST NOT be altered during the TLV

                                                            	leaking.

                                                            .. data:: DOWN = 1

                                                            	When the IS-IS Router CAPABILITY TLV is leaked

                                                            	from level - 2 to level-1, the Down bit MUST be

                                                            	set. Otherwise, this bit MUST be clear. IS - IS

                                                            	Router capability TLVs with the Down bit set

                                                            	MUST NOT be leaked from level - 1 to level-2.

                                                            	This is to prevent TLV looping.

                                                            """

                                                            FLOOD = Enum.YLeaf(0, "FLOOD")

                                                            DOWN = Enum.YLeaf(1, "DOWN")



                                                    class Subtlvs(Entity):
                                                        """
                                                        This container describes router capability TLV
                                                        sub\-TLVs
                                                        
                                                        .. attribute:: subtlv
                                                        
                                                        	List of subTLV types in the LSDB for the specified TLV
                                                        	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs, self).__init__()

                                                            self.yang_name = "subtlvs"
                                                            self.yang_parent_name = "router-capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv))])
                                                            self._leafs = OrderedDict()

                                                            self.subtlv = YList(self)
                                                            self._segment_path = lambda: "subtlvs"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs, [], name, value)


                                                        class Subtlv(Entity):
                                                            """
                                                            List of subTLV types in the LSDB for the specified
                                                            TLV
                                                            
                                                            .. attribute:: type  (key)
                                                            
                                                            	Reference to the sub\-TLV type
                                                            	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of IS Router Capabilities
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.State>`
                                                            
                                                            .. attribute:: segment_routing_algorithms
                                                            
                                                            	This container defines SR algorithm sub\-TLV 19
                                                            	**type**\:  :py:class:`SegmentRoutingAlgorithms <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms>`
                                                            
                                                            .. attribute:: segment_routing_capability
                                                            
                                                            	This container defines SR Capability sub\-TLV 2
                                                            	**type**\:  :py:class:`SegmentRoutingCapability <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv, self).__init__()

                                                                self.yang_name = "subtlv"
                                                                self.yang_parent_name = "subtlvs"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['type']
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.State)), ("segment-routing-algorithms", ("segment_routing_algorithms", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms)), ("segment-routing-capability", ("segment_routing_capability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', YLeaf(YType.identityref, 'type')),
                                                                ])
                                                                self.type = None

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")

                                                                self.segment_routing_algorithms = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms()
                                                                self.segment_routing_algorithms.parent = self
                                                                self._children_name_map["segment_routing_algorithms"] = "segment-routing-algorithms"
                                                                self._children_yang_names.add("segment-routing-algorithms")

                                                                self.segment_routing_capability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability()
                                                                self.segment_routing_capability.parent = self
                                                                self._children_name_map["segment_routing_capability"] = "segment-routing-capability"
                                                                self._children_yang_names.add("segment-routing-capability")
                                                                self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv, ['type'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of IS Router Capabilities
                                                                
                                                                .. attribute:: type
                                                                
                                                                	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.State, ['type'], name, value)


                                                            class SegmentRoutingAlgorithms(Entity):
                                                                """
                                                                This container defines SR algorithm sub\-TLV 19.
                                                                
                                                                .. attribute:: segment_routing_algorithm
                                                                
                                                                	List of the segment routing algorithsm advertised within the TLV
                                                                	**type**\: list of  		 :py:class:`SegmentRoutingAlgorithm <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms, self).__init__()

                                                                    self.yang_name = "segment-routing-algorithms"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([("segment-routing-algorithm", ("segment_routing_algorithm", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm))])
                                                                    self._leafs = OrderedDict()

                                                                    self.segment_routing_algorithm = YList(self)
                                                                    self._segment_path = lambda: "segment-routing-algorithms"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms, [], name, value)


                                                                class SegmentRoutingAlgorithm(Entity):
                                                                    """
                                                                    List of the segment routing algorithsm advertised within the TLV.
                                                                    
                                                                    .. attribute:: algorithm  (key)
                                                                    
                                                                    	Reference to the SR algorithm that the subTLV describes
                                                                    	**type**\:  :py:class:`Algorithm <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State.Algorithm>`
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 19 \- Segment Routing Algorithm
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm, self).__init__()

                                                                        self.yang_name = "segment-routing-algorithm"
                                                                        self.yang_parent_name = "segment-routing-algorithms"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['algorithm']
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('algorithm', YLeaf(YType.enumeration, 'algorithm')),
                                                                        ])
                                                                        self.algorithm = None

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "segment-routing-algorithm" + "[algorithm='" + str(self.algorithm) + "']"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm, ['algorithm'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 19 \- Segment
                                                                        Routing Algorithm.
                                                                        
                                                                        .. attribute:: algorithm
                                                                        
                                                                        	The Segment Routing algorithm that is described by the TLV
                                                                        	**type**\:  :py:class:`Algorithm <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State.Algorithm>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "segment-routing-algorithm"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('algorithm', YLeaf(YType.enumeration, 'algorithm')),
                                                                            ])
                                                                            self.algorithm = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State, ['algorithm'], name, value)

                                                                        class Algorithm(Enum):
                                                                            """
                                                                            Algorithm (Enum Class)

                                                                            The Segment Routing algorithm that is described

                                                                            by the TLV.

                                                                            .. data:: SPF = 0

                                                                            	Shortest Path First (SPF) algorithm based

                                                                            	on link metric.  This is the well-known

                                                                            	shortest path algorithm as computed by

                                                                            	the IS-IS Decision process.  Consistent

                                                                            	with the deployed practice for link-

                                                                            	state protocols, algorithm 0 permits any

                                                                            	node to overwrite the SPF

                                                                            	path with a different path based on local

                                                                            	policy.

                                                                            .. data:: STRICT_SPF = 1

                                                                            	Strict Shortest Path First (SPF)

                                                                            	algorithm based on link metric. The

                                                                            	algorithm is identical to algorithm 0 but

                                                                            	algorithm 1 requires that all nodes

                                                                            	along the path will honor the SPF routing

                                                                            	decision. Local policy MUST NOT alter the

                                                                            	forwarding decision computed by algorithm

                                                                            	1 at the node claiming to support

                                                                            	algorithm 1.

                                                                            """

                                                                            SPF = Enum.YLeaf(0, "SPF")

                                                                            STRICT_SPF = Enum.YLeaf(1, "STRICT_SPF")



                                                            class SegmentRoutingCapability(Entity):
                                                                """
                                                                This container defines SR Capability sub\-TLV 2.
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of IS SR Router Capability
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State>`
                                                                
                                                                .. attribute:: srgb_descriptors
                                                                
                                                                	SRGB Descriptors included within the SR capability sub\-TLV
                                                                	**type**\:  :py:class:`SrgbDescriptors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability, self).__init__()

                                                                    self.yang_name = "segment-routing-capability"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State)), ("srgb-descriptors", ("srgb_descriptors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.srgb_descriptors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors()
                                                                    self.srgb_descriptors.parent = self
                                                                    self._children_name_map["srgb_descriptors"] = "srgb-descriptors"
                                                                    self._children_yang_names.add("srgb-descriptors")
                                                                    self._segment_path = lambda: "segment-routing-capability"


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of IS SR Router Capability
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	Segment Routing Capability Flags
                                                                    	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State.Flags>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "segment-routing-capability"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                        ])
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State, ['flags'], name, value)

                                                                    class Flags(Enum):
                                                                        """
                                                                        Flags (Enum Class)

                                                                        Segment Routing Capability Flags.

                                                                        .. data:: IPV4_MPLS = 0

                                                                        	When set, the router is capable of

                                                                        	processing SR MPLS encapsulated IPv4

                                                                        	packets on all interfaces.

                                                                        .. data:: IPV6_MPLS = 1

                                                                        	When set, the router is capable of

                                                                        	processing SR MPLS encapsulated IPv6

                                                                        	packets on all interfaces.

                                                                        .. data:: IPV6_SR = 2

                                                                        	When set, the router is capable of

                                                                        	processing the IPv6 Segment Routing Header

                                                                        	on all interfaces.

                                                                        """

                                                                        IPV4_MPLS = Enum.YLeaf(0, "IPV4_MPLS")

                                                                        IPV6_MPLS = Enum.YLeaf(1, "IPV6_MPLS")

                                                                        IPV6_SR = Enum.YLeaf(2, "IPV6_SR")



                                                                class SrgbDescriptors(Entity):
                                                                    """
                                                                    SRGB Descriptors included within the SR
                                                                    capability sub\-TLV
                                                                    
                                                                    .. attribute:: srgb_descriptor
                                                                    
                                                                    	Descriptor entry within the SR capabilty sub\-TLV
                                                                    	**type**\: list of  		 :py:class:`SrgbDescriptor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors, self).__init__()

                                                                        self.yang_name = "srgb-descriptors"
                                                                        self.yang_parent_name = "segment-routing-capability"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("srgb-descriptor", ("srgb_descriptor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor))])
                                                                        self._leafs = OrderedDict()

                                                                        self.srgb_descriptor = YList(self)
                                                                        self._segment_path = lambda: "srgb-descriptors"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors, [], name, value)


                                                                    class SrgbDescriptor(Entity):
                                                                        """
                                                                        Descriptor entry within the SR capabilty
                                                                        sub\-TLV
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of the SR range
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor, self).__init__()

                                                                            self.yang_name = "srgb-descriptor"
                                                                            self.yang_parent_name = "srgb-descriptors"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "srgb-descriptor"


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of the SR range
                                                                            
                                                                            .. attribute:: range
                                                                            
                                                                            	Number of SRGB elements. The range value MUST be greater than 0
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                            	The first value of the SRGB when expressed as an MPLS label
                                                                            	**type**\: union of the below types:
                                                                            
                                                                            		**type**\: int
                                                                            
                                                                            			**range:** 16..1048575
                                                                            
                                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "srgb-descriptor"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('range', YLeaf(YType.uint32, 'range')),
                                                                                    ('label', YLeaf(YType.str, 'label')),
                                                                                ])
                                                                                self.range = None
                                                                                self.label = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State, ['range', 'label'], name, value)


                                                    class UndefinedSubtlvs(Entity):
                                                        """
                                                        This container describes undefined ISIS TLVs.
                                                        
                                                        .. attribute:: undefined_subtlv
                                                        
                                                        	Sub\-TLVs that are not defined in the model or not recognised by system
                                                        	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs, self).__init__()

                                                            self.yang_name = "undefined-subtlvs"
                                                            self.yang_parent_name = "router-capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_container_classes = OrderedDict([])
                                                            self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv))])
                                                            self._leafs = OrderedDict()

                                                            self.undefined_subtlv = YList(self)
                                                            self._segment_path = lambda: "undefined-subtlvs"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs, [], name, value)


                                                        class UndefinedSubtlv(Entity):
                                                            """
                                                            Sub\-TLVs that are not defined in the model or not
                                                            recognised by system.
                                                            
                                                            .. attribute:: type  (key)
                                                            
                                                            	Reference to the type of the undefined sub\-TLV
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of the undefined sub\-TLV
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                self.yang_name = "undefined-subtlv"
                                                                self.yang_parent_name = "undefined-subtlvs"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['type']
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', YLeaf(YType.str, 'type')),
                                                                ])
                                                                self.type = None

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of the undefined sub\-TLV.
                                                                
                                                                .. attribute:: type
                                                                
                                                                	TLV Type
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: length
                                                                
                                                                	TLV length
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: value
                                                                
                                                                	TLV value
                                                                	**type**\: str
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "undefined-subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.uint8, 'type')),
                                                                        ('length', YLeaf(YType.uint8, 'length')),
                                                                        ('value', YLeaf(YType.str, 'value')),
                                                                    ])
                                                                    self.type = None
                                                                    self.length = None
                                                                    self.value = None
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class IsReachability(Entity):
                                                """
                                                This container describes list of ISIS neighbors and
                                                attributes.
                                                
                                                .. attribute:: neighbors
                                                
                                                	This container describes IS neighbors
                                                	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability, self).__init__()

                                                    self.yang_name = "is-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._children_yang_names.add("neighbors")
                                                    self._segment_path = lambda: "is-reachability"


                                                class Neighbors(Entity):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbors
                                                    
                                                    	IS reachability neighbor attributes
                                                    	**type**\: list of  		 :py:class:`Neighbors_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors, self).__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "is-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbors = YList(self)
                                                        self._segment_path = lambda: "neighbors"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors, [], name, value)


                                                    class Neighbors_(Entity):
                                                        """
                                                        IS reachability neighbor attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                        	Reference to the system ID of the neighbor
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of IS standard neighbor
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State>`
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                        	This container defines ISIS Default Metric
                                                        	**type**\:  :py:class:`DefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric>`
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                        	This container defines the ISIS delay metric
                                                        	**type**\:  :py:class:`DelayMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric>`
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                        	This container defines the ISIS expense metric
                                                        	**type**\:  :py:class:`ExpenseMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric>`
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                        	This container defines the ISIS error metric
                                                        	**type**\:  :py:class:`ErrorMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_, self).__init__()

                                                            self.yang_name = "neighbors"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"
                                                            self._children_yang_names.add("default-metric")

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"
                                                            self._children_yang_names.add("delay-metric")

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"
                                                            self._children_yang_names.add("expense-metric")

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._children_yang_names.add("error-metric")
                                                            self._segment_path = lambda: "neighbors" + "[system-id='" + str(self.system_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_, ['system_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of IS standard neighbor.
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	System\-ID of IS neighbor
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                                ])
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.State, ['system_id'], name, value)


                                                        class DefaultMetric(Entity):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters for default\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric, self).__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "default-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Default\-Metric Flags
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State.Flags>`
                                                                
                                                                .. attribute:: default_metric
                                                                
                                                                	ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', YLeaf(YType.enumeration, 'flags')),
                                                                        ('default_metric', YLeaf(YType.uint8, 'default-metric')),
                                                                    ])
                                                                    self.flags = None
                                                                    self.default_metric = None
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DefaultMetric.State, ['flags', 'default_metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    ISIS Default\-Metric Flags.

                                                                    .. data:: INTERNAL = 0

                                                                    	When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")



                                                        class DelayMetric(Entity):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of delay\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric, self).__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "delay-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Delay Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.DelayMetric.State, ['metric', 'flags'], name, value)


                                                        class ExpenseMetric(Entity):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of expense\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric, self).__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "expense-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Expense Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ExpenseMetric.State, ['metric', 'flags'], name, value)


                                                        class ErrorMetric(Entity):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of error\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric, self).__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "error-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	IS\-IS error metric flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbors_.ErrorMetric.State, ['metric', 'flags'], name, value)


                                            class Ipv4InternalReachability(Entity):
                                                """
                                                This container defines list of IPv4 internal reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS prefixes
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability, self).__init__()

                                                    self.yang_name = "ipv4-internal-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "ipv4-internal-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefixes
                                                    
                                                    	IPv4 prefixes and internal reachability attributes
                                                    	**type**\: list of  		 :py:class:`Prefixes_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv4-internal-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_))])
                                                        self._leafs = OrderedDict()

                                                        self.prefixes = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes, [], name, value)


                                                    class Prefixes_(Entity):
                                                        """
                                                        IPv4 prefixes and internal reachability attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the IPv4 prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of IPv4 standard prefix
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                        	This container defines ISIS Default Metric
                                                        	**type**\:  :py:class:`DefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric>`
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                        	This container defines the ISIS delay metric
                                                        	**type**\:  :py:class:`DelayMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric>`
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                        	This container defines the ISIS expense metric
                                                        	**type**\:  :py:class:`ExpenseMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric>`
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                        	This container defines the ISIS error metric
                                                        	**type**\:  :py:class:`ErrorMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_, self).__init__()

                                                            self.yang_name = "prefixes"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"
                                                            self._children_yang_names.add("default-metric")

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"
                                                            self._children_yang_names.add("delay-metric")

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"
                                                            self._children_yang_names.add("expense-metric")

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._children_yang_names.add("error-metric")
                                                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_, ['prefix'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of IPv4 standard prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv4 prefix contained within reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                ])
                                                                self.up_down = None
                                                                self.prefix = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.State, ['up_down', 'prefix'], name, value)


                                                        class DefaultMetric(Entity):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters for default\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric, self).__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "default-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Default\-Metric Flags
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State.Flags>`
                                                                
                                                                .. attribute:: default_metric
                                                                
                                                                	ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', YLeaf(YType.enumeration, 'flags')),
                                                                        ('default_metric', YLeaf(YType.uint8, 'default-metric')),
                                                                    ])
                                                                    self.flags = None
                                                                    self.default_metric = None
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DefaultMetric.State, ['flags', 'default_metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    ISIS Default\-Metric Flags.

                                                                    .. data:: INTERNAL = 0

                                                                    	When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")



                                                        class DelayMetric(Entity):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of delay\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric, self).__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "delay-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Delay Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.DelayMetric.State, ['metric', 'flags'], name, value)


                                                        class ExpenseMetric(Entity):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of expense\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric, self).__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "expense-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Expense Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ExpenseMetric.State, ['metric', 'flags'], name, value)


                                                        class ErrorMetric(Entity):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of error\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric, self).__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "error-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	IS\-IS error metric flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefixes_.ErrorMetric.State, ['metric', 'flags'], name, value)


                                            class Ipv4ExternalReachability(Entity):
                                                """
                                                This container defines list of IPv4 external reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS neighbors
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability, self).__init__()

                                                    self.yang_name = "ipv4-external-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "ipv4-external-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: prefixes
                                                    
                                                    	IPv4 external prefixes and reachability attributes
                                                    	**type**\: list of  		 :py:class:`Prefixes_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv4-external-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_))])
                                                        self._leafs = OrderedDict()

                                                        self.prefixes = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes, [], name, value)


                                                    class Prefixes_(Entity):
                                                        """
                                                        IPv4 external prefixes and reachability attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the IPv4 prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of IPv4 standard prefix
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                        	This container defines ISIS Default Metric
                                                        	**type**\:  :py:class:`DefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric>`
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                        	This container defines the ISIS delay metric
                                                        	**type**\:  :py:class:`DelayMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric>`
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                        	This container defines the ISIS expense metric
                                                        	**type**\:  :py:class:`ExpenseMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric>`
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                        	This container defines the ISIS error metric
                                                        	**type**\:  :py:class:`ErrorMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_, self).__init__()

                                                            self.yang_name = "prefixes"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"
                                                            self._children_yang_names.add("default-metric")

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"
                                                            self._children_yang_names.add("delay-metric")

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"
                                                            self._children_yang_names.add("expense-metric")

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._children_yang_names.add("error-metric")
                                                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_, ['prefix'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of IPv4 standard prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv4 prefix contained within reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                ])
                                                                self.up_down = None
                                                                self.prefix = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.State, ['up_down', 'prefix'], name, value)


                                                        class DefaultMetric(Entity):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters for default\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric, self).__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "default-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Default\-Metric Flags
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State.Flags>`
                                                                
                                                                .. attribute:: default_metric
                                                                
                                                                	ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', YLeaf(YType.enumeration, 'flags')),
                                                                        ('default_metric', YLeaf(YType.uint8, 'default-metric')),
                                                                    ])
                                                                    self.flags = None
                                                                    self.default_metric = None
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DefaultMetric.State, ['flags', 'default_metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    ISIS Default\-Metric Flags.

                                                                    .. data:: INTERNAL = 0

                                                                    	When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")



                                                        class DelayMetric(Entity):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of delay\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric, self).__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "delay-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Delay Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.DelayMetric.State, ['metric', 'flags'], name, value)


                                                        class ExpenseMetric(Entity):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of expense\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric, self).__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "expense-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	ISIS Expense Metric Flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ExpenseMetric.State, ['metric', 'flags'], name, value)


                                                        class ErrorMetric(Entity):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of error\-metric
                                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric, self).__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric.State))])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._children_yang_names.add("state")
                                                                self._segment_path = lambda: "error-metric"


                                                            class State(Entity):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                	**type**\: int
                                                                
                                                                	**range:** 1..63
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	IS\-IS error metric flags
                                                                	**type**\: list of   :py:class:`IsisMetricFlags <ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_container_classes = OrderedDict([])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', YLeaf(YType.uint8, 'metric')),
                                                                        ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefixes_.ErrorMetric.State, ['metric', 'flags'], name, value)


                                            class Authentication(Entity):
                                                """
                                                This container defines authentication information of the
                                                node.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of TLV 10
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication, self).__init__()

                                                    self.yang_name = "authentication"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "authentication"


                                                class State(Entity):
                                                    """
                                                    State parameters of TLV 10.
                                                    
                                                    .. attribute:: crypto_type
                                                    
                                                    	Authentication type to be used
                                                    	**type**\:  :py:class:`CryptoType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State.CryptoType>`
                                                    
                                                    .. attribute:: authentication_key
                                                    
                                                    	Authentication key to be used
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "authentication"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('crypto_type', YLeaf(YType.enumeration, 'crypto-type')),
                                                            ('authentication_key', YLeaf(YType.str, 'authentication-key')),
                                                        ])
                                                        self.crypto_type = None
                                                        self.authentication_key = None
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State, ['crypto_type', 'authentication_key'], name, value)

                                                    class CryptoType(Enum):
                                                        """
                                                        CryptoType (Enum Class)

                                                        Authentication type to be used.

                                                        .. data:: HMAC_MD5 = 0

                                                        	HMAC-MD5 Authentication type.

                                                        .. data:: CLEARTEXT = 1

                                                        	Cleartext Authentication type.

                                                        """

                                                        HMAC_MD5 = Enum.YLeaf(0, "HMAC_MD5")

                                                        CLEARTEXT = Enum.YLeaf(1, "CLEARTEXT")



                                            class ExtendedIsReachability(Entity):
                                                """
                                                This container defines list of ISIS extended reachability
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                	This container describes IS neighbors
                                                	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability, self).__init__()

                                                    self.yang_name = "extended-is-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._children_yang_names.add("neighbors")
                                                    self._segment_path = lambda: "extended-is-reachability"


                                                class Neighbors(Entity):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbors
                                                    
                                                    	This list describes ISIS extended neigbors and reachability attributes
                                                    	**type**\: list of  		 :py:class:`Neighbors_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors, self).__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "extended-is-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbors = YList(self)
                                                        self._segment_path = lambda: "neighbors"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors, [], name, value)


                                                    class Neighbors_(Entity):
                                                        """
                                                        This list describes ISIS extended neigbors and
                                                        reachability attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                        	Reference to the neighboring system's system ID
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of extended neighbor
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS Neighbor sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_, self).__init__()

                                                            self.yang_name = "neighbors"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "neighbors" + "[system-id='" + str(self.system_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_, ['system_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of extended neighbor
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	System\-id of the neighbor
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.system_id = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.State, ['system_id', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS Neighbor sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of IS neighbor state
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: admin_group
                                                                
                                                                	This container defines sub\-TLV 3
                                                                	**type**\:  :py:class:`AdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup>`
                                                                
                                                                .. attribute:: ipv4_interface_address
                                                                
                                                                	This container defines sub\-TLV 6
                                                                	**type**\:  :py:class:`Ipv4InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv4_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 8
                                                                	**type**\:  :py:class:`Ipv4NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                
                                                                .. attribute:: max_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 9
                                                                	**type**\:  :py:class:`MaxLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                
                                                                .. attribute:: max_reservable_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 10
                                                                	**type**\:  :py:class:`MaxReservableLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                
                                                                .. attribute:: unreserved_bandwidth
                                                                
                                                                	This container defines unreserved\-bandwidth. The units are bytes per second
                                                                	**type**\:  :py:class:`UnreservedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                
                                                                .. attribute:: ipv6_interface_address
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv6_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 13
                                                                	**type**\:  :py:class:`Ipv6NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                
                                                                .. attribute:: extended_admin_group
                                                                
                                                                	This container defines sub\-TLV 14
                                                                	**type**\:  :py:class:`ExtendedAdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                
                                                                .. attribute:: te_default_metric
                                                                
                                                                	This container defines sub\-TLV 18
                                                                	**type**\:  :py:class:`TeDefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                
                                                                .. attribute:: link_attributes
                                                                
                                                                	This container defines link\-attributes
                                                                	**type**\:  :py:class:`LinkAttributes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes>`
                                                                
                                                                .. attribute:: link_protection_type
                                                                
                                                                	ISIS LSDB parameters relating to the type of link protection offered
                                                                	**type**\:  :py:class:`LinkProtectionType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType>`
                                                                
                                                                .. attribute:: bandwidth_constraints
                                                                
                                                                	This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                	**type**\:  :py:class:`BandwidthConstraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                
                                                                .. attribute:: unconstrained_lsp
                                                                
                                                                	This container defines sub\-TLV 23
                                                                	**type**\:  :py:class:`UnconstrainedLsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                
                                                                .. attribute:: adjacency_sids
                                                                
                                                                	This container defines segment routing adjacency SIDs
                                                                	**type**\:  :py:class:`AdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids>`
                                                                
                                                                .. attribute:: lan_adjacency_sids
                                                                
                                                                	This container defines segment routing LAN adjacency SIDs
                                                                	**type**\:  :py:class:`LanAdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                
                                                                .. attribute:: link_delay
                                                                
                                                                	This container defines unidirectional link delay
                                                                	**type**\:  :py:class:`LinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay>`
                                                                
                                                                .. attribute:: min_max_link_delay
                                                                
                                                                	This container defines min/max link delay
                                                                	**type**\:  :py:class:`MinMaxLinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                
                                                                .. attribute:: link_delay_variation
                                                                
                                                                	This container defines unidirectional link delay variation
                                                                	**type**\:  :py:class:`LinkDelayVariation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                
                                                                .. attribute:: link_loss
                                                                
                                                                	This container defines unidirectional link loss delay
                                                                	**type**\:  :py:class:`LinkLoss <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss>`
                                                                
                                                                .. attribute:: residual_bandwidth
                                                                
                                                                	This container defines unidirectional residual bandwidth
                                                                	**type**\:  :py:class:`ResidualBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                
                                                                .. attribute:: available_bandwidth
                                                                
                                                                	This container defines unidirectional lavailable bandwidth
                                                                	**type**\:  :py:class:`AvailableBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                
                                                                .. attribute:: utilized_bandwidth
                                                                
                                                                	This container defines unidirectional utilized bandwidth
                                                                	**type**\:  :py:class:`UtilizedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup()
                                                                    self.admin_group.parent = self
                                                                    self._children_name_map["admin_group"] = "admin-group"
                                                                    self._children_yang_names.add("admin-group")

                                                                    self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                    self.ipv4_interface_address.parent = self
                                                                    self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"
                                                                    self._children_yang_names.add("ipv4-interface-address")

                                                                    self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                    self.ipv4_neighbor_address.parent = self
                                                                    self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"
                                                                    self._children_yang_names.add("ipv4-neighbor-address")

                                                                    self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                    self.max_link_bandwidth.parent = self
                                                                    self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"
                                                                    self._children_yang_names.add("max-link-bandwidth")

                                                                    self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                    self.max_reservable_link_bandwidth.parent = self
                                                                    self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"
                                                                    self._children_yang_names.add("max-reservable-link-bandwidth")

                                                                    self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                    self.unreserved_bandwidth.parent = self
                                                                    self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"
                                                                    self._children_yang_names.add("unreserved-bandwidth")

                                                                    self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                    self.ipv6_interface_address.parent = self
                                                                    self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"
                                                                    self._children_yang_names.add("ipv6-interface-address")

                                                                    self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                    self.ipv6_neighbor_address.parent = self
                                                                    self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"
                                                                    self._children_yang_names.add("ipv6-neighbor-address")

                                                                    self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                    self.extended_admin_group.parent = self
                                                                    self._children_name_map["extended_admin_group"] = "extended-admin-group"
                                                                    self._children_yang_names.add("extended-admin-group")

                                                                    self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric()
                                                                    self.te_default_metric.parent = self
                                                                    self._children_name_map["te_default_metric"] = "te-default-metric"
                                                                    self._children_yang_names.add("te-default-metric")

                                                                    self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes()
                                                                    self.link_attributes.parent = self
                                                                    self._children_name_map["link_attributes"] = "link-attributes"
                                                                    self._children_yang_names.add("link-attributes")

                                                                    self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType()
                                                                    self.link_protection_type.parent = self
                                                                    self._children_name_map["link_protection_type"] = "link-protection-type"
                                                                    self._children_yang_names.add("link-protection-type")

                                                                    self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints()
                                                                    self.bandwidth_constraints.parent = self
                                                                    self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"
                                                                    self._children_yang_names.add("bandwidth-constraints")

                                                                    self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                    self.unconstrained_lsp.parent = self
                                                                    self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"
                                                                    self._children_yang_names.add("unconstrained-lsp")

                                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids()
                                                                    self.adjacency_sids.parent = self
                                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                                    self._children_yang_names.add("adjacency-sids")

                                                                    self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids()
                                                                    self.lan_adjacency_sids.parent = self
                                                                    self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"
                                                                    self._children_yang_names.add("lan-adjacency-sids")

                                                                    self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay()
                                                                    self.link_delay.parent = self
                                                                    self._children_name_map["link_delay"] = "link-delay"
                                                                    self._children_yang_names.add("link-delay")

                                                                    self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                    self.min_max_link_delay.parent = self
                                                                    self._children_name_map["min_max_link_delay"] = "min-max-link-delay"
                                                                    self._children_yang_names.add("min-max-link-delay")

                                                                    self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation()
                                                                    self.link_delay_variation.parent = self
                                                                    self._children_name_map["link_delay_variation"] = "link-delay-variation"
                                                                    self._children_yang_names.add("link-delay-variation")

                                                                    self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss()
                                                                    self.link_loss.parent = self
                                                                    self._children_name_map["link_loss"] = "link-loss"
                                                                    self._children_yang_names.add("link-loss")

                                                                    self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth()
                                                                    self.residual_bandwidth.parent = self
                                                                    self._children_name_map["residual_bandwidth"] = "residual-bandwidth"
                                                                    self._children_yang_names.add("residual-bandwidth")

                                                                    self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth()
                                                                    self.available_bandwidth.parent = self
                                                                    self._children_name_map["available_bandwidth"] = "available-bandwidth"
                                                                    self._children_yang_names.add("available-bandwidth")

                                                                    self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                    self.utilized_bandwidth.parent = self
                                                                    self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                    self._children_yang_names.add("utilized-bandwidth")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of IS neighbor state
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class AdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 3.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 3
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup, self).__init__()

                                                                        self.yang_name = "admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 3.
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                        	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('admin_group', YLeafList(YType.uint32, 'admin-group')),
                                                                            ])
                                                                            self.admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)


                                                                class Ipv4InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 6.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 6
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv4-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 6.
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                        	A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_interface_address', YLeafList(YType.str, 'ipv4-interface-address')),
                                                                            ])
                                                                            self.ipv4_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['ipv4_interface_address'], name, value)


                                                                class Ipv4NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 8.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 8
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv4-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 8.
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                        	A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_neighbor_address', YLeafList(YType.str, 'ipv4-neighbor-address')),
                                                                            ])
                                                                            self.ipv4_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['ipv4_neighbor_address'], name, value)


                                                                class MaxLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 9.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 9
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 9.
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                        	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_link_bandwidth', YLeaf(YType.str, 'max-link-bandwidth')),
                                                                            ])
                                                                            self.max_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['max_link_bandwidth'], name, value)


                                                                class MaxReservableLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 10.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 10
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-reservable-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-reservable-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 10.
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                        	The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_reservable_link_bandwidth', YLeaf(YType.str, 'max-reservable-link-bandwidth')),
                                                                            ])
                                                                            self.max_reservable_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['max_reservable_link_bandwidth'], name, value)


                                                                class UnreservedBandwidth(Entity):
                                                                    """
                                                                    This container defines unreserved\-bandwidth. The units
                                                                    are bytes per second.
                                                                    
                                                                    .. attribute:: setup_priority
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\: list of  		 :py:class:`SetupPriority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth, self).__init__()

                                                                        self.yang_name = "unreserved-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                        self._leafs = OrderedDict()

                                                                        self.setup_priority = YList(self)
                                                                        self._segment_path = lambda: "unreserved-bandwidth"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)


                                                                    class SetupPriority(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for unreserved
                                                                        bandwidth.
                                                                        
                                                                        .. attribute:: priority  (key)
                                                                        
                                                                        	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..7
                                                                        
                                                                        	**refers to**\:  :py:class:`priority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, self).__init__()

                                                                            self.yang_name = "setup-priority"
                                                                            self.yang_parent_name = "unreserved-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['priority']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('priority', YLeaf(YType.str, 'priority')),
                                                                            ])
                                                                            self.priority = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            11.
                                                                            
                                                                            .. attribute:: priority
                                                                            
                                                                            	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..7
                                                                            
                                                                            .. attribute:: unreserved_bandwidth
                                                                            
                                                                            	The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                            	**type**\: str
                                                                            
                                                                            	**length:** 32
                                                                            
                                                                            	**units**\: bytes per second
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "setup-priority"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', YLeaf(YType.uint8, 'priority')),
                                                                                    ('unreserved_bandwidth', YLeaf(YType.str, 'unreserved-bandwidth')),
                                                                                ])
                                                                                self.priority = None
                                                                                self.unreserved_bandwidth = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'unreserved_bandwidth'], name, value)


                                                                class Ipv6InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv6-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_interface_address', YLeafList(YType.str, 'ipv6-interface-address')),
                                                                            ])
                                                                            self.ipv6_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['ipv6_interface_address'], name, value)


                                                                class Ipv6NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 13.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 13
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv6-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 13.
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_neighbor_address', YLeafList(YType.str, 'ipv6-neighbor-address')),
                                                                            ])
                                                                            self.ipv6_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['ipv6_neighbor_address'], name, value)


                                                                class ExtendedAdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 14.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 14
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup, self).__init__()

                                                                        self.yang_name = "extended-admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "extended-admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 14.
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                        	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "extended-admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('extended_admin_group', YLeafList(YType.uint32, 'extended-admin-group')),
                                                                            ])
                                                                            self.extended_admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)


                                                                class TeDefaultMetric(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 18.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 18
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric, self).__init__()

                                                                        self.yang_name = "te-default-metric"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "te-default-metric"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 18.
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                        	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "te-default-metric"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('te_default_metric', YLeaf(YType.uint32, 'te-default-metric')),
                                                                            ])
                                                                            self.te_default_metric = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.TeDefaultMetric.State, ['te_default_metric'], name, value)


                                                                class LinkAttributes(Entity):
                                                                    """
                                                                    This container defines link\-attributes.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 19
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes, self).__init__()

                                                                        self.yang_name = "link-attributes"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-attributes"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        19.
                                                                        
                                                                        .. attribute:: local_protection
                                                                        
                                                                        	Link local\-protection attributes
                                                                        	**type**\: list of   :py:class:`LocalProtection <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-attributes"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('local_protection', YLeafList(YType.enumeration, 'local-protection')),
                                                                            ])
                                                                            self.local_protection = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                        class LocalProtection(Enum):
                                                                            """
                                                                            LocalProtection (Enum Class)

                                                                            Link local\-protection attributes.

                                                                            .. data:: LOCAL_PROTECTION = 0

                                                                            	If set, local protection is available for the

                                                                            	link.

                                                                            .. data:: LINK_EXCLUDED = 1

                                                                            	If set, the link is excluded from local

                                                                            	protection.

                                                                            """

                                                                            LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                            LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")



                                                                class LinkProtectionType(Entity):
                                                                    """
                                                                    ISIS LSDB parameters relating to the type of link
                                                                    protection offered.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 20
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType, self).__init__()

                                                                        self.yang_name = "link-protection-type"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-protection-type"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 20.
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                        	Link protection capabilities
                                                                        	**type**\: list of   :py:class:`LinkProtectionType_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State.LinkProtectionType_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-protection-type"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('link_protection_type', YLeafList(YType.enumeration, 'link-protection-type')),
                                                                            ])
                                                                            self.link_protection_type = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkProtectionType.State, ['link_protection_type'], name, value)

                                                                        class LinkProtectionType_(Enum):
                                                                            """
                                                                            LinkProtectionType\_ (Enum Class)

                                                                            Link protection capabilities.

                                                                            .. data:: EXTRA_TRAFFIC = 0

                                                                            	If set the link has extra traffic protection. If

                                                                            	the link is of type Extra Traffic, it means that

                                                                            	the link is protecting another link or links. The

                                                                            	LSPs on a link of this type will be lost if any of

                                                                            	the links it is protecting fail.

                                                                            .. data:: UNPROTECTED = 1

                                                                            	If set, the link is unprotected. If the link is

                                                                            	of type Unprotected, it means that there is no

                                                                            	other link protecting this link.  The LSPs on a

                                                                            	link of this type will be lost if the link

                                                                            	fails.

                                                                            .. data:: SHARED = 2

                                                                            	If set, the link has shared protection. If the

                                                                            	link is of type Shared, it means that there are

                                                                            	one or more disjoint links of type Extra Traffic

                                                                            	that are protecting this link.  These Extra

                                                                            	Traffic links are shared between one or more links

                                                                            	of type Shared.

                                                                            .. data:: ONE_ONE = 3

                                                                            	If set, the link has dedicated 1:1 protection. If

                                                                            	the link is of type Dedicated 1:1, it means that

                                                                            	there is one dedicated disjoint link of type Extra

                                                                            	Traffic that is protecting this link.

                                                                            .. data:: PLUS_ONE = 4

                                                                            	If set, the link has dedicated 1+1 protection. If

                                                                            	the link is of type Dedicated 1+1, it means that a

                                                                            	dedicated disjoint link is protecting this link.

                                                                            	However, the protecting link is not advertised in

                                                                            	the link state database and is therefore not

                                                                            	available for the routing of LSPs.

                                                                            .. data:: ENHANCED = 5

                                                                            	If set the link has enhanced protection.  If the

                                                                            	link is of type Enhanced, it means that a

                                                                            	protection scheme that is more reliable than

                                                                            	Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                            	being used to protect this link.

                                                                            """

                                                                            EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                            UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                            SHARED = Enum.YLeaf(2, "SHARED")

                                                                            ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                            PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                            ENHANCED = Enum.YLeaf(5, "ENHANCED")



                                                                class BandwidthConstraints(Entity):
                                                                    """
                                                                    This container defines bandwidth\-constraints. For DS\-TE,
                                                                    the existing Maximum Reservable link bandwidth parameter
                                                                    is retained, but its semantics is generalized and
                                                                    interpreted as the aggregate bandwidth constraint across
                                                                    all Class\-Types
                                                                    
                                                                    .. attribute:: bandwidth_constraint
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\: list of  		 :py:class:`BandwidthConstraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints, self).__init__()

                                                                        self.yang_name = "bandwidth-constraints"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                        self._leafs = OrderedDict()

                                                                        self.bandwidth_constraint = YList(self)
                                                                        self._segment_path = lambda: "bandwidth-constraints"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)


                                                                    class BandwidthConstraint(Entity):
                                                                        """
                                                                        List of the Bandwidth Constraints sub\-TLV instances
                                                                        present in the TLV.
                                                                        
                                                                        .. attribute:: model_id  (key)
                                                                        
                                                                        	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        	**refers to**\:  :py:class:`model_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 22
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: constraints
                                                                        
                                                                        	Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                        	**type**\:  :py:class:`Constraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, self).__init__()

                                                                            self.yang_name = "bandwidth-constraint"
                                                                            self.yang_parent_name = "bandwidth-constraints"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['model_id']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('model_id', YLeaf(YType.str, 'model-id')),
                                                                            ])
                                                                            self.model_id = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")

                                                                            self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                            self.constraints.parent = self
                                                                            self._children_name_map["constraints"] = "constraints"
                                                                            self._children_yang_names.add("constraints")
                                                                            self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            22.
                                                                            
                                                                            .. attribute:: model_id
                                                                            
                                                                            	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', YLeaf(YType.uint8, 'model-id')),
                                                                                ])
                                                                                self.model_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                        class Constraints(Entity):
                                                                            """
                                                                            Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                            
                                                                            .. attribute:: constraint
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                            	**type**\: list of  		 :py:class:`Constraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, self).__init__()

                                                                                self.yang_name = "constraints"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.constraint = YList(self)
                                                                                self._segment_path = lambda: "constraints"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)


                                                                            class Constraint(Entity):
                                                                                """
                                                                                List of the constraints within the Bandwidth Constraints
                                                                                sub\-TLV. The BC0 level is indicated by the constraint\-id
                                                                                leaf being set to 0, with BCN being indicated by constraint\-id
                                                                                N.
                                                                                
                                                                                .. attribute:: constraint_id  (key)
                                                                                
                                                                                	Reference to the unique ID for the BCN level
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                	**refers to**\:  :py:class:`constraint_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                	Operational state parameters of the BCN level
                                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, self).__init__()

                                                                                    self.yang_name = "constraint"
                                                                                    self.yang_parent_name = "constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['constraint_id']
                                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                    self._child_list_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('constraint_id', YLeaf(YType.str, 'constraint-id')),
                                                                                    ])
                                                                                    self.constraint_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._children_yang_names.add("state")
                                                                                    self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)


                                                                                class State(Entity):
                                                                                    """
                                                                                    Operational state parameters of the BCN level
                                                                                    
                                                                                    .. attribute:: constraint_id
                                                                                    
                                                                                    	Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                    	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                    	**type**\: str
                                                                                    
                                                                                    	**length:** 32
                                                                                    
                                                                                    	**units**\: bytes per second
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, self).__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_container_classes = OrderedDict([])
                                                                                        self._child_list_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', YLeaf(YType.uint32, 'constraint-id')),
                                                                                            ('bandwidth', YLeaf(YType.str, 'bandwidth')),
                                                                                        ])
                                                                                        self.constraint_id = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)


                                                                class UnconstrainedLsp(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 23.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 23
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp, self).__init__()

                                                                        self.yang_name = "unconstrained-lsp"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "unconstrained-lsp"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 23.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                        	Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..65535
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "unconstrained-lsp"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('unconstrained_lsp', YLeaf(YType.uint16, 'unconstrained-lsp')),
                                                                            ])
                                                                            self.type = None
                                                                            self.unconstrained_lsp = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'unconstrained_lsp'], name, value)


                                                                class AdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing adjacency SIDs.
                                                                    
                                                                    .. attribute:: adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids, self).__init__()

                                                                        self.yang_name = "adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids, [], name, value)


                                                                    class AdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, self).__init__()

                                                                            self.yang_name = "adjacency-sid"
                                                                            self.yang_parent_name = "adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LanAdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing LAN adjacency
                                                                    SIDs
                                                                    
                                                                    .. attribute:: lan_adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`LanAdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids, self).__init__()

                                                                        self.yang_name = "lan-adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.lan_adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "lan-adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)


                                                                    class LanAdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the LAN Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of LAN Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, self).__init__()

                                                                            self.yang_name = "lan-adjacency-sid"
                                                                            self.yang_parent_name = "lan-adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of LAN Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	LAN Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with LAN\-Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: neighbor_id
                                                                            
                                                                            	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                            	**type**\: str
                                                                            
                                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "lan-adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                    ('neighbor_id', YLeaf(YType.str, 'neighbor-id')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self.neighbor_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with LAN\-Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LinkDelay(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 33
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay, self).__init__()

                                                                        self.yang_name = "link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        33.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)


                                                                class MinMaxLinkDelay(Entity):
                                                                    """
                                                                    This container defines min/max link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 34
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay, self).__init__()

                                                                        self.yang_name = "min-max-link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "min-max-link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        34.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: min_delay
                                                                        
                                                                        	Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        .. attribute:: max_delay
                                                                        
                                                                        	Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "min-max-link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('min_delay', YLeaf(YType.uint32, 'min-delay')),
                                                                                ('max_delay', YLeaf(YType.uint32, 'max-delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.min_delay = None
                                                                            self.max_delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)


                                                                class LinkDelayVariation(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay
                                                                    variation.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 35
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation, self).__init__()

                                                                        self.yang_name = "link-delay-variation"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay-variation"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        35.
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay-variation"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)


                                                                class LinkLoss(Entity):
                                                                    """
                                                                    This container defines unidirectional link loss delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 36
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss, self).__init__()

                                                                        self.yang_name = "link-loss"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-loss"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        36.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                        	Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-loss"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('link_loss', YLeaf(YType.uint32, 'link-loss')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.link_loss = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)


                                                                class ResidualBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional residual
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 37
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth, self).__init__()

                                                                        self.yang_name = "residual-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "residual-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        37.
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                        	Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "residual-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('residual_bandwidth', YLeaf(YType.str, 'residual-bandwidth')),
                                                                            ])
                                                                            self.residual_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.ResidualBandwidth.State, ['residual_bandwidth'], name, value)


                                                                class AvailableBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional lavailable
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 38
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth, self).__init__()

                                                                        self.yang_name = "available-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "available-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        38.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                        	The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "available-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('available_bandwidth', YLeaf(YType.str, 'available-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.available_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'available_bandwidth'], name, value)


                                                                class UtilizedBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional utilized
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 39
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth, self).__init__()

                                                                        self.yang_name = "utilized-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "utilized-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        39.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                        	The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "utilized-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('utilized_bandwidth', YLeaf(YType.str, 'utilized-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.utilized_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'utilized_bandwidth'], name, value)


                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbors_.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class ExtendedIpv4Reachability(Entity):
                                                """
                                                This container defines list of IPv4 extended reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS prefixes
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability, self).__init__()

                                                    self.yang_name = "extended-ipv4-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "extended-ipv4-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	This list describes IPv4 extended prefixes and attributes
                                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "extended-ipv4-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes, [], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        This list describes IPv4 extended prefixes and
                                                        attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the IPv4 prefix that the TLV describes the attributes of
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of an IPv4 extended prefix
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS prefix sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix, ['prefix'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of an IPv4 extended prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                            	The Sub\-TLV present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv4 prefix contained within extended reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('s_bit', YLeaf(YType.boolean, 's-bit')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.up_down = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State, ['up_down', 's_bit', 'prefix', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for a prefix
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: tag
                                                                
                                                                	This container defines sub\-TLV 1
                                                                	**type**\:  :py:class:`Tag <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                	This container defines sub\-TLV 2
                                                                	**type**\:  :py:class:`Tag64 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	This container defines sub\-TLV 4
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                	This container defines sub\-TLV 11
                                                                	**type**\:  :py:class:`Ipv4SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                	This container defines segment routing extensions for prefixes
                                                                	**type**\:  :py:class:`PrefixSids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"
                                                                    self._children_yang_names.add("tag")

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"
                                                                    self._children_yang_names.add("tag64")

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"
                                                                    self._children_yang_names.add("flags")

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"
                                                                    self._children_yang_names.add("ipv4-source-router-id")

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"
                                                                    self._children_yang_names.add("ipv6-source-router-id")

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._children_yang_names.add("prefix-sids")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 1
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, self).__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                        	List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', YLeafList(YType.uint32, 'tag32')),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)


                                                                class Tag64(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 2
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, self).__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag64"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                        	List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', YLeafList(YType.uint64, 'tag64')),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)


                                                                class Flags(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 4
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, self).__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "flags"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                        	Additional prefix reachability flags
                                                                        	**type**\: list of   :py:class:`Flags_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            Additional prefix reachability flags.

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                            	External prefix flag. Set if the prefix has been

                                                                            	redistributed from another protocol. This includes

                                                                            	the case where multiple virtual routers are

                                                                            	supported and the source of the redistributed prefix

                                                                            	is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                            	Readvertisement flag. Set when the prefix has been

                                                                            	leaked from one level to another (upwards or

                                                                            	downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                            	Node flag. Set when the prefix identifies the

                                                                            	advertising router, i.e., the prefix is a host

                                                                            	prefix advertising  a globally reachable address

                                                                            	typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")



                                                                class Ipv4SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 11
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv4_source_router_id
                                                                        
                                                                        	IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv4_source_router_id', YLeaf(YType.str, 'ipv4-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv4_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'ipv4_source_router_id'], name, value)


                                                                class Ipv6SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv6_source_router_id
                                                                        
                                                                        	IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv6_source_router_id', YLeaf(YType.str, 'ipv6-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv6_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'ipv6_source_router_id'], name, value)


                                                                class PrefixSids(Entity):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                    	Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, self).__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)


                                                                    class PrefixSid(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the prefix SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters for Prefix\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, self).__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	IGP Prefix\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Prefix Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                            	Prefix\-SID algorithm to be used for path computation
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('algorithm', YLeaf(YType.uint8, 'algorithm')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Prefix Segment\-ID.

                                                                                .. data:: READVERTISEMENT = 0

                                                                                	Readvertisment flag. When set, the prefix to which

                                                                                	this Prefix-SID is attached, has been propagated by

                                                                                	the router either from another level or from

                                                                                	redistribution.

                                                                                .. data:: NODE = 1

                                                                                	Node flag. When set, the Prefix-SID refers to the

                                                                                	router identified by the prefix. Typically, the

                                                                                	N-Flag is set on Prefix-SIDs attached to a router

                                                                                	loopback address.

                                                                                .. data:: PHP = 2

                                                                                	Penultimate-Hop-Popping flag. When set, then the

                                                                                	penultimate hop MUST NOT pop the Prefix-SID before

                                                                                	delivering the packet to the node that advertised

                                                                                	the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                	Explicit-Null flag. When set, any upstream neighbor

                                                                                	of the Prefix-SID originator MUST replace the

                                                                                	Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                	value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                	the packet.

                                                                                .. data:: VALUE = 4

                                                                                	Value flag. When set, the Prefix-SID carries a

                                                                                	value (instead of an index). By default the flag is

                                                                                	UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                	Local flag. When set, the value/index carried by

                                                                                	the Prefix-SID has local significance. By default

                                                                                	the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                PHP = Enum.YLeaf(2, "PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")



                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class Ipv6Reachability(Entity):
                                                """
                                                This container defines list of IPv6 reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS prefixes
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability, self).__init__()

                                                    self.yang_name = "ipv6-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "ipv6-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefixes
                                                    
                                                    	This list defines IPv6 extended prefix attributes
                                                    	**type**\: list of  		 :py:class:`Prefixes_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv6-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_))])
                                                        self._leafs = OrderedDict()

                                                        self.prefixes = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes, [], name, value)


                                                    class Prefixes_(Entity):
                                                        """
                                                        This list defines IPv6 extended prefix attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the IPv6 prefix that the TLV corresponds to
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of IPv6 prefix attributes
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS prefix sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_, self).__init__()

                                                            self.yang_name = "prefixes"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "prefixes" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_, ['prefix'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of IPv6 prefix attributes
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                            	The Sub\-TLV present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv4 prefix contained within extended reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('s_bit', YLeaf(YType.boolean, 's-bit')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.up_down = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.State, ['up_down', 's_bit', 'prefix', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for a prefix
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: tag
                                                                
                                                                	This container defines sub\-TLV 1
                                                                	**type**\:  :py:class:`Tag <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag>`
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                	This container defines sub\-TLV 2
                                                                	**type**\:  :py:class:`Tag64 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	This container defines sub\-TLV 4
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags>`
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                	This container defines sub\-TLV 11
                                                                	**type**\:  :py:class:`Ipv4SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                	This container defines segment routing extensions for prefixes
                                                                	**type**\:  :py:class:`PrefixSids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"
                                                                    self._children_yang_names.add("tag")

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"
                                                                    self._children_yang_names.add("tag64")

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"
                                                                    self._children_yang_names.add("flags")

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"
                                                                    self._children_yang_names.add("ipv4-source-router-id")

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"
                                                                    self._children_yang_names.add("ipv6-source-router-id")

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._children_yang_names.add("prefix-sids")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 1
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag, self).__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                        	List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', YLeafList(YType.uint32, 'tag32')),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)


                                                                class Tag64(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 2
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64, self).__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag64"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                        	List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', YLeafList(YType.uint64, 'tag64')),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)


                                                                class Flags(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 4
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags, self).__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "flags"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                        	Additional prefix reachability flags
                                                                        	**type**\: list of   :py:class:`Flags_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            Additional prefix reachability flags.

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                            	External prefix flag. Set if the prefix has been

                                                                            	redistributed from another protocol. This includes

                                                                            	the case where multiple virtual routers are

                                                                            	supported and the source of the redistributed prefix

                                                                            	is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                            	Readvertisement flag. Set when the prefix has been

                                                                            	leaked from one level to another (upwards or

                                                                            	downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                            	Node flag. Set when the prefix identifies the

                                                                            	advertising router, i.e., the prefix is a host

                                                                            	prefix advertising  a globally reachable address

                                                                            	typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")



                                                                class Ipv4SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 11
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv4_source_router_id
                                                                        
                                                                        	IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv4_source_router_id', YLeaf(YType.str, 'ipv4-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv4_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'ipv4_source_router_id'], name, value)


                                                                class Ipv6SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv6_source_router_id
                                                                        
                                                                        	IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv6_source_router_id', YLeaf(YType.str, 'ipv6-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv6_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'ipv6_source_router_id'], name, value)


                                                                class PrefixSids(Entity):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                    	Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids, self).__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids, [], name, value)


                                                                    class PrefixSid(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the prefix SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters for Prefix\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid, self).__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	IGP Prefix\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Prefix Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                            	Prefix\-SID algorithm to be used for path computation
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('algorithm', YLeaf(YType.uint8, 'algorithm')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Prefix Segment\-ID.

                                                                                .. data:: READVERTISEMENT = 0

                                                                                	Readvertisment flag. When set, the prefix to which

                                                                                	this Prefix-SID is attached, has been propagated by

                                                                                	the router either from another level or from

                                                                                	redistribution.

                                                                                .. data:: NODE = 1

                                                                                	Node flag. When set, the Prefix-SID refers to the

                                                                                	router identified by the prefix. Typically, the

                                                                                	N-Flag is set on Prefix-SIDs attached to a router

                                                                                	loopback address.

                                                                                .. data:: PHP = 2

                                                                                	Penultimate-Hop-Popping flag. When set, then the

                                                                                	penultimate hop MUST NOT pop the Prefix-SID before

                                                                                	delivering the packet to the node that advertised

                                                                                	the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                	Explicit-Null flag. When set, any upstream neighbor

                                                                                	of the Prefix-SID originator MUST replace the

                                                                                	Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                	value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                	the packet.

                                                                                .. data:: VALUE = 4

                                                                                	Value flag. When set, the Prefix-SID carries a

                                                                                	value (instead of an index). By default the flag is

                                                                                	UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                	Local flag. When set, the value/index carried by

                                                                                	the Prefix-SID has local significance. By default

                                                                                	the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                PHP = Enum.YLeaf(2, "PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")



                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefixes_.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class MultiTopology(Entity):
                                                """
                                                This container defines the topology supported.
                                                
                                                .. attribute:: topologies
                                                
                                                	This container describes IS topologies
                                                	**type**\:  :py:class:`Topologies <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology, self).__init__()

                                                    self.yang_name = "multi-topology"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("topologies", ("topologies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.topologies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies()
                                                    self.topologies.parent = self
                                                    self._children_name_map["topologies"] = "topologies"
                                                    self._children_yang_names.add("topologies")
                                                    self._segment_path = lambda: "multi-topology"


                                                class Topologies(Entity):
                                                    """
                                                    This container describes IS topologies.
                                                    
                                                    .. attribute:: topology
                                                    
                                                    	This list describes a topology
                                                    	**type**\: list of  		 :py:class:`Topology <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies, self).__init__()

                                                        self.yang_name = "topologies"
                                                        self.yang_parent_name = "multi-topology"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("topology", ("topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology))])
                                                        self._leafs = OrderedDict()

                                                        self.topology = YList(self)
                                                        self._segment_path = lambda: "topologies"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies, [], name, value)


                                                    class Topology(Entity):
                                                        """
                                                        This list describes a topology.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                        	Reference to the multi\-topology ID being described by the list entry
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4095
                                                        
                                                        	**refers to**\:  :py:class:`mt_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of IS multi\-topology TLV 229
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology, self).__init__()

                                                            self.yang_name = "topology"
                                                            self.yang_parent_name = "topologies"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', YLeaf(YType.str, 'mt-id')),
                                                            ])
                                                            self.mt_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")
                                                            self._segment_path = lambda: "topology" + "[mt-id='" + str(self.mt_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology, ['mt_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of IS multi\-topology TLV 229.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Multi\-topology ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4095
                                                            
                                                            .. attribute:: attributes
                                                            
                                                            	Attributes of the LSP for the associated topology
                                                            	**type**\:  :py:class:`Attributes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State.Attributes>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "topology"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', YLeaf(YType.uint16, 'mt-id')),
                                                                    ('attributes', YLeaf(YType.enumeration, 'attributes')),
                                                                ])
                                                                self.mt_id = None
                                                                self.attributes = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State, ['mt_id', 'attributes'], name, value)

                                                            class Attributes(Enum):
                                                                """
                                                                Attributes (Enum Class)

                                                                Attributes of the LSP for the associated

                                                                topology.

                                                                .. data:: OVERLOAD = 0

                                                                	When set, node is overloaded, still part of

                                                                	the topology but cannot be used for transit.

                                                                .. data:: ATTACHED = 1

                                                                	When set, node is attached to another area

                                                                	using the referred metric and can be used as

                                                                	default gateway.

                                                                """

                                                                OVERLOAD = Enum.YLeaf(0, "OVERLOAD")

                                                                ATTACHED = Enum.YLeaf(1, "ATTACHED")



                                            class IsisNeighborAttribute(Entity):
                                                """
                                                This container defines list of ISIS topology neighbors
                                                for extended ISIS LSP (multiple system IDs). 
                                                
                                                .. attribute:: neighbors
                                                
                                                	This container describes IS neighbors
                                                	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute, self).__init__()

                                                    self.yang_name = "isis-neighbor-attribute"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._children_yang_names.add("neighbors")
                                                    self._segment_path = lambda: "isis-neighbor-attribute"


                                                class Neighbors(Entity):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                    	This list defines ISIS extended reachability neighbor attributes
                                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors, self).__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "isis-neighbor-attribute"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors, [], name, value)


                                                    class Neighbor(Entity):
                                                        """
                                                        This list defines ISIS extended reachability neighbor
                                                        attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                        	Reference to the neighboring IS
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of extended neighbor
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS Neighbor sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor, self).__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "neighbor" + "[system-id='" + str(self.system_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor, ['system_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of extended neighbor.
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	System\-id of the neighbor
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	Metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.system_id = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State, ['system_id', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS Neighbor sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of IS neighbor state
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: admin_group
                                                                
                                                                	This container defines sub\-TLV 3
                                                                	**type**\:  :py:class:`AdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup>`
                                                                
                                                                .. attribute:: ipv4_interface_address
                                                                
                                                                	This container defines sub\-TLV 6
                                                                	**type**\:  :py:class:`Ipv4InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv4_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 8
                                                                	**type**\:  :py:class:`Ipv4NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                
                                                                .. attribute:: max_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 9
                                                                	**type**\:  :py:class:`MaxLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                
                                                                .. attribute:: max_reservable_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 10
                                                                	**type**\:  :py:class:`MaxReservableLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                
                                                                .. attribute:: unreserved_bandwidth
                                                                
                                                                	This container defines unreserved\-bandwidth. The units are bytes per second
                                                                	**type**\:  :py:class:`UnreservedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                
                                                                .. attribute:: ipv6_interface_address
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv6_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 13
                                                                	**type**\:  :py:class:`Ipv6NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                
                                                                .. attribute:: extended_admin_group
                                                                
                                                                	This container defines sub\-TLV 14
                                                                	**type**\:  :py:class:`ExtendedAdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                
                                                                .. attribute:: te_default_metric
                                                                
                                                                	This container defines sub\-TLV 18
                                                                	**type**\:  :py:class:`TeDefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                
                                                                .. attribute:: link_attributes
                                                                
                                                                	This container defines link\-attributes
                                                                	**type**\:  :py:class:`LinkAttributes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes>`
                                                                
                                                                .. attribute:: link_protection_type
                                                                
                                                                	ISIS LSDB parameters relating to the type of link protection offered
                                                                	**type**\:  :py:class:`LinkProtectionType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType>`
                                                                
                                                                .. attribute:: bandwidth_constraints
                                                                
                                                                	This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                	**type**\:  :py:class:`BandwidthConstraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                
                                                                .. attribute:: unconstrained_lsp
                                                                
                                                                	This container defines sub\-TLV 23
                                                                	**type**\:  :py:class:`UnconstrainedLsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                
                                                                .. attribute:: adjacency_sids
                                                                
                                                                	This container defines segment routing adjacency SIDs
                                                                	**type**\:  :py:class:`AdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids>`
                                                                
                                                                .. attribute:: lan_adjacency_sids
                                                                
                                                                	This container defines segment routing LAN adjacency SIDs
                                                                	**type**\:  :py:class:`LanAdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                
                                                                .. attribute:: link_delay
                                                                
                                                                	This container defines unidirectional link delay
                                                                	**type**\:  :py:class:`LinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay>`
                                                                
                                                                .. attribute:: min_max_link_delay
                                                                
                                                                	This container defines min/max link delay
                                                                	**type**\:  :py:class:`MinMaxLinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                
                                                                .. attribute:: link_delay_variation
                                                                
                                                                	This container defines unidirectional link delay variation
                                                                	**type**\:  :py:class:`LinkDelayVariation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                
                                                                .. attribute:: link_loss
                                                                
                                                                	This container defines unidirectional link loss delay
                                                                	**type**\:  :py:class:`LinkLoss <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss>`
                                                                
                                                                .. attribute:: residual_bandwidth
                                                                
                                                                	This container defines unidirectional residual bandwidth
                                                                	**type**\:  :py:class:`ResidualBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                
                                                                .. attribute:: available_bandwidth
                                                                
                                                                	This container defines unidirectional lavailable bandwidth
                                                                	**type**\:  :py:class:`AvailableBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                
                                                                .. attribute:: utilized_bandwidth
                                                                
                                                                	This container defines unidirectional utilized bandwidth
                                                                	**type**\:  :py:class:`UtilizedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup()
                                                                    self.admin_group.parent = self
                                                                    self._children_name_map["admin_group"] = "admin-group"
                                                                    self._children_yang_names.add("admin-group")

                                                                    self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                    self.ipv4_interface_address.parent = self
                                                                    self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"
                                                                    self._children_yang_names.add("ipv4-interface-address")

                                                                    self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                    self.ipv4_neighbor_address.parent = self
                                                                    self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"
                                                                    self._children_yang_names.add("ipv4-neighbor-address")

                                                                    self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                    self.max_link_bandwidth.parent = self
                                                                    self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"
                                                                    self._children_yang_names.add("max-link-bandwidth")

                                                                    self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                    self.max_reservable_link_bandwidth.parent = self
                                                                    self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"
                                                                    self._children_yang_names.add("max-reservable-link-bandwidth")

                                                                    self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                    self.unreserved_bandwidth.parent = self
                                                                    self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"
                                                                    self._children_yang_names.add("unreserved-bandwidth")

                                                                    self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                    self.ipv6_interface_address.parent = self
                                                                    self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"
                                                                    self._children_yang_names.add("ipv6-interface-address")

                                                                    self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                    self.ipv6_neighbor_address.parent = self
                                                                    self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"
                                                                    self._children_yang_names.add("ipv6-neighbor-address")

                                                                    self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                    self.extended_admin_group.parent = self
                                                                    self._children_name_map["extended_admin_group"] = "extended-admin-group"
                                                                    self._children_yang_names.add("extended-admin-group")

                                                                    self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric()
                                                                    self.te_default_metric.parent = self
                                                                    self._children_name_map["te_default_metric"] = "te-default-metric"
                                                                    self._children_yang_names.add("te-default-metric")

                                                                    self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes()
                                                                    self.link_attributes.parent = self
                                                                    self._children_name_map["link_attributes"] = "link-attributes"
                                                                    self._children_yang_names.add("link-attributes")

                                                                    self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType()
                                                                    self.link_protection_type.parent = self
                                                                    self._children_name_map["link_protection_type"] = "link-protection-type"
                                                                    self._children_yang_names.add("link-protection-type")

                                                                    self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints()
                                                                    self.bandwidth_constraints.parent = self
                                                                    self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"
                                                                    self._children_yang_names.add("bandwidth-constraints")

                                                                    self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                    self.unconstrained_lsp.parent = self
                                                                    self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"
                                                                    self._children_yang_names.add("unconstrained-lsp")

                                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids()
                                                                    self.adjacency_sids.parent = self
                                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                                    self._children_yang_names.add("adjacency-sids")

                                                                    self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids()
                                                                    self.lan_adjacency_sids.parent = self
                                                                    self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"
                                                                    self._children_yang_names.add("lan-adjacency-sids")

                                                                    self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay()
                                                                    self.link_delay.parent = self
                                                                    self._children_name_map["link_delay"] = "link-delay"
                                                                    self._children_yang_names.add("link-delay")

                                                                    self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                    self.min_max_link_delay.parent = self
                                                                    self._children_name_map["min_max_link_delay"] = "min-max-link-delay"
                                                                    self._children_yang_names.add("min-max-link-delay")

                                                                    self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation()
                                                                    self.link_delay_variation.parent = self
                                                                    self._children_name_map["link_delay_variation"] = "link-delay-variation"
                                                                    self._children_yang_names.add("link-delay-variation")

                                                                    self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss()
                                                                    self.link_loss.parent = self
                                                                    self._children_name_map["link_loss"] = "link-loss"
                                                                    self._children_yang_names.add("link-loss")

                                                                    self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth()
                                                                    self.residual_bandwidth.parent = self
                                                                    self._children_name_map["residual_bandwidth"] = "residual-bandwidth"
                                                                    self._children_yang_names.add("residual-bandwidth")

                                                                    self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth()
                                                                    self.available_bandwidth.parent = self
                                                                    self._children_name_map["available_bandwidth"] = "available-bandwidth"
                                                                    self._children_yang_names.add("available-bandwidth")

                                                                    self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                    self.utilized_bandwidth.parent = self
                                                                    self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                    self._children_yang_names.add("utilized-bandwidth")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of IS neighbor state
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class AdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 3.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 3
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup, self).__init__()

                                                                        self.yang_name = "admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 3.
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                        	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('admin_group', YLeafList(YType.uint32, 'admin-group')),
                                                                            ])
                                                                            self.admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)


                                                                class Ipv4InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 6.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 6
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv4-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 6.
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                        	A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_interface_address', YLeafList(YType.str, 'ipv4-interface-address')),
                                                                            ])
                                                                            self.ipv4_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['ipv4_interface_address'], name, value)


                                                                class Ipv4NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 8.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 8
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv4-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 8.
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                        	A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_neighbor_address', YLeafList(YType.str, 'ipv4-neighbor-address')),
                                                                            ])
                                                                            self.ipv4_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['ipv4_neighbor_address'], name, value)


                                                                class MaxLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 9.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 9
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 9.
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                        	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_link_bandwidth', YLeaf(YType.str, 'max-link-bandwidth')),
                                                                            ])
                                                                            self.max_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['max_link_bandwidth'], name, value)


                                                                class MaxReservableLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 10.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 10
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-reservable-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-reservable-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 10.
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                        	The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_reservable_link_bandwidth', YLeaf(YType.str, 'max-reservable-link-bandwidth')),
                                                                            ])
                                                                            self.max_reservable_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['max_reservable_link_bandwidth'], name, value)


                                                                class UnreservedBandwidth(Entity):
                                                                    """
                                                                    This container defines unreserved\-bandwidth. The units
                                                                    are bytes per second.
                                                                    
                                                                    .. attribute:: setup_priority
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\: list of  		 :py:class:`SetupPriority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, self).__init__()

                                                                        self.yang_name = "unreserved-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                        self._leafs = OrderedDict()

                                                                        self.setup_priority = YList(self)
                                                                        self._segment_path = lambda: "unreserved-bandwidth"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)


                                                                    class SetupPriority(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for unreserved
                                                                        bandwidth.
                                                                        
                                                                        .. attribute:: priority  (key)
                                                                        
                                                                        	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..7
                                                                        
                                                                        	**refers to**\:  :py:class:`priority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, self).__init__()

                                                                            self.yang_name = "setup-priority"
                                                                            self.yang_parent_name = "unreserved-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['priority']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('priority', YLeaf(YType.str, 'priority')),
                                                                            ])
                                                                            self.priority = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            11.
                                                                            
                                                                            .. attribute:: priority
                                                                            
                                                                            	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..7
                                                                            
                                                                            .. attribute:: unreserved_bandwidth
                                                                            
                                                                            	The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                            	**type**\: str
                                                                            
                                                                            	**length:** 32
                                                                            
                                                                            	**units**\: bytes per second
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "setup-priority"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', YLeaf(YType.uint8, 'priority')),
                                                                                    ('unreserved_bandwidth', YLeaf(YType.str, 'unreserved-bandwidth')),
                                                                                ])
                                                                                self.priority = None
                                                                                self.unreserved_bandwidth = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'unreserved_bandwidth'], name, value)


                                                                class Ipv6InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv6-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_interface_address', YLeafList(YType.str, 'ipv6-interface-address')),
                                                                            ])
                                                                            self.ipv6_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['ipv6_interface_address'], name, value)


                                                                class Ipv6NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 13.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 13
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv6-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 13.
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_neighbor_address', YLeafList(YType.str, 'ipv6-neighbor-address')),
                                                                            ])
                                                                            self.ipv6_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['ipv6_neighbor_address'], name, value)


                                                                class ExtendedAdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 14.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 14
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup, self).__init__()

                                                                        self.yang_name = "extended-admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "extended-admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 14.
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                        	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "extended-admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('extended_admin_group', YLeafList(YType.uint32, 'extended-admin-group')),
                                                                            ])
                                                                            self.extended_admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)


                                                                class TeDefaultMetric(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 18.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 18
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric, self).__init__()

                                                                        self.yang_name = "te-default-metric"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "te-default-metric"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 18.
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                        	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "te-default-metric"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('te_default_metric', YLeaf(YType.uint32, 'te-default-metric')),
                                                                            ])
                                                                            self.te_default_metric = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, ['te_default_metric'], name, value)


                                                                class LinkAttributes(Entity):
                                                                    """
                                                                    This container defines link\-attributes.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 19
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes, self).__init__()

                                                                        self.yang_name = "link-attributes"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-attributes"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        19.
                                                                        
                                                                        .. attribute:: local_protection
                                                                        
                                                                        	Link local\-protection attributes
                                                                        	**type**\: list of   :py:class:`LocalProtection <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-attributes"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('local_protection', YLeafList(YType.enumeration, 'local-protection')),
                                                                            ])
                                                                            self.local_protection = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                        class LocalProtection(Enum):
                                                                            """
                                                                            LocalProtection (Enum Class)

                                                                            Link local\-protection attributes.

                                                                            .. data:: LOCAL_PROTECTION = 0

                                                                            	If set, local protection is available for the

                                                                            	link.

                                                                            .. data:: LINK_EXCLUDED = 1

                                                                            	If set, the link is excluded from local

                                                                            	protection.

                                                                            """

                                                                            LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                            LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")



                                                                class LinkProtectionType(Entity):
                                                                    """
                                                                    ISIS LSDB parameters relating to the type of link
                                                                    protection offered.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 20
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType, self).__init__()

                                                                        self.yang_name = "link-protection-type"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-protection-type"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 20.
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                        	Link protection capabilities
                                                                        	**type**\: list of   :py:class:`LinkProtectionType_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State.LinkProtectionType_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-protection-type"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('link_protection_type', YLeafList(YType.enumeration, 'link-protection-type')),
                                                                            ])
                                                                            self.link_protection_type = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, ['link_protection_type'], name, value)

                                                                        class LinkProtectionType_(Enum):
                                                                            """
                                                                            LinkProtectionType\_ (Enum Class)

                                                                            Link protection capabilities.

                                                                            .. data:: EXTRA_TRAFFIC = 0

                                                                            	If set the link has extra traffic protection. If

                                                                            	the link is of type Extra Traffic, it means that

                                                                            	the link is protecting another link or links. The

                                                                            	LSPs on a link of this type will be lost if any of

                                                                            	the links it is protecting fail.

                                                                            .. data:: UNPROTECTED = 1

                                                                            	If set, the link is unprotected. If the link is

                                                                            	of type Unprotected, it means that there is no

                                                                            	other link protecting this link.  The LSPs on a

                                                                            	link of this type will be lost if the link

                                                                            	fails.

                                                                            .. data:: SHARED = 2

                                                                            	If set, the link has shared protection. If the

                                                                            	link is of type Shared, it means that there are

                                                                            	one or more disjoint links of type Extra Traffic

                                                                            	that are protecting this link.  These Extra

                                                                            	Traffic links are shared between one or more links

                                                                            	of type Shared.

                                                                            .. data:: ONE_ONE = 3

                                                                            	If set, the link has dedicated 1:1 protection. If

                                                                            	the link is of type Dedicated 1:1, it means that

                                                                            	there is one dedicated disjoint link of type Extra

                                                                            	Traffic that is protecting this link.

                                                                            .. data:: PLUS_ONE = 4

                                                                            	If set, the link has dedicated 1+1 protection. If

                                                                            	the link is of type Dedicated 1+1, it means that a

                                                                            	dedicated disjoint link is protecting this link.

                                                                            	However, the protecting link is not advertised in

                                                                            	the link state database and is therefore not

                                                                            	available for the routing of LSPs.

                                                                            .. data:: ENHANCED = 5

                                                                            	If set the link has enhanced protection.  If the

                                                                            	link is of type Enhanced, it means that a

                                                                            	protection scheme that is more reliable than

                                                                            	Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                            	being used to protect this link.

                                                                            """

                                                                            EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                            UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                            SHARED = Enum.YLeaf(2, "SHARED")

                                                                            ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                            PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                            ENHANCED = Enum.YLeaf(5, "ENHANCED")



                                                                class BandwidthConstraints(Entity):
                                                                    """
                                                                    This container defines bandwidth\-constraints. For DS\-TE,
                                                                    the existing Maximum Reservable link bandwidth parameter
                                                                    is retained, but its semantics is generalized and
                                                                    interpreted as the aggregate bandwidth constraint across
                                                                    all Class\-Types
                                                                    
                                                                    .. attribute:: bandwidth_constraint
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\: list of  		 :py:class:`BandwidthConstraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, self).__init__()

                                                                        self.yang_name = "bandwidth-constraints"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                        self._leafs = OrderedDict()

                                                                        self.bandwidth_constraint = YList(self)
                                                                        self._segment_path = lambda: "bandwidth-constraints"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)


                                                                    class BandwidthConstraint(Entity):
                                                                        """
                                                                        List of the Bandwidth Constraints sub\-TLV instances
                                                                        present in the TLV.
                                                                        
                                                                        .. attribute:: model_id  (key)
                                                                        
                                                                        	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        	**refers to**\:  :py:class:`model_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 22
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: constraints
                                                                        
                                                                        	Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                        	**type**\:  :py:class:`Constraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, self).__init__()

                                                                            self.yang_name = "bandwidth-constraint"
                                                                            self.yang_parent_name = "bandwidth-constraints"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['model_id']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('model_id', YLeaf(YType.str, 'model-id')),
                                                                            ])
                                                                            self.model_id = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")

                                                                            self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                            self.constraints.parent = self
                                                                            self._children_name_map["constraints"] = "constraints"
                                                                            self._children_yang_names.add("constraints")
                                                                            self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            22.
                                                                            
                                                                            .. attribute:: model_id
                                                                            
                                                                            	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', YLeaf(YType.uint8, 'model-id')),
                                                                                ])
                                                                                self.model_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                        class Constraints(Entity):
                                                                            """
                                                                            Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                            
                                                                            .. attribute:: constraint
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                            	**type**\: list of  		 :py:class:`Constraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, self).__init__()

                                                                                self.yang_name = "constraints"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.constraint = YList(self)
                                                                                self._segment_path = lambda: "constraints"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)


                                                                            class Constraint(Entity):
                                                                                """
                                                                                List of the constraints within the Bandwidth Constraints
                                                                                sub\-TLV. The BC0 level is indicated by the constraint\-id
                                                                                leaf being set to 0, with BCN being indicated by constraint\-id
                                                                                N.
                                                                                
                                                                                .. attribute:: constraint_id  (key)
                                                                                
                                                                                	Reference to the unique ID for the BCN level
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                	**refers to**\:  :py:class:`constraint_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                	Operational state parameters of the BCN level
                                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, self).__init__()

                                                                                    self.yang_name = "constraint"
                                                                                    self.yang_parent_name = "constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['constraint_id']
                                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                    self._child_list_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('constraint_id', YLeaf(YType.str, 'constraint-id')),
                                                                                    ])
                                                                                    self.constraint_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._children_yang_names.add("state")
                                                                                    self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)


                                                                                class State(Entity):
                                                                                    """
                                                                                    Operational state parameters of the BCN level
                                                                                    
                                                                                    .. attribute:: constraint_id
                                                                                    
                                                                                    	Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                    	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                    	**type**\: str
                                                                                    
                                                                                    	**length:** 32
                                                                                    
                                                                                    	**units**\: bytes per second
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, self).__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_container_classes = OrderedDict([])
                                                                                        self._child_list_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', YLeaf(YType.uint32, 'constraint-id')),
                                                                                            ('bandwidth', YLeaf(YType.str, 'bandwidth')),
                                                                                        ])
                                                                                        self.constraint_id = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)


                                                                class UnconstrainedLsp(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 23.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 23
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp, self).__init__()

                                                                        self.yang_name = "unconstrained-lsp"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "unconstrained-lsp"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 23.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                        	Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..65535
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "unconstrained-lsp"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('unconstrained_lsp', YLeaf(YType.uint16, 'unconstrained-lsp')),
                                                                            ])
                                                                            self.type = None
                                                                            self.unconstrained_lsp = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'unconstrained_lsp'], name, value)


                                                                class AdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing adjacency SIDs.
                                                                    
                                                                    .. attribute:: adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, self).__init__()

                                                                        self.yang_name = "adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, [], name, value)


                                                                    class AdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, self).__init__()

                                                                            self.yang_name = "adjacency-sid"
                                                                            self.yang_parent_name = "adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LanAdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing LAN adjacency
                                                                    SIDs
                                                                    
                                                                    .. attribute:: lan_adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`LanAdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, self).__init__()

                                                                        self.yang_name = "lan-adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.lan_adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "lan-adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)


                                                                    class LanAdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the LAN Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of LAN Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, self).__init__()

                                                                            self.yang_name = "lan-adjacency-sid"
                                                                            self.yang_parent_name = "lan-adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of LAN Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	LAN Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with LAN\-Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: neighbor_id
                                                                            
                                                                            	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                            	**type**\: str
                                                                            
                                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "lan-adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                    ('neighbor_id', YLeaf(YType.str, 'neighbor-id')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self.neighbor_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with LAN\-Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LinkDelay(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 33
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay, self).__init__()

                                                                        self.yang_name = "link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        33.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)


                                                                class MinMaxLinkDelay(Entity):
                                                                    """
                                                                    This container defines min/max link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 34
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay, self).__init__()

                                                                        self.yang_name = "min-max-link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "min-max-link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        34.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: min_delay
                                                                        
                                                                        	Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        .. attribute:: max_delay
                                                                        
                                                                        	Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "min-max-link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('min_delay', YLeaf(YType.uint32, 'min-delay')),
                                                                                ('max_delay', YLeaf(YType.uint32, 'max-delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.min_delay = None
                                                                            self.max_delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)


                                                                class LinkDelayVariation(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay
                                                                    variation.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 35
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation, self).__init__()

                                                                        self.yang_name = "link-delay-variation"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay-variation"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        35.
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay-variation"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)


                                                                class LinkLoss(Entity):
                                                                    """
                                                                    This container defines unidirectional link loss delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 36
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss, self).__init__()

                                                                        self.yang_name = "link-loss"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-loss"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        36.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                        	Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-loss"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('link_loss', YLeaf(YType.uint32, 'link-loss')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.link_loss = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)


                                                                class ResidualBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional residual
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 37
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth, self).__init__()

                                                                        self.yang_name = "residual-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "residual-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        37.
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                        	Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "residual-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('residual_bandwidth', YLeaf(YType.str, 'residual-bandwidth')),
                                                                            ])
                                                                            self.residual_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, ['residual_bandwidth'], name, value)


                                                                class AvailableBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional lavailable
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 38
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth, self).__init__()

                                                                        self.yang_name = "available-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "available-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        38.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                        	The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "available-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('available_bandwidth', YLeaf(YType.str, 'available-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.available_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'available_bandwidth'], name, value)


                                                                class UtilizedBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional utilized
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 39
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth, self).__init__()

                                                                        self.yang_name = "utilized-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "utilized-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        39.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                        	The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "utilized-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('utilized_bandwidth', YLeaf(YType.str, 'utilized-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.utilized_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'utilized_bandwidth'], name, value)


                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class IsAliasId(Entity):
                                                """
                                                This container defines the IS\-Alias TLV which allows
                                                extension\-capable ISs to recognize the Originating System
                                                of an Extended LSP set. It identifies the Normal system\-
                                                id of the Originating System.
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of alias ID
                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId, self).__init__()

                                                    self.yang_name = "is-alias-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._children_yang_names.add("state")
                                                    self._segment_path = lambda: "is-alias-id"


                                                class State(Entity):
                                                    """
                                                    State parameters of alias ID.
                                                    
                                                    .. attribute:: alias_id
                                                    
                                                    	List of alias ID(s)
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "is-alias-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('alias_id', YLeaf(YType.str, 'alias-id')),
                                                        ])
                                                        self.alias_id = None
                                                        self._segment_path = lambda: "state"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State, ['alias_id'], name, value)


                                            class MtIsn(Entity):
                                                """
                                                This container defines list of ISIS multi\-topology
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                	MT\-IS neigbor attributes
                                                	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn, self).__init__()

                                                    self.yang_name = "mt-isn"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._children_yang_names.add("neighbors")
                                                    self._segment_path = lambda: "mt-isn"


                                                class Neighbors(Entity):
                                                    """
                                                    MT\-IS neigbor attributes.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                    	This container describes IS neighbors
                                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors, self).__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "mt-isn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors, [], name, value)


                                                    class Neighbor(Entity):
                                                        """
                                                        This container describes IS neighbors.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                        	       Reference to the topology that the neighbor is within
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4095
                                                        
                                                        	**refers to**\:  :py:class:`mt_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                        	Reference to the System ID of the neighbor
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of MT neighbor
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS Neighbor sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor, self).__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','system_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', YLeaf(YType.str, 'mt-id')),
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                            ])
                                                            self.mt_id = None
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "neighbor" + "[mt-id='" + str(self.mt_id) + "']" + "[system-id='" + str(self.system_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor, ['mt_id', 'system_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of MT neighbor.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Identifier of a topology being announced
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4095
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	System\-id of the IS neighbor
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', YLeaf(YType.uint16, 'mt-id')),
                                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.mt_id = None
                                                                self.system_id = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State, ['mt_id', 'system_id', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS Neighbor sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of IS neighbor state
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: admin_group
                                                                
                                                                	This container defines sub\-TLV 3
                                                                	**type**\:  :py:class:`AdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup>`
                                                                
                                                                .. attribute:: ipv4_interface_address
                                                                
                                                                	This container defines sub\-TLV 6
                                                                	**type**\:  :py:class:`Ipv4InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv4_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 8
                                                                	**type**\:  :py:class:`Ipv4NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                
                                                                .. attribute:: max_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 9
                                                                	**type**\:  :py:class:`MaxLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                
                                                                .. attribute:: max_reservable_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 10
                                                                	**type**\:  :py:class:`MaxReservableLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                
                                                                .. attribute:: unreserved_bandwidth
                                                                
                                                                	This container defines unreserved\-bandwidth. The units are bytes per second
                                                                	**type**\:  :py:class:`UnreservedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                
                                                                .. attribute:: ipv6_interface_address
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv6_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 13
                                                                	**type**\:  :py:class:`Ipv6NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                
                                                                .. attribute:: extended_admin_group
                                                                
                                                                	This container defines sub\-TLV 14
                                                                	**type**\:  :py:class:`ExtendedAdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                
                                                                .. attribute:: te_default_metric
                                                                
                                                                	This container defines sub\-TLV 18
                                                                	**type**\:  :py:class:`TeDefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                
                                                                .. attribute:: link_attributes
                                                                
                                                                	This container defines link\-attributes
                                                                	**type**\:  :py:class:`LinkAttributes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes>`
                                                                
                                                                .. attribute:: link_protection_type
                                                                
                                                                	ISIS LSDB parameters relating to the type of link protection offered
                                                                	**type**\:  :py:class:`LinkProtectionType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType>`
                                                                
                                                                .. attribute:: bandwidth_constraints
                                                                
                                                                	This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                	**type**\:  :py:class:`BandwidthConstraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                
                                                                .. attribute:: unconstrained_lsp
                                                                
                                                                	This container defines sub\-TLV 23
                                                                	**type**\:  :py:class:`UnconstrainedLsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                
                                                                .. attribute:: adjacency_sids
                                                                
                                                                	This container defines segment routing adjacency SIDs
                                                                	**type**\:  :py:class:`AdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids>`
                                                                
                                                                .. attribute:: lan_adjacency_sids
                                                                
                                                                	This container defines segment routing LAN adjacency SIDs
                                                                	**type**\:  :py:class:`LanAdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                
                                                                .. attribute:: link_delay
                                                                
                                                                	This container defines unidirectional link delay
                                                                	**type**\:  :py:class:`LinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay>`
                                                                
                                                                .. attribute:: min_max_link_delay
                                                                
                                                                	This container defines min/max link delay
                                                                	**type**\:  :py:class:`MinMaxLinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                
                                                                .. attribute:: link_delay_variation
                                                                
                                                                	This container defines unidirectional link delay variation
                                                                	**type**\:  :py:class:`LinkDelayVariation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                
                                                                .. attribute:: link_loss
                                                                
                                                                	This container defines unidirectional link loss delay
                                                                	**type**\:  :py:class:`LinkLoss <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss>`
                                                                
                                                                .. attribute:: residual_bandwidth
                                                                
                                                                	This container defines unidirectional residual bandwidth
                                                                	**type**\:  :py:class:`ResidualBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                
                                                                .. attribute:: available_bandwidth
                                                                
                                                                	This container defines unidirectional lavailable bandwidth
                                                                	**type**\:  :py:class:`AvailableBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                
                                                                .. attribute:: utilized_bandwidth
                                                                
                                                                	This container defines unidirectional utilized bandwidth
                                                                	**type**\:  :py:class:`UtilizedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup()
                                                                    self.admin_group.parent = self
                                                                    self._children_name_map["admin_group"] = "admin-group"
                                                                    self._children_yang_names.add("admin-group")

                                                                    self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                    self.ipv4_interface_address.parent = self
                                                                    self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"
                                                                    self._children_yang_names.add("ipv4-interface-address")

                                                                    self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                    self.ipv4_neighbor_address.parent = self
                                                                    self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"
                                                                    self._children_yang_names.add("ipv4-neighbor-address")

                                                                    self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                    self.max_link_bandwidth.parent = self
                                                                    self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"
                                                                    self._children_yang_names.add("max-link-bandwidth")

                                                                    self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                    self.max_reservable_link_bandwidth.parent = self
                                                                    self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"
                                                                    self._children_yang_names.add("max-reservable-link-bandwidth")

                                                                    self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                    self.unreserved_bandwidth.parent = self
                                                                    self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"
                                                                    self._children_yang_names.add("unreserved-bandwidth")

                                                                    self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                    self.ipv6_interface_address.parent = self
                                                                    self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"
                                                                    self._children_yang_names.add("ipv6-interface-address")

                                                                    self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                    self.ipv6_neighbor_address.parent = self
                                                                    self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"
                                                                    self._children_yang_names.add("ipv6-neighbor-address")

                                                                    self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                    self.extended_admin_group.parent = self
                                                                    self._children_name_map["extended_admin_group"] = "extended-admin-group"
                                                                    self._children_yang_names.add("extended-admin-group")

                                                                    self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric()
                                                                    self.te_default_metric.parent = self
                                                                    self._children_name_map["te_default_metric"] = "te-default-metric"
                                                                    self._children_yang_names.add("te-default-metric")

                                                                    self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes()
                                                                    self.link_attributes.parent = self
                                                                    self._children_name_map["link_attributes"] = "link-attributes"
                                                                    self._children_yang_names.add("link-attributes")

                                                                    self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType()
                                                                    self.link_protection_type.parent = self
                                                                    self._children_name_map["link_protection_type"] = "link-protection-type"
                                                                    self._children_yang_names.add("link-protection-type")

                                                                    self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints()
                                                                    self.bandwidth_constraints.parent = self
                                                                    self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"
                                                                    self._children_yang_names.add("bandwidth-constraints")

                                                                    self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                    self.unconstrained_lsp.parent = self
                                                                    self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"
                                                                    self._children_yang_names.add("unconstrained-lsp")

                                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids()
                                                                    self.adjacency_sids.parent = self
                                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                                    self._children_yang_names.add("adjacency-sids")

                                                                    self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids()
                                                                    self.lan_adjacency_sids.parent = self
                                                                    self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"
                                                                    self._children_yang_names.add("lan-adjacency-sids")

                                                                    self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay()
                                                                    self.link_delay.parent = self
                                                                    self._children_name_map["link_delay"] = "link-delay"
                                                                    self._children_yang_names.add("link-delay")

                                                                    self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                    self.min_max_link_delay.parent = self
                                                                    self._children_name_map["min_max_link_delay"] = "min-max-link-delay"
                                                                    self._children_yang_names.add("min-max-link-delay")

                                                                    self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation()
                                                                    self.link_delay_variation.parent = self
                                                                    self._children_name_map["link_delay_variation"] = "link-delay-variation"
                                                                    self._children_yang_names.add("link-delay-variation")

                                                                    self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss()
                                                                    self.link_loss.parent = self
                                                                    self._children_name_map["link_loss"] = "link-loss"
                                                                    self._children_yang_names.add("link-loss")

                                                                    self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth()
                                                                    self.residual_bandwidth.parent = self
                                                                    self._children_name_map["residual_bandwidth"] = "residual-bandwidth"
                                                                    self._children_yang_names.add("residual-bandwidth")

                                                                    self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth()
                                                                    self.available_bandwidth.parent = self
                                                                    self._children_name_map["available_bandwidth"] = "available-bandwidth"
                                                                    self._children_yang_names.add("available-bandwidth")

                                                                    self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                    self.utilized_bandwidth.parent = self
                                                                    self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                    self._children_yang_names.add("utilized-bandwidth")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of IS neighbor state
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class AdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 3.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 3
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup, self).__init__()

                                                                        self.yang_name = "admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 3.
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                        	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('admin_group', YLeafList(YType.uint32, 'admin-group')),
                                                                            ])
                                                                            self.admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)


                                                                class Ipv4InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 6.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 6
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv4-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 6.
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                        	A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_interface_address', YLeafList(YType.str, 'ipv4-interface-address')),
                                                                            ])
                                                                            self.ipv4_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['ipv4_interface_address'], name, value)


                                                                class Ipv4NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 8.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 8
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv4-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 8.
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                        	A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_neighbor_address', YLeafList(YType.str, 'ipv4-neighbor-address')),
                                                                            ])
                                                                            self.ipv4_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['ipv4_neighbor_address'], name, value)


                                                                class MaxLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 9.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 9
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 9.
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                        	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_link_bandwidth', YLeaf(YType.str, 'max-link-bandwidth')),
                                                                            ])
                                                                            self.max_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['max_link_bandwidth'], name, value)


                                                                class MaxReservableLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 10.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 10
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-reservable-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-reservable-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 10.
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                        	The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_reservable_link_bandwidth', YLeaf(YType.str, 'max-reservable-link-bandwidth')),
                                                                            ])
                                                                            self.max_reservable_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['max_reservable_link_bandwidth'], name, value)


                                                                class UnreservedBandwidth(Entity):
                                                                    """
                                                                    This container defines unreserved\-bandwidth. The units
                                                                    are bytes per second.
                                                                    
                                                                    .. attribute:: setup_priority
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\: list of  		 :py:class:`SetupPriority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, self).__init__()

                                                                        self.yang_name = "unreserved-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                        self._leafs = OrderedDict()

                                                                        self.setup_priority = YList(self)
                                                                        self._segment_path = lambda: "unreserved-bandwidth"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)


                                                                    class SetupPriority(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for unreserved
                                                                        bandwidth.
                                                                        
                                                                        .. attribute:: priority  (key)
                                                                        
                                                                        	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..7
                                                                        
                                                                        	**refers to**\:  :py:class:`priority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, self).__init__()

                                                                            self.yang_name = "setup-priority"
                                                                            self.yang_parent_name = "unreserved-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['priority']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('priority', YLeaf(YType.str, 'priority')),
                                                                            ])
                                                                            self.priority = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            11.
                                                                            
                                                                            .. attribute:: priority
                                                                            
                                                                            	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..7
                                                                            
                                                                            .. attribute:: unreserved_bandwidth
                                                                            
                                                                            	The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                            	**type**\: str
                                                                            
                                                                            	**length:** 32
                                                                            
                                                                            	**units**\: bytes per second
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "setup-priority"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', YLeaf(YType.uint8, 'priority')),
                                                                                    ('unreserved_bandwidth', YLeaf(YType.str, 'unreserved-bandwidth')),
                                                                                ])
                                                                                self.priority = None
                                                                                self.unreserved_bandwidth = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'unreserved_bandwidth'], name, value)


                                                                class Ipv6InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv6-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_interface_address', YLeafList(YType.str, 'ipv6-interface-address')),
                                                                            ])
                                                                            self.ipv6_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['ipv6_interface_address'], name, value)


                                                                class Ipv6NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 13.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 13
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv6-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 13.
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_neighbor_address', YLeafList(YType.str, 'ipv6-neighbor-address')),
                                                                            ])
                                                                            self.ipv6_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['ipv6_neighbor_address'], name, value)


                                                                class ExtendedAdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 14.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 14
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup, self).__init__()

                                                                        self.yang_name = "extended-admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "extended-admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 14.
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                        	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "extended-admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('extended_admin_group', YLeafList(YType.uint32, 'extended-admin-group')),
                                                                            ])
                                                                            self.extended_admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)


                                                                class TeDefaultMetric(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 18.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 18
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric, self).__init__()

                                                                        self.yang_name = "te-default-metric"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "te-default-metric"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 18.
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                        	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "te-default-metric"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('te_default_metric', YLeaf(YType.uint32, 'te-default-metric')),
                                                                            ])
                                                                            self.te_default_metric = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, ['te_default_metric'], name, value)


                                                                class LinkAttributes(Entity):
                                                                    """
                                                                    This container defines link\-attributes.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 19
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes, self).__init__()

                                                                        self.yang_name = "link-attributes"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-attributes"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        19.
                                                                        
                                                                        .. attribute:: local_protection
                                                                        
                                                                        	Link local\-protection attributes
                                                                        	**type**\: list of   :py:class:`LocalProtection <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-attributes"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('local_protection', YLeafList(YType.enumeration, 'local-protection')),
                                                                            ])
                                                                            self.local_protection = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                        class LocalProtection(Enum):
                                                                            """
                                                                            LocalProtection (Enum Class)

                                                                            Link local\-protection attributes.

                                                                            .. data:: LOCAL_PROTECTION = 0

                                                                            	If set, local protection is available for the

                                                                            	link.

                                                                            .. data:: LINK_EXCLUDED = 1

                                                                            	If set, the link is excluded from local

                                                                            	protection.

                                                                            """

                                                                            LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                            LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")



                                                                class LinkProtectionType(Entity):
                                                                    """
                                                                    ISIS LSDB parameters relating to the type of link
                                                                    protection offered.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 20
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType, self).__init__()

                                                                        self.yang_name = "link-protection-type"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-protection-type"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 20.
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                        	Link protection capabilities
                                                                        	**type**\: list of   :py:class:`LinkProtectionType_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State.LinkProtectionType_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-protection-type"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('link_protection_type', YLeafList(YType.enumeration, 'link-protection-type')),
                                                                            ])
                                                                            self.link_protection_type = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, ['link_protection_type'], name, value)

                                                                        class LinkProtectionType_(Enum):
                                                                            """
                                                                            LinkProtectionType\_ (Enum Class)

                                                                            Link protection capabilities.

                                                                            .. data:: EXTRA_TRAFFIC = 0

                                                                            	If set the link has extra traffic protection. If

                                                                            	the link is of type Extra Traffic, it means that

                                                                            	the link is protecting another link or links. The

                                                                            	LSPs on a link of this type will be lost if any of

                                                                            	the links it is protecting fail.

                                                                            .. data:: UNPROTECTED = 1

                                                                            	If set, the link is unprotected. If the link is

                                                                            	of type Unprotected, it means that there is no

                                                                            	other link protecting this link.  The LSPs on a

                                                                            	link of this type will be lost if the link

                                                                            	fails.

                                                                            .. data:: SHARED = 2

                                                                            	If set, the link has shared protection. If the

                                                                            	link is of type Shared, it means that there are

                                                                            	one or more disjoint links of type Extra Traffic

                                                                            	that are protecting this link.  These Extra

                                                                            	Traffic links are shared between one or more links

                                                                            	of type Shared.

                                                                            .. data:: ONE_ONE = 3

                                                                            	If set, the link has dedicated 1:1 protection. If

                                                                            	the link is of type Dedicated 1:1, it means that

                                                                            	there is one dedicated disjoint link of type Extra

                                                                            	Traffic that is protecting this link.

                                                                            .. data:: PLUS_ONE = 4

                                                                            	If set, the link has dedicated 1+1 protection. If

                                                                            	the link is of type Dedicated 1+1, it means that a

                                                                            	dedicated disjoint link is protecting this link.

                                                                            	However, the protecting link is not advertised in

                                                                            	the link state database and is therefore not

                                                                            	available for the routing of LSPs.

                                                                            .. data:: ENHANCED = 5

                                                                            	If set the link has enhanced protection.  If the

                                                                            	link is of type Enhanced, it means that a

                                                                            	protection scheme that is more reliable than

                                                                            	Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                            	being used to protect this link.

                                                                            """

                                                                            EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                            UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                            SHARED = Enum.YLeaf(2, "SHARED")

                                                                            ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                            PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                            ENHANCED = Enum.YLeaf(5, "ENHANCED")



                                                                class BandwidthConstraints(Entity):
                                                                    """
                                                                    This container defines bandwidth\-constraints. For DS\-TE,
                                                                    the existing Maximum Reservable link bandwidth parameter
                                                                    is retained, but its semantics is generalized and
                                                                    interpreted as the aggregate bandwidth constraint across
                                                                    all Class\-Types
                                                                    
                                                                    .. attribute:: bandwidth_constraint
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\: list of  		 :py:class:`BandwidthConstraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, self).__init__()

                                                                        self.yang_name = "bandwidth-constraints"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                        self._leafs = OrderedDict()

                                                                        self.bandwidth_constraint = YList(self)
                                                                        self._segment_path = lambda: "bandwidth-constraints"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)


                                                                    class BandwidthConstraint(Entity):
                                                                        """
                                                                        List of the Bandwidth Constraints sub\-TLV instances
                                                                        present in the TLV.
                                                                        
                                                                        .. attribute:: model_id  (key)
                                                                        
                                                                        	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        	**refers to**\:  :py:class:`model_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 22
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: constraints
                                                                        
                                                                        	Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                        	**type**\:  :py:class:`Constraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, self).__init__()

                                                                            self.yang_name = "bandwidth-constraint"
                                                                            self.yang_parent_name = "bandwidth-constraints"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['model_id']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('model_id', YLeaf(YType.str, 'model-id')),
                                                                            ])
                                                                            self.model_id = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")

                                                                            self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                            self.constraints.parent = self
                                                                            self._children_name_map["constraints"] = "constraints"
                                                                            self._children_yang_names.add("constraints")
                                                                            self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            22.
                                                                            
                                                                            .. attribute:: model_id
                                                                            
                                                                            	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', YLeaf(YType.uint8, 'model-id')),
                                                                                ])
                                                                                self.model_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                        class Constraints(Entity):
                                                                            """
                                                                            Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                            
                                                                            .. attribute:: constraint
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                            	**type**\: list of  		 :py:class:`Constraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, self).__init__()

                                                                                self.yang_name = "constraints"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.constraint = YList(self)
                                                                                self._segment_path = lambda: "constraints"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)


                                                                            class Constraint(Entity):
                                                                                """
                                                                                List of the constraints within the Bandwidth Constraints
                                                                                sub\-TLV. The BC0 level is indicated by the constraint\-id
                                                                                leaf being set to 0, with BCN being indicated by constraint\-id
                                                                                N.
                                                                                
                                                                                .. attribute:: constraint_id  (key)
                                                                                
                                                                                	Reference to the unique ID for the BCN level
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                	**refers to**\:  :py:class:`constraint_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                	Operational state parameters of the BCN level
                                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, self).__init__()

                                                                                    self.yang_name = "constraint"
                                                                                    self.yang_parent_name = "constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['constraint_id']
                                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                    self._child_list_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('constraint_id', YLeaf(YType.str, 'constraint-id')),
                                                                                    ])
                                                                                    self.constraint_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._children_yang_names.add("state")
                                                                                    self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)


                                                                                class State(Entity):
                                                                                    """
                                                                                    Operational state parameters of the BCN level
                                                                                    
                                                                                    .. attribute:: constraint_id
                                                                                    
                                                                                    	Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                    	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                    	**type**\: str
                                                                                    
                                                                                    	**length:** 32
                                                                                    
                                                                                    	**units**\: bytes per second
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, self).__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_container_classes = OrderedDict([])
                                                                                        self._child_list_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', YLeaf(YType.uint32, 'constraint-id')),
                                                                                            ('bandwidth', YLeaf(YType.str, 'bandwidth')),
                                                                                        ])
                                                                                        self.constraint_id = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)


                                                                class UnconstrainedLsp(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 23.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 23
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp, self).__init__()

                                                                        self.yang_name = "unconstrained-lsp"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "unconstrained-lsp"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 23.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                        	Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..65535
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "unconstrained-lsp"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('unconstrained_lsp', YLeaf(YType.uint16, 'unconstrained-lsp')),
                                                                            ])
                                                                            self.type = None
                                                                            self.unconstrained_lsp = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'unconstrained_lsp'], name, value)


                                                                class AdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing adjacency SIDs.
                                                                    
                                                                    .. attribute:: adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, self).__init__()

                                                                        self.yang_name = "adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, [], name, value)


                                                                    class AdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, self).__init__()

                                                                            self.yang_name = "adjacency-sid"
                                                                            self.yang_parent_name = "adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LanAdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing LAN adjacency
                                                                    SIDs
                                                                    
                                                                    .. attribute:: lan_adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`LanAdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, self).__init__()

                                                                        self.yang_name = "lan-adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.lan_adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "lan-adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)


                                                                    class LanAdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the LAN Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of LAN Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, self).__init__()

                                                                            self.yang_name = "lan-adjacency-sid"
                                                                            self.yang_parent_name = "lan-adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of LAN Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	LAN Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with LAN\-Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: neighbor_id
                                                                            
                                                                            	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                            	**type**\: str
                                                                            
                                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "lan-adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                    ('neighbor_id', YLeaf(YType.str, 'neighbor-id')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self.neighbor_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with LAN\-Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LinkDelay(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 33
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay, self).__init__()

                                                                        self.yang_name = "link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        33.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)


                                                                class MinMaxLinkDelay(Entity):
                                                                    """
                                                                    This container defines min/max link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 34
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay, self).__init__()

                                                                        self.yang_name = "min-max-link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "min-max-link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        34.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: min_delay
                                                                        
                                                                        	Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        .. attribute:: max_delay
                                                                        
                                                                        	Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "min-max-link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('min_delay', YLeaf(YType.uint32, 'min-delay')),
                                                                                ('max_delay', YLeaf(YType.uint32, 'max-delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.min_delay = None
                                                                            self.max_delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)


                                                                class LinkDelayVariation(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay
                                                                    variation.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 35
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation, self).__init__()

                                                                        self.yang_name = "link-delay-variation"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay-variation"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        35.
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay-variation"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)


                                                                class LinkLoss(Entity):
                                                                    """
                                                                    This container defines unidirectional link loss delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 36
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss, self).__init__()

                                                                        self.yang_name = "link-loss"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-loss"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        36.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                        	Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-loss"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('link_loss', YLeaf(YType.uint32, 'link-loss')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.link_loss = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)


                                                                class ResidualBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional residual
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 37
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth, self).__init__()

                                                                        self.yang_name = "residual-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "residual-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        37.
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                        	Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "residual-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('residual_bandwidth', YLeaf(YType.str, 'residual-bandwidth')),
                                                                            ])
                                                                            self.residual_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, ['residual_bandwidth'], name, value)


                                                                class AvailableBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional lavailable
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 38
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth, self).__init__()

                                                                        self.yang_name = "available-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "available-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        38.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                        	The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "available-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('available_bandwidth', YLeaf(YType.str, 'available-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.available_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'available_bandwidth'], name, value)


                                                                class UtilizedBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional utilized
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 39
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth, self).__init__()

                                                                        self.yang_name = "utilized-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "utilized-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        39.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                        	The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "utilized-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('utilized_bandwidth', YLeaf(YType.str, 'utilized-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.utilized_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'utilized_bandwidth'], name, value)


                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class MtIsisNeighborAttribute(Entity):
                                                """
                                                This container defines list of ISIS multi\-topology
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                	This container describes IS neighbors
                                                	**type**\:  :py:class:`Neighbors <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute, self).__init__()

                                                    self.yang_name = "mt-isis-neighbor-attribute"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._children_yang_names.add("neighbors")
                                                    self._segment_path = lambda: "mt-isis-neighbor-attribute"


                                                class Neighbors(Entity):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                    	List of multi\-topology neighbors
                                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors, self).__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "mt-isis-neighbor-attribute"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors, [], name, value)


                                                    class Neighbor(Entity):
                                                        """
                                                        List of multi\-topology neighbors.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                        	Reference to the topology that the neighbor is within
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4095
                                                        
                                                        	**refers to**\:  :py:class:`mt_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                        	Reference to the system ID of the neighbor
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                        	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of MT neighbor
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS Neighbor sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor, self).__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','system_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', YLeaf(YType.str, 'mt-id')),
                                                                ('system_id', YLeaf(YType.str, 'system-id')),
                                                            ])
                                                            self.mt_id = None
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "neighbor" + "[mt-id='" + str(self.mt_id) + "']" + "[system-id='" + str(self.system_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor, ['mt_id', 'system_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of MT neighbor.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Identifier of a topology being announced
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4095
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	System\-id of the IS neighbor
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', YLeaf(YType.uint16, 'mt-id')),
                                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                ])
                                                                self.mt_id = None
                                                                self.system_id = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State, ['mt_id', 'system_id', 'metric'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS Neighbor sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of IS neighbor state
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: admin_group
                                                                
                                                                	This container defines sub\-TLV 3
                                                                	**type**\:  :py:class:`AdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup>`
                                                                
                                                                .. attribute:: ipv4_interface_address
                                                                
                                                                	This container defines sub\-TLV 6
                                                                	**type**\:  :py:class:`Ipv4InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv4_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 8
                                                                	**type**\:  :py:class:`Ipv4NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                
                                                                .. attribute:: max_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 9
                                                                	**type**\:  :py:class:`MaxLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                
                                                                .. attribute:: max_reservable_link_bandwidth
                                                                
                                                                	This container defines sub\-TLV 10
                                                                	**type**\:  :py:class:`MaxReservableLinkBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                
                                                                .. attribute:: unreserved_bandwidth
                                                                
                                                                	This container defines unreserved\-bandwidth. The units are bytes per second
                                                                	**type**\:  :py:class:`UnreservedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                
                                                                .. attribute:: ipv6_interface_address
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6InterfaceAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                
                                                                .. attribute:: ipv6_neighbor_address
                                                                
                                                                	This container defines sub\-TLV 13
                                                                	**type**\:  :py:class:`Ipv6NeighborAddress <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                
                                                                .. attribute:: extended_admin_group
                                                                
                                                                	This container defines sub\-TLV 14
                                                                	**type**\:  :py:class:`ExtendedAdminGroup <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                
                                                                .. attribute:: te_default_metric
                                                                
                                                                	This container defines sub\-TLV 18
                                                                	**type**\:  :py:class:`TeDefaultMetric <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                
                                                                .. attribute:: link_attributes
                                                                
                                                                	This container defines link\-attributes
                                                                	**type**\:  :py:class:`LinkAttributes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes>`
                                                                
                                                                .. attribute:: link_protection_type
                                                                
                                                                	ISIS LSDB parameters relating to the type of link protection offered
                                                                	**type**\:  :py:class:`LinkProtectionType <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType>`
                                                                
                                                                .. attribute:: bandwidth_constraints
                                                                
                                                                	This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                	**type**\:  :py:class:`BandwidthConstraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                
                                                                .. attribute:: unconstrained_lsp
                                                                
                                                                	This container defines sub\-TLV 23
                                                                	**type**\:  :py:class:`UnconstrainedLsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                
                                                                .. attribute:: adjacency_sids
                                                                
                                                                	This container defines segment routing adjacency SIDs
                                                                	**type**\:  :py:class:`AdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids>`
                                                                
                                                                .. attribute:: lan_adjacency_sids
                                                                
                                                                	This container defines segment routing LAN adjacency SIDs
                                                                	**type**\:  :py:class:`LanAdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                
                                                                .. attribute:: link_delay
                                                                
                                                                	This container defines unidirectional link delay
                                                                	**type**\:  :py:class:`LinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay>`
                                                                
                                                                .. attribute:: min_max_link_delay
                                                                
                                                                	This container defines min/max link delay
                                                                	**type**\:  :py:class:`MinMaxLinkDelay <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                
                                                                .. attribute:: link_delay_variation
                                                                
                                                                	This container defines unidirectional link delay variation
                                                                	**type**\:  :py:class:`LinkDelayVariation <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                
                                                                .. attribute:: link_loss
                                                                
                                                                	This container defines unidirectional link loss delay
                                                                	**type**\:  :py:class:`LinkLoss <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss>`
                                                                
                                                                .. attribute:: residual_bandwidth
                                                                
                                                                	This container defines unidirectional residual bandwidth
                                                                	**type**\:  :py:class:`ResidualBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                
                                                                .. attribute:: available_bandwidth
                                                                
                                                                	This container defines unidirectional lavailable bandwidth
                                                                	**type**\:  :py:class:`AvailableBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                
                                                                .. attribute:: utilized_bandwidth
                                                                
                                                                	This container defines unidirectional utilized bandwidth
                                                                	**type**\:  :py:class:`UtilizedBandwidth <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup()
                                                                    self.admin_group.parent = self
                                                                    self._children_name_map["admin_group"] = "admin-group"
                                                                    self._children_yang_names.add("admin-group")

                                                                    self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                    self.ipv4_interface_address.parent = self
                                                                    self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"
                                                                    self._children_yang_names.add("ipv4-interface-address")

                                                                    self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                    self.ipv4_neighbor_address.parent = self
                                                                    self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"
                                                                    self._children_yang_names.add("ipv4-neighbor-address")

                                                                    self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                    self.max_link_bandwidth.parent = self
                                                                    self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"
                                                                    self._children_yang_names.add("max-link-bandwidth")

                                                                    self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                    self.max_reservable_link_bandwidth.parent = self
                                                                    self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"
                                                                    self._children_yang_names.add("max-reservable-link-bandwidth")

                                                                    self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                    self.unreserved_bandwidth.parent = self
                                                                    self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"
                                                                    self._children_yang_names.add("unreserved-bandwidth")

                                                                    self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                    self.ipv6_interface_address.parent = self
                                                                    self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"
                                                                    self._children_yang_names.add("ipv6-interface-address")

                                                                    self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                    self.ipv6_neighbor_address.parent = self
                                                                    self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"
                                                                    self._children_yang_names.add("ipv6-neighbor-address")

                                                                    self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                    self.extended_admin_group.parent = self
                                                                    self._children_name_map["extended_admin_group"] = "extended-admin-group"
                                                                    self._children_yang_names.add("extended-admin-group")

                                                                    self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric()
                                                                    self.te_default_metric.parent = self
                                                                    self._children_name_map["te_default_metric"] = "te-default-metric"
                                                                    self._children_yang_names.add("te-default-metric")

                                                                    self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes()
                                                                    self.link_attributes.parent = self
                                                                    self._children_name_map["link_attributes"] = "link-attributes"
                                                                    self._children_yang_names.add("link-attributes")

                                                                    self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType()
                                                                    self.link_protection_type.parent = self
                                                                    self._children_name_map["link_protection_type"] = "link-protection-type"
                                                                    self._children_yang_names.add("link-protection-type")

                                                                    self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints()
                                                                    self.bandwidth_constraints.parent = self
                                                                    self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"
                                                                    self._children_yang_names.add("bandwidth-constraints")

                                                                    self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                    self.unconstrained_lsp.parent = self
                                                                    self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"
                                                                    self._children_yang_names.add("unconstrained-lsp")

                                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids()
                                                                    self.adjacency_sids.parent = self
                                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                                    self._children_yang_names.add("adjacency-sids")

                                                                    self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids()
                                                                    self.lan_adjacency_sids.parent = self
                                                                    self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"
                                                                    self._children_yang_names.add("lan-adjacency-sids")

                                                                    self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay()
                                                                    self.link_delay.parent = self
                                                                    self._children_name_map["link_delay"] = "link-delay"
                                                                    self._children_yang_names.add("link-delay")

                                                                    self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                    self.min_max_link_delay.parent = self
                                                                    self._children_name_map["min_max_link_delay"] = "min-max-link-delay"
                                                                    self._children_yang_names.add("min-max-link-delay")

                                                                    self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation()
                                                                    self.link_delay_variation.parent = self
                                                                    self._children_name_map["link_delay_variation"] = "link-delay-variation"
                                                                    self._children_yang_names.add("link-delay-variation")

                                                                    self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss()
                                                                    self.link_loss.parent = self
                                                                    self._children_name_map["link_loss"] = "link-loss"
                                                                    self._children_yang_names.add("link-loss")

                                                                    self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth()
                                                                    self.residual_bandwidth.parent = self
                                                                    self._children_name_map["residual_bandwidth"] = "residual-bandwidth"
                                                                    self._children_yang_names.add("residual-bandwidth")

                                                                    self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth()
                                                                    self.available_bandwidth.parent = self
                                                                    self._children_name_map["available_bandwidth"] = "available-bandwidth"
                                                                    self._children_yang_names.add("available-bandwidth")

                                                                    self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                    self.utilized_bandwidth.parent = self
                                                                    self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                    self._children_yang_names.add("utilized-bandwidth")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of IS neighbor state
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class AdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 3.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 3
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup, self).__init__()

                                                                        self.yang_name = "admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 3.
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                        	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('admin_group', YLeafList(YType.uint32, 'admin-group')),
                                                                            ])
                                                                            self.admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)


                                                                class Ipv4InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 6.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 6
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv4-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 6.
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                        	A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_interface_address', YLeafList(YType.str, 'ipv4-interface-address')),
                                                                            ])
                                                                            self.ipv4_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['ipv4_interface_address'], name, value)


                                                                class Ipv4NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 8.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 8
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv4-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 8.
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                        	A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv4_neighbor_address', YLeafList(YType.str, 'ipv4-neighbor-address')),
                                                                            ])
                                                                            self.ipv4_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['ipv4_neighbor_address'], name, value)


                                                                class MaxLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 9.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 9
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 9.
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                        	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_link_bandwidth', YLeaf(YType.str, 'max-link-bandwidth')),
                                                                            ])
                                                                            self.max_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['max_link_bandwidth'], name, value)


                                                                class MaxReservableLinkBandwidth(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 10.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 10
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth, self).__init__()

                                                                        self.yang_name = "max-reservable-link-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "max-reservable-link-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 10.
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                        	The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('max_reservable_link_bandwidth', YLeaf(YType.str, 'max-reservable-link-bandwidth')),
                                                                            ])
                                                                            self.max_reservable_link_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['max_reservable_link_bandwidth'], name, value)


                                                                class UnreservedBandwidth(Entity):
                                                                    """
                                                                    This container defines unreserved\-bandwidth. The units
                                                                    are bytes per second.
                                                                    
                                                                    .. attribute:: setup_priority
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\: list of  		 :py:class:`SetupPriority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, self).__init__()

                                                                        self.yang_name = "unreserved-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                        self._leafs = OrderedDict()

                                                                        self.setup_priority = YList(self)
                                                                        self._segment_path = lambda: "unreserved-bandwidth"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)


                                                                    class SetupPriority(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for unreserved
                                                                        bandwidth.
                                                                        
                                                                        .. attribute:: priority  (key)
                                                                        
                                                                        	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..7
                                                                        
                                                                        	**refers to**\:  :py:class:`priority <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, self).__init__()

                                                                            self.yang_name = "setup-priority"
                                                                            self.yang_parent_name = "unreserved-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['priority']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('priority', YLeaf(YType.str, 'priority')),
                                                                            ])
                                                                            self.priority = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            11.
                                                                            
                                                                            .. attribute:: priority
                                                                            
                                                                            	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..7
                                                                            
                                                                            .. attribute:: unreserved_bandwidth
                                                                            
                                                                            	The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                            	**type**\: str
                                                                            
                                                                            	**length:** 32
                                                                            
                                                                            	**units**\: bytes per second
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "setup-priority"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', YLeaf(YType.uint8, 'priority')),
                                                                                    ('unreserved_bandwidth', YLeaf(YType.str, 'unreserved-bandwidth')),
                                                                                ])
                                                                                self.priority = None
                                                                                self.unreserved_bandwidth = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'unreserved_bandwidth'], name, value)


                                                                class Ipv6InterfaceAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress, self).__init__()

                                                                        self.yang_name = "ipv6-interface-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-interface-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-interface-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_interface_address', YLeafList(YType.str, 'ipv6-interface-address')),
                                                                            ])
                                                                            self.ipv6_interface_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['ipv6_interface_address'], name, value)


                                                                class Ipv6NeighborAddress(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 13.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 13
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress, self).__init__()

                                                                        self.yang_name = "ipv6-neighbor-address"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-neighbor-address"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 13.
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                        	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                        	**type**\: list of str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-neighbor-address"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('ipv6_neighbor_address', YLeafList(YType.str, 'ipv6-neighbor-address')),
                                                                            ])
                                                                            self.ipv6_neighbor_address = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['ipv6_neighbor_address'], name, value)


                                                                class ExtendedAdminGroup(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 14.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 14
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup, self).__init__()

                                                                        self.yang_name = "extended-admin-group"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "extended-admin-group"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 14.
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                        	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "extended-admin-group"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('extended_admin_group', YLeafList(YType.uint32, 'extended-admin-group')),
                                                                            ])
                                                                            self.extended_admin_group = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)


                                                                class TeDefaultMetric(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 18.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 18
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric, self).__init__()

                                                                        self.yang_name = "te-default-metric"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "te-default-metric"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 18.
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                        	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "te-default-metric"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('te_default_metric', YLeaf(YType.uint32, 'te-default-metric')),
                                                                            ])
                                                                            self.te_default_metric = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.TeDefaultMetric.State, ['te_default_metric'], name, value)


                                                                class LinkAttributes(Entity):
                                                                    """
                                                                    This container defines link\-attributes.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 19
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes, self).__init__()

                                                                        self.yang_name = "link-attributes"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-attributes"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        19.
                                                                        
                                                                        .. attribute:: local_protection
                                                                        
                                                                        	Link local\-protection attributes
                                                                        	**type**\: list of   :py:class:`LocalProtection <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-attributes"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('local_protection', YLeafList(YType.enumeration, 'local-protection')),
                                                                            ])
                                                                            self.local_protection = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                        class LocalProtection(Enum):
                                                                            """
                                                                            LocalProtection (Enum Class)

                                                                            Link local\-protection attributes.

                                                                            .. data:: LOCAL_PROTECTION = 0

                                                                            	If set, local protection is available for the

                                                                            	link.

                                                                            .. data:: LINK_EXCLUDED = 1

                                                                            	If set, the link is excluded from local

                                                                            	protection.

                                                                            """

                                                                            LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                            LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")



                                                                class LinkProtectionType(Entity):
                                                                    """
                                                                    ISIS LSDB parameters relating to the type of link
                                                                    protection offered.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 20
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType, self).__init__()

                                                                        self.yang_name = "link-protection-type"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-protection-type"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 20.
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                        	Link protection capabilities
                                                                        	**type**\: list of   :py:class:`LinkProtectionType_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State.LinkProtectionType_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-protection-type"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('link_protection_type', YLeafList(YType.enumeration, 'link-protection-type')),
                                                                            ])
                                                                            self.link_protection_type = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkProtectionType.State, ['link_protection_type'], name, value)

                                                                        class LinkProtectionType_(Enum):
                                                                            """
                                                                            LinkProtectionType\_ (Enum Class)

                                                                            Link protection capabilities.

                                                                            .. data:: EXTRA_TRAFFIC = 0

                                                                            	If set the link has extra traffic protection. If

                                                                            	the link is of type Extra Traffic, it means that

                                                                            	the link is protecting another link or links. The

                                                                            	LSPs on a link of this type will be lost if any of

                                                                            	the links it is protecting fail.

                                                                            .. data:: UNPROTECTED = 1

                                                                            	If set, the link is unprotected. If the link is

                                                                            	of type Unprotected, it means that there is no

                                                                            	other link protecting this link.  The LSPs on a

                                                                            	link of this type will be lost if the link

                                                                            	fails.

                                                                            .. data:: SHARED = 2

                                                                            	If set, the link has shared protection. If the

                                                                            	link is of type Shared, it means that there are

                                                                            	one or more disjoint links of type Extra Traffic

                                                                            	that are protecting this link.  These Extra

                                                                            	Traffic links are shared between one or more links

                                                                            	of type Shared.

                                                                            .. data:: ONE_ONE = 3

                                                                            	If set, the link has dedicated 1:1 protection. If

                                                                            	the link is of type Dedicated 1:1, it means that

                                                                            	there is one dedicated disjoint link of type Extra

                                                                            	Traffic that is protecting this link.

                                                                            .. data:: PLUS_ONE = 4

                                                                            	If set, the link has dedicated 1+1 protection. If

                                                                            	the link is of type Dedicated 1+1, it means that a

                                                                            	dedicated disjoint link is protecting this link.

                                                                            	However, the protecting link is not advertised in

                                                                            	the link state database and is therefore not

                                                                            	available for the routing of LSPs.

                                                                            .. data:: ENHANCED = 5

                                                                            	If set the link has enhanced protection.  If the

                                                                            	link is of type Enhanced, it means that a

                                                                            	protection scheme that is more reliable than

                                                                            	Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                            	being used to protect this link.

                                                                            """

                                                                            EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                            UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                            SHARED = Enum.YLeaf(2, "SHARED")

                                                                            ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                            PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                            ENHANCED = Enum.YLeaf(5, "ENHANCED")



                                                                class BandwidthConstraints(Entity):
                                                                    """
                                                                    This container defines bandwidth\-constraints. For DS\-TE,
                                                                    the existing Maximum Reservable link bandwidth parameter
                                                                    is retained, but its semantics is generalized and
                                                                    interpreted as the aggregate bandwidth constraint across
                                                                    all Class\-Types
                                                                    
                                                                    .. attribute:: bandwidth_constraint
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\: list of  		 :py:class:`BandwidthConstraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, self).__init__()

                                                                        self.yang_name = "bandwidth-constraints"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                        self._leafs = OrderedDict()

                                                                        self.bandwidth_constraint = YList(self)
                                                                        self._segment_path = lambda: "bandwidth-constraints"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)


                                                                    class BandwidthConstraint(Entity):
                                                                        """
                                                                        List of the Bandwidth Constraints sub\-TLV instances
                                                                        present in the TLV.
                                                                        
                                                                        .. attribute:: model_id  (key)
                                                                        
                                                                        	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        	**refers to**\:  :py:class:`model_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of IS Extended Reachability sub\-TLV 22
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                        
                                                                        .. attribute:: constraints
                                                                        
                                                                        	Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                        	**type**\:  :py:class:`Constraints <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, self).__init__()

                                                                            self.yang_name = "bandwidth-constraint"
                                                                            self.yang_parent_name = "bandwidth-constraints"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['model_id']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('model_id', YLeaf(YType.str, 'model-id')),
                                                                            ])
                                                                            self.model_id = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")

                                                                            self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                            self.constraints.parent = self
                                                                            self._children_name_map["constraints"] = "constraints"
                                                                            self._children_yang_names.add("constraints")
                                                                            self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of IS Extended Reachability sub\-TLV
                                                                            22.
                                                                            
                                                                            .. attribute:: model_id
                                                                            
                                                                            	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', YLeaf(YType.uint8, 'model-id')),
                                                                                ])
                                                                                self.model_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                        class Constraints(Entity):
                                                                            """
                                                                            Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                            
                                                                            .. attribute:: constraint
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                            	**type**\: list of  		 :py:class:`Constraint <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, self).__init__()

                                                                                self.yang_name = "constraints"
                                                                                self.yang_parent_name = "bandwidth-constraint"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.constraint = YList(self)
                                                                                self._segment_path = lambda: "constraints"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)


                                                                            class Constraint(Entity):
                                                                                """
                                                                                List of the constraints within the Bandwidth Constraints
                                                                                sub\-TLV. The BC0 level is indicated by the constraint\-id
                                                                                leaf being set to 0, with BCN being indicated by constraint\-id
                                                                                N.
                                                                                
                                                                                .. attribute:: constraint_id  (key)
                                                                                
                                                                                	Reference to the unique ID for the BCN level
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                	**refers to**\:  :py:class:`constraint_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                	Operational state parameters of the BCN level
                                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, self).__init__()

                                                                                    self.yang_name = "constraint"
                                                                                    self.yang_parent_name = "constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['constraint_id']
                                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                    self._child_list_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('constraint_id', YLeaf(YType.str, 'constraint-id')),
                                                                                    ])
                                                                                    self.constraint_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._children_yang_names.add("state")
                                                                                    self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)


                                                                                class State(Entity):
                                                                                    """
                                                                                    Operational state parameters of the BCN level
                                                                                    
                                                                                    .. attribute:: constraint_id
                                                                                    
                                                                                    	Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                    	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                    	**type**\: str
                                                                                    
                                                                                    	**length:** 32
                                                                                    
                                                                                    	**units**\: bytes per second
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, self).__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_container_classes = OrderedDict([])
                                                                                        self._child_list_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', YLeaf(YType.uint32, 'constraint-id')),
                                                                                            ('bandwidth', YLeaf(YType.str, 'bandwidth')),
                                                                                        ])
                                                                                        self.constraint_id = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)


                                                                class UnconstrainedLsp(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 23.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 23
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp, self).__init__()

                                                                        self.yang_name = "unconstrained-lsp"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "unconstrained-lsp"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 23.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                        	Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..65535
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "unconstrained-lsp"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('unconstrained_lsp', YLeaf(YType.uint16, 'unconstrained-lsp')),
                                                                            ])
                                                                            self.type = None
                                                                            self.unconstrained_lsp = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'unconstrained_lsp'], name, value)


                                                                class AdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing adjacency SIDs.
                                                                    
                                                                    .. attribute:: adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, self).__init__()

                                                                        self.yang_name = "adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids, [], name, value)


                                                                    class AdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, self).__init__()

                                                                            self.yang_name = "adjacency-sid"
                                                                            self.yang_parent_name = "adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LanAdjacencySids(Entity):
                                                                    """
                                                                    This container defines segment routing LAN adjacency
                                                                    SIDs
                                                                    
                                                                    .. attribute:: lan_adjacency_sid
                                                                    
                                                                    	Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                    	**type**\: list of  		 :py:class:`LanAdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, self).__init__()

                                                                        self.yang_name = "lan-adjacency-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.lan_adjacency_sid = YList(self)
                                                                        self._segment_path = lambda: "lan-adjacency-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)


                                                                    class LanAdjacencySid(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                        an IGP segment attached to a unidirectional adjacency or
                                                                        a set of unidirectional adjacencies. By default, an IGP\-
                                                                        Adjacency Segment is local to the node which advertises
                                                                        it.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the LAN Adjacency\-SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of LAN Adjacency\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, self).__init__()

                                                                            self.yang_name = "lan-adjacency-sid"
                                                                            self.yang_parent_name = "lan-adjacency-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of LAN Adjacency\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	LAN Adjacency\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with LAN\-Adj\-Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                            
                                                                            .. attribute:: weight
                                                                            
                                                                            	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: neighbor_id
                                                                            
                                                                            	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                            	**type**\: str
                                                                            
                                                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "lan-adjacency-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('weight', YLeaf(YType.uint8, 'weight')),
                                                                                    ('neighbor_id', YLeaf(YType.str, 'neighbor-id')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.weight = None
                                                                                self.neighbor_id = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with LAN\-Adj\-Segment\-ID.

                                                                                .. data:: ADDRESS_FAMILY = 0

                                                                                	Address-family flag. When unset, the Adj-SID

                                                                                	refers to an adjacency with outgoing IPv4

                                                                                	encapsulation. If set then the Adj-SID refers to

                                                                                	an adjacency with outgoing IPv6 encapsulation.

                                                                                .. data:: BACKUP = 1

                                                                                	Backup flag. When set, the Adj-SID refers to an

                                                                                	adjacency being protected (e.g.: using IPFRR or

                                                                                	MPLS-FRR).

                                                                                .. data:: VALUE = 2

                                                                                	Value flag. When set, the SID carries a value

                                                                                	(instead of an index). By default the flag is

                                                                                	SET.

                                                                                .. data:: LOCAL = 3

                                                                                	Local flag. When set, the value/index carried

                                                                                	by the SID has local significance. By default

                                                                                	the flag is SET.

                                                                                .. data:: SET = 4

                                                                                	Set flag. When set, the S-Flag indicates that

                                                                                	the Adj-SID refers to a set of adjacencies.

                                                                                """

                                                                                ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                VALUE = Enum.YLeaf(2, "VALUE")

                                                                                LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                SET = Enum.YLeaf(4, "SET")



                                                                class LinkDelay(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 33
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay, self).__init__()

                                                                        self.yang_name = "link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        33.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)


                                                                class MinMaxLinkDelay(Entity):
                                                                    """
                                                                    This container defines min/max link delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 34
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay, self).__init__()

                                                                        self.yang_name = "min-max-link-delay"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "min-max-link-delay"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        34.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: min_delay
                                                                        
                                                                        	Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        .. attribute:: max_delay
                                                                        
                                                                        	Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "min-max-link-delay"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('min_delay', YLeaf(YType.uint32, 'min-delay')),
                                                                                ('max_delay', YLeaf(YType.uint32, 'max-delay')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.min_delay = None
                                                                            self.max_delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)


                                                                class LinkDelayVariation(Entity):
                                                                    """
                                                                    This container defines unidirectional link delay
                                                                    variation.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 35
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation, self).__init__()

                                                                        self.yang_name = "link-delay-variation"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-delay-variation"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        35.
                                                                        
                                                                        .. attribute:: delay
                                                                        
                                                                        	Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**units**\: microseconds
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-delay-variation"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('delay', YLeaf(YType.uint32, 'delay')),
                                                                            ])
                                                                            self.delay = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)


                                                                class LinkLoss(Entity):
                                                                    """
                                                                    This container defines unidirectional link loss delay.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 36
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss, self).__init__()

                                                                        self.yang_name = "link-loss"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "link-loss"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        36.
                                                                        
                                                                        .. attribute:: a_bit
                                                                        
                                                                        	The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                        	**type**\: bool
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                        	Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "link-loss"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('a_bit', YLeaf(YType.boolean, 'a-bit')),
                                                                                ('link_loss', YLeaf(YType.uint32, 'link-loss')),
                                                                            ])
                                                                            self.a_bit = None
                                                                            self.link_loss = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)


                                                                class ResidualBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional residual
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 37
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth, self).__init__()

                                                                        self.yang_name = "residual-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "residual-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        37.
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                        	Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "residual-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('residual_bandwidth', YLeaf(YType.str, 'residual-bandwidth')),
                                                                            ])
                                                                            self.residual_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.ResidualBandwidth.State, ['residual_bandwidth'], name, value)


                                                                class AvailableBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional lavailable
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 38
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth, self).__init__()

                                                                        self.yang_name = "available-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "available-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        38.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                        	The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "available-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('available_bandwidth', YLeaf(YType.str, 'available-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.available_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'available_bandwidth'], name, value)


                                                                class UtilizedBandwidth(Entity):
                                                                    """
                                                                    This container defines unidirectional utilized
                                                                    bandwidth.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS Extended Reachability sub\-TLV 39
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth, self).__init__()

                                                                        self.yang_name = "utilized-bandwidth"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "utilized-bandwidth"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS Extended Reachability sub\-TLV
                                                                        39.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                        	The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                        	**type**\: str
                                                                        
                                                                        	**length:** 32
                                                                        
                                                                        	**units**\: bytes per second
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "utilized-bandwidth"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('utilized_bandwidth', YLeaf(YType.str, 'utilized-bandwidth')),
                                                                            ])
                                                                            self.type = None
                                                                            self.utilized_bandwidth = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'utilized_bandwidth'], name, value)


                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class MtIpv4Reachability(Entity):
                                                """
                                                This container defines list of IPv4 reachability
                                                Information in multi\-topology environment.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS prefixes
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability, self).__init__()

                                                    self.yang_name = "mt-ipv4-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "mt-ipv4-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	IPv4 prefixes that are contained within MT reachability TLV
                                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "mt-ipv4-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes, [], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        IPv4 prefixes that are contained within MT
                                                        reachability TLV.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                        	Reference to the topology ID of the topology that the prefix is within
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4095
                                                        
                                                        	**refers to**\:  :py:class:`mt_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the prefix to which reachability is being advertised
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of an IPv4 extended prefix
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS prefix sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','prefix']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', YLeaf(YType.str, 'mt-id')),
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.mt_id = None
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "prefix" + "[mt-id='" + str(self.mt_id) + "']" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix, ['mt_id', 'prefix'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of an IPv4 extended prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                            	The Sub\-TLV present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv4 prefix contained within extended reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Multi\-topology ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4095
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('s_bit', YLeaf(YType.boolean, 's-bit')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                    ('mt_id', YLeaf(YType.uint16, 'mt-id')),
                                                                ])
                                                                self.up_down = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self.mt_id = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State, ['up_down', 's_bit', 'prefix', 'metric', 'mt_id'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for a prefix
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: tag
                                                                
                                                                	This container defines sub\-TLV 1
                                                                	**type**\:  :py:class:`Tag <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                	This container defines sub\-TLV 2
                                                                	**type**\:  :py:class:`Tag64 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	This container defines sub\-TLV 4
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                	This container defines sub\-TLV 11
                                                                	**type**\:  :py:class:`Ipv4SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                	This container defines segment routing extensions for prefixes
                                                                	**type**\:  :py:class:`PrefixSids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"
                                                                    self._children_yang_names.add("tag")

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"
                                                                    self._children_yang_names.add("tag64")

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"
                                                                    self._children_yang_names.add("flags")

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"
                                                                    self._children_yang_names.add("ipv4-source-router-id")

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"
                                                                    self._children_yang_names.add("ipv6-source-router-id")

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._children_yang_names.add("prefix-sids")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 1
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, self).__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                        	List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', YLeafList(YType.uint32, 'tag32')),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)


                                                                class Tag64(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 2
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, self).__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag64"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                        	List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', YLeafList(YType.uint64, 'tag64')),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)


                                                                class Flags(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 4
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, self).__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "flags"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                        	Additional prefix reachability flags
                                                                        	**type**\: list of   :py:class:`Flags_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            Additional prefix reachability flags.

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                            	External prefix flag. Set if the prefix has been

                                                                            	redistributed from another protocol. This includes

                                                                            	the case where multiple virtual routers are

                                                                            	supported and the source of the redistributed prefix

                                                                            	is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                            	Readvertisement flag. Set when the prefix has been

                                                                            	leaked from one level to another (upwards or

                                                                            	downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                            	Node flag. Set when the prefix identifies the

                                                                            	advertising router, i.e., the prefix is a host

                                                                            	prefix advertising  a globally reachable address

                                                                            	typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")



                                                                class Ipv4SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 11
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv4_source_router_id
                                                                        
                                                                        	IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv4_source_router_id', YLeaf(YType.str, 'ipv4-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv4_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'ipv4_source_router_id'], name, value)


                                                                class Ipv6SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv6_source_router_id
                                                                        
                                                                        	IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv6_source_router_id', YLeaf(YType.str, 'ipv6-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv6_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'ipv6_source_router_id'], name, value)


                                                                class PrefixSids(Entity):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                    	Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, self).__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)


                                                                    class PrefixSid(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the prefix SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters for Prefix\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, self).__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	IGP Prefix\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Prefix Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                            	Prefix\-SID algorithm to be used for path computation
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('algorithm', YLeaf(YType.uint8, 'algorithm')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Prefix Segment\-ID.

                                                                                .. data:: READVERTISEMENT = 0

                                                                                	Readvertisment flag. When set, the prefix to which

                                                                                	this Prefix-SID is attached, has been propagated by

                                                                                	the router either from another level or from

                                                                                	redistribution.

                                                                                .. data:: NODE = 1

                                                                                	Node flag. When set, the Prefix-SID refers to the

                                                                                	router identified by the prefix. Typically, the

                                                                                	N-Flag is set on Prefix-SIDs attached to a router

                                                                                	loopback address.

                                                                                .. data:: PHP = 2

                                                                                	Penultimate-Hop-Popping flag. When set, then the

                                                                                	penultimate hop MUST NOT pop the Prefix-SID before

                                                                                	delivering the packet to the node that advertised

                                                                                	the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                	Explicit-Null flag. When set, any upstream neighbor

                                                                                	of the Prefix-SID originator MUST replace the

                                                                                	Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                	value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                	the packet.

                                                                                .. data:: VALUE = 4

                                                                                	Value flag. When set, the Prefix-SID carries a

                                                                                	value (instead of an index). By default the flag is

                                                                                	UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                	Local flag. When set, the value/index carried by

                                                                                	the Prefix-SID has local significance. By default

                                                                                	the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                PHP = Enum.YLeaf(2, "PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")



                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                            class MtIpv6Reachability(Entity):
                                                """
                                                This container defines list of IPv6 reachability
                                                information in multi \- topology environment.
                                                
                                                .. attribute:: prefixes
                                                
                                                	This container describes IS prefixes
                                                	**type**\:  :py:class:`Prefixes <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability, self).__init__()

                                                    self.yang_name = "mt-ipv6-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._children_yang_names.add("prefixes")
                                                    self._segment_path = lambda: "mt-ipv6-reachability"


                                                class Prefixes(Entity):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	List of IPv6 prefixes contained within MT reachability TLV
                                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes, self).__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "mt-ipv6-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes, [], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        List of IPv6 prefixes contained within MT
                                                        reachability TLV.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the IPv6 prefix described by the TLV
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                        	Reference to the multi\-topology ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4095
                                                        
                                                        	**refers to**\:  :py:class:`mt_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters relating an IPv6 prefix attribute
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	This container describes IS prefix sub\-TLVs
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	This container describes undefined ISIS TLVs
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix','mt_id']
                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                                ('mt_id', YLeaf(YType.str, 'mt-id')),
                                                            ])
                                                            self.prefix = None
                                                            self.mt_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._children_yang_names.add("subtlvs")

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._children_yang_names.add("undefined-subtlvs")
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']" + "[mt-id='" + str(self.mt_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix, ['prefix', 'mt_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters relating an IPv6 prefix attribute
                                                            
                                                            .. attribute:: up_down
                                                            
                                                            	The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: x_bit
                                                            
                                                            	The external bit. Set when the prefix was distributed into IS\-IS from another routing protocol
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                            	The sub\-tlv present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	IPv6 prefix contained within extended reachability TLVs
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                            
                                                            .. attribute:: metric
                                                            
                                                            	ISIS metric value
                                                            	**type**\: int
                                                            
                                                            	**range:** 1..16777215
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Multi\-topology ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4095
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', YLeaf(YType.boolean, 'up-down')),
                                                                    ('x_bit', YLeaf(YType.boolean, 'x-bit')),
                                                                    ('s_bit', YLeaf(YType.boolean, 's-bit')),
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('metric', YLeaf(YType.uint32, 'metric')),
                                                                    ('mt_id', YLeaf(YType.uint16, 'mt-id')),
                                                                ])
                                                                self.up_down = None
                                                                self.x_bit = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self.mt_id = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State, ['up_down', 'x_bit', 's_bit', 'prefix', 'metric', 'mt_id'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for a prefix
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                .. attribute:: tag
                                                                
                                                                	This container defines sub\-TLV 1
                                                                	**type**\:  :py:class:`Tag <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                	This container defines sub\-TLV 2
                                                                	**type**\:  :py:class:`Tag64 <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	This container defines sub\-TLV 4
                                                                	**type**\:  :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                	This container defines sub\-TLV 11
                                                                	**type**\:  :py:class:`Ipv4SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                	This container defines sub\-TLV 12
                                                                	**type**\:  :py:class:`Ipv6SourceRouterId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                	This container defines segment routing extensions for prefixes
                                                                	**type**\:  :py:class:`PrefixSids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.identityref, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"
                                                                    self._children_yang_names.add("tag")

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"
                                                                    self._children_yang_names.add("tag64")

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"
                                                                    self._children_yang_names.add("flags")

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"
                                                                    self._children_yang_names.add("ipv4-source-router-id")

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"
                                                                    self._children_yang_names.add("ipv6-source-router-id")

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._children_yang_names.add("prefix-sids")
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.identityref, 'type')),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 1
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, self).__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                        	List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', YLeafList(YType.uint32, 'tag32')),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)


                                                                class Tag64(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 2
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, self).__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "tag64"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                        	List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        	**type**\: list of int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', YLeafList(YType.uint64, 'tag64')),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)


                                                                class Flags(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 4
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, self).__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "flags"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                        	Additional prefix reachability flags
                                                                        	**type**\: list of   :py:class:`Flags_ <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            Additional prefix reachability flags.

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                            	External prefix flag. Set if the prefix has been

                                                                            	redistributed from another protocol. This includes

                                                                            	the case where multiple virtual routers are

                                                                            	supported and the source of the redistributed prefix

                                                                            	is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                            	Readvertisement flag. Set when the prefix has been

                                                                            	leaked from one level to another (upwards or

                                                                            	downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                            	Node flag. Set when the prefix identifies the

                                                                            	advertising router, i.e., the prefix is a host

                                                                            	prefix advertising  a globally reachable address

                                                                            	typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")



                                                                class Ipv4SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 11
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv4-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv4_source_router_id
                                                                        
                                                                        	IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv4_source_router_id', YLeaf(YType.str, 'ipv4-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv4_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'ipv4_source_router_id'], name, value)


                                                                class Ipv6SourceRouterId(Entity):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of sub\-TLV 12
                                                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, self).__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._children_yang_names.add("state")
                                                                        self._segment_path = lambda: "ipv6-source-router-id"


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        	**type**\:  :py:class:`ISISSUBTLVTYPE <ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                        .. attribute:: ipv6_source_router_id
                                                                        
                                                                        	IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        	**type**\: str
                                                                        
                                                                        	**pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_container_classes = OrderedDict([])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', YLeaf(YType.identityref, 'type')),
                                                                                ('ipv6_source_router_id', YLeaf(YType.str, 'ipv6-source-router-id')),
                                                                            ])
                                                                            self.type = None
                                                                            self.ipv6_source_router_id = None
                                                                            self._segment_path = lambda: "state"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'ipv6_source_router_id'], name, value)


                                                                class PrefixSids(Entity):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                    	Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, self).__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)


                                                                    class PrefixSid(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                        	Reference to the value of the prefix SID
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        	**refers to**\:  :py:class:`value <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters for Prefix\-SID
                                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, self).__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._child_list_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', YLeaf(YType.str, 'value')),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._children_yang_names.add("state")
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                            	IGP Prefix\-SID value
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Flags associated with Prefix Segment\-ID
                                                                            	**type**\: list of   :py:class:`Flags <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                            	Prefix\-SID algorithm to be used for path computation
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_container_classes = OrderedDict([])
                                                                                self._child_list_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', YLeaf(YType.uint32, 'value')),
                                                                                    ('flags', YLeafList(YType.enumeration, 'flags')),
                                                                                    ('algorithm', YLeaf(YType.uint8, 'algorithm')),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                Flags associated with Prefix Segment\-ID.

                                                                                .. data:: READVERTISEMENT = 0

                                                                                	Readvertisment flag. When set, the prefix to which

                                                                                	this Prefix-SID is attached, has been propagated by

                                                                                	the router either from another level or from

                                                                                	redistribution.

                                                                                .. data:: NODE = 1

                                                                                	Node flag. When set, the Prefix-SID refers to the

                                                                                	router identified by the prefix. Typically, the

                                                                                	N-Flag is set on Prefix-SIDs attached to a router

                                                                                	loopback address.

                                                                                .. data:: PHP = 2

                                                                                	Penultimate-Hop-Popping flag. When set, then the

                                                                                	penultimate hop MUST NOT pop the Prefix-SID before

                                                                                	delivering the packet to the node that advertised

                                                                                	the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                	Explicit-Null flag. When set, any upstream neighbor

                                                                                	of the Prefix-SID originator MUST replace the

                                                                                	Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                	value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                	the packet.

                                                                                .. data:: VALUE = 4

                                                                                	Value flag. When set, the Prefix-SID carries a

                                                                                	value (instead of an index). By default the flag is

                                                                                	UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                	Local flag. When set, the value/index carried by

                                                                                	the Prefix-SID has local significance. By default

                                                                                	the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                PHP = Enum.YLeaf(2, "PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")



                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._child_list_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', YLeaf(YType.str, 'type')),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._children_yang_names.add("state")
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_container_classes = OrderedDict([])
                                                                        self._child_list_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', YLeaf(YType.uint8, 'type')),
                                                                            ('length', YLeaf(YType.uint8, 'length')),
                                                                            ('value', YLeaf(YType.str, 'value')),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)


                                    class UndefinedTlvs(Entity):
                                        """
                                        Surrounding container for a list of unknown TLVs.
                                        
                                        .. attribute:: undefined_tlv
                                        
                                        	List of TLVs that are not defined within the model, or are not recognised by the system
                                        	**type**\: list of  		 :py:class:`UndefinedTlv <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs, self).__init__()

                                            self.yang_name = "undefined-tlvs"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([("undefined-tlv", ("undefined_tlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv))])
                                            self._leafs = OrderedDict()

                                            self.undefined_tlv = YList(self)
                                            self._segment_path = lambda: "undefined-tlvs"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs, [], name, value)


                                        class UndefinedTlv(Entity):
                                            """
                                            List of TLVs that are not defined within the model, or are
                                            not recognised by the system.
                                            
                                            .. attribute:: type  (key)
                                            
                                            	Reference to the undefined TLV's type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**refers to**\:  :py:class:`type <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State>`
                                            
                                            .. attribute:: state
                                            
                                            	State parameters of the undefined TLV
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv, self).__init__()

                                                self.yang_name = "undefined-tlv"
                                                self.yang_parent_name = "undefined-tlvs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['type']
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.str, 'type')),
                                                ])
                                                self.type = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "undefined-tlv" + "[type='" + str(self.type) + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv, ['type'], name, value)


                                            class State(Entity):
                                                """
                                                State parameters of the undefined TLV.
                                                
                                                .. attribute:: type
                                                
                                                	TLV Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: length
                                                
                                                	TLV length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: value
                                                
                                                	TLV value
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "undefined-tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', YLeaf(YType.uint8, 'type')),
                                                        ('length', YLeaf(YType.uint8, 'length')),
                                                        ('value', YLeaf(YType.str, 'value')),
                                                    ])
                                                    self.type = None
                                                    self.length = None
                                                    self.value = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State, ['type', 'length', 'value'], name, value)


                            class TrafficEngineering(Entity):
                                """
                                This container defines ISIS TE.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS TE configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines ISIS TE state information
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering, self).__init__()

                                    self.yang_name = "traffic-engineering"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "traffic-engineering"


                                class Config(Entity):
                                    """
                                    This container defines ISIS TE configuration.
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: ipv4_router_id
                                    
                                    	IPv4 MPLS Traffic Engineering Router\-ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_router_id
                                    
                                    	IPv6 MPLS Traffic Engineering Router\-ID
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "traffic-engineering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('ipv4_router_id', YLeaf(YType.str, 'ipv4-router-id')),
                                            ('ipv6_router_id', YLeaf(YType.str, 'ipv6-router-id')),
                                        ])
                                        self.enabled = None
                                        self.ipv4_router_id = None
                                        self.ipv6_router_id = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config, ['enabled', 'ipv4_router_id', 'ipv6_router_id'], name, value)


                                class State(Entity):
                                    """
                                    This container defines ISIS TE state information.
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: ipv4_router_id
                                    
                                    	IPv4 MPLS Traffic Engineering Router\-ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_router_id
                                    
                                    	IPv6 MPLS Traffic Engineering Router\-ID
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "traffic-engineering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ('ipv4_router_id', YLeaf(YType.str, 'ipv4-router-id')),
                                            ('ipv6_router_id', YLeaf(YType.str, 'ipv6-router-id')),
                                        ])
                                        self.enabled = None
                                        self.ipv4_router_id = None
                                        self.ipv6_router_id = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State, ['enabled', 'ipv4_router_id', 'ipv6_router_id'], name, value)


                            class RoutePreference(Entity):
                                """
                                This container defines Administrative Distance (or preference)
                                assigned to ISIS routes (level1 internal, level2 internal, level1
                                external, level2 external).
                                
                                .. attribute:: config
                                
                                	This container defines route preference configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines ISIS route preference state information
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference, self).__init__()

                                    self.yang_name = "route-preference"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "route-preference"


                                class Config(Entity):
                                    """
                                    This container defines route preference configuration.
                                    
                                    .. attribute:: external_route_preference
                                    
                                    	Administrative Distance(preference) for external ISIS routes
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_route_preference
                                    
                                    	Administrative Distance(preference) for internal ISIS routes
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-preference"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external_route_preference', YLeaf(YType.uint8, 'external-route-preference')),
                                            ('internal_route_preference', YLeaf(YType.uint8, 'internal-route-preference')),
                                        ])
                                        self.external_route_preference = None
                                        self.internal_route_preference = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config, ['external_route_preference', 'internal_route_preference'], name, value)


                                class State(Entity):
                                    """
                                    This container defines ISIS route preference state information.
                                    
                                    .. attribute:: external_route_preference
                                    
                                    	Administrative Distance(preference) for external ISIS routes
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: internal_route_preference
                                    
                                    	Administrative Distance(preference) for internal ISIS routes
                                    	**type**\: int
                                    
                                    	**range:** 1..255
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-preference"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external_route_preference', YLeaf(YType.uint8, 'external-route-preference')),
                                            ('internal_route_preference', YLeaf(YType.uint8, 'internal-route-preference')),
                                        ])
                                        self.external_route_preference = None
                                        self.internal_route_preference = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State, ['external_route_preference', 'internal_route_preference'], name, value)


                            class Authentication(Entity):
                                """
                                This container defines ISIS authentication.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS authentication configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines ISIS authentication state
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State>`
                                
                                .. attribute:: key
                                
                                	This container defines ISIS authentication key
                                	**type**\:  :py:class:`Key <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key>`
                                
                                .. attribute:: keychain
                                
                                	This container defines keychain parameters
                                	**type**\:  :py:class:`Keychain <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._children_yang_names.add("key")

                                    self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")
                                    self._segment_path = lambda: "authentication"


                                class Config(Entity):
                                    """
                                    This container defines ISIS authentication configuration.
                                    
                                    .. attribute:: csnp_authentication
                                    
                                    	Enable or disable for IS\-IS CSNPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: psnp_authentication
                                    
                                    	Enable or disable authentication for IS\-IS PSNPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: lsp_authentication
                                    
                                    	Enable or disable authentication for IS\-IS LSPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_authentication', YLeaf(YType.boolean, 'csnp-authentication')),
                                            ('psnp_authentication', YLeaf(YType.boolean, 'psnp-authentication')),
                                            ('lsp_authentication', YLeaf(YType.boolean, 'lsp-authentication')),
                                        ])
                                        self.csnp_authentication = None
                                        self.psnp_authentication = None
                                        self.lsp_authentication = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config, ['csnp_authentication', 'psnp_authentication', 'lsp_authentication'], name, value)


                                class State(Entity):
                                    """
                                    This container defines ISIS authentication state.
                                    
                                    .. attribute:: csnp_authentication
                                    
                                    	Enable or disable for IS\-IS CSNPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: psnp_authentication
                                    
                                    	Enable or disable authentication for IS\-IS PSNPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: lsp_authentication
                                    
                                    	Enable or disable authentication for IS\-IS LSPs
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_authentication', YLeaf(YType.boolean, 'csnp-authentication')),
                                            ('psnp_authentication', YLeaf(YType.boolean, 'psnp-authentication')),
                                            ('lsp_authentication', YLeaf(YType.boolean, 'lsp-authentication')),
                                        ])
                                        self.csnp_authentication = None
                                        self.psnp_authentication = None
                                        self.lsp_authentication = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State, ['csnp_authentication', 'psnp_authentication', 'lsp_authentication'], name, value)


                                class Key(Entity):
                                    """
                                    This container defines ISIS authentication key
                                    
                                    .. attribute:: config
                                    
                                    	This container defines ISIS authentication key configuration
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	This container defines ISIS authentication key state
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "key"


                                    class Config(Entity):
                                        """
                                        This container defines ISIS authentication key configuration.
                                        
                                        .. attribute:: auth_password
                                        
                                        	Authentication key string
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', YLeaf(YType.str, 'auth-password')),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config, ['auth_password'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines ISIS authentication key state.
                                        
                                        .. attribute:: auth_password
                                        
                                        	Authentication key string
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', YLeaf(YType.str, 'auth-password')),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State, ['auth_password'], name, value)


                                class Keychain(Entity):
                                    """
                                    This container defines keychain parameters.
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "keychain"


                    class Interfaces(Entity):
                        """
                        This container defines global ISIS interface configuration and
                        state information.
                        
                        .. attribute:: interface
                        
                        	This list contains ISIS interfaces
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface>`
                        
                        

                        """

                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces, self).__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_container_classes = OrderedDict([])
                            self._child_list_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces, [], name, value)


                        class Interface(Entity):
                            """
                            This list contains ISIS interfaces.
                            
                            .. attribute:: interface_id  (key)
                            
                            	Reference to interface\-id
                            	**type**\: str
                            
                            	**refers to**\:  :py:class:`interface_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config>`
                            
                            .. attribute:: config
                            
                            	This container defines ISIS interface configuration
                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config>`
                            
                            .. attribute:: state
                            
                            	This container defines state information for ISIS interfaces
                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State>`
                            
                            .. attribute:: circuit_counters
                            
                            	This container defines state information for ISIS circuit counters
                            	**type**\:  :py:class:`CircuitCounters <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters>`
                            
                            .. attribute:: authentication
                            
                            	This container defines ISIS authentication
                            	**type**\:  :py:class:`Authentication <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication>`
                            
                            .. attribute:: afi_safi
                            
                            	This container defines address\-family specific configuration and state information
                            	**type**\:  :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi>`
                            
                            .. attribute:: levels
                            
                            	This container defines ISIS level specific configuration and state information
                            	**type**\:  :py:class:`Levels <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels>`
                            
                            .. attribute:: timers
                            
                            	This container describes ISIS interface timers configuration
                            	**type**\:  :py:class:`Timers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers>`
                            
                            .. attribute:: bfd
                            
                            	This container defines BFD
                            	**type**\:  :py:class:`Bfd <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd>`
                            
                            .. attribute:: interface_ref
                            
                            	Reference to an interface or subinterface
                            	**type**\:  :py:class:`InterfaceRef <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef>`
                            
                            

                            """

                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_id']
                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State)), ("circuit-counters", ("circuit_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi)), ("levels", ("levels", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers)), ("bfd", ("bfd", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef))])
                                self._child_list_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_id', YLeaf(YType.str, 'interface-id')),
                                ])
                                self.interface_id = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"
                                self._children_yang_names.add("config")

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._children_yang_names.add("state")

                                self.circuit_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters()
                                self.circuit_counters.parent = self
                                self._children_name_map["circuit_counters"] = "circuit-counters"
                                self._children_yang_names.add("circuit-counters")

                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")

                                self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi()
                                self.afi_safi.parent = self
                                self._children_name_map["afi_safi"] = "afi-safi"
                                self._children_yang_names.add("afi-safi")

                                self.levels = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels()
                                self.levels.parent = self
                                self._children_name_map["levels"] = "levels"
                                self._children_yang_names.add("levels")

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"
                                self._children_yang_names.add("timers")

                                self.bfd = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.interface_ref = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._children_yang_names.add("interface-ref")
                                self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface, ['interface_id'], name, value)


                            class Config(Entity):
                                """
                                This container defines ISIS interface configuration.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: interface_id
                                
                                	Interface for which ISIS configuration is to be applied
                                	**type**\: str
                                
                                .. attribute:: passive
                                
                                	When set to true, the referenced interface is a passive interface such that it is not eligible to establish adjacencies with other systems, but is advertised into the IS\-IS topology
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_padding
                                
                                	This leaf controls padding type for IS\-IS Hello PDUs
                                	**type**\:  :py:class:`HelloPaddingType <ydk.models.openconfig.openconfig_isis_types.HelloPaddingType>`
                                
                                .. attribute:: circuit_type
                                
                                	ISIS circuit type (p2p, broadcast)
                                	**type**\:  :py:class:`CircuitType <ydk.models.openconfig.openconfig_isis_types.CircuitType>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config, self).__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('interface_id', YLeaf(YType.str, 'interface-id')),
                                        ('passive', YLeaf(YType.boolean, 'passive')),
                                        ('hello_padding', YLeaf(YType.enumeration, 'hello-padding')),
                                        ('circuit_type', YLeaf(YType.enumeration, 'circuit-type')),
                                    ])
                                    self.enabled = None
                                    self.interface_id = None
                                    self.passive = None
                                    self.hello_padding = None
                                    self.circuit_type = None
                                    self._segment_path = lambda: "config"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config, ['enabled', 'interface_id', 'passive', 'hello_padding', 'circuit_type'], name, value)


                            class State(Entity):
                                """
                                This container defines state information for ISIS interfaces.
                                
                                .. attribute:: enabled
                                
                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: interface_id
                                
                                	Interface for which ISIS configuration is to be applied
                                	**type**\: str
                                
                                .. attribute:: passive
                                
                                	When set to true, the referenced interface is a passive interface such that it is not eligible to establish adjacencies with other systems, but is advertised into the IS\-IS topology
                                	**type**\: bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_padding
                                
                                	This leaf controls padding type for IS\-IS Hello PDUs
                                	**type**\:  :py:class:`HelloPaddingType <ydk.models.openconfig.openconfig_isis_types.HelloPaddingType>`
                                
                                .. attribute:: circuit_type
                                
                                	ISIS circuit type (p2p, broadcast)
                                	**type**\:  :py:class:`CircuitType <ydk.models.openconfig.openconfig_isis_types.CircuitType>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                        ('interface_id', YLeaf(YType.str, 'interface-id')),
                                        ('passive', YLeaf(YType.boolean, 'passive')),
                                        ('hello_padding', YLeaf(YType.enumeration, 'hello-padding')),
                                        ('circuit_type', YLeaf(YType.enumeration, 'circuit-type')),
                                    ])
                                    self.enabled = None
                                    self.interface_id = None
                                    self.passive = None
                                    self.hello_padding = None
                                    self.circuit_type = None
                                    self._segment_path = lambda: "state"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State, ['enabled', 'interface_id', 'passive', 'hello_padding', 'circuit_type'], name, value)


                            class CircuitCounters(Entity):
                                """
                                This container defines state information for ISIS circuit counters.
                                
                                .. attribute:: state
                                
                                	The container defines a list of counters for IS circuit
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters, self).__init__()

                                    self.yang_name = "circuit-counters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "circuit-counters"


                                class State(Entity):
                                    """
                                    The container defines a list of counters for IS circuit.
                                    
                                    .. attribute:: adj_changes
                                    
                                    	Number of times an adjacency state change has occurred on this circuit. MIB Entry\: CircAdjChanges
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: init_fails
                                    
                                    	Number of times initialization of this circuit has failed. This counts events such as PPP NCP failures. MIB Entry\: CircInitFails
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_adj
                                    
                                    	Number of times an adjacency has been rejected on this circuit. MIB Entry\: CircRejAdjs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: id_field_len_mismatches
                                    
                                    	Number of times an IS\-IS control PDU with an ID field length different from that for this system has been received. MIB Entry\: CircIDFieldLenMismatches
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_area_address_mismatches
                                    
                                    	Number of times an IS\-IS control PDU with a max area address field different from that for this system has been received. MIB Entry\: CircMaxAreaAddrMismatches
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auth_type_fails
                                    
                                    	Number of times an IS\-IS control PDU with an auth type field different from that for this system has been received. MIB Entry\: CircAuthTypeFails
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auth_fails
                                    
                                    	Number of times an IS\-IS control PDU with the correct auth type has failed to pass authentication validation. MIB Entry\: CircAuthFails
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lan_dis_changes
                                    
                                    	Number of times the Designated IS has changed on this circuit at this level. If the circuit is point to point, this count is zero. MIB Entry\: CircLANDesISChanges
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: adj_number
                                    
                                    	Number of adjacencies on this circuit. MIB Entry\: CircNumAdj
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "circuit-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('adj_changes', YLeaf(YType.uint32, 'adj-changes')),
                                            ('init_fails', YLeaf(YType.uint32, 'init-fails')),
                                            ('rejected_adj', YLeaf(YType.uint32, 'rejected-adj')),
                                            ('id_field_len_mismatches', YLeaf(YType.uint32, 'id-field-len-mismatches')),
                                            ('max_area_address_mismatches', YLeaf(YType.uint32, 'max-area-address-mismatches')),
                                            ('auth_type_fails', YLeaf(YType.uint32, 'auth-type-fails')),
                                            ('auth_fails', YLeaf(YType.uint32, 'auth-fails')),
                                            ('lan_dis_changes', YLeaf(YType.uint32, 'lan-dis-changes')),
                                            ('adj_number', YLeaf(YType.uint32, 'adj-number')),
                                        ])
                                        self.adj_changes = None
                                        self.init_fails = None
                                        self.rejected_adj = None
                                        self.id_field_len_mismatches = None
                                        self.max_area_address_mismatches = None
                                        self.auth_type_fails = None
                                        self.auth_fails = None
                                        self.lan_dis_changes = None
                                        self.adj_number = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State, ['adj_changes', 'init_fails', 'rejected_adj', 'id_field_len_mismatches', 'max_area_address_mismatches', 'auth_type_fails', 'auth_fails', 'lan_dis_changes', 'adj_number'], name, value)


                            class Authentication(Entity):
                                """
                                This container defines ISIS authentication.
                                
                                .. attribute:: config
                                
                                	This container defines ISIS authentication configuration
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines ISIS authentication state
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State>`
                                
                                .. attribute:: key
                                
                                	This container defines ISIS authentication key
                                	**type**\:  :py:class:`Key <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key>`
                                
                                .. attribute:: keychain
                                
                                	This container defines keychain parameters
                                	**type**\:  :py:class:`Keychain <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")

                                    self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"
                                    self._children_yang_names.add("key")

                                    self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")
                                    self._segment_path = lambda: "authentication"


                                class Config(Entity):
                                    """
                                    This container defines ISIS authentication configuration.
                                    
                                    .. attribute:: hello_authentication
                                    
                                    	Enabled or disable ISIS Hello authentication
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_authentication', YLeaf(YType.boolean, 'hello-authentication')),
                                        ])
                                        self.hello_authentication = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config, ['hello_authentication'], name, value)


                                class State(Entity):
                                    """
                                    This container defines ISIS authentication state.
                                    
                                    .. attribute:: hello_authentication
                                    
                                    	Enabled or disable ISIS Hello authentication
                                    	**type**\: bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_authentication', YLeaf(YType.boolean, 'hello-authentication')),
                                        ])
                                        self.hello_authentication = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State, ['hello_authentication'], name, value)


                                class Key(Entity):
                                    """
                                    This container defines ISIS authentication key
                                    
                                    .. attribute:: config
                                    
                                    	This container defines ISIS authentication key configuration
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	This container defines ISIS authentication key state
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key, self).__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "key"


                                    class Config(Entity):
                                        """
                                        This container defines ISIS authentication key configuration.
                                        
                                        .. attribute:: auth_password
                                        
                                        	Authentication key string
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', YLeaf(YType.str, 'auth-password')),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config, ['auth_password'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines ISIS authentication key state.
                                        
                                        .. attribute:: auth_password
                                        
                                        	Authentication key string
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', YLeaf(YType.str, 'auth-password')),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State, ['auth_password'], name, value)


                                class Keychain(Entity):
                                    """
                                    This container defines keychain parameters.
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "keychain"


                            class AfiSafi(Entity):
                                """
                                This container defines address\-family specific configuration
                                and state information.
                                
                                .. attribute:: af
                                
                                	Address\-family/Subsequent Address\-family list
                                	**type**\: list of  		 :py:class:`Af <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi, self).__init__()

                                    self.yang_name = "afi-safi"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af))])
                                    self._leafs = OrderedDict()

                                    self.af = YList(self)
                                    self._segment_path = lambda: "afi-safi"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi, [], name, value)


                                class Af(Entity):
                                    """
                                    Address\-family/Subsequent Address\-family list.
                                    
                                    .. attribute:: afi_name  (key)
                                    
                                    	Reference to address\-family type
                                    	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: safi_name  (key)
                                    
                                    	Reference to subsequent address\-family type
                                    	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                    	This container defines AFI\-SAFI configuration parameters. Single topology is the default setting
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	This container defines AFI\-SAFI State information
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af, self).__init__()

                                        self.yang_name = "af"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_name','safi_name']
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                            ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")
                                        self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)


                                    class Config(Entity):
                                        """
                                        This container defines AFI\-SAFI configuration parameters. Single
                                        topology is the default setting.
                                        
                                        .. attribute:: afi_name
                                        
                                        	Address\-family type
                                        	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                        	Subsequent address\-family type
                                        	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'enabled'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines AFI\-SAFI State information
                                        
                                        .. attribute:: afi_name
                                        
                                        	Address\-family type
                                        	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                        	Subsequent address\-family type
                                        	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State, ['afi_name', 'safi_name', 'enabled'], name, value)


                            class Levels(Entity):
                                """
                                This container defines ISIS level specific configuration and
                                state information.
                                
                                .. attribute:: level
                                
                                	Configuration and operational state parameters related to a particular level on an IS\-IS enabled interface
                                	**type**\: list of  		 :py:class:`Level <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels, self).__init__()

                                    self.yang_name = "levels"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([])
                                    self._child_list_classes = OrderedDict([("level", ("level", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level))])
                                    self._leafs = OrderedDict()

                                    self.level = YList(self)
                                    self._segment_path = lambda: "levels"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels, [], name, value)


                                class Level(Entity):
                                    """
                                    Configuration and operational state parameters related to a
                                    particular level on an IS\-IS enabled interface.
                                    
                                    .. attribute:: level_number  (key)
                                    
                                    	Reference to ISIS level\-number
                                    	**type**\: int
                                    
                                    	**range:** 1..2
                                    
                                    	**refers to**\:  :py:class:`level_number <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config>`
                                    
                                    .. attribute:: config
                                    
                                    	This container defines interface ISIS level configuration
                                    	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config>`
                                    
                                    .. attribute:: state
                                    
                                    	This container defines interface ISIS level state information
                                    	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State>`
                                    
                                    .. attribute:: packet_counters
                                    
                                    	This container defines ISIS interface packet counters
                                    	**type**\:  :py:class:`PacketCounters <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters>`
                                    
                                    .. attribute:: adjacencies
                                    
                                    	This container defines ISIS adjacencies
                                    	**type**\:  :py:class:`Adjacencies <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies>`
                                    
                                    .. attribute:: timers
                                    
                                    	This container defines ISIS timers
                                    	**type**\:  :py:class:`Timers <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers>`
                                    
                                    .. attribute:: afi_safi
                                    
                                    	This container defines address\-family specific configuration and state information
                                    	**type**\:  :py:class:`AfiSafi <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi>`
                                    
                                    .. attribute:: hello_authentication
                                    
                                    	This container defines ISIS authentication
                                    	**type**\:  :py:class:`HelloAuthentication <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level, self).__init__()

                                        self.yang_name = "level"
                                        self.yang_parent_name = "levels"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['level_number']
                                        self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State)), ("packet-counters", ("packet_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters)), ("adjacencies", ("adjacencies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi)), ("hello-authentication", ("hello_authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication))])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level_number', YLeaf(YType.str, 'level-number')),
                                        ])
                                        self.level_number = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"
                                        self._children_yang_names.add("config")

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._children_yang_names.add("state")

                                        self.packet_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters()
                                        self.packet_counters.parent = self
                                        self._children_name_map["packet_counters"] = "packet-counters"
                                        self._children_yang_names.add("packet-counters")

                                        self.adjacencies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies()
                                        self.adjacencies.parent = self
                                        self._children_name_map["adjacencies"] = "adjacencies"
                                        self._children_yang_names.add("adjacencies")

                                        self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"
                                        self._children_yang_names.add("timers")

                                        self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi()
                                        self.afi_safi.parent = self
                                        self._children_name_map["afi_safi"] = "afi-safi"
                                        self._children_yang_names.add("afi-safi")

                                        self.hello_authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication()
                                        self.hello_authentication.parent = self
                                        self._children_name_map["hello_authentication"] = "hello-authentication"
                                        self._children_yang_names.add("hello-authentication")
                                        self._segment_path = lambda: "level" + "[level-number='" + str(self.level_number) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level, ['level_number'], name, value)


                                    class Config(Entity):
                                        """
                                        This container defines interface ISIS level configuration.
                                        
                                        .. attribute:: level_number
                                        
                                        	ISIS level number(level\-1, level\-2)
                                        	**type**\: int
                                        
                                        	**range:** 1..2
                                        
                                        .. attribute:: passive
                                        
                                        	ISIS passive interface admin enable/disable function
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: priority
                                        
                                        	ISIS neighbor priority(LAN hello PDU only)
                                        	**type**\: int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config, self).__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('level_number', YLeaf(YType.uint8, 'level-number')),
                                                ('passive', YLeaf(YType.boolean, 'passive')),
                                                ('priority', YLeaf(YType.uint8, 'priority')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.level_number = None
                                            self.passive = None
                                            self.priority = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config, ['level_number', 'passive', 'priority', 'enabled'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines interface ISIS level state information.
                                        
                                        .. attribute:: level_number
                                        
                                        	ISIS level number(level\-1, level\-2)
                                        	**type**\: int
                                        
                                        	**range:** 1..2
                                        
                                        .. attribute:: passive
                                        
                                        	ISIS passive interface admin enable/disable function
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: priority
                                        
                                        	ISIS neighbor priority(LAN hello PDU only)
                                        	**type**\: int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('level_number', YLeaf(YType.uint8, 'level-number')),
                                                ('passive', YLeaf(YType.boolean, 'passive')),
                                                ('priority', YLeaf(YType.uint8, 'priority')),
                                                ('enabled', YLeaf(YType.boolean, 'enabled')),
                                            ])
                                            self.level_number = None
                                            self.passive = None
                                            self.priority = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State, ['level_number', 'passive', 'priority', 'enabled'], name, value)


                                    class PacketCounters(Entity):
                                        """
                                        This container defines ISIS interface packet counters.
                                        
                                        .. attribute:: lsp
                                        
                                        	This container defines LSP packet counters
                                        	**type**\:  :py:class:`Lsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp>`
                                        
                                        .. attribute:: iih
                                        
                                        	This container defines IIH packet counters
                                        	**type**\:  :py:class:`Iih <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih>`
                                        
                                        .. attribute:: ish
                                        
                                        	This container defines ISH packet counters
                                        	**type**\:  :py:class:`Ish <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish>`
                                        
                                        .. attribute:: esh
                                        
                                        	This container defines ESH packet counters
                                        	**type**\:  :py:class:`Esh <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh>`
                                        
                                        .. attribute:: psnp
                                        
                                        	This container defines PSNP packet counters
                                        	**type**\:  :py:class:`Psnp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp>`
                                        
                                        .. attribute:: cnsp
                                        
                                        	Operational state parameters relating to CNSPs
                                        	**type**\:  :py:class:`Cnsp <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp>`
                                        
                                        .. attribute:: unknown
                                        
                                        	Operational state parameters relating to IS\-IS PDUs that are not otherwise classified \- referred to as Unknown PDUs
                                        	**type**\:  :py:class:`Unknown <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters, self).__init__()

                                            self.yang_name = "packet-counters"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("lsp", ("lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp)), ("iih", ("iih", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih)), ("ish", ("ish", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish)), ("esh", ("esh", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh)), ("psnp", ("psnp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp)), ("cnsp", ("cnsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp)), ("unknown", ("unknown", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp()
                                            self.lsp.parent = self
                                            self._children_name_map["lsp"] = "lsp"
                                            self._children_yang_names.add("lsp")

                                            self.iih = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih()
                                            self.iih.parent = self
                                            self._children_name_map["iih"] = "iih"
                                            self._children_yang_names.add("iih")

                                            self.ish = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish()
                                            self.ish.parent = self
                                            self._children_name_map["ish"] = "ish"
                                            self._children_yang_names.add("ish")

                                            self.esh = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh()
                                            self.esh.parent = self
                                            self._children_name_map["esh"] = "esh"
                                            self._children_yang_names.add("esh")

                                            self.psnp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp()
                                            self.psnp.parent = self
                                            self._children_name_map["psnp"] = "psnp"
                                            self._children_yang_names.add("psnp")

                                            self.cnsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp()
                                            self.cnsp.parent = self
                                            self._children_name_map["cnsp"] = "cnsp"
                                            self._children_yang_names.add("cnsp")

                                            self.unknown = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown()
                                            self.unknown.parent = self
                                            self._children_name_map["unknown"] = "unknown"
                                            self._children_yang_names.add("unknown")
                                            self._segment_path = lambda: "packet-counters"


                                        class Lsp(Entity):
                                            """
                                            This container defines LSP packet counters.
                                            
                                            .. attribute:: state
                                            
                                            	This container defines LSP PDU counters
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp, self).__init__()

                                                self.yang_name = "lsp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "lsp"


                                            class State(Entity):
                                                """
                                                This container defines LSP PDU counters.
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "lsp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Iih(Entity):
                                            """
                                            This container defines IIH packet counters.
                                            
                                            .. attribute:: state
                                            
                                            	Operational counters relating to IIH PDUs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih, self).__init__()

                                                self.yang_name = "iih"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "iih"


                                            class State(Entity):
                                                """
                                                Operational counters relating to IIH PDUs
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "iih"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Ish(Entity):
                                            """
                                            This container defines ISH packet counters.
                                            
                                            .. attribute:: state
                                            
                                            	Operational state relating to ISH PDUs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish, self).__init__()

                                                self.yang_name = "ish"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "ish"


                                            class State(Entity):
                                                """
                                                Operational state relating to ISH PDUs.
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ish"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Esh(Entity):
                                            """
                                            This container defines ESH packet counters.
                                            
                                            .. attribute:: state
                                            
                                            	Operational state relating to ESH PDUs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh, self).__init__()

                                                self.yang_name = "esh"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "esh"


                                            class State(Entity):
                                                """
                                                Operational state relating to ESH PDUs
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "esh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Psnp(Entity):
                                            """
                                            This container defines PSNP packet counters.
                                            
                                            .. attribute:: state
                                            
                                            	Packet counters relating to PSNPs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp, self).__init__()

                                                self.yang_name = "psnp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "psnp"


                                            class State(Entity):
                                                """
                                                Packet counters relating to PSNPs.
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "psnp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Cnsp(Entity):
                                            """
                                            Operational state parameters relating to CNSPs.
                                            
                                            .. attribute:: state
                                            
                                            	Packet counters relating to CNSPs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp, self).__init__()

                                                self.yang_name = "cnsp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "cnsp"


                                            class State(Entity):
                                                """
                                                Packet counters relating to CNSPs.
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "cnsp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Cnsp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                        class Unknown(Entity):
                                            """
                                            Operational state parameters relating to IS\-IS PDUs that are not
                                            otherwise classified \- referred to as Unknown PDUs.
                                            
                                            .. attribute:: state
                                            
                                            	Packet counters relating to unknown PDUs
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown, self).__init__()

                                                self.yang_name = "unknown"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "unknown"


                                            class State(Entity):
                                                """
                                                Packet counters relating to unknown PDUs.
                                                
                                                .. attribute:: received
                                                
                                                	The number of the specified type of PDU received on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed
                                                
                                                	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: dropped
                                                
                                                	The number of the specified type of PDU received on the interface that have been dropped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent
                                                
                                                	The number of the specified type of PDU that have been sent by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: retransmit
                                                
                                                	The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "unknown"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', YLeaf(YType.uint32, 'received')),
                                                        ('processed', YLeaf(YType.uint32, 'processed')),
                                                        ('dropped', YLeaf(YType.uint32, 'dropped')),
                                                        ('sent', YLeaf(YType.uint32, 'sent')),
                                                        ('retransmit', YLeaf(YType.uint32, 'retransmit')),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)


                                    class Adjacencies(Entity):
                                        """
                                        This container defines ISIS adjacencies.
                                        
                                        .. attribute:: adjacency
                                        
                                        	List of the local system's IS\-IS adjacencies
                                        	**type**\: list of  		 :py:class:`Adjacency <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies, self).__init__()

                                            self.yang_name = "adjacencies"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([("adjacency", ("adjacency", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency))])
                                            self._leafs = OrderedDict()

                                            self.adjacency = YList(self)
                                            self._segment_path = lambda: "adjacencies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies, [], name, value)


                                        class Adjacency(Entity):
                                            """
                                            List of the local system's IS\-IS adjacencies.
                                            
                                            .. attribute:: system_id  (key)
                                            
                                            	Reference to the IS neighbor
                                            	**type**\: str
                                            
                                            	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                            
                                            	**refers to**\:  :py:class:`system_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State>`
                                            
                                            .. attribute:: state
                                            
                                            	Operational state relating to the IS\-IS adjacency with the remote system
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency, self).__init__()

                                                self.yang_name = "adjacency"
                                                self.yang_parent_name = "adjacencies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['system_id']
                                                self._child_container_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('system_id', YLeaf(YType.str, 'system-id')),
                                                ])
                                                self.system_id = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "adjacency" + "[system-id='" + str(self.system_id) + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency, ['system_id'], name, value)


                                            class State(Entity):
                                                """
                                                Operational state relating to the IS\-IS adjacency with the
                                                remote system
                                                
                                                .. attribute:: system_id
                                                
                                                	ISIS neighbor system\-id
                                                	**type**\: str
                                                
                                                	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                
                                                .. attribute:: neighbor_ipv4_address
                                                
                                                	ISIS Neighbor IPv4 address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_ipv6_address
                                                
                                                	ISIS Neighbor IPv6 address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	ISIS neighbor SNPA
                                                	**type**\: str
                                                
                                                	**length:** 0..20
                                                
                                                .. attribute:: local_extended_circuit_id
                                                
                                                	Local extended circuit ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: neighbor_extended_circuit_id
                                                
                                                	ISIS neighbor extended circuit ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: priority
                                                
                                                	Priority of the neighboring IS(LAN Hello only)
                                                	**type**\: int
                                                
                                                	**range:** 0..127
                                                
                                                .. attribute:: dis_system_id
                                                
                                                	DIS System ID(LAN hello only)
                                                	**type**\: str
                                                
                                                	**pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                
                                                .. attribute:: neighbor_circuit_type
                                                
                                                	Received ISIS circuit type (level\-1, level\-2, level\-1\-2)
                                                	**type**\:  :py:class:`LevelType <ydk.models.openconfig.openconfig_isis_types.LevelType>`
                                                
                                                .. attribute:: adjacency_type
                                                
                                                	Formed ISIS adjacency type(level\-1, level\-2, level\-1\-2)
                                                	**type**\:  :py:class:`LevelType <ydk.models.openconfig.openconfig_isis_types.LevelType>`
                                                
                                                .. attribute:: adjacency_state
                                                
                                                	P2P 3\-way ISIS adjacency state(up, down, init, failed)
                                                	**type**\:  :py:class:`IsisInterfaceAdjState <ydk.models.openconfig.openconfig_isis_types.IsisInterfaceAdjState>`
                                                
                                                .. attribute:: remaining_hold_time
                                                
                                                	Holding time in seconds for adjacency. This value is based on received hello PDUs and the elapsed time since receipt
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: seconds
                                                
                                                .. attribute:: up_time
                                                
                                                	Adjacency up time
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: multi_topology
                                                
                                                	When set to true, ISIS multi\-topology is supported
                                                	**type**\: bool
                                                
                                                .. attribute:: topology
                                                
                                                	ISIS topology type support(ipv4\-unicast, ipv6\-unicast, ipv4\-multicast, ipv6\-multicast)
                                                	**type**\: list of   :py:class:`AFISAFITYPE <ydk.models.openconfig.openconfig_isis_types.AFISAFITYPE>`
                                                
                                                .. attribute:: restart_support
                                                
                                                	When set to true, Graceful\-restart signaling is supported
                                                	**type**\: bool
                                                
                                                .. attribute:: restart_suppress
                                                
                                                	When set to true, adjacency is not advertised. The SA bit is used by a starting router to  request that its neighbor suppress advertisement of the adjacency  to the starting router in the neighbor's LSPs
                                                	**type**\: bool
                                                
                                                .. attribute:: restart_status
                                                
                                                	When set to true, neighbor is being helped. The RR bit is used by a (re)starting router to signal to its neighbors that a (re)start is in progress
                                                	**type**\: bool
                                                
                                                .. attribute:: area_address
                                                
                                                	List of ISIS area\-address(es)
                                                	**type**\: list of str
                                                
                                                	**pattern:** ^[0\-9A\-Fa\-f]{2}\\.([0\-9A\-Fa\-f]{4}\\.){0,3}$
                                                
                                                .. attribute:: nlpid
                                                
                                                	Supported Protocol. IPv4 is defined as (0xcc) and IPv6 \- (0x8e). ISIS reference is TLV 129
                                                	**type**\: list of   :py:class:`Nlpid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State.Nlpid>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "adjacency"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('system_id', YLeaf(YType.str, 'system-id')),
                                                        ('neighbor_ipv4_address', YLeaf(YType.str, 'neighbor-ipv4-address')),
                                                        ('neighbor_ipv6_address', YLeaf(YType.str, 'neighbor-ipv6-address')),
                                                        ('neighbor_snpa', YLeaf(YType.str, 'neighbor-snpa')),
                                                        ('local_extended_circuit_id', YLeaf(YType.uint32, 'local-extended-circuit-id')),
                                                        ('neighbor_extended_circuit_id', YLeaf(YType.uint32, 'neighbor-extended-circuit-id')),
                                                        ('priority', YLeaf(YType.uint8, 'priority')),
                                                        ('dis_system_id', YLeaf(YType.str, 'dis-system-id')),
                                                        ('neighbor_circuit_type', YLeaf(YType.enumeration, 'neighbor-circuit-type')),
                                                        ('adjacency_type', YLeaf(YType.enumeration, 'adjacency-type')),
                                                        ('adjacency_state', YLeaf(YType.enumeration, 'adjacency-state')),
                                                        ('remaining_hold_time', YLeaf(YType.uint16, 'remaining-hold-time')),
                                                        ('up_time', YLeaf(YType.uint32, 'up-time')),
                                                        ('multi_topology', YLeaf(YType.boolean, 'multi-topology')),
                                                        ('topology', YLeafList(YType.identityref, 'topology')),
                                                        ('restart_support', YLeaf(YType.boolean, 'restart-support')),
                                                        ('restart_suppress', YLeaf(YType.boolean, 'restart-suppress')),
                                                        ('restart_status', YLeaf(YType.boolean, 'restart-status')),
                                                        ('area_address', YLeafList(YType.str, 'area-address')),
                                                        ('nlpid', YLeafList(YType.enumeration, 'nlpid')),
                                                    ])
                                                    self.system_id = None
                                                    self.neighbor_ipv4_address = None
                                                    self.neighbor_ipv6_address = None
                                                    self.neighbor_snpa = None
                                                    self.local_extended_circuit_id = None
                                                    self.neighbor_extended_circuit_id = None
                                                    self.priority = None
                                                    self.dis_system_id = None
                                                    self.neighbor_circuit_type = None
                                                    self.adjacency_type = None
                                                    self.adjacency_state = None
                                                    self.remaining_hold_time = None
                                                    self.up_time = None
                                                    self.multi_topology = None
                                                    self.topology = []
                                                    self.restart_support = None
                                                    self.restart_suppress = None
                                                    self.restart_status = None
                                                    self.area_address = []
                                                    self.nlpid = []
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State, ['system_id', 'neighbor_ipv4_address', 'neighbor_ipv6_address', 'neighbor_snpa', 'local_extended_circuit_id', 'neighbor_extended_circuit_id', 'priority', 'dis_system_id', 'neighbor_circuit_type', 'adjacency_type', 'adjacency_state', 'remaining_hold_time', 'up_time', 'multi_topology', 'topology', 'restart_support', 'restart_suppress', 'restart_status', 'area_address', 'nlpid'], name, value)

                                                class Nlpid(Enum):
                                                    """
                                                    Nlpid (Enum Class)

                                                    Supported Protocol. IPv4 is defined as (0xcc)

                                                    and IPv6 \- (0x8e). ISIS reference is TLV 129.

                                                    .. data:: IPV4 = 0

                                                    	IPv4 Address family.

                                                    .. data:: IPV6 = 1

                                                    	IPv6 Address family.

                                                    """

                                                    IPV4 = Enum.YLeaf(0, "IPV4")

                                                    IPV6 = Enum.YLeaf(1, "IPV6")



                                    class Timers(Entity):
                                        """
                                        This container defines ISIS timers.
                                        
                                        .. attribute:: config
                                        
                                        	This container defines ISIS interface hello\-timers configuration
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	This container defines ISIS interface hello\-timers state
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers, self).__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")
                                            self._segment_path = lambda: "timers"


                                        class Config(Entity):
                                            """
                                            This container defines ISIS interface hello\-timers configuration.
                                            
                                            .. attribute:: hello_interval
                                            
                                            	ISIS hello\-interval value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hello_multiplier
                                            
                                            	ISIS hello\-multiplier value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "timers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_interval', YLeaf(YType.uint32, 'hello-interval')),
                                                    ('hello_multiplier', YLeaf(YType.uint8, 'hello-multiplier')),
                                                ])
                                                self.hello_interval = None
                                                self.hello_multiplier = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config, ['hello_interval', 'hello_multiplier'], name, value)


                                        class State(Entity):
                                            """
                                            This container defines ISIS interface hello\-timers state.
                                            
                                            .. attribute:: hello_interval
                                            
                                            	ISIS hello\-interval value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: hello_multiplier
                                            
                                            	ISIS hello\-multiplier value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "timers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_interval', YLeaf(YType.uint32, 'hello-interval')),
                                                    ('hello_multiplier', YLeaf(YType.uint8, 'hello-multiplier')),
                                                ])
                                                self.hello_interval = None
                                                self.hello_multiplier = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State, ['hello_interval', 'hello_multiplier'], name, value)


                                    class AfiSafi(Entity):
                                        """
                                        This container defines address\-family specific configuration
                                        and state information.
                                        
                                        .. attribute:: af
                                        
                                        	Address\-family/Subsequent Address\-family list
                                        	**type**\: list of  		 :py:class:`Af <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi, self).__init__()

                                            self.yang_name = "afi-safi"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([])
                                            self._child_list_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af))])
                                            self._leafs = OrderedDict()

                                            self.af = YList(self)
                                            self._segment_path = lambda: "afi-safi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi, [], name, value)


                                        class Af(Entity):
                                            """
                                            Address\-family/Subsequent Address\-family list.
                                            
                                            .. attribute:: afi_name  (key)
                                            
                                            	Reference to address\-family type
                                            	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                            
                                            .. attribute:: safi_name  (key)
                                            
                                            	Reference to subsequent address\-family type
                                            	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                            
                                            .. attribute:: config
                                            
                                            	This container defines AFI\-SAFI configuration parameters. Single topology is the default setting
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	This container defines AFI\-SAFI State information
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State>`
                                            
                                            .. attribute:: segment_routing
                                            
                                            	Configuration and operatioanl state parameters relating to segment routing for an interface within the IGP
                                            	**type**\:  :py:class:`SegmentRouting <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af, self).__init__()

                                                self.yang_name = "af"
                                                self.yang_parent_name = "afi-safi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['afi_name','safi_name']
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                    ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                ])
                                                self.afi_name = None
                                                self.safi_name = None

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")

                                                self.segment_routing = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting()
                                                self.segment_routing.parent = self
                                                self._children_name_map["segment_routing"] = "segment-routing"
                                                self._children_yang_names.add("segment-routing")
                                                self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)


                                            class Config(Entity):
                                                """
                                                This container defines AFI\-SAFI configuration parameters. Single
                                                topology is the default setting.
                                                
                                                .. attribute:: afi_name
                                                
                                                	Address\-family type
                                                	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                                
                                                .. attribute:: safi_name
                                                
                                                	Subsequent address\-family type
                                                	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS metric value(default=10)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 10
                                                
                                                .. attribute:: enabled
                                                
                                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                        ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                        ('metric', YLeaf(YType.uint32, 'metric')),
                                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                    ])
                                                    self.afi_name = None
                                                    self.safi_name = None
                                                    self.metric = None
                                                    self.enabled = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                            class State(Entity):
                                                """
                                                This container defines AFI\-SAFI State information
                                                
                                                .. attribute:: afi_name
                                                
                                                	Address\-family type
                                                	**type**\:  :py:class:`AFITYPE <ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                                
                                                .. attribute:: safi_name
                                                
                                                	Subsequent address\-family type
                                                	**type**\:  :py:class:`SAFITYPE <ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                                
                                                .. attribute:: metric
                                                
                                                	ISIS metric value(default=10)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 10
                                                
                                                .. attribute:: enabled
                                                
                                                	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi_name', YLeaf(YType.identityref, 'afi-name')),
                                                        ('safi_name', YLeaf(YType.identityref, 'safi-name')),
                                                        ('metric', YLeaf(YType.uint32, 'metric')),
                                                        ('enabled', YLeaf(YType.boolean, 'enabled')),
                                                    ])
                                                    self.afi_name = None
                                                    self.safi_name = None
                                                    self.metric = None
                                                    self.enabled = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                            class SegmentRouting(Entity):
                                                """
                                                Configuration and operatioanl state parameters relating to segment
                                                routing for an interface within the IGP.
                                                
                                                .. attribute:: prefix_sids
                                                
                                                	Configuration and operational state parameters relating to the advertisement of a segment routing IGP\-Prefix SID for this interface
                                                	**type**\:  :py:class:`PrefixSids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids>`
                                                
                                                .. attribute:: adjacency_sids
                                                
                                                	Configuration and operational state parameters relating to the advertisement of a segment routing adjacency SID for this interface
                                                	**type**\:  :py:class:`AdjacencySids <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids>`
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting, self).__init__()

                                                    self.yang_name = "segment-routing"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids))])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids()
                                                    self.prefix_sids.parent = self
                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                    self._children_yang_names.add("prefix-sids")

                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids()
                                                    self.adjacency_sids.parent = self
                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                    self._children_yang_names.add("adjacency-sids")
                                                    self._segment_path = lambda: "segment-routing"


                                                class PrefixSids(Entity):
                                                    """
                                                    Configuration and operational state parameters relating to
                                                    the advertisement of a segment routing IGP\-Prefix SID for this
                                                    interface.
                                                    
                                                    .. attribute:: prefix_sid
                                                    
                                                    	An IGP prefix that should have a segment routing IGP\-Prefix SID allocated to it. The value of the SID is specified by the SID ID, as an absolute value. If the absolute value falls within the SRGB, the Global flag should be advertised by the system
                                                    	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids, self).__init__()

                                                        self.yang_name = "prefix-sids"
                                                        self.yang_parent_name = "segment-routing"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid = YList(self)
                                                        self._segment_path = lambda: "prefix-sids"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids, [], name, value)


                                                    class PrefixSid(Entity):
                                                        """
                                                        An IGP prefix that should have a segment routing IGP\-Prefix SID
                                                        allocated to it. The value of the SID is specified by the SID ID,
                                                        as an absolute value. If the absolute value falls within the SRGB,
                                                        the Global flag should be advertised by the system.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                        	Reference to the prefix for which the IGP\-Prefix SID is to be advertised
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                        
                                                        	**refers to**\:  :py:class:`prefix <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config>`
                                                        
                                                        .. attribute:: config
                                                        
                                                        	Configuration parameters for the IGP Prefix SID
                                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	Operational state parameters for the IGP\-Prefix SID
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid, self).__init__()

                                                            self.yang_name = "prefix-sid"
                                                            self.yang_parent_name = "prefix-sids"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', YLeaf(YType.str, 'prefix')),
                                                            ])
                                                            self.prefix = None

                                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config()
                                                            self.config.parent = self
                                                            self._children_name_map["config"] = "config"
                                                            self._children_yang_names.add("config")

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")
                                                            self._segment_path = lambda: "prefix-sid" + "[prefix='" + str(self.prefix) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid, ['prefix'], name, value)


                                                        class Config(Entity):
                                                            """
                                                            Configuration parameters for the IGP Prefix SID.
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	The IP prefix for which the IGP prefix SID should be advertised. The value specified is a local prefix on the interface which is advertised into the IGP
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                            	The Segment Identifier to be used when advertising the IGP Prefix SID
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: int
                                                            
                                                            			**range:** 16..1048575
                                                            
                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_options
                                                            
                                                            	The options associated with the IGP prefix SID for MPLS. The value of this leaf specifies the option that the SID should be advertised into the IGP with
                                                            	**type**\:  :py:class:`LabelOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config.LabelOptions>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config, self).__init__()

                                                                self.yang_name = "config"
                                                                self.yang_parent_name = "prefix-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('sid_id', YLeaf(YType.str, 'sid-id')),
                                                                    ('label_options', YLeaf(YType.enumeration, 'label-options')),
                                                                ])
                                                                self.prefix = None
                                                                self.sid_id = None
                                                                self.label_options = None
                                                                self._segment_path = lambda: "config"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config, ['prefix', 'sid_id', 'label_options'], name, value)

                                                            class LabelOptions(Enum):
                                                                """
                                                                LabelOptions (Enum Class)

                                                                The options associated with the IGP prefix SID for MPLS. The value

                                                                of this leaf specifies the option that the SID should be advertised

                                                                into the IGP with.

                                                                .. data:: NO_PHP = 0

                                                                	When this value is specified, the penultimate hop must not pop

                                                                	the Prefix-SID label before forwarding it to the local system.

                                                                .. data:: EXPLICIT_NULL = 1

                                                                	When set, the penultimate hop must swap the prefix SID for the

                                                                	relevant explicit null label before forwarding the packet.

                                                                """

                                                                NO_PHP = Enum.YLeaf(0, "NO_PHP")

                                                                EXPLICIT_NULL = Enum.YLeaf(1, "EXPLICIT_NULL")



                                                        class State(Entity):
                                                            """
                                                            Operational state parameters for the IGP\-Prefix SID.
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	The IP prefix for which the IGP prefix SID should be advertised. The value specified is a local prefix on the interface which is advertised into the IGP
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                            	The Segment Identifier to be used when advertising the IGP Prefix SID
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: int
                                                            
                                                            			**range:** 16..1048575
                                                            
                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_options
                                                            
                                                            	The options associated with the IGP prefix SID for MPLS. The value of this leaf specifies the option that the SID should be advertised into the IGP with
                                                            	**type**\:  :py:class:`LabelOptions <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State.LabelOptions>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', YLeaf(YType.str, 'prefix')),
                                                                    ('sid_id', YLeaf(YType.str, 'sid-id')),
                                                                    ('label_options', YLeaf(YType.enumeration, 'label-options')),
                                                                ])
                                                                self.prefix = None
                                                                self.sid_id = None
                                                                self.label_options = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State, ['prefix', 'sid_id', 'label_options'], name, value)

                                                            class LabelOptions(Enum):
                                                                """
                                                                LabelOptions (Enum Class)

                                                                The options associated with the IGP prefix SID for MPLS. The value

                                                                of this leaf specifies the option that the SID should be advertised

                                                                into the IGP with.

                                                                .. data:: NO_PHP = 0

                                                                	When this value is specified, the penultimate hop must not pop

                                                                	the Prefix-SID label before forwarding it to the local system.

                                                                .. data:: EXPLICIT_NULL = 1

                                                                	When set, the penultimate hop must swap the prefix SID for the

                                                                	relevant explicit null label before forwarding the packet.

                                                                """

                                                                NO_PHP = Enum.YLeaf(0, "NO_PHP")

                                                                EXPLICIT_NULL = Enum.YLeaf(1, "EXPLICIT_NULL")



                                                class AdjacencySids(Entity):
                                                    """
                                                    Configuration and operational state parameters relating to
                                                    the advertisement of a segment routing adjacency SID for this
                                                    interface.
                                                    
                                                    .. attribute:: adjacency_sid
                                                    
                                                    	An Adjacency SID to be advertised for the specified interface. The Adj\-SID's identifier (the SID ID) must be unique, with flags specified indicating the parameters that should be set for the SID. Where a SID value is specified that is allocated from the SRGB, the global flag must be set by the system
                                                    	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids, self).__init__()

                                                        self.yang_name = "adjacency-sids"
                                                        self.yang_parent_name = "segment-routing"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_container_classes = OrderedDict([])
                                                        self._child_list_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid))])
                                                        self._leafs = OrderedDict()

                                                        self.adjacency_sid = YList(self)
                                                        self._segment_path = lambda: "adjacency-sids"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids, [], name, value)


                                                    class AdjacencySid(Entity):
                                                        """
                                                        An Adjacency SID to be advertised for the specified interface.
                                                        The Adj\-SID's identifier (the SID ID) must be unique, with flags
                                                        specified indicating the parameters that should be set for the SID.
                                                        Where a SID value is specified that is allocated from the SRGB, the
                                                        global flag must be set by the system.
                                                        
                                                        .. attribute:: neighbor  (key)
                                                        
                                                        	Reference to the neighbor with which the Adjacency SID is associated
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        	**refers to**\:  :py:class:`neighbor <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: sid_id  (key)
                                                        
                                                        	Reference to the segment identifier to be used by the local system
                                                        	**type**\: union of the below types:
                                                        
                                                        		**type**\: int
                                                        
                                                        			**range:** 16..1048575
                                                        
                                                        		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                        
                                                        		**type**\: str
                                                        
                                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        		**type**\:  :py:class:`SidId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                        
                                                        	**refers to**\:  :py:class:`sid_id <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: config
                                                        
                                                        	Configuraton parameters relating to the AdjSID
                                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: state
                                                        
                                                        	Operational state parameters relating to the AdjSID
                                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid, self).__init__()

                                                            self.yang_name = "adjacency-sid"
                                                            self.yang_parent_name = "adjacency-sids"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['neighbor','sid_id']
                                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State))])
                                                            self._child_list_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('neighbor', YLeaf(YType.str, 'neighbor')),
                                                                ('sid_id', YLeaf(YType.str, 'sid-id')),
                                                            ])
                                                            self.neighbor = None
                                                            self.sid_id = None

                                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config()
                                                            self.config.parent = self
                                                            self._children_name_map["config"] = "config"
                                                            self._children_yang_names.add("config")

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._children_yang_names.add("state")
                                                            self._segment_path = lambda: "adjacency-sid" + "[neighbor='" + str(self.neighbor) + "']" + "[sid-id='" + str(self.sid_id) + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid, ['neighbor', 'sid_id'], name, value)


                                                        class Config(Entity):
                                                            """
                                                            Configuraton parameters relating to the AdjSID.
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                            	The value of the Adj\-SID to be advertised. Where a static SID identifier is specified, this should be advertised directly by the system. Where the DYNAMIC value is specified, this should be treated as a dynamically allocated value. When the MPLS data plane is in use the dynamic value should not fall within a reserved\-label\-block
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: int
                                                            
                                                            			**range:** 16..1048575
                                                            
                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            		**type**\:  :py:class:`SidId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                            
                                                            .. attribute:: protection_eligible
                                                            
                                                            	Whether the Adj\-SID should be considered to be eligible for protection using IP or MPLS FRR during a network failure. When this value is set to true, the B\-flag of the Adj\-SID is set to 1, and the local system should provide FRR paths for the associated label forwarding entry. When it is set to false, the local system must not provide FRR for the specified LFIB entry
                                                            	**type**\: bool
                                                            
                                                            	**default value**\: true
                                                            
                                                            .. attribute:: group
                                                            
                                                            	When set to true, the Adj\-SID is indicated to be part of a group, and the G flag is set to 1 in the corresponding advertisement in the IGP
                                                            	**type**\: bool
                                                            
                                                            	**default value**\: false
                                                            
                                                            .. attribute:: neighbor
                                                            
                                                            	The remote system on the interface with which the Adj\-SID is associated
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config, self).__init__()

                                                                self.yang_name = "config"
                                                                self.yang_parent_name = "adjacency-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('sid_id', YLeaf(YType.str, 'sid-id')),
                                                                    ('protection_eligible', YLeaf(YType.boolean, 'protection-eligible')),
                                                                    ('group', YLeaf(YType.boolean, 'group')),
                                                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                                                ])
                                                                self.sid_id = None
                                                                self.protection_eligible = None
                                                                self.group = None
                                                                self.neighbor = None
                                                                self._segment_path = lambda: "config"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config, ['sid_id', 'protection_eligible', 'group', 'neighbor'], name, value)

                                                            class SidId(Enum):
                                                                """
                                                                SidId (Enum Class)

                                                                The value of the Adj\-SID to be advertised. Where a static SID

                                                                identifier is specified, this should be advertised directly by the

                                                                system. Where the DYNAMIC value is specified, this should be treated

                                                                as a dynamically allocated value. When the MPLS data plane is in use

                                                                the dynamic value should not fall within a reserved\-label\-block.

                                                                .. data:: DYNAMIC = 0

                                                                	The SID chosen for the Adjacency SID should be dynamically

                                                                	allocated from the system's dynamic range of Segment

                                                                	Identifiers. For MPLS, this range should be considered to be

                                                                	those labels that do not fall within a reserved label block.

                                                                """

                                                                DYNAMIC = Enum.YLeaf(0, "DYNAMIC")



                                                        class State(Entity):
                                                            """
                                                            Operational state parameters relating to the AdjSID.
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                            	The value of the Adj\-SID to be advertised. Where a static SID identifier is specified, this should be advertised directly by the system. Where the DYNAMIC value is specified, this should be treated as a dynamically allocated value. When the MPLS data plane is in use the dynamic value should not fall within a reserved\-label\-block
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: int
                                                            
                                                            			**range:** 16..1048575
                                                            
                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            		**type**\:  :py:class:`SidId <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                            
                                                            .. attribute:: protection_eligible
                                                            
                                                            	Whether the Adj\-SID should be considered to be eligible for protection using IP or MPLS FRR during a network failure. When this value is set to true, the B\-flag of the Adj\-SID is set to 1, and the local system should provide FRR paths for the associated label forwarding entry. When it is set to false, the local system must not provide FRR for the specified LFIB entry
                                                            	**type**\: bool
                                                            
                                                            	**default value**\: true
                                                            
                                                            .. attribute:: group
                                                            
                                                            	When set to true, the Adj\-SID is indicated to be part of a group, and the G flag is set to 1 in the corresponding advertisement in the IGP
                                                            	**type**\: bool
                                                            
                                                            	**default value**\: false
                                                            
                                                            .. attribute:: neighbor
                                                            
                                                            	The remote system on the interface with which the Adj\-SID is associated
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: allocated_dynamic_local
                                                            
                                                            	Where an Adjacency SID with a dynamic value is to be allocated by the system, this leaf reports to the value of the Adj\-SID allocated to this interface
                                                            	**type**\: union of the below types:
                                                            
                                                            		**type**\: int
                                                            
                                                            			**range:** 16..1048575
                                                            
                                                            		**type**\:  :py:class:`MplsLabel <ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                            		**type**\: str
                                                            
                                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "adjacency-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_container_classes = OrderedDict([])
                                                                self._child_list_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('sid_id', YLeaf(YType.str, 'sid-id')),
                                                                    ('protection_eligible', YLeaf(YType.boolean, 'protection-eligible')),
                                                                    ('group', YLeaf(YType.boolean, 'group')),
                                                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                                                    ('allocated_dynamic_local', YLeaf(YType.str, 'allocated-dynamic-local')),
                                                                ])
                                                                self.sid_id = None
                                                                self.protection_eligible = None
                                                                self.group = None
                                                                self.neighbor = None
                                                                self.allocated_dynamic_local = None
                                                                self._segment_path = lambda: "state"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State, ['sid_id', 'protection_eligible', 'group', 'neighbor', 'allocated_dynamic_local'], name, value)

                                                            class SidId(Enum):
                                                                """
                                                                SidId (Enum Class)

                                                                The value of the Adj\-SID to be advertised. Where a static SID

                                                                identifier is specified, this should be advertised directly by the

                                                                system. Where the DYNAMIC value is specified, this should be treated

                                                                as a dynamically allocated value. When the MPLS data plane is in use

                                                                the dynamic value should not fall within a reserved\-label\-block.

                                                                .. data:: DYNAMIC = 0

                                                                	The SID chosen for the Adjacency SID should be dynamically

                                                                	allocated from the system's dynamic range of Segment

                                                                	Identifiers. For MPLS, this range should be considered to be

                                                                	those labels that do not fall within a reserved label block.

                                                                """

                                                                DYNAMIC = Enum.YLeaf(0, "DYNAMIC")



                                    class HelloAuthentication(Entity):
                                        """
                                        This container defines ISIS authentication.
                                        
                                        .. attribute:: config
                                        
                                        	This container defines ISIS authentication configuration
                                        	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config>`
                                        
                                        .. attribute:: state
                                        
                                        	This container defines ISIS authentication state
                                        	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State>`
                                        
                                        .. attribute:: key
                                        
                                        	This container defines ISIS authentication key
                                        	**type**\:  :py:class:`Key <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key>`
                                        
                                        .. attribute:: keychain
                                        
                                        	This container defines keychain parameters
                                        	**type**\:  :py:class:`Keychain <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain>`
                                        
                                        

                                        """

                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication, self).__init__()

                                            self.yang_name = "hello-authentication"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain))])
                                            self._child_list_classes = OrderedDict([])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"
                                            self._children_yang_names.add("config")

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._children_yang_names.add("state")

                                            self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"
                                            self._children_yang_names.add("key")

                                            self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                            self._children_yang_names.add("keychain")
                                            self._segment_path = lambda: "hello-authentication"


                                        class Config(Entity):
                                            """
                                            This container defines ISIS authentication configuration.
                                            
                                            .. attribute:: hello_authentication
                                            
                                            	Enabled or disable ISIS Hello authentication
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config, self).__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_authentication', YLeaf(YType.boolean, 'hello-authentication')),
                                                ])
                                                self.hello_authentication = None
                                                self._segment_path = lambda: "config"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config, ['hello_authentication'], name, value)


                                        class State(Entity):
                                            """
                                            This container defines ISIS authentication state.
                                            
                                            .. attribute:: hello_authentication
                                            
                                            	Enabled or disable ISIS Hello authentication
                                            	**type**\: bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_authentication', YLeaf(YType.boolean, 'hello-authentication')),
                                                ])
                                                self.hello_authentication = None
                                                self._segment_path = lambda: "state"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State, ['hello_authentication'], name, value)


                                        class Key(Entity):
                                            """
                                            This container defines ISIS authentication key
                                            
                                            .. attribute:: config
                                            
                                            	This container defines ISIS authentication key configuration
                                            	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config>`
                                            
                                            .. attribute:: state
                                            
                                            	This container defines ISIS authentication key state
                                            	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State>`
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key, self).__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State))])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"
                                                self._children_yang_names.add("config")

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._children_yang_names.add("state")
                                                self._segment_path = lambda: "key"


                                            class Config(Entity):
                                                """
                                                This container defines ISIS authentication key configuration.
                                                
                                                .. attribute:: auth_password
                                                
                                                	Authentication key string
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config, self).__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                                    ])
                                                    self.auth_password = None
                                                    self._segment_path = lambda: "config"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config, ['auth_password'], name, value)


                                            class State(Entity):
                                                """
                                                This container defines ISIS authentication key state.
                                                
                                                .. attribute:: auth_password
                                                
                                                	Authentication key string
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_container_classes = OrderedDict([])
                                                    self._child_list_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_password', YLeaf(YType.str, 'auth-password')),
                                                    ])
                                                    self.auth_password = None
                                                    self._segment_path = lambda: "state"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State, ['auth_password'], name, value)


                                        class Keychain(Entity):
                                            """
                                            This container defines keychain parameters.
                                            
                                            

                                            """

                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain, self).__init__()

                                                self.yang_name = "keychain"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_container_classes = OrderedDict([])
                                                self._child_list_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "keychain"


                            class Timers(Entity):
                                """
                                This container describes ISIS interface timers configuration
                                
                                .. attribute:: config
                                
                                	Configuration parameters relating to interface timers for IS\-IS
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS interface timers
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "timers"


                                class Config(Entity):
                                    """
                                    Configuration parameters relating to interface
                                    timers for IS\-IS
                                    
                                    .. attribute:: csnp_interval
                                    
                                    	The interval, specified in seconds, at which periodic CSNP packets should be transmitted by the local IS
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: seconds
                                    
                                    .. attribute:: lsp_pacing_interval
                                    
                                    	The interval interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_interval', YLeaf(YType.uint16, 'csnp-interval')),
                                            ('lsp_pacing_interval', YLeaf(YType.uint64, 'lsp-pacing-interval')),
                                        ])
                                        self.csnp_interval = None
                                        self.lsp_pacing_interval = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config, ['csnp_interval', 'lsp_pacing_interval'], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for ISIS interface timers.
                                    
                                    .. attribute:: csnp_interval
                                    
                                    	The interval, specified in seconds, at which periodic CSNP packets should be transmitted by the local IS
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: seconds
                                    
                                    .. attribute:: lsp_pacing_interval
                                    
                                    	The interval interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: milliseconds
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_interval', YLeaf(YType.uint16, 'csnp-interval')),
                                            ('lsp_pacing_interval', YLeaf(YType.uint64, 'lsp-pacing-interval')),
                                        ])
                                        self.csnp_interval = None
                                        self.lsp_pacing_interval = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State, ['csnp_interval', 'lsp_pacing_interval'], name, value)


                            class Bfd(Entity):
                                """
                                This container defines BFD.
                                
                                .. attribute:: config
                                
                                	This container defines BFD configuration parameters
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config>`
                                
                                .. attribute:: state
                                
                                	This container defines BFD state information
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "bfd"


                                class Config(Entity):
                                    """
                                    This container defines BFD configuration parameters.
                                    
                                    .. attribute:: bfd_tlv
                                    
                                    	When set to true, BFD TLV is used. This enables support for the IS\-IS BFD TLV options, which specify that a BFD session must be established before an IS\-IS adjacency can transition to the established state. This option should be enabled on all IS\-IS neighbors on a shared interface
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_tlv', YLeaf(YType.boolean, 'bfd-tlv')),
                                        ])
                                        self.bfd_tlv = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config, ['bfd_tlv'], name, value)


                                class State(Entity):
                                    """
                                    This container defines BFD state information.
                                    
                                    .. attribute:: bfd_tlv
                                    
                                    	When set to true, BFD TLV is used. This enables support for the IS\-IS BFD TLV options, which specify that a BFD session must be established before an IS\-IS adjacency can transition to the established state. This option should be enabled on all IS\-IS neighbors on a shared interface
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_tlv', YLeaf(YType.boolean, 'bfd-tlv')),
                                        ])
                                        self.bfd_tlv = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State, ['bfd_tlv'], name, value)


                            class InterfaceRef(Entity):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                	Configured reference to interface / subinterface
                                	**type**\:  :py:class:`Config <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                	Operational state for interface\-ref
                                	**type**\:  :py:class:`State <ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State>`
                                
                                

                                """

                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef, self).__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_container_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State))])
                                    self._child_list_classes = OrderedDict([])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"
                                    self._children_yang_names.add("config")

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._children_yang_names.add("state")
                                    self._segment_path = lambda: "interface-ref"


                                class Config(Entity):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config, self).__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', YLeaf(YType.str, 'interface')),
                                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(Entity):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                    	Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    	**type**\: str
                                    
                                    	**refers to**\:  :py:class:`name <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                    	Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**refers to**\:  :py:class:`index <ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    

                                    """

                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_container_classes = OrderedDict([])
                                        self._child_list_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', YLeaf(YType.str, 'interface')),
                                            ('subinterface', YLeaf(YType.str, 'subinterface')),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)

    def clone_ptr(self):
        self._top_entity = NetworkInstances()
        return self._top_entity

